"""Generated message classes for compute version alpha.

Creates and runs virtual machines on Google Cloud Platform.
"""
# NOTE: This file is autogenerated and should not be edited by hand.

from __future__ import absolute_import

from apitools.base.protorpclite import messages as _messages
from apitools.base.py import encoding
from apitools.base.py import extra_types


package = 'compute'


class AWSV4Signature(_messages.Message):
  r"""Contains the configurations necessary to generate a signature for access
  to private storage buckets that support Signature Version 4 for
  authentication. The service name for generating the authentication header
  will always default to 's3'.

  Fields:
    accessKey: The access key used for s3 bucket authentication. Required for
      updating or creating a backend that uses AWS v4 signature
      authentication, but will not be returned as part of the configuration
      when queried with a REST API GET request. @InputOnly
    accessKeyId: The identifier of an access key used for s3 bucket
      authentication.
    accessKeyVersion: The optional version identifier for the access key. You
      can use this to keep track of different iterations of your access key.
    originRegion: The name of the cloud region of your origin. This is a free-
      form field with the name of the region your cloud uses to host your
      origin. For example, "us-east-1" for AWS or "us-ashburn-1" for OCI.
  """

  accessKey = _messages.StringField(1)
  accessKeyId = _messages.StringField(2)
  accessKeyVersion = _messages.StringField(3)
  originRegion = _messages.StringField(4)


class AcceleratorConfig(_messages.Message):
  r"""A specification of the type and number of accelerator cards attached to
  the instance.

  Fields:
    acceleratorCount: The number of the guest accelerator cards exposed to
      this instance.
    acceleratorType: Full or partial URL of the accelerator type resource to
      attach to this instance. For example: projects/my-project/zones/us-
      central1-c/acceleratorTypes/nvidia-tesla-p100 If you are creating an
      instance template, specify only the accelerator name. See GPUs on
      Compute Engine for a full list of accelerator types.
  """

  acceleratorCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  acceleratorType = _messages.StringField(2)


class AcceleratorType(_messages.Message):
  r"""Represents an Accelerator Type resource. Google Cloud Platform provides
  graphics processing units (accelerators) that you can add to VM instances to
  improve or accelerate performance when working with intensive workloads. For
  more information, read GPUs on Compute Engine.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      accelerator type.
    description: [Output Only] An optional textual description of the
      resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] The type of the resource. Always
      compute#acceleratorType for accelerator types.
    maximumCardsPerInstance: [Output Only] Maximum number of accelerator cards
      allowed per instance.
    name: [Output Only] Name of the resource.
    selfLink: [Output Only] Server-defined, fully qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    zone: [Output Only] The name of the zone where the accelerator type
      resides, such as us-central1-a. You must specify this field as part of
      the HTTP request URL. It is not settable as a field in the request body.
  """

  creationTimestamp = _messages.StringField(1)
  deprecated = _messages.MessageField('DeprecationStatus', 2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#acceleratorType')
  maximumCardsPerInstance = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  name = _messages.StringField(7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  zone = _messages.StringField(10)


class AcceleratorTypeAggregatedList(_messages.Message):
  r"""A AcceleratorTypeAggregatedList object.

  Messages:
    ItemsValue: A list of AcceleratorTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of AcceleratorTypesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#acceleratorTypeAggregatedList for aggregated lists of
      accelerator types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of AcceleratorTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of accelerator types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A AcceleratorTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('AcceleratorTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#acceleratorTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class AcceleratorTypeList(_messages.Message):
  r"""Contains a list of accelerator types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of AcceleratorType resources.
    kind: [Output Only] Type of resource. Always compute#acceleratorTypeList
      for lists of accelerator types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('AcceleratorType', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#acceleratorTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class AcceleratorTypesScopedList(_messages.Message):
  r"""A AcceleratorTypesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      accelerator types list is empty.

  Fields:
    acceleratorTypes: [Output Only] A list of accelerator types contained in
      this scope.
    warning: [Output Only] An informational warning that appears when the
      accelerator types list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the
    accelerator types list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  acceleratorTypes = _messages.MessageField('AcceleratorType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class AccessConfig(_messages.Message):
  r"""An access configuration attached to an instance's network interface.
  Only one access config per instance is supported.

  Enums:
    NetworkTierValueValuesEnum: This signifies the networking tier used for
      configuring this access configuration and can only take the following
      values: PREMIUM, STANDARD. If an AccessConfig is specified without a
      valid external IP address, an ephemeral IP will be created with this
      networkTier. If an AccessConfig with a valid external IP address is
      specified, it must match that of the networkTier associated with the
      Address resource owning that IP.
    TypeValueValuesEnum: The type of configuration. In accessConfigs (IPv4),
      the default and only option is ONE_TO_ONE_NAT. In ipv6AccessConfigs, the
      default and only option is DIRECT_IPV6.

  Fields:
    externalIpv6: Applies to ipv6AccessConfigs only. The first IPv6 address of
      the external IPv6 range associated with this instance, prefix length is
      stored in externalIpv6PrefixLength in ipv6AccessConfig. To use a static
      external IP address, it must be unused and in the same region as the
      instance's zone. If not specified, Google Cloud will automatically
      assign an external IPv6 address from the instance's subnetwork.
    externalIpv6PrefixLength: Applies to ipv6AccessConfigs only. The prefix
      length of the external IPv6 range.
    kind: [Output Only] Type of the resource. Always compute#accessConfig for
      access configs.
    name: The name of this access configuration. In accessConfigs (IPv4), the
      default and recommended name is External NAT, but you can use any
      arbitrary string, such as My external IP or Network Access. In
      ipv6AccessConfigs, the recommend name is External IPv6.
    natIP: Applies to accessConfigs (IPv4) only. An external IP address
      associated with this instance. Specify an unused static external IP
      address available to the project or leave this field undefined to use an
      IP from a shared ephemeral IP address pool. If you specify a static
      external IP address, it must live in the same region as the zone of the
      instance.
    networkTier: This signifies the networking tier used for configuring this
      access configuration and can only take the following values: PREMIUM,
      STANDARD. If an AccessConfig is specified without a valid external IP
      address, an ephemeral IP will be created with this networkTier. If an
      AccessConfig with a valid external IP address is specified, it must
      match that of the networkTier associated with the Address resource
      owning that IP.
    publicDnsName: [Output Only] The public DNS domain name for the instance.
    publicPtrDomainName: The DNS domain name for the public PTR record. You
      can set this field only if the `setPublicPtr` field is enabled in
      accessConfig. If this field is unspecified in ipv6AccessConfig, a
      default PTR record will be created for first IP in associated external
      IPv6 range.
    securityPolicy: The resource URL for the security policy associated with
      this access config.
    setPublicDns: Specifies whether a public DNS 'A' record should be created
      for the external IP address of this access configuration.
    setPublicPtr: Specifies whether a public DNS 'PTR' record should be
      created to map the external IP address of the instance to a DNS domain
      name. This field is not used in ipv6AccessConfig. A default PTR record
      will be created if the VM has external IPv6 range associated.
    type: The type of configuration. In accessConfigs (IPv4), the default and
      only option is ONE_TO_ONE_NAT. In ipv6AccessConfigs, the default and
      only option is DIRECT_IPV6.
  """

  class NetworkTierValueValuesEnum(_messages.Enum):
    r"""This signifies the networking tier used for configuring this access
    configuration and can only take the following values: PREMIUM, STANDARD.
    If an AccessConfig is specified without a valid external IP address, an
    ephemeral IP will be created with this networkTier. If an AccessConfig
    with a valid external IP address is specified, it must match that of the
    networkTier associated with the Address resource owning that IP.

    Values:
      FIXED_STANDARD: Public internet quality with fixed bandwidth.
      PREMIUM: High quality, Google-grade network tier, support for all
        networking products.
      SELECT: Price competitive network tier, support for all networking
        products.
      STANDARD: Public internet quality, only limited support for other
        networking products.
      STANDARD_OVERRIDES_FIXED_STANDARD: (Output only) Temporary tier for
        FIXED_STANDARD when fixed standard tier is expired or not configured.
    """
    FIXED_STANDARD = 0
    PREMIUM = 1
    SELECT = 2
    STANDARD = 3
    STANDARD_OVERRIDES_FIXED_STANDARD = 4

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of configuration. In accessConfigs (IPv4), the default and
    only option is ONE_TO_ONE_NAT. In ipv6AccessConfigs, the default and only
    option is DIRECT_IPV6.

    Values:
      DIRECT_IPV6: <no description>
      ONE_TO_ONE_NAT: <no description>
    """
    DIRECT_IPV6 = 0
    ONE_TO_ONE_NAT = 1

  externalIpv6 = _messages.StringField(1)
  externalIpv6PrefixLength = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  kind = _messages.StringField(3, default='compute#accessConfig')
  name = _messages.StringField(4)
  natIP = _messages.StringField(5)
  networkTier = _messages.EnumField('NetworkTierValueValuesEnum', 6)
  publicDnsName = _messages.StringField(7)
  publicPtrDomainName = _messages.StringField(8)
  securityPolicy = _messages.StringField(9)
  setPublicDns = _messages.BooleanField(10)
  setPublicPtr = _messages.BooleanField(11)
  type = _messages.EnumField('TypeValueValuesEnum', 12)


class Address(_messages.Message):
  r"""Represents an IP Address resource. Google Compute Engine has two IP
  Address resources: * [Global (external and internal)](https://cloud.google.c
  om/compute/docs/reference/rest/alpha/globalAddresses) * [Regional (external
  and internal)](https://cloud.google.com/compute/docs/reference/rest/alpha/ad
  dresses) For more information, see Reserving a static external IP address.

  Enums:
    AddressTypeValueValuesEnum: The type of address to reserve, either
      INTERNAL or EXTERNAL. If unspecified, defaults to EXTERNAL.
    IpVersionValueValuesEnum: The IP version that will be used by this
      address. Valid options are IPV4 or IPV6.
    Ipv6EndpointTypeValueValuesEnum: The endpoint type of this address, which
      should be VM or NETLB. This is used for deciding which type of endpoint
      this address can be used after the external IPv6 address reservation.
    NetworkTierValueValuesEnum: This signifies the networking tier used for
      configuring this address and can only take the following values: PREMIUM
      or STANDARD. Internal IP addresses are always Premium Tier; global
      external IP addresses are always Premium Tier; regional external IP
      addresses can be either Standard or Premium Tier. If this field is not
      specified, it is assumed to be PREMIUM.
    PurposeValueValuesEnum: The purpose of this resource, which can be one of
      the following values: - GCE_ENDPOINT for addresses that are used by VM
      instances, alias IP ranges, load balancers, and similar resources. -
      DNS_RESOLVER for a DNS resolver address in a subnetwork for a Cloud DNS
      inbound forwarder IP addresses (regional internal IP address in a subnet
      of a VPC network) - VPC_PEERING for global internal IP addresses used
      for private services access allocated ranges. - NAT_AUTO for the
      regional external IP addresses used by Cloud NAT when allocating
      addresses using automatic NAT IP address allocation. -
      IPSEC_INTERCONNECT for addresses created from a private IP range that
      are reserved for a VLAN attachment in an *HA VPN over Cloud
      Interconnect* configuration. These addresses are regional resources. -
      `SHARED_LOADBALANCER_VIP` for an internal IP address that is assigned to
      multiple internal forwarding rules. - `PRIVATE_SERVICE_CONNECT` for a
      private network address that is used to configure Private Service
      Connect. Only global internal addresses can use this purpose.
    StatusValueValuesEnum: [Output Only] The status of the address, which can
      be one of RESERVING, RESERVED, or IN_USE. An address that is RESERVING
      is currently in the process of being reserved. A RESERVED address is
      currently reserved and available to use. An IN_USE address is currently
      being used by another resource and is not available.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    address: The static IP address represented by this resource.
    addressType: The type of address to reserve, either INTERNAL or EXTERNAL.
      If unspecified, defaults to EXTERNAL.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this field
      when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ipVersion: The IP version that will be used by this address. Valid options
      are IPV4 or IPV6.
    ipv6EndpointType: The endpoint type of this address, which should be VM or
      NETLB. This is used for deciding which type of endpoint this address can
      be used after the external IPv6 address reservation.
    kind: [Output Only] Type of the resource. Always compute#address for
      addresses.
    labelFingerprint: A fingerprint for the labels being applied to this
      Address, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve an Address.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character
      must be a lowercase letter, and all following characters (except for the
      last character) must be a dash, lowercase letter, or digit. The last
      character must be a lowercase letter or digit.
    network: The URL of the network in which to reserve the address. This
      field can only be used with INTERNAL type with the VPC_PEERING purpose.
    networkTier: This signifies the networking tier used for configuring this
      address and can only take the following values: PREMIUM or STANDARD.
      Internal IP addresses are always Premium Tier; global external IP
      addresses are always Premium Tier; regional external IP addresses can be
      either Standard or Premium Tier. If this field is not specified, it is
      assumed to be PREMIUM.
    prefixLength: The prefix length if the resource represents an IP range.
    purpose: The purpose of this resource, which can be one of the following
      values: - GCE_ENDPOINT for addresses that are used by VM instances,
      alias IP ranges, load balancers, and similar resources. - DNS_RESOLVER
      for a DNS resolver address in a subnetwork for a Cloud DNS inbound
      forwarder IP addresses (regional internal IP address in a subnet of a
      VPC network) - VPC_PEERING for global internal IP addresses used for
      private services access allocated ranges. - NAT_AUTO for the regional
      external IP addresses used by Cloud NAT when allocating addresses using
      automatic NAT IP address allocation. - IPSEC_INTERCONNECT for addresses
      created from a private IP range that are reserved for a VLAN attachment
      in an *HA VPN over Cloud Interconnect* configuration. These addresses
      are regional resources. - `SHARED_LOADBALANCER_VIP` for an internal IP
      address that is assigned to multiple internal forwarding rules. -
      `PRIVATE_SERVICE_CONNECT` for a private network address that is used to
      configure Private Service Connect. Only global internal addresses can
      use this purpose.
    region: [Output Only] The URL of the region where a regional address
      resides. For regional addresses, you must specify the region as a path
      parameter in the HTTP request URL. *This field is not applicable to
      global addresses.*
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] The status of the address, which can be one of
      RESERVING, RESERVED, or IN_USE. An address that is RESERVING is
      currently in the process of being reserved. A RESERVED address is
      currently reserved and available to use. An IN_USE address is currently
      being used by another resource and is not available.
    subnetwork: The URL of the subnetwork in which to reserve the address. If
      an IP address is specified, it must be within the subnetwork's IP range.
      This field can only be used with INTERNAL type with a GCE_ENDPOINT or
      DNS_RESOLVER purpose.
    users: [Output Only] The URLs of the resources that are using this
      address.
  """

  class AddressTypeValueValuesEnum(_messages.Enum):
    r"""The type of address to reserve, either INTERNAL or EXTERNAL. If
    unspecified, defaults to EXTERNAL.

    Values:
      DNS_FORWARDING: DNS resolver address in the subnetwork.
      EXTERNAL: A publicly visible external IP address.
      INTERNAL: A private network IP address, for use with an Instance or
        Internal Load Balancer forwarding rule.
      UNSPECIFIED_TYPE: <no description>
    """
    DNS_FORWARDING = 0
    EXTERNAL = 1
    INTERNAL = 2
    UNSPECIFIED_TYPE = 3

  class IpVersionValueValuesEnum(_messages.Enum):
    r"""The IP version that will be used by this address. Valid options are
    IPV4 or IPV6.

    Values:
      IPV4: <no description>
      IPV6: <no description>
      UNSPECIFIED_VERSION: <no description>
    """
    IPV4 = 0
    IPV6 = 1
    UNSPECIFIED_VERSION = 2

  class Ipv6EndpointTypeValueValuesEnum(_messages.Enum):
    r"""The endpoint type of this address, which should be VM or NETLB. This
    is used for deciding which type of endpoint this address can be used after
    the external IPv6 address reservation.

    Values:
      NETLB: Reserved IPv6 address can be used on network load balancer.
      VM: Reserved IPv6 address can be used on VM.
    """
    NETLB = 0
    VM = 1

  class NetworkTierValueValuesEnum(_messages.Enum):
    r"""This signifies the networking tier used for configuring this address
    and can only take the following values: PREMIUM or STANDARD. Internal IP
    addresses are always Premium Tier; global external IP addresses are always
    Premium Tier; regional external IP addresses can be either Standard or
    Premium Tier. If this field is not specified, it is assumed to be PREMIUM.

    Values:
      FIXED_STANDARD: Public internet quality with fixed bandwidth.
      PREMIUM: High quality, Google-grade network tier, support for all
        networking products.
      SELECT: Price competitive network tier, support for all networking
        products.
      STANDARD: Public internet quality, only limited support for other
        networking products.
      STANDARD_OVERRIDES_FIXED_STANDARD: (Output only) Temporary tier for
        FIXED_STANDARD when fixed standard tier is expired or not configured.
    """
    FIXED_STANDARD = 0
    PREMIUM = 1
    SELECT = 2
    STANDARD = 3
    STANDARD_OVERRIDES_FIXED_STANDARD = 4

  class PurposeValueValuesEnum(_messages.Enum):
    r"""The purpose of this resource, which can be one of the following
    values: - GCE_ENDPOINT for addresses that are used by VM instances, alias
    IP ranges, load balancers, and similar resources. - DNS_RESOLVER for a DNS
    resolver address in a subnetwork for a Cloud DNS inbound forwarder IP
    addresses (regional internal IP address in a subnet of a VPC network) -
    VPC_PEERING for global internal IP addresses used for private services
    access allocated ranges. - NAT_AUTO for the regional external IP addresses
    used by Cloud NAT when allocating addresses using automatic NAT IP address
    allocation. - IPSEC_INTERCONNECT for addresses created from a private IP
    range that are reserved for a VLAN attachment in an *HA VPN over Cloud
    Interconnect* configuration. These addresses are regional resources. -
    `SHARED_LOADBALANCER_VIP` for an internal IP address that is assigned to
    multiple internal forwarding rules. - `PRIVATE_SERVICE_CONNECT` for a
    private network address that is used to configure Private Service Connect.
    Only global internal addresses can use this purpose.

    Values:
      DNS_RESOLVER: DNS resolver address in the subnetwork.
      GCE_ENDPOINT: VM internal/alias IP, Internal LB service IP, etc.
      IPSEC_INTERCONNECT: A regional internal IP address range reserved for
        the VLAN attachment that is used in HA VPN over Cloud Interconnect.
        This regional internal IP address range must not overlap with any IP
        address range of subnet/route in the VPC network and its peering
        networks. After the VLAN attachment is created with the reserved IP
        address range, when creating a new VPN gateway, its interface IP
        address is allocated from the associated VLAN attachment's IP address
        range.
      NAT_AUTO: External IP automatically reserved for Cloud NAT.
      PRIVATE_SERVICE_CONNECT: A private network IP address that can be used
        to configure Private Service Connect. This purpose can be specified
        only for GLOBAL addresses of Type INTERNAL
      SERVERLESS: A regional internal IP address range reserved for
        Serverless.
      SHARED_LOADBALANCER_VIP: A private network IP address that can be shared
        by multiple Internal Load Balancer forwarding rules.
      SYSTEM_MANAGED: A regional internal IP address that is reserved and
        managed by Google Cloud. It can not be assigned to Google Cloud
        compute resources such as VM and internal load balancer.
      VPC_PEERING: IP range for peer networks.
    """
    DNS_RESOLVER = 0
    GCE_ENDPOINT = 1
    IPSEC_INTERCONNECT = 2
    NAT_AUTO = 3
    PRIVATE_SERVICE_CONNECT = 4
    SERVERLESS = 5
    SHARED_LOADBALANCER_VIP = 6
    SYSTEM_MANAGED = 7
    VPC_PEERING = 8

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the address, which can be one of
    RESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently
    in the process of being reserved. A RESERVED address is currently reserved
    and available to use. An IN_USE address is currently being used by another
    resource and is not available.

    Values:
      IN_USE: Address is being used by another resource and is not available.
      RESERVED: Address is reserved and available to use.
      RESERVING: Address is being reserved.
    """
    IN_USE = 0
    RESERVED = 1
    RESERVING = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  address = _messages.StringField(1)
  addressType = _messages.EnumField('AddressTypeValueValuesEnum', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  ipVersion = _messages.EnumField('IpVersionValueValuesEnum', 6)
  ipv6EndpointType = _messages.EnumField('Ipv6EndpointTypeValueValuesEnum', 7)
  kind = _messages.StringField(8, default='compute#address')
  labelFingerprint = _messages.BytesField(9)
  labels = _messages.MessageField('LabelsValue', 10)
  name = _messages.StringField(11)
  network = _messages.StringField(12)
  networkTier = _messages.EnumField('NetworkTierValueValuesEnum', 13)
  prefixLength = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  purpose = _messages.EnumField('PurposeValueValuesEnum', 15)
  region = _messages.StringField(16)
  selfLink = _messages.StringField(17)
  selfLinkWithId = _messages.StringField(18)
  status = _messages.EnumField('StatusValueValuesEnum', 19)
  subnetwork = _messages.StringField(20)
  users = _messages.StringField(21, repeated=True)


class AddressAggregatedList(_messages.Message):
  r"""A AddressAggregatedList object.

  Messages:
    ItemsValue: A list of AddressesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of AddressesScopedList resources.
    kind: [Output Only] Type of resource. Always compute#addressAggregatedList
      for aggregated lists of addresses.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of AddressesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of addresses.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A AddressesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('AddressesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#addressAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class AddressList(_messages.Message):
  r"""Contains a list of addresses.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Address resources.
    kind: [Output Only] Type of resource. Always compute#addressList for lists
      of addresses.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Address', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#addressList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class AddressesScopedList(_messages.Message):
  r"""A AddressesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of addresses when the list is empty.

  Fields:
    addresses: [Output Only] A list of addresses contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      addresses when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    addresses when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  addresses = _messages.MessageField('Address', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class AdvancedMachineFeatures(_messages.Message):
  r"""Specifies options for controlling advanced machine features. Options
  that would traditionally be configured in a BIOS belong here. Features that
  require operating system support may have corresponding entries in the
  GuestOsFeatures of an Image (e.g., whether or not the OS in the Image
  supports nested virtualization being enabled or disabled).

  Enums:
    PerformanceMonitoringUnitValueValuesEnum: Type of Performance Monitoring
      Unit requested on instance.

  Fields:
    enableNestedVirtualization: Whether to enable nested virtualization or not
      (default is false).
    enableUefiNetworking: Whether to enable UEFI networking for instance
      creation.
    enableWatchdogTimer: Whether to enable the watchdog timer.
    numaNodeCount: The number of vNUMA nodes.
    performanceMonitoringUnit: Type of Performance Monitoring Unit requested
      on instance.
    threadsPerCore: The number of threads per physical core. To disable
      simultaneous multithreading (SMT) set this to 1. If unset, the maximum
      number of threads supported per core by the underlying processor is
      assumed.
    turboMode: Turbo frequency mode to use for the instance. Supported modes
      include: * ALL_CORE_MAX Using empty string or not setting this field
      will use the platform-specific default turbo mode.
    visibleCoreCount: The number of physical cores to expose to an instance.
      Multiply by the number of threads per core to compute the total number
      of virtual CPUs to expose to the instance. If unset, the number of cores
      is inferred from the instance's nominal CPU count and the underlying
      platform's SMT width.
  """

  class PerformanceMonitoringUnitValueValuesEnum(_messages.Enum):
    r"""Type of Performance Monitoring Unit requested on instance.

    Values:
      ARCHITECTURAL: Architecturally defined non-LLC events.
      ENHANCED: Most documented core/L2 and LLC events.
      PERFORMANCE_MONITORING_UNIT_UNSPECIFIED: <no description>
      STANDARD: Most documented core/L2 events.
    """
    ARCHITECTURAL = 0
    ENHANCED = 1
    PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 2
    STANDARD = 3

  enableNestedVirtualization = _messages.BooleanField(1)
  enableUefiNetworking = _messages.BooleanField(2)
  enableWatchdogTimer = _messages.BooleanField(3)
  numaNodeCount = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  performanceMonitoringUnit = _messages.EnumField('PerformanceMonitoringUnitValueValuesEnum', 5)
  threadsPerCore = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  turboMode = _messages.StringField(7)
  visibleCoreCount = _messages.IntegerField(8, variant=_messages.Variant.INT32)


class AliasIpRange(_messages.Message):
  r"""An alias IP range attached to an instance's network interface.

  Fields:
    ipCidrRange: The IP alias ranges to allocate for this interface. This IP
      CIDR range must belong to the specified subnetwork and cannot contain IP
      addresses reserved by system or used by other network interfaces. This
      range may be a single IP address (such as 10.2.3.4), a netmask (such as
      /24) or a CIDR-formatted string (such as 10.1.2.0/24).
    subnetworkRangeName: The name of a subnetwork secondary IP range from
      which to allocate an IP alias range. If not specified, the primary range
      of the subnetwork is used.
  """

  ipCidrRange = _messages.StringField(1)
  subnetworkRangeName = _messages.StringField(2)


class AllocationAggregateReservation(_messages.Message):
  r"""This reservation type is specified by total resource amounts (e.g. total
  count of CPUs) and can account for multiple instance SKUs. In other words,
  one can create instances of varying shapes against this reservation.

  Enums:
    VmFamilyValueValuesEnum: The VM family that all instances scheduled
      against this reservation must belong to.
    WorkloadTypeValueValuesEnum: The workload type of the instances that will
      target this reservation.

  Fields:
    inUseResources: [Output only] List of resources currently in use.
    reservedResources: List of reserved resources (CPUs, memory,
      accelerators).
    vmFamily: The VM family that all instances scheduled against this
      reservation must belong to.
    workloadType: The workload type of the instances that will target this
      reservation.
  """

  class VmFamilyValueValuesEnum(_messages.Enum):
    r"""The VM family that all instances scheduled against this reservation
    must belong to.

    Values:
      VM_FAMILY_CLOUD_TPU_DEVICE_CT3: <no description>
      VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L: <no description>
      VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP: <no description>
      VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E: <no description>
      VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P: <no description>
      VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P: <no description>
      VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P: <no description>
    """
    VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 0
    VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 1
    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 2
    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 3
    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 4
    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 5
    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 6

  class WorkloadTypeValueValuesEnum(_messages.Enum):
    r"""The workload type of the instances that will target this reservation.

    Values:
      BATCH: Reserved resources will be optimized for BATCH workloads, such as
        ML training.
      SERVING: Reserved resources will be optimized for SERVING workloads,
        such as ML inference.
      UNSPECIFIED: <no description>
    """
    BATCH = 0
    SERVING = 1
    UNSPECIFIED = 2

  inUseResources = _messages.MessageField('AllocationAggregateReservationReservedResourceInfo', 1, repeated=True)
  reservedResources = _messages.MessageField('AllocationAggregateReservationReservedResourceInfo', 2, repeated=True)
  vmFamily = _messages.EnumField('VmFamilyValueValuesEnum', 3)
  workloadType = _messages.EnumField('WorkloadTypeValueValuesEnum', 4)


class AllocationAggregateReservationReservedResourceInfo(_messages.Message):
  r"""A AllocationAggregateReservationReservedResourceInfo object.

  Fields:
    accelerator: Properties of accelerator resources in this reservation.
  """

  accelerator = _messages.MessageField('AllocationAggregateReservationReservedResourceInfoAccelerator', 1)


class AllocationAggregateReservationReservedResourceInfoAccelerator(_messages.Message):
  r"""A AllocationAggregateReservationReservedResourceInfoAccelerator object.

  Fields:
    acceleratorCount: Number of accelerators of specified type.
    acceleratorType: Full or partial URL to accelerator type. e.g.
      "projects/{PROJECT}/zones/{ZONE}/acceleratorTypes/ct4l"
  """

  acceleratorCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  acceleratorType = _messages.StringField(2)


class AllocationReservationSharingPolicy(_messages.Message):
  r"""A AllocationReservationSharingPolicy object.

  Enums:
    ServiceShareTypeValueValuesEnum: Sharing config for all Google Cloud
      services.

  Fields:
    serviceShareType: Sharing config for all Google Cloud services.
  """

  class ServiceShareTypeValueValuesEnum(_messages.Enum):
    r"""Sharing config for all Google Cloud services.

    Values:
      ALLOW_ALL: Allow all Google Cloud managed services to share
        reservations.
      DISALLOW_ALL: [Default] Disallow sharing with all Google Cloud services.
      SERVICE_SHARE_TYPE_UNSPECIFIED: <no description>
    """
    ALLOW_ALL = 0
    DISALLOW_ALL = 1
    SERVICE_SHARE_TYPE_UNSPECIFIED = 2

  serviceShareType = _messages.EnumField('ServiceShareTypeValueValuesEnum', 1)


class AllocationResourceStatus(_messages.Message):
  r"""[Output Only] Contains output only fields.

  Fields:
    aggregateAllocation: Properties of this aggregatereservation.
    reservationBlockCount: The number of reservation blocks associated with
      this reservation.
    reservationMaintenance: Maintenance information for this reservation
    specificSkuAllocation: Allocation Properties of this reservation.
  """

  aggregateAllocation = _messages.MessageField('AllocationResourceStatusAggregateAllocation', 1)
  reservationBlockCount = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  reservationMaintenance = _messages.MessageField('GroupMaintenanceInfo', 3)
  specificSkuAllocation = _messages.MessageField('AllocationResourceStatusSpecificSKUAllocation', 4)


class AllocationResourceStatusAggregateAllocation(_messages.Message):
  r"""Contains Properties set for the aggregate reservation.

  Messages:
    UtilizationsValue: Per service utilization breakdown. The Key is the
      Google Cloud managed service name.

  Fields:
    utilizations: Per service utilization breakdown. The Key is the Google
      Cloud managed service name.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class UtilizationsValue(_messages.Message):
    r"""Per service utilization breakdown. The Key is the Google Cloud managed
    service name.

    Messages:
      AdditionalProperty: An additional property for a UtilizationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type UtilizationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a UtilizationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.IntegerField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  utilizations = _messages.MessageField('UtilizationsValue', 1)


class AllocationResourceStatusSpecificSKUAllocation(_messages.Message):
  r"""Contains Properties set for the reservation.

  Messages:
    UtilizationsValue: Per service utilization breakdown. The Key is the
      Google Cloud managed service name.

  Fields:
    sourceInstanceTemplateId: ID of the instance template used to populate
      reservation properties.
    utilizations: Per service utilization breakdown. The Key is the Google
      Cloud managed service name.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class UtilizationsValue(_messages.Message):
    r"""Per service utilization breakdown. The Key is the Google Cloud managed
    service name.

    Messages:
      AdditionalProperty: An additional property for a UtilizationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type UtilizationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a UtilizationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.IntegerField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  sourceInstanceTemplateId = _messages.StringField(1)
  utilizations = _messages.MessageField('UtilizationsValue', 2)


class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk(_messages.Message):
  r"""A AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  object.

  Enums:
    InterfaceValueValuesEnum: Specifies the disk interface to use for
      attaching this disk, which is either SCSI or NVME. The default is SCSI.
      For performance characteristics of SCSI over NVMe, see Local SSD
      performance.

  Fields:
    diskSizeGb: Specifies the size of the disk in base-2 GB.
    interface: Specifies the disk interface to use for attaching this disk,
      which is either SCSI or NVME. The default is SCSI. For performance
      characteristics of SCSI over NVMe, see Local SSD performance.
  """

  class InterfaceValueValuesEnum(_messages.Enum):
    r"""Specifies the disk interface to use for attaching this disk, which is
    either SCSI or NVME. The default is SCSI. For performance characteristics
    of SCSI over NVMe, see Local SSD performance.

    Values:
      NVDIMM: <no description>
      NVME: <no description>
      SCSI: <no description>
    """
    NVDIMM = 0
    NVME = 1
    SCSI = 2

  diskSizeGb = _messages.IntegerField(1)
  interface = _messages.EnumField('InterfaceValueValuesEnum', 2)


class AllocationSpecificSKUAllocationReservedInstanceProperties(_messages.Message):
  r"""Properties of the SKU instances being reserved. Next ID: 9

  Enums:
    MaintenanceIntervalValueValuesEnum: Specifies the frequency of planned
      maintenance events. The accepted values are: `PERIODIC`.

  Fields:
    guestAccelerators: Specifies accelerator type and count.
    localSsds: Specifies amount of local ssd to reserve with each instance.
      The type of disk is local-ssd.
    locationHint: An opaque location hint used to place the allocation close
      to other resources. This field is for use by internal tools that use the
      public API.
    machineType: Specifies type of machine (name only) which has fixed number
      of vCPUs and fixed amount of memory. This also includes specifying
      custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY
      pattern.
    maintenanceFreezeDurationHours: Specifies the number of hours after
      reservation creation where instances using the reservation won't be
      scheduled for maintenance.
    maintenanceInterval: Specifies the frequency of planned maintenance
      events. The accepted values are: `PERIODIC`.
    minCpuPlatform: Minimum cpu platform the reservation.
  """

  class MaintenanceIntervalValueValuesEnum(_messages.Enum):
    r"""Specifies the frequency of planned maintenance events. The accepted
    values are: `PERIODIC`.

    Values:
      AS_NEEDED: VMs are eligible to receive infrastructure and hypervisor
        updates as they become available. This may result in more maintenance
        operations (live migrations or terminations) for the VM than the
        PERIODIC and RECURRENT options.
      PERIODIC: VMs receive infrastructure and hypervisor updates on a
        periodic basis, minimizing the number of maintenance operations (live
        migrations or terminations) on an individual VM. This may mean a VM
        will take longer to receive an update than if it was configured for
        AS_NEEDED. Security updates will still be applied as soon as they are
        available.
      RECURRENT: VMs receive infrastructure and hypervisor updates on a
        periodic basis, minimizing the number of maintenance operations (live
        migrations or terminations) on an individual VM. This may mean a VM
        will take longer to receive an update than if it was configured for
        AS_NEEDED. Security updates will still be applied as soon as they are
        available. RECURRENT is used for GEN3 and Slice of Hardware VMs.
    """
    AS_NEEDED = 0
    PERIODIC = 1
    RECURRENT = 2

  guestAccelerators = _messages.MessageField('AcceleratorConfig', 1, repeated=True)
  localSsds = _messages.MessageField('AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk', 2, repeated=True)
  locationHint = _messages.StringField(3)
  machineType = _messages.StringField(4)
  maintenanceFreezeDurationHours = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  maintenanceInterval = _messages.EnumField('MaintenanceIntervalValueValuesEnum', 6)
  minCpuPlatform = _messages.StringField(7)


class AllocationSpecificSKUReservation(_messages.Message):
  r"""This reservation type allows to pre allocate specific instance
  configuration.

  Fields:
    assuredCount: [Output Only] Indicates how many instances are actually
      usable currently.
    count: Specifies the number of resources that are allocated.
    inUseCount: [Output Only] Indicates how many instances are in use.
    instanceProperties: The instance properties for the reservation.
    sourceInstanceTemplate: Specifies the instance template to create the
      reservation. If you use this field, you must exclude the
      instanceProperties field. This field is optional, and it can be a full
      or partial URL. For example, the following are all valid URLs to an
      instance template: -
      https://www.googleapis.com/compute/v1/projects/project
      /global/instanceTemplates/instanceTemplate -
      projects/project/global/instanceTemplates/instanceTemplate -
      global/instanceTemplates/instanceTemplate
  """

  assuredCount = _messages.IntegerField(1)
  count = _messages.IntegerField(2)
  inUseCount = _messages.IntegerField(3)
  instanceProperties = _messages.MessageField('AllocationSpecificSKUAllocationReservedInstanceProperties', 4)
  sourceInstanceTemplate = _messages.StringField(5)


class AsyncReplicationStatus(_messages.Message):
  r"""A AsyncReplicationStatus object.

  Fields:
    diskPairReplicationState: A DiskPairReplicationState attribute.
    lastReplicationDetails: A ReplicationDetails attribute.
  """

  diskPairReplicationState = _messages.MessageField('DiskPairReplicationState', 1)
  lastReplicationDetails = _messages.MessageField('ReplicationDetails', 2)


class AttachedDisk(_messages.Message):
  r"""An instance-attached disk resource.

  Enums:
    ArchitectureValueValuesEnum: [Output Only] The architecture of the
      attached disk. Valid values are ARM64 or X86_64.
    InterfaceValueValuesEnum: Specifies the disk interface to use for
      attaching this disk, which is either SCSI or NVME. For most machine
      types, the default is SCSI. Local SSDs can use either NVME or SCSI. In
      certain configurations, persistent disks can use NVMe. For more
      information, see About persistent disks.
    ModeValueValuesEnum: The mode in which to attach this disk, either
      READ_WRITE or READ_ONLY. If not specified, the default is to attach the
      disk in READ_WRITE mode.
    SavedStateValueValuesEnum: For LocalSSD disks on VM Instances in STOPPED
      or SUSPENDED state, this field is set to PRESERVED if the LocalSSD data
      has been saved to a persistent location by customer request. (see the
      discard_local_ssd option on Stop/Suspend). Read-only in the api.
    TypeValueValuesEnum: Specifies the type of the disk, either SCRATCH or
      PERSISTENT. If not specified, the default is PERSISTENT.

  Fields:
    architecture: [Output Only] The architecture of the attached disk. Valid
      values are ARM64 or X86_64.
    autoDelete: Specifies whether the disk will be auto-deleted when the
      instance is deleted (but not when the disk is detached from the
      instance).
    boot: Indicates that this is a boot disk. The virtual machine will use the
      first partition of the disk for its root filesystem.
    deviceName: Specifies a unique device name of your choice that is
      reflected into the /dev/disk/by-id/google-* tree of a Linux operating
      system running within the instance. This name can be used to reference
      the device for mounting, resizing, and so on, from within the instance.
      If not specified, the server chooses a default device name to apply to
      this disk, in the form persistent-disk-x, where x is a number assigned
      by Google Compute Engine. This field is only applicable for persistent
      disks.
    diskEncryptionKey: Encrypts or decrypts a disk using a customer-supplied
      encryption key. If you are creating a new disk, this field encrypts the
      new disk using an encryption key that you provide. If you are attaching
      an existing disk that is already encrypted, this field decrypts the disk
      using the customer-supplied encryption key. If you encrypt a disk using
      a customer-supplied key, you must provide the same key again when you
      attempt to use this resource at a later time. For example, you must
      provide the key when you create a snapshot or an image from the disk or
      when you attach the disk to a virtual machine instance. If you do not
      provide an encryption key, then the disk will be encrypted using an
      automatically generated key and you do not need to provide a key to use
      the disk later. Note: Instance templates do not store customer-supplied
      encryption keys, so you cannot use your own keys to encrypt disks in a
      managed instance group. You cannot create VMs that have disks with
      customer-supplied keys using the bulk insert method.
    diskSizeGb: The size of the disk in GB.
    forceAttach: [Input Only] Whether to force attach the regional disk even
      if it's currently attached to another instance. If you try to force
      attach a zonal disk to an instance, you will receive an error.
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read Enabling guest
      operating system features to see a list of available options.
    index: [Output Only] A zero-based index to this disk, where 0 is reserved
      for the boot disk. If you have many disks attached to an instance, each
      disk would have a unique index number.
    initializeParams: [Input Only] Specifies the parameters for a new disk
      that will be created alongside the new instance. Use initialization
      parameters to create boot disks or local SSDs attached to the new
      instance. This property is mutually exclusive with the source property;
      you can only define one or the other, but not both.
    interface: Specifies the disk interface to use for attaching this disk,
      which is either SCSI or NVME. For most machine types, the default is
      SCSI. Local SSDs can use either NVME or SCSI. In certain configurations,
      persistent disks can use NVMe. For more information, see About
      persistent disks.
    kind: [Output Only] Type of the resource. Always compute#attachedDisk for
      attached disks.
    licenses: [Output Only] Any valid publicly visible licenses.
    locked: [Output Only] Whether to indicate the attached disk is locked. The
      locked disk is not allowed to be detached from the instance, or to be
      used as the source of the snapshot creation, and the image creation. The
      instance with at least one locked attached disk is not allow to be used
      as source of machine image creation, instant snapshot creation, and not
      allowed to be deleted with --keep-disk parameter set to true for locked
      disks.
    mode: The mode in which to attach this disk, either READ_WRITE or
      READ_ONLY. If not specified, the default is to attach the disk in
      READ_WRITE mode.
    savedState: For LocalSSD disks on VM Instances in STOPPED or SUSPENDED
      state, this field is set to PRESERVED if the LocalSSD data has been
      saved to a persistent location by customer request. (see the
      discard_local_ssd option on Stop/Suspend). Read-only in the api.
    shieldedInstanceInitialState: [Output Only] shielded vm initial state
      stored on disk
    source: Specifies a valid partial or full URL to an existing Persistent
      Disk resource. When creating a new instance boot disk, one of
      initializeParams.sourceImage or initializeParams.sourceSnapshot or
      disks.source is required. If desired, you can also attach existing non-
      root persistent disks using this property. This field is only applicable
      for persistent disks. Note that for InstanceTemplate, specify the disk
      name for zonal disk, and the URL for regional disk.
    type: Specifies the type of the disk, either SCRATCH or PERSISTENT. If not
      specified, the default is PERSISTENT.
    userLicenses: [Output Only] A list of user provided licenses. It
      represents a list of URLs to the license resource. Unlike regular
      licenses, user provided licenses can be modified after the disk is
      created.
  """

  class ArchitectureValueValuesEnum(_messages.Enum):
    r"""[Output Only] The architecture of the attached disk. Valid values are
    ARM64 or X86_64.

    Values:
      ARCHITECTURE_UNSPECIFIED: Default value indicating Architecture is not
        set.
      ARM64: Machines with architecture ARM64
      X86_64: Machines with architecture X86_64
    """
    ARCHITECTURE_UNSPECIFIED = 0
    ARM64 = 1
    X86_64 = 2

  class InterfaceValueValuesEnum(_messages.Enum):
    r"""Specifies the disk interface to use for attaching this disk, which is
    either SCSI or NVME. For most machine types, the default is SCSI. Local
    SSDs can use either NVME or SCSI. In certain configurations, persistent
    disks can use NVMe. For more information, see About persistent disks.

    Values:
      NVDIMM: <no description>
      NVME: <no description>
      SCSI: <no description>
    """
    NVDIMM = 0
    NVME = 1
    SCSI = 2

  class ModeValueValuesEnum(_messages.Enum):
    r"""The mode in which to attach this disk, either READ_WRITE or READ_ONLY.
    If not specified, the default is to attach the disk in READ_WRITE mode.

    Values:
      READ_ONLY: Attaches this disk in read-only mode. Multiple virtual
        machines can use a disk in read-only mode at a time.
      READ_WRITE: *[Default]* Attaches this disk in read-write mode. Only one
        virtual machine at a time can be attached to a disk in read-write
        mode.
    """
    READ_ONLY = 0
    READ_WRITE = 1

  class SavedStateValueValuesEnum(_messages.Enum):
    r"""For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this
    field is set to PRESERVED if the LocalSSD data has been saved to a
    persistent location by customer request. (see the discard_local_ssd option
    on Stop/Suspend). Read-only in the api.

    Values:
      DISK_SAVED_STATE_UNSPECIFIED: *[Default]* Disk state has not been
        preserved.
      PRESERVED: Disk state has been preserved.
    """
    DISK_SAVED_STATE_UNSPECIFIED = 0
    PRESERVED = 1

  class TypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of the disk, either SCRATCH or PERSISTENT. If not
    specified, the default is PERSISTENT.

    Values:
      PERSISTENT: <no description>
      SCRATCH: <no description>
    """
    PERSISTENT = 0
    SCRATCH = 1

  architecture = _messages.EnumField('ArchitectureValueValuesEnum', 1)
  autoDelete = _messages.BooleanField(2)
  boot = _messages.BooleanField(3)
  deviceName = _messages.StringField(4)
  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 5)
  diskSizeGb = _messages.IntegerField(6)
  forceAttach = _messages.BooleanField(7)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 8, repeated=True)
  index = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  initializeParams = _messages.MessageField('AttachedDiskInitializeParams', 10)
  interface = _messages.EnumField('InterfaceValueValuesEnum', 11)
  kind = _messages.StringField(12, default='compute#attachedDisk')
  licenses = _messages.StringField(13, repeated=True)
  locked = _messages.BooleanField(14)
  mode = _messages.EnumField('ModeValueValuesEnum', 15)
  savedState = _messages.EnumField('SavedStateValueValuesEnum', 16)
  shieldedInstanceInitialState = _messages.MessageField('InitialStateConfig', 17)
  source = _messages.StringField(18)
  type = _messages.EnumField('TypeValueValuesEnum', 19)
  userLicenses = _messages.StringField(20, repeated=True)


class AttachedDiskInitializeParams(_messages.Message):
  r"""[Input Only] Specifies the parameters for a new disk that will be
  created alongside the new instance. Use initialization parameters to create
  boot disks or local SSDs attached to the new instance. This field is
  persisted and returned for instanceTemplate and not returned in the context
  of instance. This property is mutually exclusive with the source property;
  you can only define one or the other, but not both.

  Enums:
    ArchitectureValueValuesEnum: The architecture of the attached disk. Valid
      values are arm64 or x86_64.
    InterfaceValueValuesEnum: [Deprecated] Specifies the disk interface to use
      for attaching this disk, which is either SCSI or NVME. The default is
      SCSI.
    OnUpdateActionValueValuesEnum: Specifies which action to take on instance
      update with this disk. Default is to use the existing disk.

  Messages:
    LabelsValue: Labels to apply to this disk. These can be later modified by
      the disks.setLabels method. This field is only applicable for persistent
      disks.
    ResourceManagerTagsValue: Resource manager tags to be bound to the disk.
      Tag keys and values have the same definition as resource manager tags.
      Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the
      format `tagValues/456`. The field is ignored (both PUT & PATCH) when
      empty.

  Fields:
    architecture: The architecture of the attached disk. Valid values are
      arm64 or x86_64.
    description: An optional description. Provide this property when creating
      the disk.
    diskName: Specifies the disk name. If not specified, the default is to use
      the name of the instance. If a disk with the same name already exists in
      the given region, the existing disk is attached to the new instance and
      the new disk is not created.
    diskSizeGb: Specifies the size of the disk in base-2 GB. The size must be
      at least 10 GB. If you specify a sourceImage, which is required for boot
      disks, the default size is the size of the sourceImage. If you do not
      specify a sourceImage, the default disk size is 500 GB.
    diskType: Specifies the disk type to use to create the instance. If not
      specified, the default is pd-standard, specified using the full URL. For
      example:
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /diskTypes/pd-standard For a full list of acceptable values, see
      Persistent disk types. If you specify this field when creating a VM, you
      can provide either the full or partial URL. For example, the following
      values are valid: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /diskTypes/diskType - projects/project/zones/zone/diskTypes/diskType -
      zones/zone/diskTypes/diskType If you specify this field when creating or
      updating an instance template or all-instances configuration, specify
      the type of the disk, not the URL. For example: pd-standard.
    enableConfidentialCompute: Whether this disk is using confidential compute
      mode.
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read Enabling guest
      operating system features to see a list of available options. Guest OS
      features are applied by merging initializeParams.guestOsFeatures and
      disks.guestOsFeatures
    interface: [Deprecated] Specifies the disk interface to use for attaching
      this disk, which is either SCSI or NVME. The default is SCSI.
    labels: Labels to apply to this disk. These can be later modified by the
      disks.setLabels method. This field is only applicable for persistent
      disks.
    licenseCodes: Integer license codes indicating which licenses are attached
      to this disk.
    licenses: A list of publicly visible licenses. Reserved for Google's use.
    multiWriter: Indicates whether or not the disk can be read/write attached
      to more than one instance.
    onUpdateAction: Specifies which action to take on instance update with
      this disk. Default is to use the existing disk.
    provisionedIops: Indicates how many IOPS to provision for the disk. This
      sets the number of I/O operations per second that the disk can handle.
      Values must be between 10,000 and 120,000. For more details, see the
      Extreme persistent disk documentation.
    provisionedThroughput: Indicates how much throughput to provision for the
      disk. This sets the number of throughput mb per second that the disk can
      handle. Values must greater than or equal to 1.
    replicaZones: Required for each regional disk associated with the
      instance. Specify the URLs of the zones where the disk should be
      replicated to. You must provide exactly two replica zones, and one zone
      must be the same as the instance zone.
    resourceManagerTags: Resource manager tags to be bound to the disk. Tag
      keys and values have the same definition as resource manager tags. Keys
      must be in the format `tagKeys/{tag_key_id}`, and values are in the
      format `tagValues/456`. The field is ignored (both PUT & PATCH) when
      empty.
    resourcePolicies: Resource policies applied to this disk for automatic
      snapshot creations. Specified using the full or partial URL. For
      instance template, specify only the resource policy name.
    sourceImage: The source image to create this disk. When creating a new
      instance boot disk, one of initializeParams.sourceImage or
      initializeParams.sourceSnapshot or disks.source is required. To create a
      disk with one of the public operating system images, specify the image
      by its family name. For example, specify family/debian-9 to use the
      latest Debian 9 image: projects/debian-
      cloud/global/images/family/debian-9 Alternatively, use a specific
      version of a public operating system image: projects/debian-
      cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a
      custom image that you created, specify the image name in the following
      format: global/images/my-custom-image You can also specify a custom
      image by its image family, which returns the latest version of the image
      in that family. Replace the image name with family/family-name:
      global/images/family/my-image-family If the source image is deleted
      later, this field will not be set.
    sourceImageEncryptionKey: The customer-supplied encryption key of the
      source image. Required if the source image is protected by a customer-
      supplied encryption key. InstanceTemplate and InstancePropertiesPatch do
      not store customer-supplied encryption keys, so you cannot create disks
      for instances in a managed instance group if the source images are
      encrypted with your own keys.
    sourceInstantSnapshot: The source instant-snapshot to create this disk.
      When creating a new instance boot disk, one of
      initializeParams.sourceSnapshot or
      initializeParams.sourceInstantSnapshot initializeParams.sourceImage or
      disks.source is required. To create a disk with a snapshot that you
      created, specify the snapshot name in the following format: us-
      central1-a/instantSnapshots/my-backup If the source instant-snapshot is
      deleted later, this field will not be set.
    sourceSnapshot: The source snapshot to create this disk. When creating a
      new instance boot disk, one of initializeParams.sourceSnapshot or
      initializeParams.sourceImage or disks.source is required. To create a
      disk with a snapshot that you created, specify the snapshot name in the
      following format: global/snapshots/my-backup If the source snapshot is
      deleted later, this field will not be set. Note: You cannot create VMs
      in bulk using a snapshot as the source. Use an image instead when you
      create VMs using the bulk insert method.
    sourceSnapshotEncryptionKey: The customer-supplied encryption key of the
      source snapshot.
    storagePool: The storage pool in which the new disk is created. You can
      provide this as a partial or full URL to the resource. For example, the
      following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /storagePools/storagePool -
      projects/project/zones/zone/storagePools/storagePool -
      zones/zone/storagePools/storagePool
  """

  class ArchitectureValueValuesEnum(_messages.Enum):
    r"""The architecture of the attached disk. Valid values are arm64 or
    x86_64.

    Values:
      ARCHITECTURE_UNSPECIFIED: Default value indicating Architecture is not
        set.
      ARM64: Machines with architecture ARM64
      X86_64: Machines with architecture X86_64
    """
    ARCHITECTURE_UNSPECIFIED = 0
    ARM64 = 1
    X86_64 = 2

  class InterfaceValueValuesEnum(_messages.Enum):
    r"""[Deprecated] Specifies the disk interface to use for attaching this
    disk, which is either SCSI or NVME. The default is SCSI.

    Values:
      NVME: <no description>
      SCSI: <no description>
      UNSPECIFIED: <no description>
    """
    NVME = 0
    SCSI = 1
    UNSPECIFIED = 2

  class OnUpdateActionValueValuesEnum(_messages.Enum):
    r"""Specifies which action to take on instance update with this disk.
    Default is to use the existing disk.

    Values:
      RECREATE_DISK: Always recreate the disk.
      RECREATE_DISK_IF_SOURCE_CHANGED: Recreate the disk if source (image,
        snapshot) of this disk is different from source of existing disk.
      USE_EXISTING_DISK: Use the existing disk, this is the default behaviour.
    """
    RECREATE_DISK = 0
    RECREATE_DISK_IF_SOURCE_CHANGED = 1
    USE_EXISTING_DISK = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this disk. These can be later modified by the
    disks.setLabels method. This field is only applicable for persistent
    disks.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ResourceManagerTagsValue(_messages.Message):
    r"""Resource manager tags to be bound to the disk. Tag keys and values
    have the same definition as resource manager tags. Keys must be in the
    format `tagKeys/{tag_key_id}`, and values are in the format
    `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.

    Messages:
      AdditionalProperty: An additional property for a
        ResourceManagerTagsValue object.

    Fields:
      additionalProperties: Additional properties of type
        ResourceManagerTagsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ResourceManagerTagsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  architecture = _messages.EnumField('ArchitectureValueValuesEnum', 1)
  description = _messages.StringField(2)
  diskName = _messages.StringField(3)
  diskSizeGb = _messages.IntegerField(4)
  diskType = _messages.StringField(5)
  enableConfidentialCompute = _messages.BooleanField(6)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 7, repeated=True)
  interface = _messages.EnumField('InterfaceValueValuesEnum', 8)
  labels = _messages.MessageField('LabelsValue', 9)
  licenseCodes = _messages.IntegerField(10, repeated=True)
  licenses = _messages.StringField(11, repeated=True)
  multiWriter = _messages.BooleanField(12)
  onUpdateAction = _messages.EnumField('OnUpdateActionValueValuesEnum', 13)
  provisionedIops = _messages.IntegerField(14)
  provisionedThroughput = _messages.IntegerField(15)
  replicaZones = _messages.StringField(16, repeated=True)
  resourceManagerTags = _messages.MessageField('ResourceManagerTagsValue', 17)
  resourcePolicies = _messages.StringField(18, repeated=True)
  sourceImage = _messages.StringField(19)
  sourceImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 20)
  sourceInstantSnapshot = _messages.StringField(21)
  sourceSnapshot = _messages.StringField(22)
  sourceSnapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 23)
  storagePool = _messages.StringField(24)


class AuditConfig(_messages.Message):
  r"""Specifies the audit configuration for a service. The configuration
  determines which permission types are logged, and what identities, if any,
  are exempted from logging. An AuditConfig must have one or more
  AuditLogConfigs. If there are AuditConfigs for both `allServices` and a
  specific service, the union of the two AuditConfigs is used for that
  service: the log_types specified in each AuditConfig are enabled, and the
  exempted_members in each AuditLogConfig are exempted. Example Policy with
  multiple AuditConfigs: { "audit_configs": [ { "service": "allServices",
  "audit_log_configs": [ { "log_type": "DATA_READ", "exempted_members": [
  "user:jose@example.com" ] }, { "log_type": "DATA_WRITE" }, { "log_type":
  "ADMIN_READ" } ] }, { "service": "sampleservice.googleapis.com",
  "audit_log_configs": [ { "log_type": "DATA_READ" }, { "log_type":
  "DATA_WRITE", "exempted_members": [ "user:aliya@example.com" ] } ] } ] } For
  sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ
  logging. It also exempts `jose@example.com` from DATA_READ logging, and
  `aliya@example.com` from DATA_WRITE logging.

  Fields:
    auditLogConfigs: The configuration for logging of each type of permission.
    service: Specifies a service that will be enabled for audit logging. For
      example, `storage.googleapis.com`, `cloudsql.googleapis.com`.
      `allServices` is a special value that covers all services.
  """

  auditLogConfigs = _messages.MessageField('AuditLogConfig', 1, repeated=True)
  service = _messages.StringField(2)


class AuditLogConfig(_messages.Message):
  r"""Provides the configuration for logging a type of permissions. Example: {
  "audit_log_configs": [ { "log_type": "DATA_READ", "exempted_members": [
  "user:jose@example.com" ] }, { "log_type": "DATA_WRITE" } ] } This enables
  'DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from
  DATA_READ logging.

  Enums:
    LogTypeValueValuesEnum: The log type that this config enables.

  Fields:
    exemptedMembers: Specifies the identities that do not cause logging for
      this type of permission. Follows the same format of Binding.members.
    logType: The log type that this config enables.
  """

  class LogTypeValueValuesEnum(_messages.Enum):
    r"""The log type that this config enables.

    Values:
      ADMIN_READ: Admin reads. Example: CloudIAM getIamPolicy
      DATA_READ: Data reads. Example: CloudSQL Users list
      DATA_WRITE: Data writes. Example: CloudSQL Users create
      LOG_TYPE_UNSPECIFIED: Default case. Should never be this.
    """
    ADMIN_READ = 0
    DATA_READ = 1
    DATA_WRITE = 2
    LOG_TYPE_UNSPECIFIED = 3

  exemptedMembers = _messages.StringField(1, repeated=True)
  logType = _messages.EnumField('LogTypeValueValuesEnum', 2)


class AuthenticationPolicy(_messages.Message):
  r"""[Deprecated] The authentication settings for the backend service. The
  authentication settings for the backend service.

  Enums:
    PrincipalBindingValueValuesEnum: Define whether peer or origin identity
      should be used for principal. Default value is USE_PEER. If peer (or
      origin) identity is not available, either because peer/origin
      authentication is not defined, or failed, principal will be left unset.
      In other words, binding rule does not affect the decision to accept or
      reject request. This field can be set to one of the following: USE_PEER:
      Principal will be set to the identity from peer authentication.
      USE_ORIGIN: Principal will be set to the identity from origin
      authentication.

  Fields:
    origins: List of authentication methods that can be used for origin
      authentication. Similar to peers, these will be evaluated in order the
      first valid one will be used to set origin identity. If none of these
      methods pass, the request will be rejected with authentication failed
      error (401). Leave the list empty if origin authentication is not
      required.
    peers: List of authentication methods that can be used for peer
      authentication. They will be evaluated in order the first valid one will
      be used to set peer identity. If none of these methods pass, the request
      will be rejected with authentication failed error (401). Leave the list
      empty if peer authentication is not required.
    principalBinding: Define whether peer or origin identity should be used
      for principal. Default value is USE_PEER. If peer (or origin) identity
      is not available, either because peer/origin authentication is not
      defined, or failed, principal will be left unset. In other words,
      binding rule does not affect the decision to accept or reject request.
      This field can be set to one of the following: USE_PEER: Principal will
      be set to the identity from peer authentication. USE_ORIGIN: Principal
      will be set to the identity from origin authentication.
    serverTlsContext: Configures the mechanism to obtain server-side security
      certificates and identity information.
  """

  class PrincipalBindingValueValuesEnum(_messages.Enum):
    r"""Define whether peer or origin identity should be used for principal.
    Default value is USE_PEER. If peer (or origin) identity is not available,
    either because peer/origin authentication is not defined, or failed,
    principal will be left unset. In other words, binding rule does not affect
    the decision to accept or reject request. This field can be set to one of
    the following: USE_PEER: Principal will be set to the identity from peer
    authentication. USE_ORIGIN: Principal will be set to the identity from
    origin authentication.

    Values:
      INVALID: <no description>
      USE_ORIGIN: Principal will be set to the identity from origin
        authentication.
      USE_PEER: Principal will be set to the identity from peer
        authentication.
    """
    INVALID = 0
    USE_ORIGIN = 1
    USE_PEER = 2

  origins = _messages.MessageField('OriginAuthenticationMethod', 1, repeated=True)
  peers = _messages.MessageField('PeerAuthenticationMethod', 2, repeated=True)
  principalBinding = _messages.EnumField('PrincipalBindingValueValuesEnum', 3)
  serverTlsContext = _messages.MessageField('TlsContext', 4)


class AuthorizationConfig(_messages.Message):
  r"""[Deprecated] Authorization configuration provides service-level and
  method-level access control for a service. control for a service.

  Fields:
    policies: List of RbacPolicies.
  """

  policies = _messages.MessageField('RbacPolicy', 1, repeated=True)


class Autoscaler(_messages.Message):
  r"""Represents an Autoscaler resource. Google Compute Engine has two
  Autoscaler resources: *
  [Zonal](/compute/docs/reference/rest/alpha/autoscalers) *
  [Regional](/compute/docs/reference/rest/alpha/regionAutoscalers) Use
  autoscalers to automatically add or delete instances from a managed instance
  group according to your defined autoscaling policy. For more information,
  read Autoscaling Groups of Instances. For zonal managed instance groups
  resource, use the autoscaler resource. For regional managed instance groups,
  use the regionAutoscalers resource.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the autoscaler
      configuration. Current set of possible values: - PENDING: Autoscaler
      backend hasn't read new/updated configuration. - DELETING: Configuration
      is being deleted. - ACTIVE: Configuration is acknowledged to be
      effective. Some warnings might be present in the statusDetails field. -
      ERROR: Configuration has errors. Actionable for users. Details are
      present in the statusDetails field. New values might be added in the
      future.

  Messages:
    ScalingScheduleStatusValue: [Output Only] Status information of existing
      scaling schedules.

  Fields:
    autoscalingPolicy: The configuration parameters for the autoscaling
      algorithm. You can define one or more signals for an autoscaler:
      cpuUtilization, customMetricUtilizations, and loadBalancingUtilization.
      If none of these are specified, the default will be to autoscale based
      on cpuUtilization to 0.6 or 60%.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#autoscaler for
      autoscalers.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    recommendedSize: [Output Only] Target recommended MIG size (number of
      instances) computed by autoscaler. Autoscaler calculates the recommended
      MIG size even when the autoscaling policy mode is different from ON.
      This field is empty when autoscaler is not connected to an existing
      managed instance group or autoscaler did not generate its prediction.
    region: [Output Only] URL of the region where the instance group resides
      (for autoscalers living in regional scope).
    scalingScheduleStatus: [Output Only] Status information of existing
      scaling schedules.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] The status of the autoscaler configuration. Current
      set of possible values: - PENDING: Autoscaler backend hasn't read
      new/updated configuration. - DELETING: Configuration is being deleted. -
      ACTIVE: Configuration is acknowledged to be effective. Some warnings
      might be present in the statusDetails field. - ERROR: Configuration has
      errors. Actionable for users. Details are present in the statusDetails
      field. New values might be added in the future.
    statusDetails: [Output Only] Human-readable details about the current
      state of the autoscaler. Read the documentation for Commonly returned
      status messages for examples of status messages you might encounter.
    target: URL of the managed instance group that this autoscaler will scale.
      This field is required when creating an autoscaler.
    zone: [Output Only] URL of the zone where the instance group resides (for
      autoscalers living in zonal scope).
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the autoscaler configuration. Current set
    of possible values: - PENDING: Autoscaler backend hasn't read new/updated
    configuration. - DELETING: Configuration is being deleted. - ACTIVE:
    Configuration is acknowledged to be effective. Some warnings might be
    present in the statusDetails field. - ERROR: Configuration has errors.
    Actionable for users. Details are present in the statusDetails field. New
    values might be added in the future.

    Values:
      ACTIVE: Configuration is acknowledged to be effective
      DELETING: Configuration is being deleted
      ERROR: Configuration has errors. Actionable for users.
      PENDING: Autoscaler backend hasn't read new/updated configuration
    """
    ACTIVE = 0
    DELETING = 1
    ERROR = 2
    PENDING = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ScalingScheduleStatusValue(_messages.Message):
    r"""[Output Only] Status information of existing scaling schedules.

    Messages:
      AdditionalProperty: An additional property for a
        ScalingScheduleStatusValue object.

    Fields:
      additionalProperties: Additional properties of type
        ScalingScheduleStatusValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ScalingScheduleStatusValue object.

      Fields:
        key: Name of the additional property.
        value: A ScalingScheduleStatus attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ScalingScheduleStatus', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  autoscalingPolicy = _messages.MessageField('AutoscalingPolicy', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#autoscaler')
  name = _messages.StringField(6)
  recommendedSize = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  region = _messages.StringField(8)
  scalingScheduleStatus = _messages.MessageField('ScalingScheduleStatusValue', 9)
  selfLink = _messages.StringField(10)
  selfLinkWithId = _messages.StringField(11)
  status = _messages.EnumField('StatusValueValuesEnum', 12)
  statusDetails = _messages.MessageField('AutoscalerStatusDetails', 13, repeated=True)
  target = _messages.StringField(14)
  zone = _messages.StringField(15)


class AutoscalerAggregatedList(_messages.Message):
  r"""A AutoscalerAggregatedList object.

  Messages:
    ItemsValue: A list of AutoscalersScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of AutoscalersScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#autoscalerAggregatedList for aggregated lists of autoscalers.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of AutoscalersScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of autoscalers.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A AutoscalersScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('AutoscalersScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#autoscalerAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class AutoscalerList(_messages.Message):
  r"""Contains a list of Autoscaler resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Autoscaler resources.
    kind: [Output Only] Type of resource. Always compute#autoscalerList for
      lists of autoscalers.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Autoscaler', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#autoscalerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class AutoscalerStatusDetails(_messages.Message):
  r"""A AutoscalerStatusDetails object.

  Enums:
    TypeValueValuesEnum: The type of error, warning, or notice returned.
      Current set of possible values: - ALL_INSTANCES_UNHEALTHY (WARNING): All
      instances in the instance group are unhealthy (not in RUNNING state). -
      BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service
      attached to the instance group. - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
      Autoscaler recommends a size greater than maxNumReplicas. -
      CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric
      samples are not exported often enough to be a credible base for
      autoscaling. - CUSTOM_METRIC_INVALID (ERROR): The custom metric that was
      specified does not exist or does not have the necessary labels. -
      MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas.
      This means the autoscaler cannot add or remove instances from the
      instance group. - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The
      autoscaler did not receive any data from the custom metric configured
      for autoscaling. - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The
      autoscaler is configured to scale based on a load balancing signal but
      the instance group has not received any requests from the load balancer.
      - MODE_OFF (WARNING): Autoscaling is turned off. The number of instances
      in the group won't change automatically. The autoscaling configuration
      is preserved. - MODE_ONLY_UP (WARNING): Autoscaling is in the "Autoscale
      only out" mode. The autoscaler can add instances but not remove any. -
      MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be
      autoscaled because it has more than one backend service attached to it.
      - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for
      the necessary resources, such as CPU or number of instances. -
      REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers:
      there is a resource stockout in the chosen region. -
      SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not
      exist. - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR):
      Autoscaling does not work with an HTTP/S load balancer that has been
      configured for maxRate. - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal
      autoscalers: there is a resource stockout in the chosen zone. For
      regional autoscalers: in at least one of the zones you're using there is
      a resource stockout. New values might be added in the future. Some of
      the values might not be available in all API versions.

  Fields:
    message: The status message.
    type: The type of error, warning, or notice returned. Current set of
      possible values: - ALL_INSTANCES_UNHEALTHY (WARNING): All instances in
      the instance group are unhealthy (not in RUNNING state). -
      BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service
      attached to the instance group. - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
      Autoscaler recommends a size greater than maxNumReplicas. -
      CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric
      samples are not exported often enough to be a credible base for
      autoscaling. - CUSTOM_METRIC_INVALID (ERROR): The custom metric that was
      specified does not exist or does not have the necessary labels. -
      MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas.
      This means the autoscaler cannot add or remove instances from the
      instance group. - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The
      autoscaler did not receive any data from the custom metric configured
      for autoscaling. - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The
      autoscaler is configured to scale based on a load balancing signal but
      the instance group has not received any requests from the load balancer.
      - MODE_OFF (WARNING): Autoscaling is turned off. The number of instances
      in the group won't change automatically. The autoscaling configuration
      is preserved. - MODE_ONLY_UP (WARNING): Autoscaling is in the "Autoscale
      only out" mode. The autoscaler can add instances but not remove any. -
      MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be
      autoscaled because it has more than one backend service attached to it.
      - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for
      the necessary resources, such as CPU or number of instances. -
      REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers:
      there is a resource stockout in the chosen region. -
      SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not
      exist. - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR):
      Autoscaling does not work with an HTTP/S load balancer that has been
      configured for maxRate. - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal
      autoscalers: there is a resource stockout in the chosen zone. For
      regional autoscalers: in at least one of the zones you're using there is
      a resource stockout. New values might be added in the future. Some of
      the values might not be available in all API versions.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of error, warning, or notice returned. Current set of
    possible values: - ALL_INSTANCES_UNHEALTHY (WARNING): All instances in the
    instance group are unhealthy (not in RUNNING state). -
    BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service
    attached to the instance group. - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
    Autoscaler recommends a size greater than maxNumReplicas. -
    CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric samples
    are not exported often enough to be a credible base for autoscaling. -
    CUSTOM_METRIC_INVALID (ERROR): The custom metric that was specified does
    not exist or does not have the necessary labels. - MIN_EQUALS_MAX
    (WARNING): The minNumReplicas is equal to maxNumReplicas. This means the
    autoscaler cannot add or remove instances from the instance group. -
    MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The autoscaler did not
    receive any data from the custom metric configured for autoscaling. -
    MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The autoscaler is configured
    to scale based on a load balancing signal but the instance group has not
    received any requests from the load balancer. - MODE_OFF (WARNING):
    Autoscaling is turned off. The number of instances in the group won't
    change automatically. The autoscaling configuration is preserved. -
    MODE_ONLY_UP (WARNING): Autoscaling is in the "Autoscale only out" mode.
    The autoscaler can add instances but not remove any. -
    MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be
    autoscaled because it has more than one backend service attached to it. -
    NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for the
    necessary resources, such as CPU or number of instances. -
    REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers:
    there is a resource stockout in the chosen region. -
    SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not
    exist. - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR):
    Autoscaling does not work with an HTTP/S load balancer that has been
    configured for maxRate. - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal
    autoscalers: there is a resource stockout in the chosen zone. For regional
    autoscalers: in at least one of the zones you're using there is a resource
    stockout. New values might be added in the future. Some of the values
    might not be available in all API versions.

    Values:
      ALL_INSTANCES_UNHEALTHY: All instances in the instance group are
        unhealthy (not in RUNNING state).
      BACKEND_SERVICE_DOES_NOT_EXIST: There is no backend service attached to
        the instance group.
      CAPPED_AT_MAX_NUM_REPLICAS: Autoscaler recommends a size greater than
        maxNumReplicas.
      CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE: The custom metric samples are not
        exported often enough to be a credible base for autoscaling.
      CUSTOM_METRIC_INVALID: The custom metric that was specified does not
        exist or does not have the necessary labels.
      MIN_EQUALS_MAX: The minNumReplicas is equal to maxNumReplicas. This
        means the autoscaler cannot add or remove instances from the instance
        group.
      MISSING_CUSTOM_METRIC_DATA_POINTS: The autoscaler did not receive any
        data from the custom metric configured for autoscaling.
      MISSING_LOAD_BALANCING_DATA_POINTS: The autoscaler is configured to
        scale based on a load balancing signal but the instance group has not
        received any requests from the load balancer.
      MODE_OFF: Autoscaling is turned off. The number of instances in the
        group won't change automatically. The autoscaling configuration is
        preserved.
      MODE_ONLY_SCALE_OUT: Autoscaling is in the "Autoscale only scale out"
        mode. Instances in the group will be only added.
      MODE_ONLY_UP: Autoscaling is in the "Autoscale only out" mode. Instances
        in the group will be only added.
      MORE_THAN_ONE_BACKEND_SERVICE: The instance group cannot be autoscaled
        because it has more than one backend service attached to it.
      NOT_ENOUGH_QUOTA_AVAILABLE: There is insufficient quota for the
        necessary resources, such as CPU or number of instances.
      REGION_RESOURCE_STOCKOUT: Showed only for regional autoscalers: there is
        a resource stockout in the chosen region.
      SCALING_TARGET_DOES_NOT_EXIST: The target to be scaled does not exist.
      SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX: For some scaling
        schedules minRequiredReplicas is greater than maxNumReplicas.
        Autoscaler always recommends at most maxNumReplicas instances.
      SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN: For some scaling schedules
        minRequiredReplicas is less than minNumReplicas. Autoscaler always
        recommends at least minNumReplicas instances.
      UNKNOWN: <no description>
      UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION: Autoscaling does not
        work with an HTTP/S load balancer that has been configured for
        maxRate.
      ZONE_RESOURCE_STOCKOUT: For zonal autoscalers: there is a resource
        stockout in the chosen zone. For regional autoscalers: in at least one
        of the zones you're using there is a resource stockout.
    """
    ALL_INSTANCES_UNHEALTHY = 0
    BACKEND_SERVICE_DOES_NOT_EXIST = 1
    CAPPED_AT_MAX_NUM_REPLICAS = 2
    CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 3
    CUSTOM_METRIC_INVALID = 4
    MIN_EQUALS_MAX = 5
    MISSING_CUSTOM_METRIC_DATA_POINTS = 6
    MISSING_LOAD_BALANCING_DATA_POINTS = 7
    MODE_OFF = 8
    MODE_ONLY_SCALE_OUT = 9
    MODE_ONLY_UP = 10
    MORE_THAN_ONE_BACKEND_SERVICE = 11
    NOT_ENOUGH_QUOTA_AVAILABLE = 12
    REGION_RESOURCE_STOCKOUT = 13
    SCALING_TARGET_DOES_NOT_EXIST = 14
    SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX = 15
    SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN = 16
    UNKNOWN = 17
    UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 18
    ZONE_RESOURCE_STOCKOUT = 19

  message = _messages.StringField(1)
  type = _messages.EnumField('TypeValueValuesEnum', 2)


class AutoscalersScopedList(_messages.Message):
  r"""A AutoscalersScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of autoscalers when the list is empty.

  Fields:
    autoscalers: [Output Only] A list of autoscalers contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      autoscalers when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    autoscalers when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  autoscalers = _messages.MessageField('Autoscaler', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class AutoscalingPolicy(_messages.Message):
  r"""Cloud Autoscaler policy.

  Enums:
    ModeValueValuesEnum: Defines the operating mode for this policy. The
      following modes are available: - OFF: Disables the autoscaler but
      maintains its configuration. - ONLY_SCALE_OUT: Restricts the autoscaler
      to add VM instances only. - ON: Enables all autoscaler activities
      according to its policy. For more information, see "Turning off or
      restricting an autoscaler"

  Messages:
    ScalingSchedulesValue: Scaling schedules defined for an autoscaler.
      Multiple schedules can be set on an autoscaler, and they can overlap.
      During overlapping periods the greatest min_required_replicas of all
      scaling schedules is applied. Up to 128 scaling schedules are allowed.

  Fields:
    coolDownPeriodSec: The number of seconds that your application takes to
      initialize on a VM instance. This is referred to as the [initialization
      period](/compute/docs/autoscaler#cool_down_period). Specifying an
      accurate initialization period improves autoscaler decisions. For
      example, when scaling out, the autoscaler ignores data from VMs that are
      still initializing because those VMs might not yet represent normal
      usage of your application. The default initialization period is 60
      seconds. Initialization periods might vary because of numerous factors.
      We recommend that you test how long your application takes to
      initialize. To do this, create a VM and time your application's startup
      process.
    cpuUtilization: Defines the CPU utilization policy that allows the
      autoscaler to scale based on the average CPU utilization of a managed
      instance group.
    customMetricUtilizations: Configuration parameters of autoscaling based on
      a custom metric.
    loadBalancingUtilization: Configuration parameters of autoscaling based on
      load balancer.
    maxNumReplicas: The maximum number of instances that the autoscaler can
      scale out to. This is required when creating or updating an autoscaler.
      The maximum number of replicas must not be lower than minimal number of
      replicas.
    minNumReplicas: The minimum number of replicas that the autoscaler can
      scale in to. This cannot be less than 0. If not provided, autoscaler
      chooses a default value depending on maximum number of instances
      allowed.
    mode: Defines the operating mode for this policy. The following modes are
      available: - OFF: Disables the autoscaler but maintains its
      configuration. - ONLY_SCALE_OUT: Restricts the autoscaler to add VM
      instances only. - ON: Enables all autoscaler activities according to its
      policy. For more information, see "Turning off or restricting an
      autoscaler"
    scaleDownControl: A AutoscalingPolicyScaleDownControl attribute.
    scaleInControl: A AutoscalingPolicyScaleInControl attribute.
    scalingSchedules: Scaling schedules defined for an autoscaler. Multiple
      schedules can be set on an autoscaler, and they can overlap. During
      overlapping periods the greatest min_required_replicas of all scaling
      schedules is applied. Up to 128 scaling schedules are allowed.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Defines the operating mode for this policy. The following modes are
    available: - OFF: Disables the autoscaler but maintains its configuration.
    - ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only. - ON:
    Enables all autoscaler activities according to its policy. For more
    information, see "Turning off or restricting an autoscaler"

    Values:
      OFF: Do not automatically scale the MIG in or out. The recommended_size
        field contains the size of MIG that would be set if the actuation mode
        was enabled.
      ON: Automatically scale the MIG in and out according to the policy.
      ONLY_SCALE_OUT: Automatically create VMs according to the policy, but do
        not scale the MIG in.
      ONLY_UP: Automatically create VMs according to the policy, but do not
        scale the MIG in.
    """
    OFF = 0
    ON = 1
    ONLY_SCALE_OUT = 2
    ONLY_UP = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ScalingSchedulesValue(_messages.Message):
    r"""Scaling schedules defined for an autoscaler. Multiple schedules can be
    set on an autoscaler, and they can overlap. During overlapping periods the
    greatest min_required_replicas of all scaling schedules is applied. Up to
    128 scaling schedules are allowed.

    Messages:
      AdditionalProperty: An additional property for a ScalingSchedulesValue
        object.

    Fields:
      additionalProperties: Additional properties of type
        ScalingSchedulesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ScalingSchedulesValue object.

      Fields:
        key: Name of the additional property.
        value: A AutoscalingPolicyScalingSchedule attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('AutoscalingPolicyScalingSchedule', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  coolDownPeriodSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  cpuUtilization = _messages.MessageField('AutoscalingPolicyCpuUtilization', 2)
  customMetricUtilizations = _messages.MessageField('AutoscalingPolicyCustomMetricUtilization', 3, repeated=True)
  loadBalancingUtilization = _messages.MessageField('AutoscalingPolicyLoadBalancingUtilization', 4)
  maxNumReplicas = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  minNumReplicas = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  mode = _messages.EnumField('ModeValueValuesEnum', 7)
  scaleDownControl = _messages.MessageField('AutoscalingPolicyScaleDownControl', 8)
  scaleInControl = _messages.MessageField('AutoscalingPolicyScaleInControl', 9)
  scalingSchedules = _messages.MessageField('ScalingSchedulesValue', 10)


class AutoscalingPolicyCpuUtilization(_messages.Message):
  r"""CPU utilization policy.

  Enums:
    PredictiveMethodValueValuesEnum: Indicates whether predictive autoscaling
      based on CPU metric is enabled. Valid values are: * NONE (default). No
      predictive method is used. The autoscaler scales the group to meet
      current demand based on real-time metrics. * OPTIMIZE_AVAILABILITY.
      Predictive autoscaling improves availability by monitoring daily and
      weekly load patterns and scaling out ahead of anticipated demand.

  Fields:
    predictiveMethod: Indicates whether predictive autoscaling based on CPU
      metric is enabled. Valid values are: * NONE (default). No predictive
      method is used. The autoscaler scales the group to meet current demand
      based on real-time metrics. * OPTIMIZE_AVAILABILITY. Predictive
      autoscaling improves availability by monitoring daily and weekly load
      patterns and scaling out ahead of anticipated demand.
    utilizationTarget: The target CPU utilization that the autoscaler
      maintains. Must be a float value in the range (0, 1]. If not specified,
      the default is 0.6. If the CPU level is below the target utilization,
      the autoscaler scales in the number of instances until it reaches the
      minimum number of instances you specified or until the average CPU of
      your instances reaches the target utilization. If the average CPU is
      above the target utilization, the autoscaler scales out until it reaches
      the maximum number of instances you specified or until the average
      utilization reaches the target utilization.
  """

  class PredictiveMethodValueValuesEnum(_messages.Enum):
    r"""Indicates whether predictive autoscaling based on CPU metric is
    enabled. Valid values are: * NONE (default). No predictive method is used.
    The autoscaler scales the group to meet current demand based on real-time
    metrics. * OPTIMIZE_AVAILABILITY. Predictive autoscaling improves
    availability by monitoring daily and weekly load patterns and scaling out
    ahead of anticipated demand.

    Values:
      NONE: No predictive method is used. The autoscaler scales the group to
        meet current demand based on real-time metrics
      OPTIMIZE_AVAILABILITY: Predictive autoscaling improves availability by
        monitoring daily and weekly load patterns and scaling out ahead of
        anticipated demand.
      PREDICTIVE_METHOD_UNSPECIFIED: <no description>
      STANDARD: Predictive autoscaling improves availability by monitoring
        daily and weekly load patterns and scaling out ahead of anticipated
        demand. This value is being DEPRECATED - it won't be promoted to beta
        and v1. Use OPTIMIZE_AVAILABILITY instead.
    """
    NONE = 0
    OPTIMIZE_AVAILABILITY = 1
    PREDICTIVE_METHOD_UNSPECIFIED = 2
    STANDARD = 3

  predictiveMethod = _messages.EnumField('PredictiveMethodValueValuesEnum', 1)
  utilizationTarget = _messages.FloatField(2)


class AutoscalingPolicyCustomMetricUtilization(_messages.Message):
  r"""Custom utilization metric policy.

  Enums:
    UtilizationTargetTypeValueValuesEnum: Defines how target utilization value
      is expressed for a Stackdriver Monitoring metric. Either GAUGE,
      DELTA_PER_SECOND, or DELTA_PER_MINUTE.

  Fields:
    filter: A filter string, compatible with a Stackdriver Monitoring filter
      string for TimeSeries.list API call. This filter is used to select a
      specific TimeSeries for the purpose of autoscaling and to determine
      whether the metric is exporting per-instance or per-group data. For the
      filter to be valid for autoscaling purposes, the following rules apply:
      - You can only use the AND operator for joining selectors. - You can
      only use direct equality comparison operator (=) without any functions
      for each selector. - You can specify the metric in both the filter
      string and in the metric field. However, if specified in both places,
      the metric must be identical. - The monitored resource type determines
      what kind of values are expected for the metric. If it is a
      gce_instance, the autoscaler expects the metric to include a separate
      TimeSeries for each instance in a group. In such a case, you cannot
      filter on resource labels. If the resource type is any other value, the
      autoscaler expects this metric to contain values that apply to the
      entire autoscaled instance group and resource label filtering can be
      performed to point autoscaler at the correct TimeSeries to scale upon.
      This is called a *per-group metric* for the purpose of autoscaling. If
      not specified, the type defaults to gce_instance. Try to provide a
      filter that is selective enough to pick just one TimeSeries for the
      autoscaled group or for each of the instances (if you are using
      gce_instance resource type). If multiple TimeSeries are returned upon
      the query execution, the autoscaler will sum their respective values to
      obtain its scaling value.
    metric: The identifier (type) of the Stackdriver Monitoring metric. The
      metric cannot have negative values. The metric must have a value type of
      INT64 or DOUBLE.
    singleInstanceAssignment: If scaling is based on a per-group metric value
      that represents the total amount of work to be done or resource usage,
      set this value to an amount assigned for a single instance of the scaled
      group. Autoscaler keeps the number of instances proportional to the
      value of this metric. The metric itself does not change value due to
      group resizing. A good metric to use with the target is for example
      pubsub.googleapis.com/subscription/num_undelivered_messages or a custom
      metric exporting the total number of requests coming to your instances.
      A bad example would be a metric exporting an average or median latency,
      since this value can't include a chunk assignable to a single instance,
      it could be better used with utilization_target instead.
    utilizationTarget: The target value of the metric that autoscaler
      maintains. This must be a positive value. A utilization metric scales
      number of virtual machines handling requests to increase or decrease
      proportionally to the metric. For example, a good metric to use as a
      utilization_target is https://www.googleapis.com/compute/v1/instance/net
      work/received_bytes_count. The autoscaler works to keep this value
      constant for each of the instances.
    utilizationTargetType: Defines how target utilization value is expressed
      for a Stackdriver Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or
      DELTA_PER_MINUTE.
  """

  class UtilizationTargetTypeValueValuesEnum(_messages.Enum):
    r"""Defines how target utilization value is expressed for a Stackdriver
    Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or DELTA_PER_MINUTE.

    Values:
      DELTA_PER_MINUTE: Sets the utilization target value for a cumulative or
        delta metric, expressed as the rate of growth per minute.
      DELTA_PER_SECOND: Sets the utilization target value for a cumulative or
        delta metric, expressed as the rate of growth per second.
      GAUGE: Sets the utilization target value for a gauge metric. The
        autoscaler will collect the average utilization of the virtual
        machines from the last couple of minutes, and compare the value to the
        utilization target value to perform autoscaling.
    """
    DELTA_PER_MINUTE = 0
    DELTA_PER_SECOND = 1
    GAUGE = 2

  filter = _messages.StringField(1)
  metric = _messages.StringField(2)
  singleInstanceAssignment = _messages.FloatField(3)
  utilizationTarget = _messages.FloatField(4)
  utilizationTargetType = _messages.EnumField('UtilizationTargetTypeValueValuesEnum', 5)


class AutoscalingPolicyLoadBalancingUtilization(_messages.Message):
  r"""Configuration parameters of autoscaling based on load balancing.

  Fields:
    utilizationTarget: Fraction of backend capacity utilization (set in
      HTTP(S) load balancing configuration) that the autoscaler maintains.
      Must be a positive float value. If not defined, the default is 0.8.
  """

  utilizationTarget = _messages.FloatField(1)


class AutoscalingPolicyScaleDownControl(_messages.Message):
  r"""Configuration that allows for slower scale in so that even if Autoscaler
  recommends an abrupt scale in of a MIG, it will be throttled as specified by
  the parameters below.

  Fields:
    maxScaledDownReplicas: Maximum allowed number (or %) of VMs that can be
      deducted from the peak recommendation during the window autoscaler looks
      at when computing recommendations. Possibly all these VMs can be deleted
      at once so user service needs to be prepared to lose that many VMs in
      one step.
    timeWindowSec: How far back autoscaling looks when computing
      recommendations to include directives regarding slower scale in, as
      described above.
  """

  maxScaledDownReplicas = _messages.MessageField('FixedOrPercent', 1)
  timeWindowSec = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class AutoscalingPolicyScaleInControl(_messages.Message):
  r"""Configuration that allows for slower scale in so that even if Autoscaler
  recommends an abrupt scale in of a MIG, it will be throttled as specified by
  the parameters below.

  Fields:
    maxScaledInReplicas: Maximum allowed number (or %) of VMs that can be
      deducted from the peak recommendation during the window autoscaler looks
      at when computing recommendations. Possibly all these VMs can be deleted
      at once so user service needs to be prepared to lose that many VMs in
      one step.
    timeWindowSec: How far back autoscaling looks when computing
      recommendations to include directives regarding slower scale in, as
      described above.
  """

  maxScaledInReplicas = _messages.MessageField('FixedOrPercent', 1)
  timeWindowSec = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class AutoscalingPolicyScalingSchedule(_messages.Message):
  r"""Scaling based on user-defined schedule. The message describes a single
  scaling schedule. A scaling schedule changes the minimum number of VM
  instances an autoscaler can recommend, which can trigger scaling out.

  Fields:
    description: A description of a scaling schedule.
    disabled: A boolean value that specifies whether a scaling schedule can
      influence autoscaler recommendations. If set to true, then a scaling
      schedule has no effect. This field is optional, and its value is false
      by default.
    durationSec: The duration of time intervals, in seconds, for which this
      scaling schedule is to run. The minimum allowed value is 300. This field
      is required.
    minRequiredReplicas: The minimum number of VM instances that the
      autoscaler will recommend in time intervals starting according to
      schedule. This field is required.
    schedule: The start timestamps of time intervals when this scaling
      schedule is to provide a scaling signal. This field uses the extended
      cron format (with an optional year field). The expression can describe a
      single timestamp if the optional year is set, in which case the scaling
      schedule runs once. The schedule is interpreted with respect to
      time_zone. This field is required. Note: These timestamps only describe
      when autoscaler starts providing the scaling signal. The VMs need
      additional time to become serving.
    timeZone: The time zone to use when interpreting the schedule. The value
      of this field must be a time zone name from the tz database:
      https://en.wikipedia.org/wiki/Tz_database. This field is assigned a
      default value of "UTC" if left empty.
  """

  description = _messages.StringField(1)
  disabled = _messages.BooleanField(2)
  durationSec = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  minRequiredReplicas = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  schedule = _messages.StringField(5)
  timeZone = _messages.StringField(6)


class Backend(_messages.Message):
  r"""Message containing information of one individual backend.

  Enums:
    BalancingModeValueValuesEnum: Specifies how to determine whether the
      backend of a load balancer can handle additional traffic or is fully
      loaded. For usage guidelines, see Connection balancing mode. Backends
      must use compatible balancing modes. For more information, see Supported
      balancing modes and target capacity settings and Restrictions and
      guidance for instance groups. Note: Currently, if you use the API to
      configure incompatible balancing modes, the configuration might be
      accepted even though it has no impact and is ignored. Specifically,
      Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In
      the future, this incompatible combination will be rejected.
    PreferenceValueValuesEnum: This field indicates whether this backend
      should be fully utilized before sending traffic to backends with default
      preference. The possible values are: - PREFERRED: Backends with this
      preference level will be filled up to their capacity limits first, based
      on RTT. - DEFAULT: If preferred backends don't have enough capacity,
      backends in this layer would be used and traffic would be assigned based
      on the load balancing algorithm you use. This is the default

  Fields:
    balancingMode: Specifies how to determine whether the backend of a load
      balancer can handle additional traffic or is fully loaded. For usage
      guidelines, see Connection balancing mode. Backends must use compatible
      balancing modes. For more information, see Supported balancing modes and
      target capacity settings and Restrictions and guidance for instance
      groups. Note: Currently, if you use the API to configure incompatible
      balancing modes, the configuration might be accepted even though it has
      no impact and is ignored. Specifically, Backend.maxUtilization is
      ignored when Backend.balancingMode is RATE. In the future, this
      incompatible combination will be rejected.
    capacityScaler: A multiplier applied to the backend's target capacity of
      its balancing mode. The default value is 1, which means the group serves
      up to 100% of its configured capacity (depending on balancingMode). A
      setting of 0 means the group is completely drained, offering 0% of its
      available capacity. The valid ranges are 0.0 and [0.1,1.0]. You cannot
      configure a setting larger than 0 and smaller than 0.1. You cannot
      configure a setting of 0 when there is only one backend attached to the
      backend service. Not available with backends that don't support using a
      balancingMode. This includes backends such as global internet NEGs,
      regional serverless NEGs, and PSC NEGs.
    customMetrics: List of custom metrics that are used for CUSTOM_METRICS
      BalancingMode.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    failover: This field designates whether this is a failover backend. More
      than one failover backend can be configured for a given BackendService.
    group: The fully-qualified URL of an instance group or network endpoint
      group (NEG) resource. To determine what types of backends a load
      balancer supports, see the [Backend services
      overview](https://cloud.google.com/load-balancing/docs/backend-
      service#backends). You must use the *fully-qualified* URL (starting with
      https://www.googleapis.com/) to specify the instance group or NEG.
      Partial URLs are not supported.
    maxConnections: Defines a target maximum number of simultaneous
      connections. For usage guidelines, see Connection balancing mode and
      Utilization balancing mode. Not available if the backend's balancingMode
      is RATE.
    maxConnectionsPerEndpoint: Defines a target maximum number of simultaneous
      connections. For usage guidelines, see Connection balancing mode and
      Utilization balancing mode. Not available if the backend's balancingMode
      is RATE.
    maxConnectionsPerInstance: Defines a target maximum number of simultaneous
      connections. For usage guidelines, see Connection balancing mode and
      Utilization balancing mode. Not available if the backend's balancingMode
      is RATE.
    maxRate: Defines a maximum number of HTTP requests per second (RPS). For
      usage guidelines, see Rate balancing mode and Utilization balancing
      mode. Not available if the backend's balancingMode is CONNECTION.
    maxRatePerEndpoint: Defines a maximum target for requests per second
      (RPS). For usage guidelines, see Rate balancing mode and Utilization
      balancing mode. Not available if the backend's balancingMode is
      CONNECTION.
    maxRatePerInstance: Defines a maximum target for requests per second
      (RPS). For usage guidelines, see Rate balancing mode and Utilization
      balancing mode. Not available if the backend's balancingMode is
      CONNECTION.
    maxUtilization: Optional parameter to define a target capacity for the
      UTILIZATION balancing mode. The valid range is [0.0, 1.0]. For usage
      guidelines, see Utilization balancing mode.
    preference: This field indicates whether this backend should be fully
      utilized before sending traffic to backends with default preference. The
      possible values are: - PREFERRED: Backends with this preference level
      will be filled up to their capacity limits first, based on RTT. -
      DEFAULT: If preferred backends don't have enough capacity, backends in
      this layer would be used and traffic would be assigned based on the load
      balancing algorithm you use. This is the default
  """

  class BalancingModeValueValuesEnum(_messages.Enum):
    r"""Specifies how to determine whether the backend of a load balancer can
    handle additional traffic or is fully loaded. For usage guidelines, see
    Connection balancing mode. Backends must use compatible balancing modes.
    For more information, see Supported balancing modes and target capacity
    settings and Restrictions and guidance for instance groups. Note:
    Currently, if you use the API to configure incompatible balancing modes,
    the configuration might be accepted even though it has no impact and is
    ignored. Specifically, Backend.maxUtilization is ignored when
    Backend.balancingMode is RATE. In the future, this incompatible
    combination will be rejected.

    Values:
      CONNECTION: Balance based on the number of simultaneous connections.
      CUSTOM_METRICS: Based on custom defined and reported metrics.
      RATE: Balance based on requests per second (RPS).
      UTILIZATION: Balance based on the backend utilization.
    """
    CONNECTION = 0
    CUSTOM_METRICS = 1
    RATE = 2
    UTILIZATION = 3

  class PreferenceValueValuesEnum(_messages.Enum):
    r"""This field indicates whether this backend should be fully utilized
    before sending traffic to backends with default preference. The possible
    values are: - PREFERRED: Backends with this preference level will be
    filled up to their capacity limits first, based on RTT. - DEFAULT: If
    preferred backends don't have enough capacity, backends in this layer
    would be used and traffic would be assigned based on the load balancing
    algorithm you use. This is the default

    Values:
      DEFAULT: No preference.
      PREFERENCE_UNSPECIFIED: If preference is unspecified, we set it to the
        DEFAULT value
      PREFERRED: Traffic will be sent to this backend first.
    """
    DEFAULT = 0
    PREFERENCE_UNSPECIFIED = 1
    PREFERRED = 2

  balancingMode = _messages.EnumField('BalancingModeValueValuesEnum', 1)
  capacityScaler = _messages.FloatField(2, variant=_messages.Variant.FLOAT)
  customMetrics = _messages.MessageField('BackendCustomMetric', 3, repeated=True)
  description = _messages.StringField(4)
  failover = _messages.BooleanField(5)
  group = _messages.StringField(6)
  maxConnections = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  maxConnectionsPerEndpoint = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  maxConnectionsPerInstance = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  maxRate = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  maxRatePerEndpoint = _messages.FloatField(11, variant=_messages.Variant.FLOAT)
  maxRatePerInstance = _messages.FloatField(12, variant=_messages.Variant.FLOAT)
  maxUtilization = _messages.FloatField(13, variant=_messages.Variant.FLOAT)
  preference = _messages.EnumField('PreferenceValueValuesEnum', 14)


class BackendBucket(_messages.Message):
  r"""Represents a Cloud Storage Bucket resource. This Cloud Storage bucket
  resource is referenced by a URL map of a load balancer. For more
  information, read Backend Buckets.

  Enums:
    CompressionModeValueValuesEnum: Compress text responses using Brotli or
      gzip compression, based on the client's Accept-Encoding header.
    LoadBalancingSchemeValueValuesEnum: The value can only be INTERNAL_MANAGED
      for cross-region internal layer 7 load balancer. If loadBalancingScheme
      is not specified, the backend bucket can be used by classic global
      external load balancers, or global application external load balancers,
      or both.

  Fields:
    bucketName: Cloud Storage bucket name.
    cdnPolicy: Cloud CDN configuration for this BackendBucket.
    compressionMode: Compress text responses using Brotli or gzip compression,
      based on the client's Accept-Encoding header.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customResponseHeaders: Headers that the Application Load Balancer should
      add to proxied responses.
    description: An optional textual description of the resource; provided by
      the client when the resource is created.
    edgeSecurityPolicy: [Output Only] The resource URL for the edge security
      policy associated with this backend bucket.
    enableCdn: If true, enable Cloud CDN for this BackendBucket.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    kind: Type of the resource.
    loadBalancingScheme: The value can only be INTERNAL_MANAGED for cross-
      region internal layer 7 load balancer. If loadBalancingScheme is not
      specified, the backend bucket can be used by classic global external
      load balancers, or global application external load balancers, or both.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    usedBy: [Output Only] List of resources referencing that backend bucket.
  """

  class CompressionModeValueValuesEnum(_messages.Enum):
    r"""Compress text responses using Brotli or gzip compression, based on the
    client's Accept-Encoding header.

    Values:
      AUTOMATIC: Automatically uses the best compression based on the Accept-
        Encoding header sent by the client.
      DISABLED: Disables compression. Existing compressed responses cached by
        Cloud CDN will not be served to clients.
    """
    AUTOMATIC = 0
    DISABLED = 1

  class LoadBalancingSchemeValueValuesEnum(_messages.Enum):
    r"""The value can only be INTERNAL_MANAGED for cross-region internal layer
    7 load balancer. If loadBalancingScheme is not specified, the backend
    bucket can be used by classic global external load balancers, or global
    application external load balancers, or both.

    Values:
      INTERNAL_MANAGED: Signifies that this will be used for internal
        Application Load Balancers.
    """
    INTERNAL_MANAGED = 0

  bucketName = _messages.StringField(1)
  cdnPolicy = _messages.MessageField('BackendBucketCdnPolicy', 2)
  compressionMode = _messages.EnumField('CompressionModeValueValuesEnum', 3)
  creationTimestamp = _messages.StringField(4)
  customResponseHeaders = _messages.StringField(5, repeated=True)
  description = _messages.StringField(6)
  edgeSecurityPolicy = _messages.StringField(7)
  enableCdn = _messages.BooleanField(8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(10, default='compute#backendBucket')
  loadBalancingScheme = _messages.EnumField('LoadBalancingSchemeValueValuesEnum', 11)
  name = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)
  usedBy = _messages.MessageField('BackendBucketUsedBy', 15, repeated=True)


class BackendBucketCdnPolicy(_messages.Message):
  r"""Message containing Cloud CDN configuration for a backend bucket.

  Enums:
    CacheModeValueValuesEnum: Specifies the cache setting for all responses
      from this backend. The possible values are: USE_ORIGIN_HEADERS Requires
      the origin to set valid caching headers to cache content. Responses
      without these headers will not be cached at Google's edge, and will
      require a full trip to the origin on every request, potentially
      impacting performance and increasing load on the origin server.
      FORCE_CACHE_ALL Cache all content, ignoring any "private", "no-store" or
      "no-cache" directives in Cache-Control response headers. Warning: this
      may result in Cloud CDN caching private, per-user (user identifiable)
      content. CACHE_ALL_STATIC Automatically cache static content, including
      common image formats, media (video and audio), and web assets
      (JavaScript and CSS). Requests and responses that are marked as
      uncacheable, as well as dynamic content (including HTML), will not be
      cached. If no value is provided for cdnPolicy.cacheMode, it defaults to
      CACHE_ALL_STATIC.

  Fields:
    bypassCacheOnRequestHeaders: Bypass the cache when the specified request
      headers are matched - e.g. Pragma or Authorization headers. Up to 5
      headers can be specified. The cache is bypassed for all
      cdnPolicy.cacheMode settings.
    cacheKeyPolicy: The CacheKeyPolicy for this CdnPolicy.
    cacheMode: Specifies the cache setting for all responses from this
      backend. The possible values are: USE_ORIGIN_HEADERS Requires the origin
      to set valid caching headers to cache content. Responses without these
      headers will not be cached at Google's edge, and will require a full
      trip to the origin on every request, potentially impacting performance
      and increasing load on the origin server. FORCE_CACHE_ALL Cache all
      content, ignoring any "private", "no-store" or "no-cache" directives in
      Cache-Control response headers. Warning: this may result in Cloud CDN
      caching private, per-user (user identifiable) content. CACHE_ALL_STATIC
      Automatically cache static content, including common image formats,
      media (video and audio), and web assets (JavaScript and CSS). Requests
      and responses that are marked as uncacheable, as well as dynamic content
      (including HTML), will not be cached. If no value is provided for
      cdnPolicy.cacheMode, it defaults to CACHE_ALL_STATIC.
    clientTtl: Specifies a separate client (e.g. browser client) maximum TTL.
      This is used to clamp the max-age (or Expires) value sent to the client.
      With FORCE_CACHE_ALL, the lesser of client_ttl and default_ttl is used
      for the response max-age directive, along with a "public" directive. For
      cacheable content in CACHE_ALL_STATIC mode, client_ttl clamps the max-
      age from the origin (if specified), or else sets the response max-age
      directive to the lesser of the client_ttl and default_ttl, and also
      ensures a "public" cache-control directive is present. If a client TTL
      is not specified, a default value (1 hour) will be used. The maximum
      allowed value is 31,622,400s (1 year).
    defaultTtl: Specifies the default TTL for cached content served by this
      origin for responses that do not have an existing valid TTL (max-age or
      s-max-age). Setting a TTL of "0" means "always revalidate". The value of
      defaultTTL cannot be set to a value greater than that of maxTTL, but can
      be equal. When the cacheMode is set to FORCE_CACHE_ALL, the defaultTTL
      will overwrite the TTL set in all responses. The maximum allowed value
      is 31,622,400s (1 year), noting that infrequently accessed objects may
      be evicted from the cache before the defined TTL.
    maxTtl: Specifies the maximum allowed TTL for cached content served by
      this origin. Cache directives that attempt to set a max-age or s-maxage
      higher than this, or an Expires header more than maxTTL seconds in the
      future will be capped at the value of maxTTL, as if it were the value of
      an s-maxage Cache-Control directive. Headers sent to the client will not
      be modified. Setting a TTL of "0" means "always revalidate". The maximum
      allowed value is 31,622,400s (1 year), noting that infrequently accessed
      objects may be evicted from the cache before the defined TTL.
    negativeCaching: Negative caching allows per-status code TTLs to be set,
      in order to apply fine-grained caching for common errors or redirects.
      This can reduce the load on your origin and improve end-user experience
      by reducing response latency. When the cache mode is set to
      CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to
      responses with the specified response code that lack any Cache-Control,
      Expires, or Pragma: no-cache directives. When the cache mode is set to
      FORCE_CACHE_ALL, negative caching applies to all responses with the
      specified response code, and override any caching headers. By default,
      Cloud CDN will apply the following default TTLs to these status codes:
      HTTP 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m HTTP 404
      (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s HTTP
      405 (Method Not Found), 421 (Misdirected Request), 501 (Not
      Implemented): 60s. These defaults can be overridden in
      negative_caching_policy.
    negativeCachingPolicy: Sets a cache TTL for the specified HTTP status
      code. negative_caching must be enabled to configure
      negative_caching_policy. Omitting the policy and leaving
      negative_caching enabled will use Cloud CDN's default cache TTLs. Note
      that when specifying an explicit negative_caching_policy, you should
      take care to specify a cache TTL for all response codes that you wish to
      cache. Cloud CDN will not apply any default negative caching when a
      policy exists.
    requestCoalescing: If true then Cloud CDN will combine multiple concurrent
      cache fill requests into a small number of requests to the origin.
    serveWhileStale: Serve existing content from the cache (if available) when
      revalidating content with the origin, or when an error is encountered
      when refreshing the cache. This setting defines the default "max-stale"
      duration for any cached responses that do not specify a max-stale
      directive. Stale responses that exceed the TTL configured here will not
      be served. The default limit (max-stale) is 86400s (1 day), which will
      allow stale content to be served up to this limit beyond the max-age (or
      s-max-age) of a cached response. The maximum allowed value is 604800 (1
      week). Set this to zero (0) to disable serve-while-stale.
    signedUrlCacheMaxAgeSec: Maximum number of seconds the response to a
      signed URL request will be considered fresh. After this time period, the
      response will be revalidated before being served. Defaults to 1hr
      (3600s). When serving responses to signed URL requests, Cloud CDN will
      internally behave as though all responses from this backend had a
      "Cache-Control: public, max-age=[TTL]" header, regardless of any
      existing Cache-Control header. The actual headers served in responses
      will not be altered.
    signedUrlKeyNames: [Output Only] Names of the keys for signing request
      URLs.
  """

  class CacheModeValueValuesEnum(_messages.Enum):
    r"""Specifies the cache setting for all responses from this backend. The
    possible values are: USE_ORIGIN_HEADERS Requires the origin to set valid
    caching headers to cache content. Responses without these headers will not
    be cached at Google's edge, and will require a full trip to the origin on
    every request, potentially impacting performance and increasing load on
    the origin server. FORCE_CACHE_ALL Cache all content, ignoring any
    "private", "no-store" or "no-cache" directives in Cache-Control response
    headers. Warning: this may result in Cloud CDN caching private, per-user
    (user identifiable) content. CACHE_ALL_STATIC Automatically cache static
    content, including common image formats, media (video and audio), and web
    assets (JavaScript and CSS). Requests and responses that are marked as
    uncacheable, as well as dynamic content (including HTML), will not be
    cached. If no value is provided for cdnPolicy.cacheMode, it defaults to
    CACHE_ALL_STATIC.

    Values:
      CACHE_ALL_STATIC: Automatically cache static content, including common
        image formats, media (video and audio), and web assets (JavaScript and
        CSS). Requests and responses that are marked as uncacheable, as well
        as dynamic content (including HTML), will not be cached.
      FORCE_CACHE_ALL: Cache all content, ignoring any "private", "no-store"
        or "no-cache" directives in Cache-Control response headers. Warning:
        this may result in Cloud CDN caching private, per-user (user
        identifiable) content.
      INVALID_CACHE_MODE: <no description>
      USE_ORIGIN_HEADERS: Requires the origin to set valid caching headers to
        cache content. Responses without these headers will not be cached at
        Google's edge, and will require a full trip to the origin on every
        request, potentially impacting performance and increasing load on the
        origin server.
    """
    CACHE_ALL_STATIC = 0
    FORCE_CACHE_ALL = 1
    INVALID_CACHE_MODE = 2
    USE_ORIGIN_HEADERS = 3

  bypassCacheOnRequestHeaders = _messages.MessageField('BackendBucketCdnPolicyBypassCacheOnRequestHeader', 1, repeated=True)
  cacheKeyPolicy = _messages.MessageField('BackendBucketCdnPolicyCacheKeyPolicy', 2)
  cacheMode = _messages.EnumField('CacheModeValueValuesEnum', 3)
  clientTtl = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  defaultTtl = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  maxTtl = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  negativeCaching = _messages.BooleanField(7)
  negativeCachingPolicy = _messages.MessageField('BackendBucketCdnPolicyNegativeCachingPolicy', 8, repeated=True)
  requestCoalescing = _messages.BooleanField(9)
  serveWhileStale = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  signedUrlCacheMaxAgeSec = _messages.IntegerField(11)
  signedUrlKeyNames = _messages.StringField(12, repeated=True)


class BackendBucketCdnPolicyBypassCacheOnRequestHeader(_messages.Message):
  r"""Bypass the cache when the specified request headers are present, e.g.
  Pragma or Authorization headers. Values are case insensitive. The presence
  of such a header overrides the cache_mode setting.

  Fields:
    headerName: The header field name to match on when bypassing cache. Values
      are case-insensitive.
  """

  headerName = _messages.StringField(1)


class BackendBucketCdnPolicyCacheKeyPolicy(_messages.Message):
  r"""Message containing what to include in the cache key for a request for
  Cloud CDN.

  Fields:
    includeHttpHeaders: Allows HTTP request headers (by name) to be used in
      the cache key.
    queryStringWhitelist: Names of query string parameters to include in cache
      keys. Default parameters are always included. '&' and '=' will be
      percent encoded and not treated as delimiters.
  """

  includeHttpHeaders = _messages.StringField(1, repeated=True)
  queryStringWhitelist = _messages.StringField(2, repeated=True)


class BackendBucketCdnPolicyNegativeCachingPolicy(_messages.Message):
  r"""Specify CDN TTLs for response error codes.

  Fields:
    code: The HTTP status code to define a TTL against. Only HTTP status codes
      300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 are can be
      specified as values, and you cannot specify a status code more than
      once.
    ttl: The TTL (in seconds) for which to cache responses with the
      corresponding status code. The maximum allowed value is 1800s (30
      minutes), noting that infrequently accessed objects may be evicted from
      the cache before the defined TTL.
  """

  code = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  ttl = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class BackendBucketList(_messages.Message):
  r"""Contains a list of BackendBucket resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of BackendBucket resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('BackendBucket', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#backendBucketList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class BackendBucketListUsable(_messages.Message):
  r"""A BackendBucketListUsable object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of BackendBucket resources.
    kind: [Output Only] Type of resource. Always
      compute#usableBackendBucketList for lists of usable backend buckets.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('BackendBucket', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#usableBackendBucketList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class BackendBucketUsedBy(_messages.Message):
  r"""A BackendBucketUsedBy object.

  Fields:
    reference: [Output Only] Server-defined URL for UrlMaps referencing that
      BackendBucket.
  """

  reference = _messages.StringField(1)


class BackendCustomMetric(_messages.Message):
  r"""Custom Metrics are used for CUSTOM_METRICS balancing_mode.

  Fields:
    dryRun: If true, the metric data is collected and reported to Cloud
      Monitoring, but is not used for load balancing.
    maxUtilization: Optional parameter to define a target utilization for the
      Custom Metrics balancing mode. The valid range is [0.0, 1.0].
    name: Name of a custom utilization signal. The name must be 1-64
      characters long and match the regular expression
      [a-z]([-_.a-z0-9]*[a-z0-9])? which means the first character must be a
      lowercase letter, and all following characters must be a dash, period,
      underscore, lowercase letter, or digit, except the last character, which
      cannot be a dash, period, or underscore. For usage guidelines, see
      Custom Metrics balancing mode. This field can only be used for a global
      or regional backend service with the loadBalancingScheme set to
      EXTERNAL_MANAGED, INTERNAL_MANAGED INTERNAL_SELF_MANAGED.
  """

  dryRun = _messages.BooleanField(1)
  maxUtilization = _messages.FloatField(2, variant=_messages.Variant.FLOAT)
  name = _messages.StringField(3)


class BackendService(_messages.Message):
  r"""Represents a Backend Service resource. A backend service defines how
  Google Cloud load balancers distribute traffic. The backend service
  configuration contains a set of values, such as the protocol used to connect
  to backends, various distribution and session settings, health checks, and
  timeouts. These settings provide fine-grained control over how your load
  balancer behaves. Most of the settings have default values that allow for
  easy configuration if you need to get started quickly. Backend services in
  Google Compute Engine can be either regionally or globally scoped. * [Global
  ](https://cloud.google.com/compute/docs/reference/rest/alpha/backendServices
  ) * [Regional](https://cloud.google.com/compute/docs/reference/rest/alpha/re
  gionBackendServices) For more information, see Backend Services.

  Enums:
    CompressionModeValueValuesEnum: Compress text responses using Brotli or
      gzip compression, based on the client's Accept-Encoding header.
    ExternalManagedMigrationStateValueValuesEnum: Specifies the canary
      migration state. Possible values are PREPARE, TEST_BY_PERCENTAGE, and
      TEST_ALL_TRAFFIC. To begin the migration from EXTERNAL to
      EXTERNAL_MANAGED, the state must be changed to PREPARE. The state must
      be changed to TEST_ALL_TRAFFIC before the loadBalancingScheme can be
      changed to EXTERNAL_MANAGED. Optionally, the TEST_BY_PERCENTAGE state
      can be used to migrate traffic by percentage using
      externalManagedMigrationTestingPercentage. Rolling back a migration
      requires the states to be set in reverse order. So changing the scheme
      from EXTERNAL_MANAGED to EXTERNAL requires the state to be set to
      TEST_ALL_TRAFFIC at the same time. Optionally, the TEST_BY_PERCENTAGE
      state can be used to migrate some traffic back to EXTERNAL or PREPARE
      can be used to migrate all traffic back to EXTERNAL.
    IpAddressSelectionPolicyValueValuesEnum: Specifies a preference for
      traffic sent from the proxy to the backend (or from the client to the
      backend for proxyless gRPC). The possible values are: - IPV4_ONLY: Only
      send IPv4 traffic to the backends of the backend service (Instance
      Group, Managed Instance Group, Network Endpoint Group), regardless of
      traffic from the client to the proxy. Only IPv4 health checks are used
      to check the health of the backends. This is the default setting. -
      PREFER_IPV6: Prioritize the connection to the endpoint's IPv6 address
      over its IPv4 address (provided there is a healthy IPv6 address). -
      IPV6_ONLY: Only send IPv6 traffic to the backends of the backend service
      (Instance Group, Managed Instance Group, Network Endpoint Group),
      regardless of traffic from the client to the proxy. Only IPv6 health
      checks are used to check the health of the backends. This field is
      applicable to either: - Advanced global external Application Load
      Balancer (load balancing scheme EXTERNAL_MANAGED), - Regional external
      Application Load Balancer, - Internal proxy Network Load Balancer (load
      balancing scheme INTERNAL_MANAGED), - Regional internal Application Load
      Balancer (load balancing scheme INTERNAL_MANAGED), - Traffic Director
      with Envoy proxies and proxyless gRPC (load balancing scheme
      INTERNAL_SELF_MANAGED).
    LoadBalancingSchemeValueValuesEnum: Specifies the load balancer type. A
      backend service created for one type of load balancer cannot be used
      with another. For more information, refer to Choosing a load balancer.
    LocalityLbPolicyValueValuesEnum: The load balancing algorithm used within
      the scope of the locality. The possible values are: - ROUND_ROBIN: This
      is a simple policy in which each healthy backend is selected in round
      robin order. This is the default. - LEAST_REQUEST: An O(1) algorithm
      which selects two random healthy hosts and picks the host which has
      fewer active requests. - RING_HASH: The ring/modulo hash load balancer
      implements consistent hashing to backends. The algorithm has the
      property that the addition/removal of a host from a set of N hosts only
      affects 1/N of the requests. - RANDOM: The load balancer selects a
      random healthy host. - ORIGINAL_DESTINATION: Backend host is selected
      based on the client connection metadata, i.e., connections are opened to
      the same address as the destination address of the incoming connection
      before the connection was redirected to the load balancer. - MAGLEV:
      used as a drop in replacement for the ring hash load balancer. Maglev is
      not as stable as ring hash but has faster table lookup build times and
      host selection times. For more information about Maglev, see
      https://ai.google/research/pubs/pub44824 This field is applicable to
      either: - A regional backend service with the service_protocol set to
      HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to
      INTERNAL_MANAGED. - A global backend service with the
      load_balancing_scheme set to INTERNAL_SELF_MANAGED, INTERNAL_MANAGED, or
      EXTERNAL_MANAGED. If sessionAffinity is not configured-that is, if
      session affinity remains at the default value of NONE-then the default
      value for localityLbPolicy is ROUND_ROBIN. If session affinity is set to
      a value other than NONE, then the default value for localityLbPolicy is
      MAGLEV. Only ROUND_ROBIN and RING_HASH are supported when the backend
      service is referenced by a URL map that is bound to target gRPC proxy
      that has validateForProxyless field set to true.
    ProtocolValueValuesEnum: The protocol this BackendService uses to
      communicate with backends. Possible values are HTTP, HTTPS, HTTP2, TCP,
      SSL, UDP or GRPC. depending on the chosen load balancer or Traffic
      Director configuration. Refer to the documentation for the load
      balancers or for Traffic Director for more information. Must be set to
      GRPC when the backend service is referenced by a URL map that is bound
      to target gRPC proxy.
    SessionAffinityValueValuesEnum: Type of session affinity to use. The
      default is NONE. Only NONE and HEADER_FIELD are supported when the
      backend service is referenced by a URL map that is bound to target gRPC
      proxy that has validateForProxyless field set to true. For more details,
      see: [Session Affinity](https://cloud.google.com/load-
      balancing/docs/backend-service#session_affinity).
    VpcNetworkScopeValueValuesEnum: The network scope of the backends that can
      be added to the backend service. This field can be either
      GLOBAL_VPC_NETWORK or REGIONAL_VPC_NETWORK. A backend service with the
      VPC scope set to GLOBAL_VPC_NETWORK is only allowed to have backends in
      global VPC networks. When the VPC scope is set to REGIONAL_VPC_NETWORK
      the backend service is only allowed to have backends in regional
      networks in the same scope as the backend service. Note: if not
      specified then GLOBAL_VPC_NETWORK will be used.

  Messages:
    MetadatasValue: Deployment metadata associated with the resource to be set
      by a GKE hub controller and read by the backend RCTH

  Fields:
    affinityCookieTtlSec: Lifetime of cookies in seconds. This setting is
      applicable to Application Load Balancers and Traffic Director and
      requires GENERATED_COOKIE or HTTP_COOKIE session affinity. If set to 0,
      the cookie is non-persistent and lasts only until the end of the browser
      session (or equivalent). The maximum allowed value is two weeks
      (1,209,600). Not supported when the backend service is referenced by a
      URL map that is bound to target gRPC proxy that has validateForProxyless
      field set to true.
    backends: The list of backends that serve this BackendService.
    cdnPolicy: Cloud CDN configuration for this BackendService. Only available
      for specified load balancer types.
    circuitBreakers: A CircuitBreakers attribute.
    compressionMode: Compress text responses using Brotli or gzip compression,
      based on the client's Accept-Encoding header.
    connectionDraining: A ConnectionDraining attribute.
    connectionTrackingPolicy: Connection Tracking configuration for this
      BackendService. Connection tracking policy settings are only available
      for external passthrough Network Load Balancers and internal passthrough
      Network Load Balancers.
    consistentHash: Consistent Hash-based load balancing can be used to
      provide soft session affinity based on HTTP headers, cookies or other
      properties. This load balancing policy is applicable only for HTTP
      connections. The affinity to a particular destination host will be lost
      when one or more hosts are added/removed from the destination service.
      This field specifies parameters that control consistent hashing. This
      field is only applicable when localityLbPolicy is set to MAGLEV or
      RING_HASH. This field is applicable to either: - A regional backend
      service with the service_protocol set to HTTP, HTTPS, or HTTP2, and
      load_balancing_scheme set to INTERNAL_MANAGED. - A global backend
      service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customMetrics: List of custom metrics that are used for the
      WEIGHTED_ROUND_ROBIN locality_lb_policy.
    customRequestHeaders: Headers that the load balancer adds to proxied
      requests. See [Creating custom headers](https://cloud.google.com/load-
      balancing/docs/custom-headers).
    customResponseHeaders: Headers that the load balancer adds to proxied
      responses. See [Creating custom headers](https://cloud.google.com/load-
      balancing/docs/custom-headers).
    description: An optional description of this resource. Provide this
      property when you create the resource.
    dynamicForwarding: Dynamic forwarding configuration. This field is used to
      configure the backend service with dynamic forwarding feature which
      together with Service Extension allows customized and complex routing
      logic.
    edgeSecurityPolicy: [Output Only] The resource URL for the edge security
      policy associated with this backend service.
    enableCDN: If true, enables Cloud CDN for the backend service of a global
      external Application Load Balancer.
    externalManagedMigrationState: Specifies the canary migration state.
      Possible values are PREPARE, TEST_BY_PERCENTAGE, and TEST_ALL_TRAFFIC.
      To begin the migration from EXTERNAL to EXTERNAL_MANAGED, the state must
      be changed to PREPARE. The state must be changed to TEST_ALL_TRAFFIC
      before the loadBalancingScheme can be changed to EXTERNAL_MANAGED.
      Optionally, the TEST_BY_PERCENTAGE state can be used to migrate traffic
      by percentage using externalManagedMigrationTestingPercentage. Rolling
      back a migration requires the states to be set in reverse order. So
      changing the scheme from EXTERNAL_MANAGED to EXTERNAL requires the state
      to be set to TEST_ALL_TRAFFIC at the same time. Optionally, the
      TEST_BY_PERCENTAGE state can be used to migrate some traffic back to
      EXTERNAL or PREPARE can be used to migrate all traffic back to EXTERNAL.
    externalManagedMigrationTestingPercentage: Determines the fraction of
      requests that should be processed by the Global external Application
      Load Balancer. The value of this field must be in the range [0, 100].
      Session affinity options will slightly affect this routing behavior, for
      more details, see: Session Affinity. This value can only be set if the
      loadBalancingScheme in the BackendService is set to EXTERNAL (when using
      the classic Application Load Balancer) and the migration state is
      TEST_BY_PERCENTAGE.
    failoverPolicy: Requires at least one backend instance group to be defined
      as a backup (failover) backend. For load balancers that have
      configurable failover: [Internal passthrough Network Load
      Balancers](https://cloud.google.com/load-
      balancing/docs/internal/failover-overview) and [external passthrough
      Network Load Balancers](https://cloud.google.com/load-
      balancing/docs/network/networklb-failover-overview).
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a BackendService. An up-to-date
      fingerprint must be provided in order to update the BackendService,
      otherwise the request will fail with error 412 conditionNotMet. To see
      the latest fingerprint, make a get() request to retrieve a
      BackendService.
    haPolicy: Configuring haPolicy is not supported.
    healthChecks: The list of URLs to the healthChecks, httpHealthChecks
      (legacy), or httpsHealthChecks (legacy) resource for health checking
      this backend service. Not all backend services support legacy health
      checks. See Load balancer guide. Currently, at most one health check can
      be specified for each backend service. Backend services with instance
      group or zonal NEG backends must have a health check. Backend services
      with internet or serverless NEG backends must not have a health check.
    iap: The configurations for Identity-Aware Proxy on this resource. Not
      available for internal passthrough Network Load Balancers and external
      passthrough Network Load Balancers.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ipAddressSelectionPolicy: Specifies a preference for traffic sent from the
      proxy to the backend (or from the client to the backend for proxyless
      gRPC). The possible values are: - IPV4_ONLY: Only send IPv4 traffic to
      the backends of the backend service (Instance Group, Managed Instance
      Group, Network Endpoint Group), regardless of traffic from the client to
      the proxy. Only IPv4 health checks are used to check the health of the
      backends. This is the default setting. - PREFER_IPV6: Prioritize the
      connection to the endpoint's IPv6 address over its IPv4 address
      (provided there is a healthy IPv6 address). - IPV6_ONLY: Only send IPv6
      traffic to the backends of the backend service (Instance Group, Managed
      Instance Group, Network Endpoint Group), regardless of traffic from the
      client to the proxy. Only IPv6 health checks are used to check the
      health of the backends. This field is applicable to either: - Advanced
      global external Application Load Balancer (load balancing scheme
      EXTERNAL_MANAGED), - Regional external Application Load Balancer, -
      Internal proxy Network Load Balancer (load balancing scheme
      INTERNAL_MANAGED), - Regional internal Application Load Balancer (load
      balancing scheme INTERNAL_MANAGED), - Traffic Director with Envoy
      proxies and proxyless gRPC (load balancing scheme
      INTERNAL_SELF_MANAGED).
    kind: [Output Only] Type of resource. Always compute#backendService for
      backend services.
    loadBalancingScheme: Specifies the load balancer type. A backend service
      created for one type of load balancer cannot be used with another. For
      more information, refer to Choosing a load balancer.
    localityLbPolicies: A list of locality load-balancing policies to be used
      in order of preference. When you use localityLbPolicies, you must set at
      least one value for either the localityLbPolicies[].policy or the
      localityLbPolicies[].customPolicy field. localityLbPolicies overrides
      any value set in the localityLbPolicy field. For an example of how to
      use this field, see Define a list of preferred policies. Caution: This
      field and its children are intended for use in a service mesh that
      includes gRPC clients only. Envoy proxies can't use backend services
      that have this configuration.
    localityLbPolicy: The load balancing algorithm used within the scope of
      the locality. The possible values are: - ROUND_ROBIN: This is a simple
      policy in which each healthy backend is selected in round robin order.
      This is the default. - LEAST_REQUEST: An O(1) algorithm which selects
      two random healthy hosts and picks the host which has fewer active
      requests. - RING_HASH: The ring/modulo hash load balancer implements
      consistent hashing to backends. The algorithm has the property that the
      addition/removal of a host from a set of N hosts only affects 1/N of the
      requests. - RANDOM: The load balancer selects a random healthy host. -
      ORIGINAL_DESTINATION: Backend host is selected based on the client
      connection metadata, i.e., connections are opened to the same address as
      the destination address of the incoming connection before the connection
      was redirected to the load balancer. - MAGLEV: used as a drop in
      replacement for the ring hash load balancer. Maglev is not as stable as
      ring hash but has faster table lookup build times and host selection
      times. For more information about Maglev, see
      https://ai.google/research/pubs/pub44824 This field is applicable to
      either: - A regional backend service with the service_protocol set to
      HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to
      INTERNAL_MANAGED. - A global backend service with the
      load_balancing_scheme set to INTERNAL_SELF_MANAGED, INTERNAL_MANAGED, or
      EXTERNAL_MANAGED. If sessionAffinity is not configured-that is, if
      session affinity remains at the default value of NONE-then the default
      value for localityLbPolicy is ROUND_ROBIN. If session affinity is set to
      a value other than NONE, then the default value for localityLbPolicy is
      MAGLEV. Only ROUND_ROBIN and RING_HASH are supported when the backend
      service is referenced by a URL map that is bound to target gRPC proxy
      that has validateForProxyless field set to true.
    logConfig: This field denotes the logging options for the load balancer
      traffic served by this backend service. If logging is enabled, logs will
      be exported to Stackdriver.
    maxStreamDuration: Specifies the default maximum duration (timeout) for
      streams to this service. Duration is computed from the beginning of the
      stream until the response has been completely processed, including all
      retries. A stream that does not complete in this duration is closed. If
      not specified, there will be no timeout limit, i.e. the maximum duration
      is infinite. This value can be overridden in the PathMatcher
      configuration of the UrlMap that references this backend service. This
      field is only allowed when the loadBalancingScheme of the backend
      service is INTERNAL_SELF_MANAGED.
    metadatas: Deployment metadata associated with the resource to be set by a
      GKE hub controller and read by the backend RCTH
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: The URL of the network to which this backend service belongs.
      This field can only be specified when the load balancing scheme is set
      to INTERNAL.
    networkPassThroughLbTrafficPolicy: Configures traffic steering properties
      of internal passthrough Network Load Balancers.
    outlierDetection: Settings controlling the ejection of unhealthy backend
      endpoints from the load balancing pool of each individual proxy instance
      that processes the traffic for the given backend service. If not set,
      this feature is considered disabled. Results of the outlier detection
      algorithm (ejection of endpoints from the load balancing pool and
      returning them back to the pool) are executed independently by each
      proxy instance of the load balancer. In most cases, more than one proxy
      instance handles the traffic received by a backend service. Thus, it is
      possible that an unhealthy endpoint is detected and ejected by only some
      of the proxies, and while this happens, other proxies may continue to
      send requests to the same unhealthy endpoint until they detect and eject
      the unhealthy endpoint. Applicable backend endpoints can be: - VM
      instances in an Instance Group - Endpoints in a Zonal NEG (GCE_VM_IP,
      GCE_VM_IP_PORT) - Endpoints in a Hybrid Connectivity NEG
      (NON_GCP_PRIVATE_IP_PORT) - Serverless NEGs, that resolve to Cloud Run,
      App Engine, or Cloud Functions Services - Private Service Connect NEGs,
      that resolve to Google-managed regional API endpoints or managed
      services published using Private Service Connect Applicable backend
      service types can be: - A global backend service with the
      loadBalancingScheme set to INTERNAL_SELF_MANAGED or EXTERNAL_MANAGED. -
      A regional backend service with the serviceProtocol set to HTTP, HTTPS,
      or HTTP2, and loadBalancingScheme set to INTERNAL_MANAGED or
      EXTERNAL_MANAGED. Not supported for Serverless NEGs. Not supported when
      the backend service is referenced by a URL map that is bound to target
      gRPC proxy that has validateForProxyless field set to true.
    port: Deprecated in favor of portName. The TCP port to connect on the
      backend. The default value is 80. For internal passthrough Network Load
      Balancers and external passthrough Network Load Balancers, omit port.
    portName: A named port on a backend instance group representing the port
      for communication to the backend VMs in that group. The named port must
      be [defined on each backend instance
      group](https://cloud.google.com/load-balancing/docs/backend-
      service#named_ports). This parameter has no meaning if the backends are
      NEGs. For internal passthrough Network Load Balancers and external
      passthrough Network Load Balancers, omit port_name.
    protocol: The protocol this BackendService uses to communicate with
      backends. Possible values are HTTP, HTTPS, HTTP2, TCP, SSL, UDP or GRPC.
      depending on the chosen load balancer or Traffic Director configuration.
      Refer to the documentation for the load balancers or for Traffic
      Director for more information. Must be set to GRPC when the backend
      service is referenced by a URL map that is bound to target gRPC proxy.
    region: [Output Only] URL of the region where the regional backend service
      resides. This field is not applicable to global backend services. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    securityPolicy: [Output Only] The resource URL for the security policy
      associated with this backend service.
    securitySettings: This field specifies the security settings that apply to
      this backend service. This field is applicable to a global backend
      service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serviceBindings: URLs of networkservices.ServiceBinding resources. Can
      only be set if load balancing scheme is INTERNAL_SELF_MANAGED. If set,
      lists of backends and health checks must be both empty.
    serviceLbPolicy: URL to networkservices.ServiceLbPolicy resource. Can only
      be set if load balancing scheme is EXTERNAL, EXTERNAL_MANAGED,
      INTERNAL_MANAGED or INTERNAL_SELF_MANAGED and the scope is global.
    sessionAffinity: Type of session affinity to use. The default is NONE.
      Only NONE and HEADER_FIELD are supported when the backend service is
      referenced by a URL map that is bound to target gRPC proxy that has
      validateForProxyless field set to true. For more details, see: [Session
      Affinity](https://cloud.google.com/load-balancing/docs/backend-
      service#session_affinity).
    strongSessionAffinityCookie: Describes the HTTP cookie used for stateful
      session affinity. This field is applicable and required if the
      sessionAffinity is set to STRONG_COOKIE_AFFINITY.
    subsetting: A Subsetting attribute.
    timeoutSec: The backend service timeout has a different meaning depending
      on the type of load balancer. For more information see, Backend service
      settings. The default is 30 seconds. The full range of timeout values
      allowed goes from 1 through 2,147,483,647 seconds. This value can be
      overridden in the PathMatcher configuration of the UrlMap that
      references this backend service. Not supported when the backend service
      is referenced by a URL map that is bound to target gRPC proxy that has
      validateForProxyless field set to true. Instead, use maxStreamDuration.
    tlsSettings: Configuration for Backend Authenticated TLS and mTLS. May
      only be specified when the backend protocol is SSL, HTTPS or HTTP2.
    usedBy: [Output Only] List of resources referencing given backend service.
    vpcNetworkScope: The network scope of the backends that can be added to
      the backend service. This field can be either GLOBAL_VPC_NETWORK or
      REGIONAL_VPC_NETWORK. A backend service with the VPC scope set to
      GLOBAL_VPC_NETWORK is only allowed to have backends in global VPC
      networks. When the VPC scope is set to REGIONAL_VPC_NETWORK the backend
      service is only allowed to have backends in regional networks in the
      same scope as the backend service. Note: if not specified then
      GLOBAL_VPC_NETWORK will be used.
  """

  class CompressionModeValueValuesEnum(_messages.Enum):
    r"""Compress text responses using Brotli or gzip compression, based on the
    client's Accept-Encoding header.

    Values:
      AUTOMATIC: Automatically uses the best compression based on the Accept-
        Encoding header sent by the client.
      DISABLED: Disables compression. Existing compressed responses cached by
        Cloud CDN will not be served to clients.
    """
    AUTOMATIC = 0
    DISABLED = 1

  class ExternalManagedMigrationStateValueValuesEnum(_messages.Enum):
    r"""Specifies the canary migration state. Possible values are PREPARE,
    TEST_BY_PERCENTAGE, and TEST_ALL_TRAFFIC. To begin the migration from
    EXTERNAL to EXTERNAL_MANAGED, the state must be changed to PREPARE. The
    state must be changed to TEST_ALL_TRAFFIC before the loadBalancingScheme
    can be changed to EXTERNAL_MANAGED. Optionally, the TEST_BY_PERCENTAGE
    state can be used to migrate traffic by percentage using
    externalManagedMigrationTestingPercentage. Rolling back a migration
    requires the states to be set in reverse order. So changing the scheme
    from EXTERNAL_MANAGED to EXTERNAL requires the state to be set to
    TEST_ALL_TRAFFIC at the same time. Optionally, the TEST_BY_PERCENTAGE
    state can be used to migrate some traffic back to EXTERNAL or PREPARE can
    be used to migrate all traffic back to EXTERNAL.

    Values:
      PREPARE: <no description>
      TEST_ALL_TRAFFIC: <no description>
      TEST_BY_PERCENTAGE: <no description>
    """
    PREPARE = 0
    TEST_ALL_TRAFFIC = 1
    TEST_BY_PERCENTAGE = 2

  class IpAddressSelectionPolicyValueValuesEnum(_messages.Enum):
    r"""Specifies a preference for traffic sent from the proxy to the backend
    (or from the client to the backend for proxyless gRPC). The possible
    values are: - IPV4_ONLY: Only send IPv4 traffic to the backends of the
    backend service (Instance Group, Managed Instance Group, Network Endpoint
    Group), regardless of traffic from the client to the proxy. Only IPv4
    health checks are used to check the health of the backends. This is the
    default setting. - PREFER_IPV6: Prioritize the connection to the
    endpoint's IPv6 address over its IPv4 address (provided there is a healthy
    IPv6 address). - IPV6_ONLY: Only send IPv6 traffic to the backends of the
    backend service (Instance Group, Managed Instance Group, Network Endpoint
    Group), regardless of traffic from the client to the proxy. Only IPv6
    health checks are used to check the health of the backends. This field is
    applicable to either: - Advanced global external Application Load Balancer
    (load balancing scheme EXTERNAL_MANAGED), - Regional external Application
    Load Balancer, - Internal proxy Network Load Balancer (load balancing
    scheme INTERNAL_MANAGED), - Regional internal Application Load Balancer
    (load balancing scheme INTERNAL_MANAGED), - Traffic Director with Envoy
    proxies and proxyless gRPC (load balancing scheme INTERNAL_SELF_MANAGED).

    Values:
      IPV4_ONLY: Only send IPv4 traffic to the backends of the Backend Service
        (Instance Group, Managed Instance Group, Network Endpoint Group)
        regardless of traffic from the client to the proxy. Only IPv4 health-
        checks are used to check the health of the backends. This is the
        default setting.
      IPV6_ONLY: Only send IPv6 traffic to the backends of the Backend Service
        (Instance Group, Managed Instance Group, Network Endpoint Group)
        regardless of traffic from the client to the proxy. Only IPv6 health-
        checks are used to check the health of the backends.
      IP_ADDRESS_SELECTION_POLICY_UNSPECIFIED: Unspecified IP address
        selection policy.
      PREFER_IPV6: Prioritize the connection to the endpoints IPv6 address
        over its IPv4 address (provided there is a healthy IPv6 address).
    """
    IPV4_ONLY = 0
    IPV6_ONLY = 1
    IP_ADDRESS_SELECTION_POLICY_UNSPECIFIED = 2
    PREFER_IPV6 = 3

  class LoadBalancingSchemeValueValuesEnum(_messages.Enum):
    r"""Specifies the load balancer type. A backend service created for one
    type of load balancer cannot be used with another. For more information,
    refer to Choosing a load balancer.

    Values:
      EXTERNAL: Signifies that this will be used for classic Application Load
        Balancers, global external proxy Network Load Balancers, or external
        passthrough Network Load Balancers.
      EXTERNAL_MANAGED: Signifies that this will be used for global external
        Application Load Balancers, regional external Application Load
        Balancers, or regional external proxy Network Load Balancers.
      INTERNAL: Signifies that this will be used for internal passthrough
        Network Load Balancers.
      INTERNAL_MANAGED: Signifies that this will be used for internal
        Application Load Balancers.
      INTERNAL_SELF_MANAGED: Signifies that this will be used by Traffic
        Director.
      INVALID_LOAD_BALANCING_SCHEME: <no description>
    """
    EXTERNAL = 0
    EXTERNAL_MANAGED = 1
    INTERNAL = 2
    INTERNAL_MANAGED = 3
    INTERNAL_SELF_MANAGED = 4
    INVALID_LOAD_BALANCING_SCHEME = 5

  class LocalityLbPolicyValueValuesEnum(_messages.Enum):
    r"""The load balancing algorithm used within the scope of the locality.
    The possible values are: - ROUND_ROBIN: This is a simple policy in which
    each healthy backend is selected in round robin order. This is the
    default. - LEAST_REQUEST: An O(1) algorithm which selects two random
    healthy hosts and picks the host which has fewer active requests. -
    RING_HASH: The ring/modulo hash load balancer implements consistent
    hashing to backends. The algorithm has the property that the
    addition/removal of a host from a set of N hosts only affects 1/N of the
    requests. - RANDOM: The load balancer selects a random healthy host. -
    ORIGINAL_DESTINATION: Backend host is selected based on the client
    connection metadata, i.e., connections are opened to the same address as
    the destination address of the incoming connection before the connection
    was redirected to the load balancer. - MAGLEV: used as a drop in
    replacement for the ring hash load balancer. Maglev is not as stable as
    ring hash but has faster table lookup build times and host selection
    times. For more information about Maglev, see
    https://ai.google/research/pubs/pub44824 This field is applicable to
    either: - A regional backend service with the service_protocol set to
    HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to INTERNAL_MANAGED.
    - A global backend service with the load_balancing_scheme set to
    INTERNAL_SELF_MANAGED, INTERNAL_MANAGED, or EXTERNAL_MANAGED. If
    sessionAffinity is not configured-that is, if session affinity remains at
    the default value of NONE-then the default value for localityLbPolicy is
    ROUND_ROBIN. If session affinity is set to a value other than NONE, then
    the default value for localityLbPolicy is MAGLEV. Only ROUND_ROBIN and
    RING_HASH are supported when the backend service is referenced by a URL
    map that is bound to target gRPC proxy that has validateForProxyless field
    set to true.

    Values:
      INVALID_LB_POLICY: <no description>
      LEAST_REQUEST: An O(1) algorithm which selects two random healthy hosts
        and picks the host which has fewer active requests.
      MAGLEV: This algorithm implements consistent hashing to backends. Maglev
        can be used as a drop in replacement for the ring hash load balancer.
        Maglev is not as stable as ring hash but has faster table lookup build
        times and host selection times. For more information about Maglev, see
        https://ai.google/research/pubs/pub44824
      ORIGINAL_DESTINATION: Backend host is selected based on the client
        connection metadata, i.e., connections are opened to the same address
        as the destination address of the incoming connection before the
        connection was redirected to the load balancer.
      RANDOM: The load balancer selects a random healthy host.
      RING_HASH: The ring/modulo hash load balancer implements consistent
        hashing to backends. The algorithm has the property that the
        addition/removal of a host from a set of N hosts only affects 1/N of
        the requests.
      ROUND_ROBIN: This is a simple policy in which each healthy backend is
        selected in round robin order. This is the default.
      WEIGHTED_MAGLEV: Per-instance weighted Load Balancing via health check
        reported weights. If set, the Backend Service must configure a non
        legacy HTTP-based Health Check, and health check replies are expected
        to contain non-standard HTTP response header field X-Load-Balancing-
        Endpoint-Weight to specify the per-instance weights. If set, Load
        Balancing is weighted based on the per-instance weights reported in
        the last processed health check replies, as long as every instance
        either reported a valid weight or had UNAVAILABLE_WEIGHT. Otherwise,
        Load Balancing remains equal-weight. This option is only supported in
        Network Load Balancing.
      WEIGHTED_ROUND_ROBIN: Per-endpoint weighted round-robin Load Balancing
        using weights computed from Backend reported Custom Metrics. If set,
        the Backend Service responses are expected to contain non-standard
        HTTP response header field X-Endpoint-Load-Metrics. The reported
        metrics to use for computing the weights are specified via the
        backends[].customMetrics fields.
    """
    INVALID_LB_POLICY = 0
    LEAST_REQUEST = 1
    MAGLEV = 2
    ORIGINAL_DESTINATION = 3
    RANDOM = 4
    RING_HASH = 5
    ROUND_ROBIN = 6
    WEIGHTED_MAGLEV = 7
    WEIGHTED_ROUND_ROBIN = 8

  class ProtocolValueValuesEnum(_messages.Enum):
    r"""The protocol this BackendService uses to communicate with backends.
    Possible values are HTTP, HTTPS, HTTP2, TCP, SSL, UDP or GRPC. depending
    on the chosen load balancer or Traffic Director configuration. Refer to
    the documentation for the load balancers or for Traffic Director for more
    information. Must be set to GRPC when the backend service is referenced by
    a URL map that is bound to target gRPC proxy.

    Values:
      ALL: ALL includes TCP, UDP, ICMP, ESP, AH and SCTP. Note that this
        should never be used together with target_xx_proxies.
      GRPC: gRPC (available for Traffic Director).
      H2C: HTTP2 over cleartext
      HTTP: <no description>
      HTTP2: HTTP/2 with SSL.
      HTTPS: <no description>
      SSL: TCP proxying with SSL.
      TCP: TCP proxying or TCP pass-through.
      UDP: UDP.
      UNSPECIFIED: If a Backend Service has UNSPECIFIED as its protocol, it
        can be used with any L3/L4 Forwarding Rules.
    """
    ALL = 0
    GRPC = 1
    H2C = 2
    HTTP = 3
    HTTP2 = 4
    HTTPS = 5
    SSL = 6
    TCP = 7
    UDP = 8
    UNSPECIFIED = 9

  class SessionAffinityValueValuesEnum(_messages.Enum):
    r"""Type of session affinity to use. The default is NONE. Only NONE and
    HEADER_FIELD are supported when the backend service is referenced by a URL
    map that is bound to target gRPC proxy that has validateForProxyless field
    set to true. For more details, see: [Session
    Affinity](https://cloud.google.com/load-balancing/docs/backend-
    service#session_affinity).

    Values:
      CLIENT_IP: 2-tuple hash on packet's source and destination IP addresses.
        Connections from the same source IP address to the same destination IP
        address will be served by the same backend VM while that VM remains
        healthy.
      CLIENT_IP_NO_DESTINATION: 1-tuple hash only on packet's source IP
        address. Connections from the same source IP address will be served by
        the same backend VM while that VM remains healthy. This option can
        only be used for Internal TCP/UDP Load Balancing.
      CLIENT_IP_PORT_PROTO: 5-tuple hash on packet's source and destination IP
        addresses, IP protocol, and source and destination ports. Connections
        for the same IP protocol from the same source IP address and port to
        the same destination IP address and port will be served by the same
        backend VM while that VM remains healthy. This option cannot be used
        for HTTP(S) load balancing.
      CLIENT_IP_PROTO: 3-tuple hash on packet's source and destination IP
        addresses, and IP protocol. Connections for the same IP protocol from
        the same source IP address to the same destination IP address will be
        served by the same backend VM while that VM remains healthy. This
        option cannot be used for HTTP(S) load balancing.
      GENERATED_COOKIE: Hash based on a cookie generated by the L7
        loadbalancer. Only valid for HTTP(S) load balancing.
      HEADER_FIELD: The hash is based on a user specified header field.
      HTTP_COOKIE: The hash is based on a user provided cookie.
      NONE: No session affinity. Connections from the same client IP may go to
        any instance in the pool.
      STRONG_COOKIE_AFFINITY: Strong cookie-based affinity. Connections
        bearing the same cookie will be served by the same backend VM while
        that VM remains healthy, as long as the cookie has not expired.
    """
    CLIENT_IP = 0
    CLIENT_IP_NO_DESTINATION = 1
    CLIENT_IP_PORT_PROTO = 2
    CLIENT_IP_PROTO = 3
    GENERATED_COOKIE = 4
    HEADER_FIELD = 5
    HTTP_COOKIE = 6
    NONE = 7
    STRONG_COOKIE_AFFINITY = 8

  class VpcNetworkScopeValueValuesEnum(_messages.Enum):
    r"""The network scope of the backends that can be added to the backend
    service. This field can be either GLOBAL_VPC_NETWORK or
    REGIONAL_VPC_NETWORK. A backend service with the VPC scope set to
    GLOBAL_VPC_NETWORK is only allowed to have backends in global VPC
    networks. When the VPC scope is set to REGIONAL_VPC_NETWORK the backend
    service is only allowed to have backends in regional networks in the same
    scope as the backend service. Note: if not specified then
    GLOBAL_VPC_NETWORK will be used.

    Values:
      GLOBAL_VPC_NETWORK: The backend service can only have backends in global
        VPCs
      REGIONAL_VPC_NETWORK: The backend service can only have backends in
        regional VPCs
    """
    GLOBAL_VPC_NETWORK = 0
    REGIONAL_VPC_NETWORK = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class MetadatasValue(_messages.Message):
    r"""Deployment metadata associated with the resource to be set by a GKE
    hub controller and read by the backend RCTH

    Messages:
      AdditionalProperty: An additional property for a MetadatasValue object.

    Fields:
      additionalProperties: Additional properties of type MetadatasValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a MetadatasValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  affinityCookieTtlSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  backends = _messages.MessageField('Backend', 2, repeated=True)
  cdnPolicy = _messages.MessageField('BackendServiceCdnPolicy', 3)
  circuitBreakers = _messages.MessageField('CircuitBreakers', 4)
  compressionMode = _messages.EnumField('CompressionModeValueValuesEnum', 5)
  connectionDraining = _messages.MessageField('ConnectionDraining', 6)
  connectionTrackingPolicy = _messages.MessageField('BackendServiceConnectionTrackingPolicy', 7)
  consistentHash = _messages.MessageField('ConsistentHashLoadBalancerSettings', 8)
  creationTimestamp = _messages.StringField(9)
  customMetrics = _messages.MessageField('BackendServiceCustomMetric', 10, repeated=True)
  customRequestHeaders = _messages.StringField(11, repeated=True)
  customResponseHeaders = _messages.StringField(12, repeated=True)
  description = _messages.StringField(13)
  dynamicForwarding = _messages.MessageField('BackendServiceDynamicForwarding', 14)
  edgeSecurityPolicy = _messages.StringField(15)
  enableCDN = _messages.BooleanField(16)
  externalManagedMigrationState = _messages.EnumField('ExternalManagedMigrationStateValueValuesEnum', 17)
  externalManagedMigrationTestingPercentage = _messages.FloatField(18, variant=_messages.Variant.FLOAT)
  failoverPolicy = _messages.MessageField('BackendServiceFailoverPolicy', 19)
  fingerprint = _messages.BytesField(20)
  haPolicy = _messages.MessageField('BackendServiceHAPolicy', 21)
  healthChecks = _messages.StringField(22, repeated=True)
  iap = _messages.MessageField('BackendServiceIAP', 23)
  id = _messages.IntegerField(24, variant=_messages.Variant.UINT64)
  ipAddressSelectionPolicy = _messages.EnumField('IpAddressSelectionPolicyValueValuesEnum', 25)
  kind = _messages.StringField(26, default='compute#backendService')
  loadBalancingScheme = _messages.EnumField('LoadBalancingSchemeValueValuesEnum', 27)
  localityLbPolicies = _messages.MessageField('BackendServiceLocalityLoadBalancingPolicyConfig', 28, repeated=True)
  localityLbPolicy = _messages.EnumField('LocalityLbPolicyValueValuesEnum', 29)
  logConfig = _messages.MessageField('BackendServiceLogConfig', 30)
  maxStreamDuration = _messages.MessageField('Duration', 31)
  metadatas = _messages.MessageField('MetadatasValue', 32)
  name = _messages.StringField(33)
  network = _messages.StringField(34)
  networkPassThroughLbTrafficPolicy = _messages.MessageField('BackendServiceNetworkPassThroughLbTrafficPolicy', 35)
  outlierDetection = _messages.MessageField('OutlierDetection', 36)
  port = _messages.IntegerField(37, variant=_messages.Variant.INT32)
  portName = _messages.StringField(38)
  protocol = _messages.EnumField('ProtocolValueValuesEnum', 39)
  region = _messages.StringField(40)
  securityPolicy = _messages.StringField(41)
  securitySettings = _messages.MessageField('SecuritySettings', 42)
  selfLink = _messages.StringField(43)
  selfLinkWithId = _messages.StringField(44)
  serviceBindings = _messages.StringField(45, repeated=True)
  serviceLbPolicy = _messages.StringField(46)
  sessionAffinity = _messages.EnumField('SessionAffinityValueValuesEnum', 47)
  strongSessionAffinityCookie = _messages.MessageField('BackendServiceHttpCookie', 48)
  subsetting = _messages.MessageField('Subsetting', 49)
  timeoutSec = _messages.IntegerField(50, variant=_messages.Variant.INT32)
  tlsSettings = _messages.MessageField('BackendServiceTlsSettings', 51)
  usedBy = _messages.MessageField('BackendServiceUsedBy', 52, repeated=True)
  vpcNetworkScope = _messages.EnumField('VpcNetworkScopeValueValuesEnum', 53)


class BackendServiceAggregatedList(_messages.Message):
  r"""Contains a list of BackendServicesScopedList.

  Messages:
    ItemsValue: A list of BackendServicesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of BackendServicesScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of BackendServicesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        BackendServices.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A BackendServicesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('BackendServicesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#backendServiceAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class BackendServiceCdnPolicy(_messages.Message):
  r"""Message containing Cloud CDN configuration for a backend service.

  Enums:
    CacheModeValueValuesEnum: Specifies the cache setting for all responses
      from this backend. The possible values are: USE_ORIGIN_HEADERS Requires
      the origin to set valid caching headers to cache content. Responses
      without these headers will not be cached at Google's edge, and will
      require a full trip to the origin on every request, potentially
      impacting performance and increasing load on the origin server.
      FORCE_CACHE_ALL Cache all content, ignoring any "private", "no-store" or
      "no-cache" directives in Cache-Control response headers. Warning: this
      may result in Cloud CDN caching private, per-user (user identifiable)
      content. CACHE_ALL_STATIC Automatically cache static content, including
      common image formats, media (video and audio), and web assets
      (JavaScript and CSS). Requests and responses that are marked as
      uncacheable, as well as dynamic content (including HTML), will not be
      cached. If no value is provided for cdnPolicy.cacheMode, it defaults to
      CACHE_ALL_STATIC.

  Fields:
    bypassCacheOnRequestHeaders: Bypass the cache when the specified request
      headers are matched - e.g. Pragma or Authorization headers. Up to 5
      headers can be specified. The cache is bypassed for all
      cdnPolicy.cacheMode settings.
    cacheKeyPolicy: The CacheKeyPolicy for this CdnPolicy.
    cacheMode: Specifies the cache setting for all responses from this
      backend. The possible values are: USE_ORIGIN_HEADERS Requires the origin
      to set valid caching headers to cache content. Responses without these
      headers will not be cached at Google's edge, and will require a full
      trip to the origin on every request, potentially impacting performance
      and increasing load on the origin server. FORCE_CACHE_ALL Cache all
      content, ignoring any "private", "no-store" or "no-cache" directives in
      Cache-Control response headers. Warning: this may result in Cloud CDN
      caching private, per-user (user identifiable) content. CACHE_ALL_STATIC
      Automatically cache static content, including common image formats,
      media (video and audio), and web assets (JavaScript and CSS). Requests
      and responses that are marked as uncacheable, as well as dynamic content
      (including HTML), will not be cached. If no value is provided for
      cdnPolicy.cacheMode, it defaults to CACHE_ALL_STATIC.
    clientTtl: Specifies a separate client (e.g. browser client) maximum TTL.
      This is used to clamp the max-age (or Expires) value sent to the client.
      With FORCE_CACHE_ALL, the lesser of client_ttl and default_ttl is used
      for the response max-age directive, along with a "public" directive. For
      cacheable content in CACHE_ALL_STATIC mode, client_ttl clamps the max-
      age from the origin (if specified), or else sets the response max-age
      directive to the lesser of the client_ttl and default_ttl, and also
      ensures a "public" cache-control directive is present. If a client TTL
      is not specified, a default value (1 hour) will be used. The maximum
      allowed value is 31,622,400s (1 year).
    defaultTtl: Specifies the default TTL for cached content served by this
      origin for responses that do not have an existing valid TTL (max-age or
      s-max-age). Setting a TTL of "0" means "always revalidate". The value of
      defaultTTL cannot be set to a value greater than that of maxTTL, but can
      be equal. When the cacheMode is set to FORCE_CACHE_ALL, the defaultTTL
      will overwrite the TTL set in all responses. The maximum allowed value
      is 31,622,400s (1 year), noting that infrequently accessed objects may
      be evicted from the cache before the defined TTL.
    maxTtl: Specifies the maximum allowed TTL for cached content served by
      this origin. Cache directives that attempt to set a max-age or s-maxage
      higher than this, or an Expires header more than maxTTL seconds in the
      future will be capped at the value of maxTTL, as if it were the value of
      an s-maxage Cache-Control directive. Headers sent to the client will not
      be modified. Setting a TTL of "0" means "always revalidate". The maximum
      allowed value is 31,622,400s (1 year), noting that infrequently accessed
      objects may be evicted from the cache before the defined TTL.
    negativeCaching: Negative caching allows per-status code TTLs to be set,
      in order to apply fine-grained caching for common errors or redirects.
      This can reduce the load on your origin and improve end-user experience
      by reducing response latency. When the cache mode is set to
      CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to
      responses with the specified response code that lack any Cache-Control,
      Expires, or Pragma: no-cache directives. When the cache mode is set to
      FORCE_CACHE_ALL, negative caching applies to all responses with the
      specified response code, and override any caching headers. By default,
      Cloud CDN will apply the following default TTLs to these status codes:
      HTTP 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m HTTP 404
      (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s HTTP
      405 (Method Not Found), 421 (Misdirected Request), 501 (Not
      Implemented): 60s. These defaults can be overridden in
      negative_caching_policy.
    negativeCachingPolicy: Sets a cache TTL for the specified HTTP status
      code. negative_caching must be enabled to configure
      negative_caching_policy. Omitting the policy and leaving
      negative_caching enabled will use Cloud CDN's default cache TTLs. Note
      that when specifying an explicit negative_caching_policy, you should
      take care to specify a cache TTL for all response codes that you wish to
      cache. Cloud CDN will not apply any default negative caching when a
      policy exists.
    requestCoalescing: If true then Cloud CDN will combine multiple concurrent
      cache fill requests into a small number of requests to the origin.
    serveWhileStale: Serve existing content from the cache (if available) when
      revalidating content with the origin, or when an error is encountered
      when refreshing the cache. This setting defines the default "max-stale"
      duration for any cached responses that do not specify a max-stale
      directive. Stale responses that exceed the TTL configured here will not
      be served. The default limit (max-stale) is 86400s (1 day), which will
      allow stale content to be served up to this limit beyond the max-age (or
      s-max-age) of a cached response. The maximum allowed value is 604800 (1
      week). Set this to zero (0) to disable serve-while-stale.
    signedUrlCacheMaxAgeSec: Maximum number of seconds the response to a
      signed URL request will be considered fresh. After this time period, the
      response will be revalidated before being served. Defaults to 1hr
      (3600s). When serving responses to signed URL requests, Cloud CDN will
      internally behave as though all responses from this backend had a
      "Cache-Control: public, max-age=[TTL]" header, regardless of any
      existing Cache-Control header. The actual headers served in responses
      will not be altered.
    signedUrlKeyNames: [Output Only] Names of the keys for signing request
      URLs.
  """

  class CacheModeValueValuesEnum(_messages.Enum):
    r"""Specifies the cache setting for all responses from this backend. The
    possible values are: USE_ORIGIN_HEADERS Requires the origin to set valid
    caching headers to cache content. Responses without these headers will not
    be cached at Google's edge, and will require a full trip to the origin on
    every request, potentially impacting performance and increasing load on
    the origin server. FORCE_CACHE_ALL Cache all content, ignoring any
    "private", "no-store" or "no-cache" directives in Cache-Control response
    headers. Warning: this may result in Cloud CDN caching private, per-user
    (user identifiable) content. CACHE_ALL_STATIC Automatically cache static
    content, including common image formats, media (video and audio), and web
    assets (JavaScript and CSS). Requests and responses that are marked as
    uncacheable, as well as dynamic content (including HTML), will not be
    cached. If no value is provided for cdnPolicy.cacheMode, it defaults to
    CACHE_ALL_STATIC.

    Values:
      CACHE_ALL_STATIC: Automatically cache static content, including common
        image formats, media (video and audio), and web assets (JavaScript and
        CSS). Requests and responses that are marked as uncacheable, as well
        as dynamic content (including HTML), will not be cached.
      FORCE_CACHE_ALL: Cache all content, ignoring any "private", "no-store"
        or "no-cache" directives in Cache-Control response headers. Warning:
        this may result in Cloud CDN caching private, per-user (user
        identifiable) content.
      INVALID_CACHE_MODE: <no description>
      USE_ORIGIN_HEADERS: Requires the origin to set valid caching headers to
        cache content. Responses without these headers will not be cached at
        Google's edge, and will require a full trip to the origin on every
        request, potentially impacting performance and increasing load on the
        origin server.
    """
    CACHE_ALL_STATIC = 0
    FORCE_CACHE_ALL = 1
    INVALID_CACHE_MODE = 2
    USE_ORIGIN_HEADERS = 3

  bypassCacheOnRequestHeaders = _messages.MessageField('BackendServiceCdnPolicyBypassCacheOnRequestHeader', 1, repeated=True)
  cacheKeyPolicy = _messages.MessageField('CacheKeyPolicy', 2)
  cacheMode = _messages.EnumField('CacheModeValueValuesEnum', 3)
  clientTtl = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  defaultTtl = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  maxTtl = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  negativeCaching = _messages.BooleanField(7)
  negativeCachingPolicy = _messages.MessageField('BackendServiceCdnPolicyNegativeCachingPolicy', 8, repeated=True)
  requestCoalescing = _messages.BooleanField(9)
  serveWhileStale = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  signedUrlCacheMaxAgeSec = _messages.IntegerField(11)
  signedUrlKeyNames = _messages.StringField(12, repeated=True)


class BackendServiceCdnPolicyBypassCacheOnRequestHeader(_messages.Message):
  r"""Bypass the cache when the specified request headers are present, e.g.
  Pragma or Authorization headers. Values are case insensitive. The presence
  of such a header overrides the cache_mode setting.

  Fields:
    headerName: The header field name to match on when bypassing cache. Values
      are case-insensitive.
  """

  headerName = _messages.StringField(1)


class BackendServiceCdnPolicyNegativeCachingPolicy(_messages.Message):
  r"""Specify CDN TTLs for response error codes.

  Fields:
    code: The HTTP status code to define a TTL against. Only HTTP status codes
      300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 are can be
      specified as values, and you cannot specify a status code more than
      once.
    ttl: The TTL (in seconds) for which to cache responses with the
      corresponding status code. The maximum allowed value is 1800s (30
      minutes), noting that infrequently accessed objects may be evicted from
      the cache before the defined TTL.
  """

  code = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  ttl = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class BackendServiceConnectionTrackingPolicy(_messages.Message):
  r"""Connection Tracking configuration for this BackendService.

  Enums:
    ConnectionPersistenceOnUnhealthyBackendsValueValuesEnum: Specifies
      connection persistence when backends are unhealthy. The default value is
      DEFAULT_FOR_PROTOCOL. If set to DEFAULT_FOR_PROTOCOL, the existing
      connections persist on unhealthy backends only for connection-oriented
      protocols (TCP and SCTP) and only if the Tracking Mode is PER_CONNECTION
      (default tracking mode) or the Session Affinity is configured for
      5-tuple. They do not persist for UDP. If set to NEVER_PERSIST, after a
      backend becomes unhealthy, the existing connections on the unhealthy
      backend are never persisted on the unhealthy backend. They are always
      diverted to newly selected healthy backends (unless all backends are
      unhealthy). If set to ALWAYS_PERSIST, existing connections always
      persist on unhealthy backends regardless of protocol and session
      affinity. It is generally not recommended to use this mode overriding
      the default. For more details, see [Connection Persistence for Network
      Load Balancing](https://cloud.google.com/load-
      balancing/docs/network/networklb-backend-service#connection-persistence)
      and [Connection Persistence for Internal TCP/UDP Load
      Balancing](https://cloud.google.com/load-
      balancing/docs/internal#connection-persistence).
    TrackingModeValueValuesEnum: Specifies the key used for connection
      tracking. There are two options: - PER_CONNECTION: This is the default
      mode. The Connection Tracking is performed as per the Connection Key
      (default Hash Method) for the specific protocol. - PER_SESSION: The
      Connection Tracking is performed as per the configured Session Affinity.
      It matches the configured Session Affinity. For more details, see
      [Tracking Mode for Network Load
      Balancing](https://cloud.google.com/load-
      balancing/docs/network/networklb-backend-service#tracking-mode) and
      [Tracking Mode for Internal TCP/UDP Load
      Balancing](https://cloud.google.com/load-
      balancing/docs/internal#tracking-mode).

  Fields:
    connectionPersistenceOnUnhealthyBackends: Specifies connection persistence
      when backends are unhealthy. The default value is DEFAULT_FOR_PROTOCOL.
      If set to DEFAULT_FOR_PROTOCOL, the existing connections persist on
      unhealthy backends only for connection-oriented protocols (TCP and SCTP)
      and only if the Tracking Mode is PER_CONNECTION (default tracking mode)
      or the Session Affinity is configured for 5-tuple. They do not persist
      for UDP. If set to NEVER_PERSIST, after a backend becomes unhealthy, the
      existing connections on the unhealthy backend are never persisted on the
      unhealthy backend. They are always diverted to newly selected healthy
      backends (unless all backends are unhealthy). If set to ALWAYS_PERSIST,
      existing connections always persist on unhealthy backends regardless of
      protocol and session affinity. It is generally not recommended to use
      this mode overriding the default. For more details, see [Connection
      Persistence for Network Load Balancing](https://cloud.google.com/load-
      balancing/docs/network/networklb-backend-service#connection-persistence)
      and [Connection Persistence for Internal TCP/UDP Load
      Balancing](https://cloud.google.com/load-
      balancing/docs/internal#connection-persistence).
    enableStrongAffinity: Enable Strong Session Affinity for external
      passthrough Network Load Balancers. This option is not available
      publicly.
    idleTimeoutSec: Specifies how long to keep a Connection Tracking entry
      while there is no matching traffic (in seconds). For internal
      passthrough Network Load Balancers: - The minimum (default) is 10
      minutes and the maximum is 16 hours. - It can be set only if Connection
      Tracking is less than 5-tuple (i.e. Session Affinity is
      CLIENT_IP_NO_DESTINATION, CLIENT_IP or CLIENT_IP_PROTO, and Tracking
      Mode is PER_SESSION). For external passthrough Network Load Balancers
      the default is 60 seconds. This option is not available publicly.
    trackingMode: Specifies the key used for connection tracking. There are
      two options: - PER_CONNECTION: This is the default mode. The Connection
      Tracking is performed as per the Connection Key (default Hash Method)
      for the specific protocol. - PER_SESSION: The Connection Tracking is
      performed as per the configured Session Affinity. It matches the
      configured Session Affinity. For more details, see [Tracking Mode for
      Network Load Balancing](https://cloud.google.com/load-
      balancing/docs/network/networklb-backend-service#tracking-mode) and
      [Tracking Mode for Internal TCP/UDP Load
      Balancing](https://cloud.google.com/load-
      balancing/docs/internal#tracking-mode).
  """

  class ConnectionPersistenceOnUnhealthyBackendsValueValuesEnum(_messages.Enum):
    r"""Specifies connection persistence when backends are unhealthy. The
    default value is DEFAULT_FOR_PROTOCOL. If set to DEFAULT_FOR_PROTOCOL, the
    existing connections persist on unhealthy backends only for connection-
    oriented protocols (TCP and SCTP) and only if the Tracking Mode is
    PER_CONNECTION (default tracking mode) or the Session Affinity is
    configured for 5-tuple. They do not persist for UDP. If set to
    NEVER_PERSIST, after a backend becomes unhealthy, the existing connections
    on the unhealthy backend are never persisted on the unhealthy backend.
    They are always diverted to newly selected healthy backends (unless all
    backends are unhealthy). If set to ALWAYS_PERSIST, existing connections
    always persist on unhealthy backends regardless of protocol and session
    affinity. It is generally not recommended to use this mode overriding the
    default. For more details, see [Connection Persistence for Network Load
    Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-
    backend-service#connection-persistence) and [Connection Persistence for
    Internal TCP/UDP Load Balancing](https://cloud.google.com/load-
    balancing/docs/internal#connection-persistence).

    Values:
      ALWAYS_PERSIST: <no description>
      DEFAULT_FOR_PROTOCOL: <no description>
      NEVER_PERSIST: <no description>
    """
    ALWAYS_PERSIST = 0
    DEFAULT_FOR_PROTOCOL = 1
    NEVER_PERSIST = 2

  class TrackingModeValueValuesEnum(_messages.Enum):
    r"""Specifies the key used for connection tracking. There are two options:
    - PER_CONNECTION: This is the default mode. The Connection Tracking is
    performed as per the Connection Key (default Hash Method) for the specific
    protocol. - PER_SESSION: The Connection Tracking is performed as per the
    configured Session Affinity. It matches the configured Session Affinity.
    For more details, see [Tracking Mode for Network Load
    Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-
    backend-service#tracking-mode) and [Tracking Mode for Internal TCP/UDP
    Load Balancing](https://cloud.google.com/load-
    balancing/docs/internal#tracking-mode).

    Values:
      INVALID_TRACKING_MODE: <no description>
      PER_CONNECTION: <no description>
      PER_SESSION: <no description>
    """
    INVALID_TRACKING_MODE = 0
    PER_CONNECTION = 1
    PER_SESSION = 2

  connectionPersistenceOnUnhealthyBackends = _messages.EnumField('ConnectionPersistenceOnUnhealthyBackendsValueValuesEnum', 1)
  enableStrongAffinity = _messages.BooleanField(2)
  idleTimeoutSec = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  trackingMode = _messages.EnumField('TrackingModeValueValuesEnum', 4)


class BackendServiceCustomMetric(_messages.Message):
  r"""Custom Metrics are used for WEIGHTED_ROUND_ROBIN locality_lb_policy.

  Fields:
    dryRun: If true, the metric data is not used for load balancing.
    name: Name of a custom utilization signal. The name must be 1-64
      characters long and match the regular expression
      [a-z]([-_.a-z0-9]*[a-z0-9])? which means the first character must be a
      lowercase letter, and all following characters must be a dash, period,
      underscore, lowercase letter, or digit, except the last character, which
      cannot be a dash, period, or underscore. For usage guidelines, see
      Custom Metrics balancing mode. This field can only be used for a global
      or regional backend service with the loadBalancingScheme set to
      EXTERNAL_MANAGED, INTERNAL_MANAGED INTERNAL_SELF_MANAGED.
  """

  dryRun = _messages.BooleanField(1)
  name = _messages.StringField(2)


class BackendServiceDynamicForwarding(_messages.Message):
  r"""Defines a dynamic forwarding configuration for the backend service.

  Fields:
    ipPortSelection: IP:PORT based dynamic forwarding configuration.
  """

  ipPortSelection = _messages.MessageField('BackendServiceDynamicForwardingIpPortSelection', 1)


class BackendServiceDynamicForwardingIpPortSelection(_messages.Message):
  r"""Defines a IP:PORT based dynamic forwarding configuration for the backend
  service. Some ranges are restricted: Restricted ranges.

  Fields:
    enabled: A boolean flag enabling IP:PORT based dynamic forwarding.
  """

  enabled = _messages.BooleanField(1)


class BackendServiceFailoverPolicy(_messages.Message):
  r"""For load balancers that have configurable failover: [Internal
  passthrough Network Load Balancers](https://cloud.google.com/load-
  balancing/docs/internal/failover-overview) and [external passthrough Network
  Load Balancers](https://cloud.google.com/load-
  balancing/docs/network/networklb-failover-overview). On failover or
  failback, this field indicates whether connection draining will be honored.
  Google Cloud has a fixed connection draining timeout of 10 minutes. A
  setting of true terminates existing TCP connections to the active pool
  during failover and failback, immediately draining traffic. A setting of
  false allows existing TCP connections to persist, even on VMs no longer in
  the active pool, for up to the duration of the connection draining timeout
  (10 minutes).

  Fields:
    disableConnectionDrainOnFailover: This can be set to true only if the
      protocol is TCP. The default is false.
    dropTrafficIfUnhealthy: If set to true, connections to the load balancer
      are dropped when all primary and all backup backend VMs are unhealthy.If
      set to false, connections are distributed among all primary VMs when all
      primary and all backup backend VMs are unhealthy. For load balancers
      that have configurable failover: [Internal passthrough Network Load
      Balancers](https://cloud.google.com/load-
      balancing/docs/internal/failover-overview) and [external passthrough
      Network Load Balancers](https://cloud.google.com/load-
      balancing/docs/network/networklb-failover-overview). The default is
      false.
    failoverRatio: The value of the field must be in the range [0, 1]. If the
      value is 0, the load balancer performs a failover when the number of
      healthy primary VMs equals zero. For all other values, the load balancer
      performs a failover when the total number of healthy primary VMs is less
      than this ratio. For load balancers that have configurable failover:
      [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-
      balancing/docs/internal/failover-overview) and [external TCP/UDP Load
      Balancing](https://cloud.google.com/load-
      balancing/docs/network/networklb-failover-overview).
  """

  disableConnectionDrainOnFailover = _messages.BooleanField(1)
  dropTrafficIfUnhealthy = _messages.BooleanField(2)
  failoverRatio = _messages.FloatField(3, variant=_messages.Variant.FLOAT)


class BackendServiceGroupHealth(_messages.Message):
  r"""A BackendServiceGroupHealth object.

  Messages:
    AnnotationsValue: Metadata defined as annotations on the network endpoint
      group.

  Fields:
    annotations: Metadata defined as annotations on the network endpoint
      group.
    healthStatus: Health state of the backend instances or endpoints in
      requested instance or network endpoint group, determined based on
      configured health checks.
    kind: [Output Only] Type of resource. Always
      compute#backendServiceGroupHealth for the health of backend services.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Metadata defined as annotations on the network endpoint group.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  healthStatus = _messages.MessageField('HealthStatus', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#backendServiceGroupHealth')


class BackendServiceHAPolicy(_messages.Message):
  r"""A BackendServiceHAPolicy object.

  Enums:
    FastIPMoveValueValuesEnum: Enabling fastIPMove is not supported.

  Fields:
    fastIPMove: Enabling fastIPMove is not supported.
    leader: Setting a leader is not supported.
  """

  class FastIPMoveValueValuesEnum(_messages.Enum):
    r"""Enabling fastIPMove is not supported.

    Values:
      DISABLED: <no description>
      GARP_RA: <no description>
    """
    DISABLED = 0
    GARP_RA = 1

  fastIPMove = _messages.EnumField('FastIPMoveValueValuesEnum', 1)
  leader = _messages.MessageField('BackendServiceHAPolicyLeader', 2)


class BackendServiceHAPolicyLeader(_messages.Message):
  r"""A BackendServiceHAPolicyLeader object.

  Fields:
    backendGroup: Setting backendGroup is not supported.
    networkEndpoint: Setting a network endpoint as leader is not supported.
  """

  backendGroup = _messages.StringField(1)
  networkEndpoint = _messages.MessageField('BackendServiceHAPolicyLeaderNetworkEndpoint', 2)


class BackendServiceHAPolicyLeaderNetworkEndpoint(_messages.Message):
  r"""A BackendServiceHAPolicyLeaderNetworkEndpoint object.

  Fields:
    instance: Specifying the instance name of a leader is not supported.
  """

  instance = _messages.StringField(1)


class BackendServiceHttpCookie(_messages.Message):
  r"""The HTTP cookie used for stateful session affinity.

  Fields:
    name: Name of the cookie.
    path: Path to set for the cookie.
    ttl: Lifetime of the cookie.
  """

  name = _messages.StringField(1)
  path = _messages.StringField(2)
  ttl = _messages.MessageField('Duration', 3)


class BackendServiceIAP(_messages.Message):
  r"""Identity-Aware Proxy

  Fields:
    enabled: Whether the serving infrastructure will authenticate and
      authorize all incoming requests.
    oauth2ClientId: OAuth2 client ID to use for the authentication flow.
    oauth2ClientInfo: [Input Only] OAuth client info required to generate
      client id to be used for IAP.
    oauth2ClientSecret: OAuth2 client secret to use for the authentication
      flow. For security reasons, this value cannot be retrieved via the API.
      Instead, the SHA-256 hash of the value is returned in the
      oauth2ClientSecretSha256 field. @InputOnly
    oauth2ClientSecretSha256: [Output Only] SHA256 hash value for the field
      oauth2_client_secret above.
  """

  enabled = _messages.BooleanField(1)
  oauth2ClientId = _messages.StringField(2)
  oauth2ClientInfo = _messages.MessageField('BackendServiceIAPOAuth2ClientInfo', 3)
  oauth2ClientSecret = _messages.StringField(4)
  oauth2ClientSecretSha256 = _messages.StringField(5)


class BackendServiceIAPOAuth2ClientInfo(_messages.Message):
  r"""A BackendServiceIAPOAuth2ClientInfo object.

  Fields:
    applicationName: Application name to be used in OAuth consent screen.
    clientName: Name of the client to be generated. Optional - If not
      provided, the name will be autogenerated by the backend.
    developerEmailAddress: Developer's information to be used in OAuth consent
      screen.
  """

  applicationName = _messages.StringField(1)
  clientName = _messages.StringField(2)
  developerEmailAddress = _messages.StringField(3)


class BackendServiceList(_messages.Message):
  r"""Contains a list of BackendService resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of BackendService resources.
    kind: [Output Only] Type of resource. Always compute#backendServiceList
      for lists of backend services.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('BackendService', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#backendServiceList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class BackendServiceListUsable(_messages.Message):
  r"""Contains a list of usable BackendService resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of BackendService resources.
    kind: [Output Only] Type of resource. Always
      compute#usableBackendServiceList for lists of usable backend services.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('BackendService', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#usableBackendServiceList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class BackendServiceLocalityLoadBalancingPolicyConfig(_messages.Message):
  r"""Container for either a built-in LB policy supported by gRPC or Envoy or
  a custom one implemented by the end user.

  Fields:
    customPolicy: A
      BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy attribute.
    policy: A BackendServiceLocalityLoadBalancingPolicyConfigPolicy attribute.
  """

  customPolicy = _messages.MessageField('BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy', 1)
  policy = _messages.MessageField('BackendServiceLocalityLoadBalancingPolicyConfigPolicy', 2)


class BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy(_messages.Message):
  r"""The configuration for a custom policy implemented by the user and
  deployed with the client.

  Fields:
    data: An optional, arbitrary JSON object with configuration data,
      understood by a locally installed custom policy implementation.
    name: Identifies the custom policy. The value should match the name of a
      custom implementation registered on the gRPC clients. It should follow
      protocol buffer message naming conventions and include the full path
      (for example, myorg.CustomLbPolicy). The maximum length is 256
      characters. Do not specify the same custom policy more than once for a
      backend. If you do, the configuration is rejected. For an example of how
      to use this field, see Use a custom policy.
  """

  data = _messages.StringField(1)
  name = _messages.StringField(2)


class BackendServiceLocalityLoadBalancingPolicyConfigPolicy(_messages.Message):
  r"""The configuration for a built-in load balancing policy.

  Enums:
    NameValueValuesEnum: The name of a locality load-balancing policy. Valid
      values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For
      information about these values, see the description of localityLbPolicy.
      Do not specify the same policy more than once for a backend. If you do,
      the configuration is rejected.

  Fields:
    name: The name of a locality load-balancing policy. Valid values include
      ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about
      these values, see the description of localityLbPolicy. Do not specify
      the same policy more than once for a backend. If you do, the
      configuration is rejected.
  """

  class NameValueValuesEnum(_messages.Enum):
    r"""The name of a locality load-balancing policy. Valid values include
    ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about
    these values, see the description of localityLbPolicy. Do not specify the
    same policy more than once for a backend. If you do, the configuration is
    rejected.

    Values:
      INVALID_LB_POLICY: <no description>
      LEAST_REQUEST: An O(1) algorithm which selects two random healthy hosts
        and picks the host which has fewer active requests.
      MAGLEV: This algorithm implements consistent hashing to backends. Maglev
        can be used as a drop in replacement for the ring hash load balancer.
        Maglev is not as stable as ring hash but has faster table lookup build
        times and host selection times. For more information about Maglev, see
        https://ai.google/research/pubs/pub44824
      ORIGINAL_DESTINATION: Backend host is selected based on the client
        connection metadata, i.e., connections are opened to the same address
        as the destination address of the incoming connection before the
        connection was redirected to the load balancer.
      RANDOM: The load balancer selects a random healthy host.
      RING_HASH: The ring/modulo hash load balancer implements consistent
        hashing to backends. The algorithm has the property that the
        addition/removal of a host from a set of N hosts only affects 1/N of
        the requests.
      ROUND_ROBIN: This is a simple policy in which each healthy backend is
        selected in round robin order. This is the default.
      WEIGHTED_MAGLEV: Per-instance weighted Load Balancing via health check
        reported weights. If set, the Backend Service must configure a non
        legacy HTTP-based Health Check, and health check replies are expected
        to contain non-standard HTTP response header field X-Load-Balancing-
        Endpoint-Weight to specify the per-instance weights. If set, Load
        Balancing is weighted based on the per-instance weights reported in
        the last processed health check replies, as long as every instance
        either reported a valid weight or had UNAVAILABLE_WEIGHT. Otherwise,
        Load Balancing remains equal-weight. This option is only supported in
        Network Load Balancing.
      WEIGHTED_ROUND_ROBIN: Per-endpoint weighted round-robin Load Balancing
        using weights computed from Backend reported Custom Metrics. If set,
        the Backend Service responses are expected to contain non-standard
        HTTP response header field X-Endpoint-Load-Metrics. The reported
        metrics to use for computing the weights are specified via the
        backends[].customMetrics fields.
    """
    INVALID_LB_POLICY = 0
    LEAST_REQUEST = 1
    MAGLEV = 2
    ORIGINAL_DESTINATION = 3
    RANDOM = 4
    RING_HASH = 5
    ROUND_ROBIN = 6
    WEIGHTED_MAGLEV = 7
    WEIGHTED_ROUND_ROBIN = 8

  name = _messages.EnumField('NameValueValuesEnum', 1)


class BackendServiceLogConfig(_messages.Message):
  r"""The available logging options for the load balancer traffic served by
  this backend service.

  Enums:
    OptionalValueValuesEnum: Deprecated in favor of optionalMode. This field
      can only be specified if logging is enabled for this backend service.
      Configures whether all, none or a subset of optional fields should be
      added to the reported logs. One of [INCLUDE_ALL_OPTIONAL,
      EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.
    OptionalModeValueValuesEnum: This field can only be specified if logging
      is enabled for this backend service. Configures whether all, none or a
      subset of optional fields should be added to the reported logs. One of
      [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is
      EXCLUDE_ALL_OPTIONAL.

  Fields:
    enable: Denotes whether to enable logging for the load balancer traffic
      served by this backend service. The default value is false.
    optional: Deprecated in favor of optionalMode. This field can only be
      specified if logging is enabled for this backend service. Configures
      whether all, none or a subset of optional fields should be added to the
      reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL,
      CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.
    optionalFields: This field can only be specified if logging is enabled for
      this backend service and "logConfig.optionalMode" was set to CUSTOM.
      Contains a list of optional fields you want to include in the logs. For
      example: serverInstance, serverGkeDetails.cluster,
      serverGkeDetails.pod.podNamespace
    optionalMode: This field can only be specified if logging is enabled for
      this backend service. Configures whether all, none or a subset of
      optional fields should be added to the reported logs. One of
      [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is
      EXCLUDE_ALL_OPTIONAL.
    sampleRate: This field can only be specified if logging is enabled for
      this backend service. The value of the field must be in [0, 1]. This
      configures the sampling rate of requests to the load balancer where 1.0
      means all logged requests are reported and 0.0 means no logged requests
      are reported. The default value is 1.0.
  """

  class OptionalModeValueValuesEnum(_messages.Enum):
    r"""This field can only be specified if logging is enabled for this
    backend service. Configures whether all, none or a subset of optional
    fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL,
    EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.

    Values:
      CUSTOM: A subset of optional fields.
      EXCLUDE_ALL_OPTIONAL: None optional fields.
      INCLUDE_ALL_OPTIONAL: All optional fields.
      UNSPECIFIED_OPTIONAL_MODE: <no description>
    """
    CUSTOM = 0
    EXCLUDE_ALL_OPTIONAL = 1
    INCLUDE_ALL_OPTIONAL = 2
    UNSPECIFIED_OPTIONAL_MODE = 3

  class OptionalValueValuesEnum(_messages.Enum):
    r"""Deprecated in favor of optionalMode. This field can only be specified
    if logging is enabled for this backend service. Configures whether all,
    none or a subset of optional fields should be added to the reported logs.
    One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is
    EXCLUDE_ALL_OPTIONAL.

    Values:
      CUSTOM: A subset of optional fields.
      EXCLUDE_ALL_OPTIONAL: None optional fields.
      INCLUDE_ALL_OPTIONAL: All optional fields.
      UNSPECIFIED_OPTIONAL_MODE: <no description>
    """
    CUSTOM = 0
    EXCLUDE_ALL_OPTIONAL = 1
    INCLUDE_ALL_OPTIONAL = 2
    UNSPECIFIED_OPTIONAL_MODE = 3

  enable = _messages.BooleanField(1)
  optional = _messages.EnumField('OptionalValueValuesEnum', 2)
  optionalFields = _messages.StringField(3, repeated=True)
  optionalMode = _messages.EnumField('OptionalModeValueValuesEnum', 4)
  sampleRate = _messages.FloatField(5, variant=_messages.Variant.FLOAT)


class BackendServiceNetworkPassThroughLbTrafficPolicy(_messages.Message):
  r"""A BackendServiceNetworkPassThroughLbTrafficPolicy object.

  Fields:
    zonalAffinity: When configured, new connections are load balanced across
      healthy backend endpoints in the local zone.
  """

  zonalAffinity = _messages.MessageField('BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity', 1)


class BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity(_messages.Message):
  r"""A BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity object.

  Enums:
    SpilloverValueValuesEnum: This field indicates whether zonal affinity is
      enabled or not. The possible values are: - ZONAL_AFFINITY_DISABLED:
      Default Value. Zonal Affinity is disabled. The load balancer distributes
      new connections to all healthy backend endpoints across all zones. -
      ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load
      balancer distributes new connections to all healthy backend endpoints in
      the local zone only. If there are no healthy backend endpoints in the
      local zone, the load balancer distributes new connections to all backend
      endpoints in the local zone. - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal
      Affinity is enabled. The load balancer distributes new connections to
      all healthy backend endpoints in the local zone only. If there aren't
      enough healthy backend endpoints in the local zone, the load balancer
      distributes new connections to all healthy backend endpoints across all
      zones.

  Fields:
    spillover: This field indicates whether zonal affinity is enabled or not.
      The possible values are: - ZONAL_AFFINITY_DISABLED: Default Value. Zonal
      Affinity is disabled. The load balancer distributes new connections to
      all healthy backend endpoints across all zones. -
      ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load
      balancer distributes new connections to all healthy backend endpoints in
      the local zone only. If there are no healthy backend endpoints in the
      local zone, the load balancer distributes new connections to all backend
      endpoints in the local zone. - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal
      Affinity is enabled. The load balancer distributes new connections to
      all healthy backend endpoints in the local zone only. If there aren't
      enough healthy backend endpoints in the local zone, the load balancer
      distributes new connections to all healthy backend endpoints across all
      zones.
    spilloverRatio: The value of the field must be in [0, 1]. When the ratio
      of the count of healthy backend endpoints in a zone to the count of
      backend endpoints in that same zone is equal to or above this threshold,
      the load balancer distributes new connections to all healthy endpoints
      in the local zone only. When the ratio of the count of healthy backend
      endpoints in a zone to the count of backend endpoints in that same zone
      is below this threshold, the load balancer distributes all new
      connections to all healthy endpoints across all zones.
  """

  class SpilloverValueValuesEnum(_messages.Enum):
    r"""This field indicates whether zonal affinity is enabled or not. The
    possible values are: - ZONAL_AFFINITY_DISABLED: Default Value. Zonal
    Affinity is disabled. The load balancer distributes new connections to all
    healthy backend endpoints across all zones. -
    ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load
    balancer distributes new connections to all healthy backend endpoints in
    the local zone only. If there are no healthy backend endpoints in the
    local zone, the load balancer distributes new connections to all backend
    endpoints in the local zone. - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal
    Affinity is enabled. The load balancer distributes new connections to all
    healthy backend endpoints in the local zone only. If there aren't enough
    healthy backend endpoints in the local zone, the load balancer distributes
    new connections to all healthy backend endpoints across all zones.

    Values:
      ZONAL_AFFINITY_DISABLED: <no description>
      ZONAL_AFFINITY_SPILL_CROSS_ZONE: <no description>
      ZONAL_AFFINITY_STAY_WITHIN_ZONE: <no description>
    """
    ZONAL_AFFINITY_DISABLED = 0
    ZONAL_AFFINITY_SPILL_CROSS_ZONE = 1
    ZONAL_AFFINITY_STAY_WITHIN_ZONE = 2

  spillover = _messages.EnumField('SpilloverValueValuesEnum', 1)
  spilloverRatio = _messages.FloatField(2, variant=_messages.Variant.FLOAT)


class BackendServiceReference(_messages.Message):
  r"""A BackendServiceReference object.

  Fields:
    backendService: A string attribute.
  """

  backendService = _messages.StringField(1)


class BackendServiceTlsSettings(_messages.Message):
  r"""A BackendServiceTlsSettings object.

  Fields:
    authenticationConfig: Reference to the BackendAuthenticationConfig
      resource from the networksecurity.googleapis.com namespace. Can be used
      in authenticating TLS connections to the backend, as specified by the
      authenticationMode field. Can only be specified if authenticationMode is
      not NONE.
    sni: Server Name Indication - see RFC3546 section 3.1. If set, the load
      balancer sends this string as the SNI hostname in the TLS connection to
      the backend, and requires that this string match a Subject Alternative
      Name (SAN) in the backend's server certificate. With a Regional Internet
      NEG backend, if the SNI is specified here, the load balancer uses it
      regardless of whether the Regional Internet NEG is specified with FQDN
      or IP address and port. When both sni and subjectAltNames[] are
      specified, the load balancer matches the backend certificate's SAN only
      to subjectAltNames[].
    subjectAltNames: A list of Subject Alternative Names (SANs) that the Load
      Balancer verifies during a TLS handshake with the backend. When the
      server presents its X.509 certificate to the Load Balancer, the Load
      Balancer inspects the certificate's SAN field, and requires that at
      least one SAN match one of the subjectAltNames in the list. This field
      is limited to 5 entries. When both sni and subjectAltNames[] are
      specified, the load balancer matches the backend certificate's SAN only
      to subjectAltNames[].
  """

  authenticationConfig = _messages.StringField(1)
  sni = _messages.StringField(2)
  subjectAltNames = _messages.MessageField('BackendServiceTlsSettingsSubjectAltName', 3, repeated=True)


class BackendServiceTlsSettingsSubjectAltName(_messages.Message):
  r"""A Subject Alternative Name that the load balancer matches against the
  SAN field in the TLS certificate provided by the backend, specified as
  either a DNS name or a URI, in accordance with RFC 5280 4.2.1.6

  Fields:
    dnsName: The SAN specified as a DNS Name.
    uniformResourceIdentifier: The SAN specified as a URI.
  """

  dnsName = _messages.StringField(1)
  uniformResourceIdentifier = _messages.StringField(2)


class BackendServiceUsedBy(_messages.Message):
  r"""A BackendServiceUsedBy object.

  Fields:
    reference: [Output Only] Server-defined URL for resources referencing
      given BackendService like UrlMaps, TargetTcpProxies, TargetSslProxies
      and ForwardingRule.
  """

  reference = _messages.StringField(1)


class BackendServicesGetEffectiveSecurityPoliciesResponse(_messages.Message):
  r"""A BackendServicesGetEffectiveSecurityPoliciesResponse object.

  Fields:
    securityPolicies: Effective security policies for the backend service.
  """

  securityPolicies = _messages.MessageField('SecurityPolicy', 1, repeated=True)


class BackendServicesScopedList(_messages.Message):
  r"""A BackendServicesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    backendServices: A list of BackendServices contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  backendServices = _messages.MessageField('BackendService', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class BfdPacket(_messages.Message):
  r"""A BfdPacket object.

  Enums:
    DiagnosticValueValuesEnum: The diagnostic code specifies the local
      system's reason for the last change in session state. This allows remote
      systems to determine the reason that the previous session failed, for
      example. These diagnostic codes are specified in section 4.1 of RFC5880
    StateValueValuesEnum: The current BFD session state as seen by the
      transmitting system. These states are specified in section 4.1 of
      RFC5880

  Fields:
    authenticationPresent: The Authentication Present bit of the BFD packet.
      This is specified in section 4.1 of RFC5880
    controlPlaneIndependent: The Control Plane Independent bit of the BFD
      packet. This is specified in section 4.1 of RFC5880
    demand: The demand bit of the BFD packet. This is specified in section 4.1
      of RFC5880
    diagnostic: The diagnostic code specifies the local system's reason for
      the last change in session state. This allows remote systems to
      determine the reason that the previous session failed, for example.
      These diagnostic codes are specified in section 4.1 of RFC5880
    final: The Final bit of the BFD packet. This is specified in section 4.1
      of RFC5880
    length: The length of the BFD Control packet in bytes. This is specified
      in section 4.1 of RFC5880
    minEchoRxIntervalMs: The Required Min Echo RX Interval value in the BFD
      packet. This is specified in section 4.1 of RFC5880
    minRxIntervalMs: The Required Min RX Interval value in the BFD packet.
      This is specified in section 4.1 of RFC5880
    minTxIntervalMs: The Desired Min TX Interval value in the BFD packet. This
      is specified in section 4.1 of RFC5880
    multiplier: The detection time multiplier of the BFD packet. This is
      specified in section 4.1 of RFC5880
    multipoint: The multipoint bit of the BFD packet. This is specified in
      section 4.1 of RFC5880
    myDiscriminator: The My Discriminator value in the BFD packet. This is
      specified in section 4.1 of RFC5880
    poll: The Poll bit of the BFD packet. This is specified in section 4.1 of
      RFC5880
    state: The current BFD session state as seen by the transmitting system.
      These states are specified in section 4.1 of RFC5880
    version: The version number of the BFD protocol, as specified in section
      4.1 of RFC5880.
    yourDiscriminator: The Your Discriminator value in the BFD packet. This is
      specified in section 4.1 of RFC5880
  """

  class DiagnosticValueValuesEnum(_messages.Enum):
    r"""The diagnostic code specifies the local system's reason for the last
    change in session state. This allows remote systems to determine the
    reason that the previous session failed, for example. These diagnostic
    codes are specified in section 4.1 of RFC5880

    Values:
      ADMINISTRATIVELY_DOWN: <no description>
      CONCATENATED_PATH_DOWN: <no description>
      CONTROL_DETECTION_TIME_EXPIRED: <no description>
      DIAGNOSTIC_UNSPECIFIED: <no description>
      ECHO_FUNCTION_FAILED: <no description>
      FORWARDING_PLANE_RESET: <no description>
      NEIGHBOR_SIGNALED_SESSION_DOWN: <no description>
      NO_DIAGNOSTIC: <no description>
      PATH_DOWN: <no description>
      REVERSE_CONCATENATED_PATH_DOWN: <no description>
    """
    ADMINISTRATIVELY_DOWN = 0
    CONCATENATED_PATH_DOWN = 1
    CONTROL_DETECTION_TIME_EXPIRED = 2
    DIAGNOSTIC_UNSPECIFIED = 3
    ECHO_FUNCTION_FAILED = 4
    FORWARDING_PLANE_RESET = 5
    NEIGHBOR_SIGNALED_SESSION_DOWN = 6
    NO_DIAGNOSTIC = 7
    PATH_DOWN = 8
    REVERSE_CONCATENATED_PATH_DOWN = 9

  class StateValueValuesEnum(_messages.Enum):
    r"""The current BFD session state as seen by the transmitting system.
    These states are specified in section 4.1 of RFC5880

    Values:
      ADMIN_DOWN: <no description>
      DOWN: <no description>
      INIT: <no description>
      STATE_UNSPECIFIED: <no description>
      UP: <no description>
    """
    ADMIN_DOWN = 0
    DOWN = 1
    INIT = 2
    STATE_UNSPECIFIED = 3
    UP = 4

  authenticationPresent = _messages.BooleanField(1)
  controlPlaneIndependent = _messages.BooleanField(2)
  demand = _messages.BooleanField(3)
  diagnostic = _messages.EnumField('DiagnosticValueValuesEnum', 4)
  final = _messages.BooleanField(5)
  length = _messages.IntegerField(6, variant=_messages.Variant.UINT32)
  minEchoRxIntervalMs = _messages.IntegerField(7, variant=_messages.Variant.UINT32)
  minRxIntervalMs = _messages.IntegerField(8, variant=_messages.Variant.UINT32)
  minTxIntervalMs = _messages.IntegerField(9, variant=_messages.Variant.UINT32)
  multiplier = _messages.IntegerField(10, variant=_messages.Variant.UINT32)
  multipoint = _messages.BooleanField(11)
  myDiscriminator = _messages.IntegerField(12, variant=_messages.Variant.UINT32)
  poll = _messages.BooleanField(13)
  state = _messages.EnumField('StateValueValuesEnum', 14)
  version = _messages.IntegerField(15, variant=_messages.Variant.UINT32)
  yourDiscriminator = _messages.IntegerField(16, variant=_messages.Variant.UINT32)


class BfdStatus(_messages.Message):
  r"""Next free: 15

  Enums:
    BfdSessionInitializationModeValueValuesEnum: The BFD session
      initialization mode for this BGP peer. If set to ACTIVE, the Cloud
      Router will initiate the BFD session for this BGP peer. If set to
      PASSIVE, the Cloud Router will wait for the peer router to initiate the
      BFD session for this BGP peer. If set to DISABLED, BFD is disabled for
      this BGP peer.
    LocalDiagnosticValueValuesEnum: The diagnostic code specifies the local
      system's reason for the last change in session state. This allows remote
      systems to determine the reason that the previous session failed, for
      example. These diagnostic codes are specified in section 4.1 of RFC5880
    LocalStateValueValuesEnum: The current BFD session state as seen by the
      transmitting system. These states are specified in section 4.1 of
      RFC5880

  Fields:
    bfdSessionInitializationMode: The BFD session initialization mode for this
      BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD
      session for this BGP peer. If set to PASSIVE, the Cloud Router will wait
      for the peer router to initiate the BFD session for this BGP peer. If
      set to DISABLED, BFD is disabled for this BGP peer.
    configUpdateTimestampMicros: Unix timestamp of the most recent config
      update.
    controlPacketCounts: Control packet counts for the current BFD session.
    controlPacketIntervals: Inter-packet time interval statistics for control
      packets.
    echoPacketCounts: Echo packet counts for the current BFD session.
    echoPacketIntervals: Inter-packet time interval statistics for echo
      packets.
    localDiagnostic: The diagnostic code specifies the local system's reason
      for the last change in session state. This allows remote systems to
      determine the reason that the previous session failed, for example.
      These diagnostic codes are specified in section 4.1 of RFC5880
    localState: The current BFD session state as seen by the transmitting
      system. These states are specified in section 4.1 of RFC5880
    negotiatedLocalControlTxIntervalMs: Negotiated transmit interval for
      control packets.
    negotiatedLocalEchoTxIntervalMs: Negotiated transmit interval for echo
      packets.
    rxPacket: The most recent Rx control packet for this BFD session.
    txPacket: The most recent Tx control packet for this BFD session.
    uptimeMs: Session uptime in milliseconds. Value will be 0 if session is
      not up.
    usingEchoMode: Indicates if echo mode is currently being used.
  """

  class BfdSessionInitializationModeValueValuesEnum(_messages.Enum):
    r"""The BFD session initialization mode for this BGP peer. If set to
    ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer.
    If set to PASSIVE, the Cloud Router will wait for the peer router to
    initiate the BFD session for this BGP peer. If set to DISABLED, BFD is
    disabled for this BGP peer.

    Values:
      ACTIVE: <no description>
      DISABLED: <no description>
      PASSIVE: <no description>
    """
    ACTIVE = 0
    DISABLED = 1
    PASSIVE = 2

  class LocalDiagnosticValueValuesEnum(_messages.Enum):
    r"""The diagnostic code specifies the local system's reason for the last
    change in session state. This allows remote systems to determine the
    reason that the previous session failed, for example. These diagnostic
    codes are specified in section 4.1 of RFC5880

    Values:
      ADMINISTRATIVELY_DOWN: <no description>
      CONCATENATED_PATH_DOWN: <no description>
      CONTROL_DETECTION_TIME_EXPIRED: <no description>
      DIAGNOSTIC_UNSPECIFIED: <no description>
      ECHO_FUNCTION_FAILED: <no description>
      FORWARDING_PLANE_RESET: <no description>
      NEIGHBOR_SIGNALED_SESSION_DOWN: <no description>
      NO_DIAGNOSTIC: <no description>
      PATH_DOWN: <no description>
      REVERSE_CONCATENATED_PATH_DOWN: <no description>
    """
    ADMINISTRATIVELY_DOWN = 0
    CONCATENATED_PATH_DOWN = 1
    CONTROL_DETECTION_TIME_EXPIRED = 2
    DIAGNOSTIC_UNSPECIFIED = 3
    ECHO_FUNCTION_FAILED = 4
    FORWARDING_PLANE_RESET = 5
    NEIGHBOR_SIGNALED_SESSION_DOWN = 6
    NO_DIAGNOSTIC = 7
    PATH_DOWN = 8
    REVERSE_CONCATENATED_PATH_DOWN = 9

  class LocalStateValueValuesEnum(_messages.Enum):
    r"""The current BFD session state as seen by the transmitting system.
    These states are specified in section 4.1 of RFC5880

    Values:
      ADMIN_DOWN: <no description>
      DOWN: <no description>
      INIT: <no description>
      STATE_UNSPECIFIED: <no description>
      UP: <no description>
    """
    ADMIN_DOWN = 0
    DOWN = 1
    INIT = 2
    STATE_UNSPECIFIED = 3
    UP = 4

  bfdSessionInitializationMode = _messages.EnumField('BfdSessionInitializationModeValueValuesEnum', 1)
  configUpdateTimestampMicros = _messages.IntegerField(2)
  controlPacketCounts = _messages.MessageField('BfdStatusPacketCounts', 3)
  controlPacketIntervals = _messages.MessageField('PacketIntervals', 4, repeated=True)
  echoPacketCounts = _messages.MessageField('BfdStatusPacketCounts', 5)
  echoPacketIntervals = _messages.MessageField('PacketIntervals', 6, repeated=True)
  localDiagnostic = _messages.EnumField('LocalDiagnosticValueValuesEnum', 7)
  localState = _messages.EnumField('LocalStateValueValuesEnum', 8)
  negotiatedLocalControlTxIntervalMs = _messages.IntegerField(9, variant=_messages.Variant.UINT32)
  negotiatedLocalEchoTxIntervalMs = _messages.IntegerField(10, variant=_messages.Variant.UINT32)
  rxPacket = _messages.MessageField('BfdPacket', 11)
  txPacket = _messages.MessageField('BfdPacket', 12)
  uptimeMs = _messages.IntegerField(13)
  usingEchoMode = _messages.BooleanField(14)


class BfdStatusPacketCounts(_messages.Message):
  r"""A BfdStatusPacketCounts object.

  Fields:
    numRx: Number of packets received since the beginning of the current BFD
      session.
    numRxRejected: Number of packets received that were rejected because of
      errors since the beginning of the current BFD session.
    numRxSuccessful: Number of packets received that were successfully
      processed since the beginning of the current BFD session.
    numTx: Number of packets transmitted since the beginning of the current
      BFD session.
  """

  numRx = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  numRxRejected = _messages.IntegerField(2, variant=_messages.Variant.UINT32)
  numRxSuccessful = _messages.IntegerField(3, variant=_messages.Variant.UINT32)
  numTx = _messages.IntegerField(4, variant=_messages.Variant.UINT32)


class BgpRoute(_messages.Message):
  r"""A BgpRoute object.

  Enums:
    OriginValueValuesEnum: [Output only] BGP origin (EGP, IGP or INCOMPLETE)

  Fields:
    asPaths: [Output only] AS-PATH for the route
    communities: [Output only] BGP communities in human-readable A:B format.
    destination: [Output only] Destination IP range for the route, in human-
      readable CIDR format
    med: [Output only] BGP multi-exit discriminator
    origin: [Output only] BGP origin (EGP, IGP or INCOMPLETE)
  """

  class OriginValueValuesEnum(_messages.Enum):
    r"""[Output only] BGP origin (EGP, IGP or INCOMPLETE)

    Values:
      BGP_ORIGIN_EGP: <no description>
      BGP_ORIGIN_IGP: <no description>
      BGP_ORIGIN_INCOMPLETE: <no description>
    """
    BGP_ORIGIN_EGP = 0
    BGP_ORIGIN_IGP = 1
    BGP_ORIGIN_INCOMPLETE = 2

  asPaths = _messages.MessageField('BgpRouteAsPath', 1, repeated=True)
  communities = _messages.StringField(2, repeated=True)
  destination = _messages.MessageField('BgpRouteNetworkLayerReachabilityInformation', 3)
  med = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  origin = _messages.EnumField('OriginValueValuesEnum', 5)


class BgpRouteAsPath(_messages.Message):
  r"""A BgpRouteAsPath object.

  Enums:
    TypeValueValuesEnum: [Output only] Type of AS-PATH segment (SEQUENCE or
      SET)

  Fields:
    asns: [Output only] ASNs in the path segment. When type is SEQUENCE, these
      are ordered.
    type: [Output only] Type of AS-PATH segment (SEQUENCE or SET)
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""[Output only] Type of AS-PATH segment (SEQUENCE or SET)

    Values:
      AS_PATH_TYPE_SEQUENCE: <no description>
      AS_PATH_TYPE_SET: <no description>
    """
    AS_PATH_TYPE_SEQUENCE = 0
    AS_PATH_TYPE_SET = 1

  asns = _messages.IntegerField(1, repeated=True, variant=_messages.Variant.INT32)
  type = _messages.EnumField('TypeValueValuesEnum', 2)


class BgpRouteNetworkLayerReachabilityInformation(_messages.Message):
  r"""Network Layer Reachability Information (NLRI) for a route.

  Fields:
    pathId: If the BGP session supports multiple paths (RFC 7911), the path
      identifier for this route.
    prefix: Human readable CIDR notation for a prefix. E.g. 10.42.0.0/16.
  """

  pathId = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  prefix = _messages.StringField(2)


class Binding(_messages.Message):
  r"""Associates `members`, or principals, with a `role`.

  Fields:
    condition: The condition that is associated with this binding. If the
      condition evaluates to `true`, then this binding applies to the current
      request. If the condition evaluates to `false`, then this binding does
      not apply to the current request. However, a different role binding
      might grant the same role to one or more of the principals in this
      binding. To learn which resources support conditions in their IAM
      policies, see the [IAM
      documentation](https://cloud.google.com/iam/help/conditions/resource-
      policies).
    members: Specifies the principals requesting access for a Google Cloud
      resource. `members` can have the following values: * `allUsers`: A
      special identifier that represents anyone who is on the internet; with
      or without a Google account. * `allAuthenticatedUsers`: A special
      identifier that represents anyone who is authenticated with a Google
      account or a service account. Does not include identities that come from
      external identity providers (IdPs) through identity federation. *
      `user:{emailid}`: An email address that represents a specific Google
      account. For example, `alice@example.com` . *
      `serviceAccount:{emailid}`: An email address that represents a Google
      service account. For example, `my-other-
      app@appspot.gserviceaccount.com`. *
      `serviceAccount:{projectid}.svc.id.goog[{namespace}/{kubernetes-sa}]`:
      An identifier for a [Kubernetes service
      account](https://cloud.google.com/kubernetes-engine/docs/how-
      to/kubernetes-service-accounts). For example, `my-
      project.svc.id.goog[my-namespace/my-kubernetes-sa]`. *
      `group:{emailid}`: An email address that represents a Google group. For
      example, `admins@example.com`. * `domain:{domain}`: The G Suite domain
      (primary) that represents all the users of that domain. For example,
      `google.com` or `example.com`. * `principal://iam.googleapis.com/locatio
      ns/global/workforcePools/{pool_id}/subject/{subject_attribute_value}`: A
      single identity in a workforce identity pool. * `principalSet://iam.goog
      leapis.com/locations/global/workforcePools/{pool_id}/group/{group_id}`:
      All workforce identities in a group. * `principalSet://iam.googleapis.co
      m/locations/global/workforcePools/{pool_id}/attribute.{attribute_name}/{
      attribute_value}`: All workforce identities with a specific attribute
      value. * `principalSet://iam.googleapis.com/locations/global/workforcePo
      ols/{pool_id}/*`: All identities in a workforce identity pool. * `princi
      pal://iam.googleapis.com/projects/{project_number}/locations/global/work
      loadIdentityPools/{pool_id}/subject/{subject_attribute_value}`: A single
      identity in a workload identity pool. * `principalSet://iam.googleapis.c
      om/projects/{project_number}/locations/global/workloadIdentityPools/{poo
      l_id}/group/{group_id}`: A workload identity pool group. * `principalSet
      ://iam.googleapis.com/projects/{project_number}/locations/global/workloa
      dIdentityPools/{pool_id}/attribute.{attribute_name}/{attribute_value}`:
      All identities in a workload identity pool with a certain attribute. * `
      principalSet://iam.googleapis.com/projects/{project_number}/locations/gl
      obal/workloadIdentityPools/{pool_id}/*`: All identities in a workload
      identity pool. * `deleted:user:{emailid}?uid={uniqueid}`: An email
      address (plus unique identifier) representing a user that has been
      recently deleted. For example,
      `alice@example.com?uid=123456789012345678901`. If the user is recovered,
      this value reverts to `user:{emailid}` and the recovered user retains
      the role in the binding. *
      `deleted:serviceAccount:{emailid}?uid={uniqueid}`: An email address
      (plus unique identifier) representing a service account that has been
      recently deleted. For example, `my-other-
      app@appspot.gserviceaccount.com?uid=123456789012345678901`. If the
      service account is undeleted, this value reverts to
      `serviceAccount:{emailid}` and the undeleted service account retains the
      role in the binding. * `deleted:group:{emailid}?uid={uniqueid}`: An
      email address (plus unique identifier) representing a Google group that
      has been recently deleted. For example,
      `admins@example.com?uid=123456789012345678901`. If the group is
      recovered, this value reverts to `group:{emailid}` and the recovered
      group retains the role in the binding. * `deleted:principal://iam.google
      apis.com/locations/global/workforcePools/{pool_id}/subject/{subject_attr
      ibute_value}`: Deleted single identity in a workforce identity pool. For
      example, `deleted:principal://iam.googleapis.com/locations/global/workfo
      rcePools/my-pool-id/subject/my-subject-attribute-value`.
    role: Role that is assigned to the list of `members`, or principals. For
      example, `roles/viewer`, `roles/editor`, or `roles/owner`. For an
      overview of the IAM roles and permissions, see the [IAM
      documentation](https://cloud.google.com/iam/docs/roles-overview). For a
      list of the available pre-defined roles, see
      [here](https://cloud.google.com/iam/docs/understanding-roles).
  """

  condition = _messages.MessageField('Expr', 1)
  members = _messages.StringField(2, repeated=True)
  role = _messages.StringField(3)


class BulkInsertDiskResource(_messages.Message):
  r"""A transient resource used in compute.disks.bulkInsert and
  compute.regionDisks.bulkInsert. It is only used to process requests and is
  not persisted.

  Fields:
    instantSnapshotGroupParameters: The parameters for the instant snapshot
      group.
    snapshotGroupParameters: The parameters for the snapshot group.
    sourceConsistencyGroupPolicy: The URL of the DiskConsistencyGroupPolicy
      for the group of disks to clone. This may be a full or partial URL, such
      as: -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /resourcePolicies/resourcePolicy -
      projects/project/regions/region/resourcePolicies/resourcePolicy -
      regions/region/resourcePolicies/resourcePolicy
  """

  instantSnapshotGroupParameters = _messages.MessageField('InstantSnapshotGroupParameters', 1)
  snapshotGroupParameters = _messages.MessageField('SnapshotGroupParameters', 2)
  sourceConsistencyGroupPolicy = _messages.StringField(3)


class BulkInsertInstanceResource(_messages.Message):
  r"""A transient resource used in compute.instances.bulkInsert and
  compute.regionInstances.bulkInsert . This resource is not persisted
  anywhere, it is used only for processing the requests.

  Messages:
    PerInstancePropertiesValue: Per-instance properties to be set on
      individual instances. Keys of this map specify requested instance names.
      Can be empty if name_pattern is used.

  Fields:
    count: The maximum number of instances to create.
    instanceProperties: The instance properties defining the VM instances to
      be created. Required if sourceInstanceTemplate is not provided.
    locationPolicy: Policy for choosing target zone. For more information, see
      Create VMs in bulk.
    minCount: The minimum number of instances to create. If no min_count is
      specified then count is used as the default value. If min_count
      instances cannot be created, then no instances will be created and
      instances already created will be deleted.
    namePattern: The string pattern used for the names of the VMs. Either
      name_pattern or per_instance_properties must be set. The pattern must
      contain one continuous sequence of placeholder hash characters (#) with
      each character corresponding to one digit of the generated instance
      name. Example: a name_pattern of inst-#### generates instance names such
      as inst-0001 and inst-0002. If existing instances in the same project
      and zone have names that match the name pattern then the generated
      instance numbers start after the biggest existing number. For example,
      if there exists an instance with name inst-0050, then instance names
      generated using the pattern inst-#### begin with inst-0051. The name
      pattern placeholder #...# can contain up to 18 characters.
    perInstanceProperties: Per-instance properties to be set on individual
      instances. Keys of this map specify requested instance names. Can be
      empty if name_pattern is used.
    sourceInstanceTemplate: Specifies the instance template from which to
      create instances. You may combine sourceInstanceTemplate with
      instanceProperties to override specific values from an existing instance
      template. Bulk API follows the semantics of JSON Merge Patch described
      by RFC 7396. It can be a full or partial URL. For example, the following
      are all valid URLs to an instance template: -
      https://www.googleapis.com/compute/v1/projects/project
      /global/instanceTemplates/instanceTemplate -
      projects/project/global/instanceTemplates/instanceTemplate -
      global/instanceTemplates/instanceTemplate This field is optional.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class PerInstancePropertiesValue(_messages.Message):
    r"""Per-instance properties to be set on individual instances. Keys of
    this map specify requested instance names. Can be empty if name_pattern is
    used.

    Messages:
      AdditionalProperty: An additional property for a
        PerInstancePropertiesValue object.

    Fields:
      additionalProperties: Additional properties of type
        PerInstancePropertiesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a PerInstancePropertiesValue object.

      Fields:
        key: Name of the additional property.
        value: A BulkInsertInstanceResourcePerInstanceProperties attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('BulkInsertInstanceResourcePerInstanceProperties', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  count = _messages.IntegerField(1)
  instanceProperties = _messages.MessageField('InstanceProperties', 2)
  locationPolicy = _messages.MessageField('LocationPolicy', 3)
  minCount = _messages.IntegerField(4)
  namePattern = _messages.StringField(5)
  perInstanceProperties = _messages.MessageField('PerInstancePropertiesValue', 6)
  sourceInstanceTemplate = _messages.StringField(7)


class BulkInsertInstanceResourcePerInstanceProperties(_messages.Message):
  r"""Per-instance properties to be set on individual instances. To be
  extended in the future.

  Fields:
    hostname: Specifies the hostname of the instance. More details in:
      https://cloud.google.com/compute/docs/instances/custom-hostname-
      vm#naming_convention
    name: This field is only temporary. It will be removed. Do not use it.
  """

  hostname = _messages.StringField(1)
  name = _messages.StringField(2)


class BulkInsertOperationStatus(_messages.Message):
  r"""A BulkInsertOperationStatus object.

  Enums:
    StatusValueValuesEnum: [Output Only] Creation status of BulkInsert
      operation - information if the flow is rolling forward or rolling back.

  Fields:
    createdVmCount: [Output Only] Count of VMs successfully created so far.
    deletedVmCount: [Output Only] Count of VMs that got deleted during
      rollback.
    failedToCreateVmCount: [Output Only] Count of VMs that started creating
      but encountered an error.
    status: [Output Only] Creation status of BulkInsert operation -
      information if the flow is rolling forward or rolling back.
    targetVmCount: [Output Only] Count of VMs originally planned to be
      created.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] Creation status of BulkInsert operation - information if
    the flow is rolling forward or rolling back.

    Values:
      CREATING: Rolling forward - creating VMs.
      DONE: Done
      ROLLING_BACK: Rolling back - cleaning up after an error.
      STATUS_UNSPECIFIED: <no description>
    """
    CREATING = 0
    DONE = 1
    ROLLING_BACK = 2
    STATUS_UNSPECIFIED = 3

  createdVmCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  deletedVmCount = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  failedToCreateVmCount = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  status = _messages.EnumField('StatusValueValuesEnum', 4)
  targetVmCount = _messages.IntegerField(5, variant=_messages.Variant.INT32)


class BulkSetLabelsRequest(_messages.Message):
  r"""A BulkSetLabelsRequest object.

  Messages:
    LabelsValue: The labels to set for this resource.

  Fields:
    labelFingerprint: The fingerprint of the previous set of labels for this
      resource, used to detect conflicts. The fingerprint is initially
      generated by Compute Engine and changes after every request to modify or
      update labels. You may optionally provide an up-to-date fingerprint hash
      in order to update or change labels. Make a get() request to the
      resource to get the latest fingerprint.
    labels: The labels to set for this resource.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""The labels to set for this resource.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class BulkZoneSetLabelsRequest(_messages.Message):
  r"""A BulkZoneSetLabelsRequest object.

  Fields:
    requests: A BulkSetLabelsRequest attribute.
  """

  requests = _messages.MessageField('BulkSetLabelsRequest', 1, repeated=True)


class BundledLocalSsds(_messages.Message):
  r"""A BundledLocalSsds object.

  Fields:
    defaultInterface: The default disk interface if the interface is not
      specified.
    partitionCount: The number of partitions.
  """

  defaultInterface = _messages.StringField(1)
  partitionCount = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class CacheInvalidationRule(_messages.Message):
  r"""A CacheInvalidationRule object.

  Fields:
    cacheTags: [Preview] A list of cache tags used to identify cached objects.
      - Cache tags are specified when the response is first cached, by setting
      the `Cache-Tag` response header at the origin. - Multiple cache tags in
      the same invalidation request are treated as Boolean `OR` - for example,
      `tag1 OR tag2 OR tag3`. - If other fields are also specified, these are
      treated as Boolean `AND` with any tags. Up to 10 tags can be specified
      in a single invalidation request.
    host: If set, this invalidation rule will only apply to requests with a
      Host header matching host.
    path: A string attribute.
  """

  cacheTags = _messages.StringField(1, repeated=True)
  host = _messages.StringField(2)
  path = _messages.StringField(3)


class CacheKeyPolicy(_messages.Message):
  r"""Message containing what to include in the cache key for a request for
  Cloud CDN.

  Fields:
    includeHost: If true, requests to different hosts will be cached
      separately.
    includeHttpHeaders: Allows HTTP request headers (by name) to be used in
      the cache key.
    includeNamedCookies: Allows HTTP cookies (by name) to be used in the cache
      key. The name=value pair will be used in the cache key Cloud CDN
      generates.
    includeProtocol: If true, http and https requests will be cached
      separately.
    includeQueryString: If true, include query string parameters in the cache
      key according to query_string_whitelist and query_string_blacklist. If
      neither is set, the entire query string will be included. If false, the
      query string will be excluded from the cache key entirely.
    queryStringBlacklist: Names of query string parameters to exclude in cache
      keys. All other parameters will be included. Either specify
      query_string_whitelist or query_string_blacklist, not both. '&' and '='
      will be percent encoded and not treated as delimiters.
    queryStringWhitelist: Names of query string parameters to include in cache
      keys. All other parameters will be excluded. Either specify
      query_string_whitelist or query_string_blacklist, not both. '&' and '='
      will be percent encoded and not treated as delimiters.
  """

  includeHost = _messages.BooleanField(1)
  includeHttpHeaders = _messages.StringField(2, repeated=True)
  includeNamedCookies = _messages.StringField(3, repeated=True)
  includeProtocol = _messages.BooleanField(4)
  includeQueryString = _messages.BooleanField(5)
  queryStringBlacklist = _messages.StringField(6, repeated=True)
  queryStringWhitelist = _messages.StringField(7, repeated=True)


class CalendarModeAdviceRequest(_messages.Message):
  r"""A request to recommend the best way to consume the specified resources
  in the future.

  Messages:
    FutureResourcesSpecsValue: Specification of resources to create in the
      future. The key of the map is an arbitrary string specified by the
      caller. Value of the map is a specification of required resources and
      their constraints. Currently only one value is allowed in this map.

  Fields:
    futureResourcesSpecs: Specification of resources to create in the future.
      The key of the map is an arbitrary string specified by the caller. Value
      of the map is a specification of required resources and their
      constraints. Currently only one value is allowed in this map.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class FutureResourcesSpecsValue(_messages.Message):
    r"""Specification of resources to create in the future. The key of the map
    is an arbitrary string specified by the caller. Value of the map is a
    specification of required resources and their constraints. Currently only
    one value is allowed in this map.

    Messages:
      AdditionalProperty: An additional property for a
        FutureResourcesSpecsValue object.

    Fields:
      additionalProperties: Additional properties of type
        FutureResourcesSpecsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a FutureResourcesSpecsValue object.

      Fields:
        key: Name of the additional property.
        value: A FutureResourcesSpec attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('FutureResourcesSpec', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  futureResourcesSpecs = _messages.MessageField('FutureResourcesSpecsValue', 1)


class CalendarModeAdviceResponse(_messages.Message):
  r"""A response containing the recommended way of creating the specified
  resources in the future. It contains (will contain) multiple recommendations
  that can be analyzed by the customer and the best one can be picked.

  Fields:
    recommendations: Recommendations where, how and when to create the
      requested resources in order to maximize their obtainability and
      minimize cost.
  """

  recommendations = _messages.MessageField('CalendarModeRecommendation', 1, repeated=True)


class CalendarModeRecommendation(_messages.Message):
  r"""A single recommendation to create requested resources. Contains detailed
  recommendations for every future resources specification specified in
  CalendarModeAdviceRequest.

  Messages:
    RecommendationsPerSpecValue: Recommendations for every future resource
      specification passed in CalendarModeAdviceRequest. Keys of the map
      correspond to keys specified in the request.

  Fields:
    recommendationsPerSpec: Recommendations for every future resource
      specification passed in CalendarModeAdviceRequest. Keys of the map
      correspond to keys specified in the request.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class RecommendationsPerSpecValue(_messages.Message):
    r"""Recommendations for every future resource specification passed in
    CalendarModeAdviceRequest. Keys of the map correspond to keys specified in
    the request.

    Messages:
      AdditionalProperty: An additional property for a
        RecommendationsPerSpecValue object.

    Fields:
      additionalProperties: Additional properties of type
        RecommendationsPerSpecValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a RecommendationsPerSpecValue object.

      Fields:
        key: Name of the additional property.
        value: A FutureResourcesRecommendation attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('FutureResourcesRecommendation', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  recommendationsPerSpec = _messages.MessageField('RecommendationsPerSpecValue', 1)


class CallCredentials(_messages.Message):
  r"""[Deprecated] gRPC call credentials to access the SDS server. gRPC call
  credentials to access the SDS server.

  Enums:
    CallCredentialTypeValueValuesEnum: The type of call credentials to use for
      GRPC requests to the SDS server. This field can be set to one of the
      following: - GCE_VM: The local GCE VM service account credentials are
      used to access the SDS server. - FROM_PLUGIN: Custom authenticator
      credentials are used to access the SDS server.

  Fields:
    callCredentialType: The type of call credentials to use for GRPC requests
      to the SDS server. This field can be set to one of the following: -
      GCE_VM: The local GCE VM service account credentials are used to access
      the SDS server. - FROM_PLUGIN: Custom authenticator credentials are used
      to access the SDS server.
    fromPlugin: Custom authenticator credentials. Valid if callCredentialType
      is FROM_PLUGIN.
  """

  class CallCredentialTypeValueValuesEnum(_messages.Enum):
    r"""The type of call credentials to use for GRPC requests to the SDS
    server. This field can be set to one of the following: - GCE_VM: The local
    GCE VM service account credentials are used to access the SDS server. -
    FROM_PLUGIN: Custom authenticator credentials are used to access the SDS
    server.

    Values:
      FROM_PLUGIN: Custom authenticator credentials are used to access the SDS
        server.
      GCE_VM: The local GCE VM service account credentials are used to access
        the SDS server.
      INVALID: <no description>
    """
    FROM_PLUGIN = 0
    GCE_VM = 1
    INVALID = 2

  callCredentialType = _messages.EnumField('CallCredentialTypeValueValuesEnum', 1)
  fromPlugin = _messages.MessageField('MetadataCredentialsFromPlugin', 2)


class ChannelCredentials(_messages.Message):
  r"""[Deprecated] gRPC channel credentials to access the SDS server. gRPC
  channel credentials to access the SDS server.

  Enums:
    ChannelCredentialTypeValueValuesEnum: The channel credentials to access
      the SDS server. This field can be set to one of the following:
      CERTIFICATES: Use TLS certificates to access the SDS server. GCE_VM: Use
      local GCE VM credentials to access the SDS server.

  Fields:
    certificates: The call credentials to access the SDS server.
    channelCredentialType: The channel credentials to access the SDS server.
      This field can be set to one of the following: CERTIFICATES: Use TLS
      certificates to access the SDS server. GCE_VM: Use local GCE VM
      credentials to access the SDS server.
  """

  class ChannelCredentialTypeValueValuesEnum(_messages.Enum):
    r"""The channel credentials to access the SDS server. This field can be
    set to one of the following: CERTIFICATES: Use TLS certificates to access
    the SDS server. GCE_VM: Use local GCE VM credentials to access the SDS
    server.

    Values:
      CERTIFICATES: Use TLS certificates to access the SDS server.
      GCE_VM: Use local GCE VM credentials to access the SDS server.
      INVALID: <no description>
    """
    CERTIFICATES = 0
    GCE_VM = 1
    INVALID = 2

  certificates = _messages.MessageField('TlsCertificatePaths', 1)
  channelCredentialType = _messages.EnumField('ChannelCredentialTypeValueValuesEnum', 2)


class CircuitBreakers(_messages.Message):
  r"""Settings controlling the volume of requests, connections and retries to
  this backend service.

  Fields:
    connectTimeout: The timeout for new network connections to hosts.
    maxConnections: The maximum number of connections to the backend service.
      If not specified, there is no limit. Not supported when the backend
      service is referenced by a URL map that is bound to target gRPC proxy
      that has validateForProxyless field set to true.
    maxPendingRequests: The maximum number of pending requests allowed to the
      backend service. If not specified, there is no limit. Not supported when
      the backend service is referenced by a URL map that is bound to target
      gRPC proxy that has validateForProxyless field set to true.
    maxRequests: The maximum number of parallel requests that allowed to the
      backend service. If not specified, there is no limit.
    maxRequestsPerConnection: Maximum requests for a single connection to the
      backend service. This parameter is respected by both the HTTP/1.1 and
      HTTP/2 implementations. If not specified, there is no limit. Setting
      this parameter to 1 will effectively disable keep alive. Not supported
      when the backend service is referenced by a URL map that is bound to
      target gRPC proxy that has validateForProxyless field set to true.
    maxRetries: The maximum number of parallel retries allowed to the backend
      cluster. If not specified, the default is 1. Not supported when the
      backend service is referenced by a URL map that is bound to target gRPC
      proxy that has validateForProxyless field set to true.
  """

  connectTimeout = _messages.MessageField('Duration', 1)
  maxConnections = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  maxPendingRequests = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  maxRequests = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  maxRequestsPerConnection = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  maxRetries = _messages.IntegerField(6, variant=_messages.Variant.INT32)


class ClientTlsSettings(_messages.Message):
  r"""[Deprecated] The client side authentication settings for connection
  originating from the backend service. the backend service.

  Enums:
    ModeValueValuesEnum: Indicates whether connections to this port should be
      secured using TLS. The value of this field determines how TLS is
      enforced. This can be set to one of the following values: DISABLE: Do
      not setup a TLS connection to the backends. SIMPLE: Originate a TLS
      connection to the backends. MUTUAL: Secure connections to the backends
      using mutual TLS by presenting client certificates for authentication.

  Fields:
    clientTlsContext: Configures the mechanism to obtain client-side security
      certificates and identity information. This field is only applicable
      when mode is set to MUTUAL.
    mode: Indicates whether connections to this port should be secured using
      TLS. The value of this field determines how TLS is enforced. This can be
      set to one of the following values: DISABLE: Do not setup a TLS
      connection to the backends. SIMPLE: Originate a TLS connection to the
      backends. MUTUAL: Secure connections to the backends using mutual TLS by
      presenting client certificates for authentication.
    sni: SNI string to present to the server during TLS handshake. This field
      is applicable only when mode is SIMPLE or MUTUAL.
    subjectAltNames: A list of alternate names to verify the subject identity
      in the certificate.If specified, the proxy will verify that the server
      certificate's subject alt name matches one of the specified values. This
      field is applicable only when mode is SIMPLE or MUTUAL.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Indicates whether connections to this port should be secured using
    TLS. The value of this field determines how TLS is enforced. This can be
    set to one of the following values: DISABLE: Do not setup a TLS connection
    to the backends. SIMPLE: Originate a TLS connection to the backends.
    MUTUAL: Secure connections to the backends using mutual TLS by presenting
    client certificates for authentication.

    Values:
      DISABLE: Do not setup a TLS connection to the backends.
      INVALID: <no description>
      MUTUAL: Secure connections to the backends using mutual TLS by
        presenting client certificates for authentication.
      SIMPLE: Originate a TLS connection to the backends.
    """
    DISABLE = 0
    INVALID = 1
    MUTUAL = 2
    SIMPLE = 3

  clientTlsContext = _messages.MessageField('TlsContext', 1)
  mode = _messages.EnumField('ModeValueValuesEnum', 2)
  sni = _messages.StringField(3)
  subjectAltNames = _messages.StringField(4, repeated=True)


class Commitment(_messages.Message):
  r"""Represents a regional resource-based commitment resource. Creating this
  commitment resource means that you are purchasing a resource-based committed
  use contract, with an explicit start and end time. You can purchase
  resource-based commitments for both hardware and software resources. For
  more information, read Resource-based committed use discounts

  Enums:
    CategoryValueValuesEnum: The category of the commitment; specifies whether
      the commitment is for hardware or software resources. Category MACHINE
      specifies that you are committing to hardware machine resources such as
      VCPU or MEMORY, listed in resources. Category LICENSE specifies that you
      are committing to software licenses, listed in licenseResources. Note
      that if you specify MACHINE commitments, then you must also specify a
      type to indicate the machine series of the hardware resource that you
      are committing to.
    PlanValueValuesEnum: The minimum time duration that you commit to
      purchasing resources. The plan that you choose determines the preset
      term length of the commitment (which is 1 year or 3 years) and affects
      the discount rate that you receive for your resources. Committing to a
      longer time duration typically gives you a higher discount rate. The
      supported values for this field are TWELVE_MONTH (1 year), and
      THIRTY_SIX_MONTH (3 years).
    StatusValueValuesEnum: [Output Only] Status of the commitment with regards
      to eventual expiration (each commitment has an end date defined). Status
      can be one of the following values: NOT_YET_ACTIVE, ACTIVE, or EXPIRED.
    TypeValueValuesEnum: The type of commitment; specifies the machine series
      for which you want to commit to purchasing resources. The choice of
      machine series affects the discount rate and the eligible resource
      types. The type must be one of the following: ACCELERATOR_OPTIMIZED,
      ACCELERATOR_OPTIMIZED_A3, ACCELERATOR_OPTIMIZED_A3_MEGA,
      COMPUTE_OPTIMIZED, COMPUTE_OPTIMIZED_C2D, COMPUTE_OPTIMIZED_C3,
      COMPUTE_OPTIMIZED_C3D, COMPUTE_OPTIMIZED_H3, GENERAL_PURPOSE,
      GENERAL_PURPOSE_C4, GENERAL_PURPOSE_E2, GENERAL_PURPOSE_N2,
      GENERAL_PURPOSE_N2D, GENERAL_PURPOSE_N4, GENERAL_PURPOSE_T2D,
      GRAPHICS_OPTIMIZED, MEMORY_OPTIMIZED, MEMORY_OPTIMIZED_M3,
      MEMORY_OPTIMIZED_X4, STORAGE_OPTIMIZED_Z3. For example, type
      MEMORY_OPTIMIZED specifies a commitment that applies only to eligible
      resources of memory optimized M1 and M2 machine series. Type
      GENERAL_PURPOSE specifies a commitment that applies only to eligible
      resources of general purpose N1 machine series.

  Fields:
    autoRenew: Specifies whether to automatically renew the commitment at the
      end of its current term. The default value is false. If you set the
      field to true, each time your commitment reaches the end of its term,
      Compute Engine automatically renews it for another term. You can update
      this field anytime before the commitment expires. For example, if the
      commitment is set to expire at 12 AM UTC-8 on January 3, 2027, you can
      update this field until 11:59 PM UTC-8 on January 2, 2027.
    category: The category of the commitment; specifies whether the commitment
      is for hardware or software resources. Category MACHINE specifies that
      you are committing to hardware machine resources such as VCPU or MEMORY,
      listed in resources. Category LICENSE specifies that you are committing
      to software licenses, listed in licenseResources. Note that if you
      specify MACHINE commitments, then you must also specify a type to
      indicate the machine series of the hardware resource that you are
      committing to.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customEndTimestamp: [Input Only] Optional, specifies the requested
      commitment end time in RFC3339 text format. Use this option when the
      desired commitment's end date is later than the start date + term
      duration.
    description: An optional description of the commitment. You can provide
      this property when you create the resource.
    endTimestamp: [Output Only] Commitment end time in RFC3339 text format.
    existingReservations: A string attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#commitment for
      commitments.
    licenseResource: The license specification required as part of a license
      commitment.
    mergeSourceCommitments: The list of source commitments that you are
      merging to create the new merged commitment. For more information, see
      Merging commitments.
    name: Name of the commitment. You must specify a name when you purchase
      the commitment. The name must be 1-63 characters long, and comply with
      RFC1035. Specifically, the name must be 1-63 characters long and match
      the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the
      first character must be a lowercase letter, and all following characters
      must be a dash, lowercase letter, or digit, except the last character,
      which cannot be a dash.
    plan: The minimum time duration that you commit to purchasing resources.
      The plan that you choose determines the preset term length of the
      commitment (which is 1 year or 3 years) and affects the discount rate
      that you receive for your resources. Committing to a longer time
      duration typically gives you a higher discount rate. The supported
      values for this field are TWELVE_MONTH (1 year), and THIRTY_SIX_MONTH (3
      years).
    region: [Output Only] URL of the region where the commitment and committed
      resources are located.
    reservations: The list of new reservations that you want to create and
      attach to this commitment. You must attach reservations to your
      commitment if your commitment specifies any GPUs or Local SSD disks. For
      more information, see Attach reservations to resource-based commitments.
      Specify this property only if you want to create new reservations to
      attach. To attach existing reservations, specify the
      existingReservations property instead.
    resourceStatus: [Output Only] Status information for Commitment resource.
    resources: The list of all the hardware resources, with their types and
      amounts, that you want to commit to. Specify as a separate entry in the
      list for each individual resource type.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    splitSourceCommitment: The source commitment from which you are
      transferring resources to create the new split commitment. For more
      information, see Split commitments.
    startTimestamp: [Output Only] Commitment start time in RFC3339 text
      format.
    status: [Output Only] Status of the commitment with regards to eventual
      expiration (each commitment has an end date defined). Status can be one
      of the following values: NOT_YET_ACTIVE, ACTIVE, or EXPIRED.
    statusMessage: [Output Only] An optional, human-readable explanation of
      the status.
    type: The type of commitment; specifies the machine series for which you
      want to commit to purchasing resources. The choice of machine series
      affects the discount rate and the eligible resource types. The type must
      be one of the following: ACCELERATOR_OPTIMIZED,
      ACCELERATOR_OPTIMIZED_A3, ACCELERATOR_OPTIMIZED_A3_MEGA,
      COMPUTE_OPTIMIZED, COMPUTE_OPTIMIZED_C2D, COMPUTE_OPTIMIZED_C3,
      COMPUTE_OPTIMIZED_C3D, COMPUTE_OPTIMIZED_H3, GENERAL_PURPOSE,
      GENERAL_PURPOSE_C4, GENERAL_PURPOSE_E2, GENERAL_PURPOSE_N2,
      GENERAL_PURPOSE_N2D, GENERAL_PURPOSE_N4, GENERAL_PURPOSE_T2D,
      GRAPHICS_OPTIMIZED, MEMORY_OPTIMIZED, MEMORY_OPTIMIZED_M3,
      MEMORY_OPTIMIZED_X4, STORAGE_OPTIMIZED_Z3. For example, type
      MEMORY_OPTIMIZED specifies a commitment that applies only to eligible
      resources of memory optimized M1 and M2 machine series. Type
      GENERAL_PURPOSE specifies a commitment that applies only to eligible
      resources of general purpose N1 machine series.
  """

  class CategoryValueValuesEnum(_messages.Enum):
    r"""The category of the commitment; specifies whether the commitment is
    for hardware or software resources. Category MACHINE specifies that you
    are committing to hardware machine resources such as VCPU or MEMORY,
    listed in resources. Category LICENSE specifies that you are committing to
    software licenses, listed in licenseResources. Note that if you specify
    MACHINE commitments, then you must also specify a type to indicate the
    machine series of the hardware resource that you are committing to.

    Values:
      CATEGORY_UNSPECIFIED: <no description>
      LICENSE: <no description>
      MACHINE: <no description>
    """
    CATEGORY_UNSPECIFIED = 0
    LICENSE = 1
    MACHINE = 2

  class PlanValueValuesEnum(_messages.Enum):
    r"""The minimum time duration that you commit to purchasing resources. The
    plan that you choose determines the preset term length of the commitment
    (which is 1 year or 3 years) and affects the discount rate that you
    receive for your resources. Committing to a longer time duration typically
    gives you a higher discount rate. The supported values for this field are
    TWELVE_MONTH (1 year), and THIRTY_SIX_MONTH (3 years).

    Values:
      INVALID: <no description>
      THIRTY_SIX_MONTH: <no description>
      TWELVE_MONTH: <no description>
    """
    INVALID = 0
    THIRTY_SIX_MONTH = 1
    TWELVE_MONTH = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] Status of the commitment with regards to eventual
    expiration (each commitment has an end date defined). Status can be one of
    the following values: NOT_YET_ACTIVE, ACTIVE, or EXPIRED.

    Values:
      ACTIVE: <no description>
      CANCELED_EARLY_TERMINATION: <no description>
      CANCELING: <no description>
      CANCELLED: Deprecate CANCELED status. Will use separate status to
        differentiate cancel by mergeCud or manual cancellation.
      CREATING: <no description>
      EXPIRED: <no description>
      NOT_YET_ACTIVE: <no description>
    """
    ACTIVE = 0
    CANCELED_EARLY_TERMINATION = 1
    CANCELING = 2
    CANCELLED = 3
    CREATING = 4
    EXPIRED = 5
    NOT_YET_ACTIVE = 6

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of commitment; specifies the machine series for which you
    want to commit to purchasing resources. The choice of machine series
    affects the discount rate and the eligible resource types. The type must
    be one of the following: ACCELERATOR_OPTIMIZED, ACCELERATOR_OPTIMIZED_A3,
    ACCELERATOR_OPTIMIZED_A3_MEGA, COMPUTE_OPTIMIZED, COMPUTE_OPTIMIZED_C2D,
    COMPUTE_OPTIMIZED_C3, COMPUTE_OPTIMIZED_C3D, COMPUTE_OPTIMIZED_H3,
    GENERAL_PURPOSE, GENERAL_PURPOSE_C4, GENERAL_PURPOSE_E2,
    GENERAL_PURPOSE_N2, GENERAL_PURPOSE_N2D, GENERAL_PURPOSE_N4,
    GENERAL_PURPOSE_T2D, GRAPHICS_OPTIMIZED, MEMORY_OPTIMIZED,
    MEMORY_OPTIMIZED_M3, MEMORY_OPTIMIZED_X4, STORAGE_OPTIMIZED_Z3. For
    example, type MEMORY_OPTIMIZED specifies a commitment that applies only to
    eligible resources of memory optimized M1 and M2 machine series. Type
    GENERAL_PURPOSE specifies a commitment that applies only to eligible
    resources of general purpose N1 machine series.

    Values:
      ACCELERATOR_OPTIMIZED: <no description>
      ACCELERATOR_OPTIMIZED_A3: <no description>
      ACCELERATOR_OPTIMIZED_A3_MEGA: <no description>
      ACCELERATOR_OPTIMIZED_A3_ULTRA: <no description>
      ACCELERATOR_OPTIMIZED_A4: <no description>
      COMPUTE_OPTIMIZED: <no description>
      COMPUTE_OPTIMIZED_C2D: <no description>
      COMPUTE_OPTIMIZED_C3: <no description>
      COMPUTE_OPTIMIZED_C3D: <no description>
      COMPUTE_OPTIMIZED_H3: <no description>
      GENERAL_PURPOSE: <no description>
      GENERAL_PURPOSE_C4: <no description>
      GENERAL_PURPOSE_C4A: <no description>
      GENERAL_PURPOSE_E2: <no description>
      GENERAL_PURPOSE_N2: <no description>
      GENERAL_PURPOSE_N2D: <no description>
      GENERAL_PURPOSE_N4: <no description>
      GENERAL_PURPOSE_T2D: <no description>
      GRAPHICS_OPTIMIZED: <no description>
      MEMORY_OPTIMIZED: <no description>
      MEMORY_OPTIMIZED_M3: <no description>
      MEMORY_OPTIMIZED_M4: <no description>
      MEMORY_OPTIMIZED_X4: <no description>
      MEMORY_OPTIMIZED_X4_16TB: <no description>
      MEMORY_OPTIMIZED_X4_24TB: <no description>
      MEMORY_OPTIMIZED_X4_32TB: <no description>
      STORAGE_OPTIMIZED_Z3: <no description>
      TYPE_UNSPECIFIED: Note for internal users: When adding a new enum Type
        for v1, make sure to also add it in the comment for the `optional Type
        type` definition. This ensures that the public documentation displays
        the new enum Type.
    """
    ACCELERATOR_OPTIMIZED = 0
    ACCELERATOR_OPTIMIZED_A3 = 1
    ACCELERATOR_OPTIMIZED_A3_MEGA = 2
    ACCELERATOR_OPTIMIZED_A3_ULTRA = 3
    ACCELERATOR_OPTIMIZED_A4 = 4
    COMPUTE_OPTIMIZED = 5
    COMPUTE_OPTIMIZED_C2D = 6
    COMPUTE_OPTIMIZED_C3 = 7
    COMPUTE_OPTIMIZED_C3D = 8
    COMPUTE_OPTIMIZED_H3 = 9
    GENERAL_PURPOSE = 10
    GENERAL_PURPOSE_C4 = 11
    GENERAL_PURPOSE_C4A = 12
    GENERAL_PURPOSE_E2 = 13
    GENERAL_PURPOSE_N2 = 14
    GENERAL_PURPOSE_N2D = 15
    GENERAL_PURPOSE_N4 = 16
    GENERAL_PURPOSE_T2D = 17
    GRAPHICS_OPTIMIZED = 18
    MEMORY_OPTIMIZED = 19
    MEMORY_OPTIMIZED_M3 = 20
    MEMORY_OPTIMIZED_M4 = 21
    MEMORY_OPTIMIZED_X4 = 22
    MEMORY_OPTIMIZED_X4_16TB = 23
    MEMORY_OPTIMIZED_X4_24TB = 24
    MEMORY_OPTIMIZED_X4_32TB = 25
    STORAGE_OPTIMIZED_Z3 = 26
    TYPE_UNSPECIFIED = 27

  autoRenew = _messages.BooleanField(1)
  category = _messages.EnumField('CategoryValueValuesEnum', 2)
  creationTimestamp = _messages.StringField(3)
  customEndTimestamp = _messages.StringField(4)
  description = _messages.StringField(5)
  endTimestamp = _messages.StringField(6)
  existingReservations = _messages.StringField(7, repeated=True)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(9, default='compute#commitment')
  licenseResource = _messages.MessageField('LicenseResourceCommitment', 10)
  mergeSourceCommitments = _messages.StringField(11, repeated=True)
  name = _messages.StringField(12)
  plan = _messages.EnumField('PlanValueValuesEnum', 13)
  region = _messages.StringField(14)
  reservations = _messages.MessageField('Reservation', 15, repeated=True)
  resourceStatus = _messages.MessageField('CommitmentResourceStatus', 16)
  resources = _messages.MessageField('ResourceCommitment', 17, repeated=True)
  selfLink = _messages.StringField(18)
  selfLinkWithId = _messages.StringField(19)
  splitSourceCommitment = _messages.StringField(20)
  startTimestamp = _messages.StringField(21)
  status = _messages.EnumField('StatusValueValuesEnum', 22)
  statusMessage = _messages.StringField(23)
  type = _messages.EnumField('TypeValueValuesEnum', 24)


class CommitmentAggregatedList(_messages.Message):
  r"""A CommitmentAggregatedList object.

  Messages:
    ItemsValue: A list of CommitmentsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of CommitmentsScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#commitmentAggregatedList for aggregated lists of commitments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of CommitmentsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of commitments.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A CommitmentsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('CommitmentsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#commitmentAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class CommitmentList(_messages.Message):
  r"""Contains a list of Commitment resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Commitment resources.
    kind: [Output Only] Type of resource. Always compute#commitmentList for
      lists of commitments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Commitment', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#commitmentList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class CommitmentResourceStatus(_messages.Message):
  r"""[Output Only] Contains output only fields.

  Fields:
    cancellationInformation: [Output Only] An optional, contains all the
      needed information of cancellation.
    customTermEligibilityEndTimestamp: [Output Only] Indicates the end time of
      customer's eligibility to send custom term requests in RFC3339 text
      format. Term extension requests that (not the end time in the request)
      after this time will be rejected.
  """

  cancellationInformation = _messages.MessageField('CommitmentResourceStatusCancellationInformation', 1)
  customTermEligibilityEndTimestamp = _messages.StringField(2)


class CommitmentResourceStatusCancellationInformation(_messages.Message):
  r"""A CommitmentResourceStatusCancellationInformation object.

  Fields:
    canceledCommitment: [Output Only] An optional amount of CUDs canceled so
      far in the last 365 days.
    canceledCommitmentLastUpdatedTimestamp: [Output Only] An optional last
      update time of canceled_commitment. RFC3339 text format.
    cancellationCap: [Output Only] An optional,the cancellation cap for how
      much commitments can be canceled in a rolling 365 per billing account.
    cancellationFee: [Output Only] An optional, cancellation fee.
    cancellationFeeExpirationTimestamp: [Output Only] An optional,
      cancellation fee expiration time. RFC3339 text format.
  """

  canceledCommitment = _messages.MessageField('Money', 1)
  canceledCommitmentLastUpdatedTimestamp = _messages.StringField(2)
  cancellationCap = _messages.MessageField('Money', 3)
  cancellationFee = _messages.MessageField('Money', 4)
  cancellationFeeExpirationTimestamp = _messages.StringField(5)


class CommitmentsScopedList(_messages.Message):
  r"""A CommitmentsScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of commitments when the list is empty.

  Fields:
    commitments: [Output Only] The list of commitments contained in this
      scope.
    warning: [Output Only] Informational warning which replaces the list of
      commitments when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    commitments when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  commitments = _messages.MessageField('Commitment', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class CompositeHealthCheck(_messages.Message):
  r"""Represents a composite health check. A composite health check resource
  specifies the health source resources and the health destination resource to
  which the aggregated health result from the health source resources is
  delivered.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a CompositeHealthCheck. An up-to-date
      fingerprint must be provided in order to patch the CompositeHealthCheck;
      Otherwise, the request will fail with error 412 conditionNotMet. To see
      the latest fingerprint, make a get() request to retrieve the
      CompositeHealthCheck.
    healthDestination: URL to the destination resource. Must be set. Must be a
      ForwardingRule. The ForwardingRule must have load balancing scheme
      INTERNAL or INTERNAL_MANAGED and must be regional and in the same region
      as the CompositeHealthCheck (cross-region deployment for
      INTERNAL_MANAGED is not supported). Can be mutated.
    healthSources: URLs to the HealthSource resources whose results are
      AND'ed. I.e. he aggregated result is is HEALTHY only if all sources are
      HEALTHY. Must have at least 1. Must not have more than 10. Must be
      regional and in the same region as the CompositeHealthCheck. Can be
      mutated.
    id: [Output Only] A unique identifier for this resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always
      compute#compositeHealthCheck for composite health checks.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the composite health check
      resides. This field applies only to the regional resource. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  healthDestination = _messages.StringField(4)
  healthSources = _messages.StringField(5, repeated=True)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#compositeHealthCheck')
  name = _messages.StringField(8)
  region = _messages.StringField(9)
  selfLink = _messages.StringField(10)
  selfLinkWithId = _messages.StringField(11)


class CompositeHealthCheckAggregatedList(_messages.Message):
  r"""Contains a list of CompositeHealthChecksScopedList.

  Messages:
    ItemsValue: A list of CompositeHealthChecksScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of CompositeHealthChecksScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of CompositeHealthChecksScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        CompositeHealthChecks.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A CompositeHealthChecksScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('CompositeHealthChecksScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#compositeHealthCheckAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class CompositeHealthCheckList(_messages.Message):
  r"""A CompositeHealthCheckList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of CompositeHealthCheck resources.
    kind: [Output Only] Type of the resource. Always
      compute#compositeHealthCheck for composite health checks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('CompositeHealthCheck', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#compositeHealthCheckList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class CompositeHealthChecksScopedList(_messages.Message):
  r"""A CompositeHealthChecksScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of composite
      health checks when the list is empty.

  Fields:
    resources: A list of CompositeHealthChecks contained in this scope.
    warning: Informational warning which replaces the list of composite health
      checks when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of composite health
    checks when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  resources = _messages.MessageField('CompositeHealthCheck', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ComputeAcceleratorTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeAcceleratorTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeAcceleratorTypesGetRequest(_messages.Message):
  r"""A ComputeAcceleratorTypesGetRequest object.

  Fields:
    acceleratorType: Name of the accelerator type to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  acceleratorType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeAcceleratorTypesListRequest(_messages.Message):
  r"""A ComputeAcceleratorTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeAddressesAggregatedListRequest(_messages.Message):
  r"""A ComputeAddressesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeAddressesDeleteRequest(_messages.Message):
  r"""A ComputeAddressesDeleteRequest object.

  Fields:
    address: Name of the address resource to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeAddressesGetRequest(_messages.Message):
  r"""A ComputeAddressesGetRequest object.

  Fields:
    address: Name of the address resource to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeAddressesInsertRequest(_messages.Message):
  r"""A ComputeAddressesInsertRequest object.

  Fields:
    address: A Address resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  address = _messages.MessageField('Address', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeAddressesListRequest(_messages.Message):
  r"""A ComputeAddressesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeAddressesMoveRequest(_messages.Message):
  r"""A ComputeAddressesMoveRequest object.

  Fields:
    address: Name of the address resource to move.
    project: Source project ID which the Address is moved from.
    region: Name of the region for this request.
    regionAddressesMoveRequest: A RegionAddressesMoveRequest resource to be
      passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionAddressesMoveRequest = _messages.MessageField('RegionAddressesMoveRequest', 4)
  requestId = _messages.StringField(5)


class ComputeAddressesSetLabelsRequest(_messages.Message):
  r"""A ComputeAddressesSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeAddressesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeAddressesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeAdviceCalendarModeRequest(_messages.Message):
  r"""A ComputeAdviceCalendarModeRequest object.

  Fields:
    calendarModeAdviceRequest: A CalendarModeAdviceRequest resource to be
      passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  calendarModeAdviceRequest = _messages.MessageField('CalendarModeAdviceRequest', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeAutoscalersAggregatedListRequest(_messages.Message):
  r"""A ComputeAutoscalersAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeAutoscalersDeleteRequest(_messages.Message):
  r"""A ComputeAutoscalersDeleteRequest object.

  Fields:
    autoscaler: Name of the autoscaler to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeAutoscalersGetRequest(_messages.Message):
  r"""A ComputeAutoscalersGetRequest object.

  Fields:
    autoscaler: Name of the autoscaler to return.
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeAutoscalersInsertRequest(_messages.Message):
  r"""A ComputeAutoscalersInsertRequest object.

  Fields:
    autoscaler: A Autoscaler resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.MessageField('Autoscaler', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeAutoscalersListRequest(_messages.Message):
  r"""A ComputeAutoscalersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: Name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeAutoscalersPatchRequest(_messages.Message):
  r"""A ComputeAutoscalersPatchRequest object.

  Fields:
    autoscaler: Name of the autoscaler to patch.
    autoscalerResource: A Autoscaler resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.StringField(1)
  autoscalerResource = _messages.MessageField('Autoscaler', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeAutoscalersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeAutoscalersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeAutoscalersUpdateRequest(_messages.Message):
  r"""A ComputeAutoscalersUpdateRequest object.

  Fields:
    autoscaler: Name of the autoscaler to update.
    autoscalerResource: A Autoscaler resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.StringField(1)
  autoscalerResource = _messages.MessageField('Autoscaler', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeBackendBucketsAddSignedUrlKeyRequest(_messages.Message):
  r"""A ComputeBackendBucketsAddSignedUrlKeyRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to which the Signed URL
      Key should be added. The name should conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    signedUrlKey: A SignedUrlKey resource to be passed as the request body.
  """

  backendBucket = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  signedUrlKey = _messages.MessageField('SignedUrlKey', 4)


class ComputeBackendBucketsDeleteRequest(_messages.Message):
  r"""A ComputeBackendBucketsDeleteRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeBackendBucketsDeleteSignedUrlKeyRequest(_messages.Message):
  r"""A ComputeBackendBucketsDeleteSignedUrlKeyRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to which the Signed URL
      Key should be added. The name should conform to RFC1035.
    keyName: The name of the Signed URL Key to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.StringField(1, required=True)
  keyName = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendBucketsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeBackendBucketsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeBackendBucketsGetRequest(_messages.Message):
  r"""A ComputeBackendBucketsGetRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to return.
    project: Project ID for this request.
  """

  backendBucket = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeBackendBucketsInsertRequest(_messages.Message):
  r"""A ComputeBackendBucketsInsertRequest object.

  Fields:
    backendBucket: A BackendBucket resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.MessageField('BackendBucket', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeBackendBucketsListRequest(_messages.Message):
  r"""A ComputeBackendBucketsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeBackendBucketsListUsableRequest(_messages.Message):
  r"""A ComputeBackendBucketsListUsableRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeBackendBucketsPatchRequest(_messages.Message):
  r"""A ComputeBackendBucketsPatchRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to patch.
    backendBucketResource: A BackendBucket resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.StringField(1, required=True)
  backendBucketResource = _messages.MessageField('BackendBucket', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendBucketsSetEdgeSecurityPolicyRequest(_messages.Message):
  r"""A ComputeBackendBucketsSetEdgeSecurityPolicyRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to which the security
      policy should be set. The name should conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicyReference: A SecurityPolicyReference resource to be passed
      as the request body.
  """

  backendBucket = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  securityPolicyReference = _messages.MessageField('SecurityPolicyReference', 4)


class ComputeBackendBucketsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeBackendBucketsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeBackendBucketsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeBackendBucketsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeBackendBucketsUpdateRequest(_messages.Message):
  r"""A ComputeBackendBucketsUpdateRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to update.
    backendBucketResource: A BackendBucket resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.StringField(1, required=True)
  backendBucketResource = _messages.MessageField('BackendBucket', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendServicesAddSignedUrlKeyRequest(_messages.Message):
  r"""A ComputeBackendServicesAddSignedUrlKeyRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the Signed
      URL Key should be added. The name should conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    signedUrlKey: A SignedUrlKey resource to be passed as the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  signedUrlKey = _messages.MessageField('SignedUrlKey', 4)


class ComputeBackendServicesAggregatedListRequest(_messages.Message):
  r"""A ComputeBackendServicesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeBackendServicesDeleteRequest(_messages.Message):
  r"""A ComputeBackendServicesDeleteRequest object.

  Fields:
    backendService: Name of the BackendService resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeBackendServicesDeleteSignedUrlKeyRequest(_messages.Message):
  r"""A ComputeBackendServicesDeleteSignedUrlKeyRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the Signed
      URL Key should be added. The name should conform to RFC1035.
    keyName: The name of the Signed URL Key to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  keyName = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendServicesGetEffectiveSecurityPoliciesRequest(_messages.Message):
  r"""A ComputeBackendServicesGetEffectiveSecurityPoliciesRequest object.

  Fields:
    backendService: Name of the Backend Service for this request.
    project: Project ID for this request.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeBackendServicesGetHealthRequest(_messages.Message):
  r"""A ComputeBackendServicesGetHealthRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the queried
      instance belongs.
    project: A string attribute.
    resourceGroupReference: A ResourceGroupReference resource to be passed as
      the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  resourceGroupReference = _messages.MessageField('ResourceGroupReference', 3)


class ComputeBackendServicesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeBackendServicesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeBackendServicesGetRequest(_messages.Message):
  r"""A ComputeBackendServicesGetRequest object.

  Fields:
    backendService: Name of the BackendService resource to return.
    project: Project ID for this request.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeBackendServicesInsertRequest(_messages.Message):
  r"""A ComputeBackendServicesInsertRequest object.

  Fields:
    backendService: A BackendService resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.MessageField('BackendService', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeBackendServicesListRequest(_messages.Message):
  r"""A ComputeBackendServicesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeBackendServicesListUsableRequest(_messages.Message):
  r"""A ComputeBackendServicesListUsableRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeBackendServicesPatchRequest(_messages.Message):
  r"""A ComputeBackendServicesPatchRequest object.

  Fields:
    backendService: Name of the BackendService resource to patch.
    backendServiceResource: A BackendService resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  backendServiceResource = _messages.MessageField('BackendService', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendServicesSetEdgeSecurityPolicyRequest(_messages.Message):
  r"""A ComputeBackendServicesSetEdgeSecurityPolicyRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the edge
      security policy should be set. The name should conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicyReference: A SecurityPolicyReference resource to be passed
      as the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  securityPolicyReference = _messages.MessageField('SecurityPolicyReference', 4)


class ComputeBackendServicesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeBackendServicesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeBackendServicesSetSecurityPolicyRequest(_messages.Message):
  r"""A ComputeBackendServicesSetSecurityPolicyRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the security
      policy should be set. The name should conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicyReference: A SecurityPolicyReference resource to be passed
      as the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  securityPolicyReference = _messages.MessageField('SecurityPolicyReference', 4)


class ComputeBackendServicesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeBackendServicesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeBackendServicesUpdateRequest(_messages.Message):
  r"""A ComputeBackendServicesUpdateRequest object.

  Fields:
    backendService: Name of the BackendService resource to update.
    backendServiceResource: A BackendService resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  backendServiceResource = _messages.MessageField('BackendService', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeCrossSiteNetworksDeleteRequest(_messages.Message):
  r"""A ComputeCrossSiteNetworksDeleteRequest object.

  Fields:
    crossSiteNetwork: Name of the cross-site network to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  crossSiteNetwork = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeCrossSiteNetworksGetRequest(_messages.Message):
  r"""A ComputeCrossSiteNetworksGetRequest object.

  Fields:
    crossSiteNetwork: Name of the cross-site network to return.
    project: Project ID for this request.
  """

  crossSiteNetwork = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeCrossSiteNetworksInsertRequest(_messages.Message):
  r"""A ComputeCrossSiteNetworksInsertRequest object.

  Fields:
    crossSiteNetwork: A CrossSiteNetwork resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
    validateOnly: [Input Only] Validate the new configuration, but don't
      create it.
  """

  crossSiteNetwork = _messages.MessageField('CrossSiteNetwork', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  validateOnly = _messages.BooleanField(4)


class ComputeCrossSiteNetworksListRequest(_messages.Message):
  r"""A ComputeCrossSiteNetworksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeCrossSiteNetworksPatchRequest(_messages.Message):
  r"""A ComputeCrossSiteNetworksPatchRequest object.

  Fields:
    crossSiteNetwork: Name of the cross-site network to update.
    crossSiteNetworkResource: A CrossSiteNetwork resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
    updateMask: update_mask indicates fields to be updated as part of this
      request.
    validateOnly: [Input Only] Validate the new configuration, but don't
      update it.
  """

  crossSiteNetwork = _messages.StringField(1, required=True)
  crossSiteNetworkResource = _messages.MessageField('CrossSiteNetwork', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  updateMask = _messages.StringField(5)
  validateOnly = _messages.BooleanField(6)


class ComputeDiskSettingsGetRequest(_messages.Message):
  r"""A ComputeDiskSettingsGetRequest object.

  Fields:
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  zone = _messages.StringField(2, required=True)


class ComputeDiskSettingsPatchRequest(_messages.Message):
  r"""A ComputeDiskSettingsPatchRequest object.

  Fields:
    diskSettings: A DiskSettings resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: update_mask indicates fields to be updated as part of this
      request.
    zone: The name of the zone for this request.
  """

  diskSettings = _messages.MessageField('DiskSettings', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  updateMask = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDiskTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeDiskTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeDiskTypesGetRequest(_messages.Message):
  r"""A ComputeDiskTypesGetRequest object.

  Fields:
    diskType: Name of the disk type to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  diskType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeDiskTypesListRequest(_messages.Message):
  r"""A ComputeDiskTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeDisksAddResourcePoliciesRequest(_messages.Message):
  r"""A ComputeDisksAddResourcePoliciesRequest object.

  Fields:
    disk: The disk name for this request.
    disksAddResourcePoliciesRequest: A DisksAddResourcePoliciesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  disksAddResourcePoliciesRequest = _messages.MessageField('DisksAddResourcePoliciesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksAggregatedListRequest(_messages.Message):
  r"""A ComputeDisksAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeDisksBulkInsertRequest(_messages.Message):
  r"""A ComputeDisksBulkInsertRequest object.

  Fields:
    bulkInsertDiskResource: A BulkInsertDiskResource resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  bulkInsertDiskResource = _messages.MessageField('BulkInsertDiskResource', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeDisksBulkSetLabelsRequest(_messages.Message):
  r"""A ComputeDisksBulkSetLabelsRequest object.

  Fields:
    bulkZoneSetLabelsRequest: A BulkZoneSetLabelsRequest resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  bulkZoneSetLabelsRequest = _messages.MessageField('BulkZoneSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resource = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksCreateSnapshotRequest(_messages.Message):
  r"""A ComputeDisksCreateSnapshotRequest object.

  Fields:
    disk: Name of the persistent disk to snapshot.
    guestFlush: [Input Only] Whether to attempt an application consistent
      snapshot by informing the OS to prepare for the snapshot process.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshot: A Snapshot resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  guestFlush = _messages.BooleanField(2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  snapshot = _messages.MessageField('Snapshot', 5)
  zone = _messages.StringField(6, required=True)


class ComputeDisksDeleteRequest(_messages.Message):
  r"""A ComputeDisksDeleteRequest object.

  Fields:
    disk: Name of the persistent disk to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeDisksGetAsyncReplicationStatusRequest(_messages.Message):
  r"""A ComputeDisksGetAsyncReplicationStatusRequest object.

  Fields:
    disk: Name of the Disk resource whose Async replication details are
      requested. Name should conform to RFC1035 or be an unsigned long
      integer.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeDisksGetIamPolicyRequest(_messages.Message):
  r"""A ComputeDisksGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeDisksGetRequest(_messages.Message):
  r"""A ComputeDisksGetRequest object.

  Fields:
    disk: Name of the persistent disk to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeDisksInsertRequest(_messages.Message):
  r"""A ComputeDisksInsertRequest object.

  Fields:
    disk: A Disk resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceImage: Source image to restore onto a disk. This field is optional.
    zone: The name of the zone for this request.
  """

  disk = _messages.MessageField('Disk', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sourceImage = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksListRequest(_messages.Message):
  r"""A ComputeDisksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeDisksRemoveResourcePoliciesRequest(_messages.Message):
  r"""A ComputeDisksRemoveResourcePoliciesRequest object.

  Fields:
    disk: The disk name for this request.
    disksRemoveResourcePoliciesRequest: A DisksRemoveResourcePoliciesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  disksRemoveResourcePoliciesRequest = _messages.MessageField('DisksRemoveResourcePoliciesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksResizeRequest(_messages.Message):
  r"""A ComputeDisksResizeRequest object.

  Fields:
    disk: The name of the persistent disk.
    disksResizeRequest: A DisksResizeRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  disksResizeRequest = _messages.MessageField('DisksResizeRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksSetIamPolicyRequest(_messages.Message):
  r"""A ComputeDisksSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeDisksSetLabelsRequest(_messages.Message):
  r"""A ComputeDisksSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetLabelsRequest: A ZoneSetLabelsRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)
  zoneSetLabelsRequest = _messages.MessageField('ZoneSetLabelsRequest', 5)


class ComputeDisksStartAsyncReplicationRequest(_messages.Message):
  r"""A ComputeDisksStartAsyncReplicationRequest object.

  Fields:
    disk: The name of the persistent disk.
    disksStartAsyncReplicationRequest: A DisksStartAsyncReplicationRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  disksStartAsyncReplicationRequest = _messages.MessageField('DisksStartAsyncReplicationRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksStopAsyncReplicationRequest(_messages.Message):
  r"""A ComputeDisksStopAsyncReplicationRequest object.

  Fields:
    disk: The name of the persistent disk.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeDisksStopGroupAsyncReplicationRequest(_messages.Message):
  r"""A ComputeDisksStopGroupAsyncReplicationRequest object.

  Fields:
    disksStopGroupAsyncReplicationResource: A
      DisksStopGroupAsyncReplicationResource resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request. This must be the zone of the
      primary or secondary disks in the consistency group.
  """

  disksStopGroupAsyncReplicationResource = _messages.MessageField('DisksStopGroupAsyncReplicationResource', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeDisksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeDisksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeDisksUpdateRequest(_messages.Message):
  r"""A ComputeDisksUpdateRequest object.

  Fields:
    disk: The disk name for this request.
    diskResource: A Disk resource to be passed as the request body.
    paths: A string attribute.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: update_mask indicates fields to be updated as part of this
      request.
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  diskResource = _messages.MessageField('Disk', 2)
  paths = _messages.StringField(3, repeated=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  updateMask = _messages.StringField(6)
  zone = _messages.StringField(7, required=True)


class ComputeDisksWaitForReplicationCatchUpRequest(_messages.Message):
  r"""A ComputeDisksWaitForReplicationCatchUpRequest object.

  Fields:
    disk: The name of the persistent disk. Name should conform to RFC1035 or
      be an unsigned long integer.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    waitForReplicationCatchUpRequest: A WaitForReplicationCatchUpRequest
      resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  waitForReplicationCatchUpRequest = _messages.MessageField('WaitForReplicationCatchUpRequest', 4)
  zone = _messages.StringField(5, required=True)


class ComputeExternalVpnGatewaysDeleteRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysDeleteRequest object.

  Fields:
    externalVpnGateway: Name of the externalVpnGateways to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  externalVpnGateway = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeExternalVpnGatewaysGetRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysGetRequest object.

  Fields:
    externalVpnGateway: Name of the externalVpnGateway to return.
    project: Project ID for this request.
  """

  externalVpnGateway = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeExternalVpnGatewaysInsertRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysInsertRequest object.

  Fields:
    externalVpnGateway: A ExternalVpnGateway resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  externalVpnGateway = _messages.MessageField('ExternalVpnGateway', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeExternalVpnGatewaysListRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeExternalVpnGatewaysSetLabelsRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeExternalVpnGatewaysTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeFirewallPoliciesAddAssociationRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesAddAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyAssociation: A FirewallPolicyAssociation resource to be
      passed as the request body.
    replaceExistingAssociation: Indicates whether or not to replace it if an
      association of the attachment already exists. This is false by default,
      in which case an error will be returned if an association already
      exists.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyAssociation = _messages.MessageField('FirewallPolicyAssociation', 2)
  replaceExistingAssociation = _messages.BooleanField(3)
  requestId = _messages.StringField(4)


class ComputeFirewallPoliciesAddPacketMirroringRuleRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesAddPacketMirroringRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  requestId = _messages.StringField(3)


class ComputeFirewallPoliciesAddRuleRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesAddRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  requestId = _messages.StringField(3)


class ComputeFirewallPoliciesCloneRulesRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesCloneRulesRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceFirewallPolicy: The firewall policy from which to copy rules.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sourceFirewallPolicy = _messages.StringField(3)


class ComputeFirewallPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesDeleteRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to delete.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)


class ComputeFirewallPoliciesGetAssociationRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesGetAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to which the queried rule
      belongs.
    name: The name of the association to get from the firewall policy.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  name = _messages.StringField(2)


class ComputeFirewallPoliciesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  resource = _messages.StringField(2, required=True)


class ComputeFirewallPoliciesGetPacketMirroringRuleRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesGetPacketMirroringRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to which the queried rule
      belongs.
    priority: The priority of the rule to get from the firewall policy.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class ComputeFirewallPoliciesGetRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesGetRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to get.
  """

  firewallPolicy = _messages.StringField(1, required=True)


class ComputeFirewallPoliciesGetRuleRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesGetRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to which the queried rule
      belongs.
    priority: The priority of the rule to get from the firewall policy.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class ComputeFirewallPoliciesInsertRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesInsertRequest object.

  Fields:
    firewallPolicy: A FirewallPolicy resource to be passed as the request
      body.
    parentId: Parent ID for this request. The ID can be either be
      "folders/[FOLDER_ID]" if the parent is a folder or
      "organizations/[ORGANIZATION_ID]" if the parent is an organization.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.MessageField('FirewallPolicy', 1)
  parentId = _messages.StringField(2)
  requestId = _messages.StringField(3)


class ComputeFirewallPoliciesListAssociationsRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesListAssociationsRequest object.

  Fields:
    targetResource: The target resource to list associations. It is an
      organization, or a folder.
  """

  targetResource = _messages.StringField(1)


class ComputeFirewallPoliciesListRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    parentId: Parent ID for this request. The ID can be either be
      "folders/[FOLDER_ID]" if the parent is a folder or
      "organizations/[ORGANIZATION_ID]" if the parent is an organization.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  parentId = _messages.StringField(5)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeFirewallPoliciesMoveRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesMoveRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    parentId: The new parent of the firewall policy. The ID can be either be
      "folders/[FOLDER_ID]" if the parent is a folder or
      "organizations/[ORGANIZATION_ID]" if the parent is an organization.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  parentId = _messages.StringField(2)
  requestId = _messages.StringField(3)


class ComputeFirewallPoliciesPatchPacketMirroringRuleRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesPatchPacketMirroringRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    priority: The priority of the rule to patch.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  priority = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  requestId = _messages.StringField(4)


class ComputeFirewallPoliciesPatchRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesPatchRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyResource: A FirewallPolicy resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyResource = _messages.MessageField('FirewallPolicy', 2)
  requestId = _messages.StringField(3)


class ComputeFirewallPoliciesPatchRuleRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesPatchRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    priority: The priority of the rule to patch.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  priority = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  requestId = _messages.StringField(4)


class ComputeFirewallPoliciesRemoveAssociationRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesRemoveAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    name: Name for the attachment that will be removed.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  name = _messages.StringField(2)
  requestId = _messages.StringField(3)


class ComputeFirewallPoliciesRemovePacketMirroringRuleRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesRemovePacketMirroringRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    priority: The priority of the rule to remove from the firewall policy.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  requestId = _messages.StringField(3)


class ComputeFirewallPoliciesRemoveRuleRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesRemoveRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    priority: The priority of the rule to remove from the firewall policy.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  requestId = _messages.StringField(3)


class ComputeFirewallPoliciesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesSetIamPolicyRequest object.

  Fields:
    globalOrganizationSetPolicyRequest: A GlobalOrganizationSetPolicyRequest
      resource to be passed as the request body.
    resource: Name or id of the resource for this request.
  """

  globalOrganizationSetPolicyRequest = _messages.MessageField('GlobalOrganizationSetPolicyRequest', 1)
  resource = _messages.StringField(2, required=True)


class ComputeFirewallPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeFirewallPoliciesTestIamPermissionsRequest object.

  Fields:
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  resource = _messages.StringField(1, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 2)


class ComputeFirewallsDeleteRequest(_messages.Message):
  r"""A ComputeFirewallsDeleteRequest object.

  Fields:
    firewall: Name of the firewall rule to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewall = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeFirewallsGetRequest(_messages.Message):
  r"""A ComputeFirewallsGetRequest object.

  Fields:
    firewall: Name of the firewall rule to return.
    project: Project ID for this request.
  """

  firewall = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeFirewallsInsertRequest(_messages.Message):
  r"""A ComputeFirewallsInsertRequest object.

  Fields:
    firewall: A Firewall resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewall = _messages.MessageField('Firewall', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeFirewallsListRequest(_messages.Message):
  r"""A ComputeFirewallsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeFirewallsPatchRequest(_messages.Message):
  r"""A ComputeFirewallsPatchRequest object.

  Fields:
    firewall: Name of the firewall rule to patch.
    firewallResource: A Firewall resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewall = _messages.StringField(1, required=True)
  firewallResource = _messages.MessageField('Firewall', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeFirewallsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeFirewallsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeFirewallsUpdateRequest(_messages.Message):
  r"""A ComputeFirewallsUpdateRequest object.

  Fields:
    firewall: Name of the firewall rule to update.
    firewallResource: A Firewall resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewall = _messages.StringField(1, required=True)
  firewallResource = _messages.MessageField('Firewall', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeForwardingRulesAggregatedListRequest(_messages.Message):
  r"""A ComputeForwardingRulesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeForwardingRulesDeleteRequest(_messages.Message):
  r"""A ComputeForwardingRulesDeleteRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeForwardingRulesGetRequest(_messages.Message):
  r"""A ComputeForwardingRulesGetRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeForwardingRulesInsertRequest(_messages.Message):
  r"""A ComputeForwardingRulesInsertRequest object.

  Fields:
    forwardingRule: A ForwardingRule resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.MessageField('ForwardingRule', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeForwardingRulesListRequest(_messages.Message):
  r"""A ComputeForwardingRulesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeForwardingRulesPatchRequest(_messages.Message):
  r"""A ComputeForwardingRulesPatchRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to patch.
    forwardingRuleResource: A ForwardingRule resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.StringField(1, required=True)
  forwardingRuleResource = _messages.MessageField('ForwardingRule', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeForwardingRulesSetLabelsRequest(_messages.Message):
  r"""A ComputeForwardingRulesSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeForwardingRulesSetTargetRequest(_messages.Message):
  r"""A ComputeForwardingRulesSetTargetRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource in which target is to
      be set.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetReference: A TargetReference resource to be passed as the request
      body.
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  targetReference = _messages.MessageField('TargetReference', 5)


class ComputeForwardingRulesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeForwardingRulesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeFutureReservationsAggregatedListRequest(_messages.Message):
  r"""A ComputeFutureReservationsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeFutureReservationsCancelRequest(_messages.Message):
  r"""A ComputeFutureReservationsCancelRequest object.

  Fields:
    futureReservation: Name of the future reservation to retrieve. Name should
      conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request. Name should conform to RFC1035.
  """

  futureReservation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeFutureReservationsDeleteRequest(_messages.Message):
  r"""A ComputeFutureReservationsDeleteRequest object.

  Fields:
    futureReservation: Name of the future reservation to retrieve. Name should
      conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request. Name should conform to RFC1035.
  """

  futureReservation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeFutureReservationsGetRequest(_messages.Message):
  r"""A ComputeFutureReservationsGetRequest object.

  Fields:
    futureReservation: Name of the future reservation to retrieve. Name should
      conform to RFC1035.
    project: Project ID for this request.
    zone: Name of the zone for this request. Name should conform to RFC1035.
  """

  futureReservation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeFutureReservationsInsertRequest(_messages.Message):
  r"""A ComputeFutureReservationsInsertRequest object.

  Fields:
    futureReservation: A FutureReservation resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request. Name should conform to RFC1035.
  """

  futureReservation = _messages.MessageField('FutureReservation', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeFutureReservationsListRequest(_messages.Message):
  r"""A ComputeFutureReservationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: Name of the zone for this request. Name should conform to RFC1035.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeFutureReservationsUpdateRequest(_messages.Message):
  r"""A ComputeFutureReservationsUpdateRequest object.

  Fields:
    futureReservation: Name of the reservation to update. Name should conform
      to RFC1035.
    futureReservationResource: A FutureReservation resource to be passed as
      the request body.
    paths: A string attribute.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: update_mask indicates fields to be updated as part of this
      request.
    zone: Name of the zone for this request. Name should conform to RFC1035.
  """

  futureReservation = _messages.StringField(1, required=True)
  futureReservationResource = _messages.MessageField('FutureReservation', 2)
  paths = _messages.StringField(3, repeated=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  updateMask = _messages.StringField(6)
  zone = _messages.StringField(7, required=True)


class ComputeGlobalAddressesDeleteRequest(_messages.Message):
  r"""A ComputeGlobalAddressesDeleteRequest object.

  Fields:
    address: Name of the address resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalAddressesGetOwnerInstanceRequest(_messages.Message):
  r"""A ComputeGlobalAddressesGetOwnerInstanceRequest object.

  Fields:
    ipAddress: The VM IP address.
    project: Project ID for this request.
  """

  ipAddress = _messages.StringField(1)
  project = _messages.StringField(2, required=True)


class ComputeGlobalAddressesGetRequest(_messages.Message):
  r"""A ComputeGlobalAddressesGetRequest object.

  Fields:
    address: Name of the address resource to return.
    project: Project ID for this request.
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalAddressesInsertRequest(_messages.Message):
  r"""A ComputeGlobalAddressesInsertRequest object.

  Fields:
    address: A Address resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  address = _messages.MessageField('Address', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalAddressesListRequest(_messages.Message):
  r"""A ComputeGlobalAddressesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalAddressesMoveRequest(_messages.Message):
  r"""A ComputeGlobalAddressesMoveRequest object.

  Fields:
    address: Name of the address resource to move.
    globalAddressesMoveRequest: A GlobalAddressesMoveRequest resource to be
      passed as the request body.
    project: Source project ID which the Address is moved from.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  address = _messages.StringField(1, required=True)
  globalAddressesMoveRequest = _messages.MessageField('GlobalAddressesMoveRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeGlobalAddressesSetLabelsRequest(_messages.Message):
  r"""A ComputeGlobalAddressesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeGlobalAddressesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeGlobalAddressesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeGlobalForwardingRulesDeleteRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesDeleteRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalForwardingRulesGetRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesGetRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to return.
    project: Project ID for this request.
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalForwardingRulesInsertRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesInsertRequest object.

  Fields:
    forwardingRule: A ForwardingRule resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.MessageField('ForwardingRule', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalForwardingRulesListRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalForwardingRulesPatchRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesPatchRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to patch.
    forwardingRuleResource: A ForwardingRule resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.StringField(1, required=True)
  forwardingRuleResource = _messages.MessageField('ForwardingRule', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeGlobalForwardingRulesSetLabelsRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeGlobalForwardingRulesSetTargetRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesSetTargetRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource in which target is to
      be set.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetReference: A TargetReference resource to be passed as the request
      body.
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetReference = _messages.MessageField('TargetReference', 4)


class ComputeGlobalForwardingRulesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeGlobalNetworkEndpointGroupsAttachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsAttachNetworkEndpointsRequest
  object.

  Fields:
    globalNetworkEndpointGroupsAttachEndpointsRequest: A
      GlobalNetworkEndpointGroupsAttachEndpointsRequest resource to be passed
      as the request body.
    networkEndpointGroup: The name of the network endpoint group where you are
      attaching network endpoints to. It should comply with RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  globalNetworkEndpointGroupsAttachEndpointsRequest = _messages.MessageField('GlobalNetworkEndpointGroupsAttachEndpointsRequest', 1)
  networkEndpointGroup = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeGlobalNetworkEndpointGroupsDeleteRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsDeleteRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group to delete. It
      should comply with RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalNetworkEndpointGroupsDetachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsDetachNetworkEndpointsRequest
  object.

  Fields:
    globalNetworkEndpointGroupsDetachEndpointsRequest: A
      GlobalNetworkEndpointGroupsDetachEndpointsRequest resource to be passed
      as the request body.
    networkEndpointGroup: The name of the network endpoint group where you are
      removing network endpoints. It should comply with RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  globalNetworkEndpointGroupsDetachEndpointsRequest = _messages.MessageField('GlobalNetworkEndpointGroupsDetachEndpointsRequest', 1)
  networkEndpointGroup = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeGlobalNetworkEndpointGroupsGetRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsGetRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group. It should
      comply with RFC1035.
    project: Project ID for this request.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalNetworkEndpointGroupsInsertRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsInsertRequest object.

  Fields:
    networkEndpointGroup: A NetworkEndpointGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.MessageField('NetworkEndpointGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalNetworkEndpointGroupsListNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsListNetworkEndpointsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    networkEndpointGroup: The name of the network endpoint group from which
      you want to generate a list of included network endpoints. It should
      comply with RFC1035.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  networkEndpointGroup = _messages.StringField(3, required=True)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeGlobalNetworkEndpointGroupsListRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalOperationsAggregatedListRequest(_messages.Message):
  r"""A ComputeGlobalOperationsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeGlobalOperationsDeleteRequest(_messages.Message):
  r"""A ComputeGlobalOperationsDeleteRequest object.

  Fields:
    operation: Name of the Operations resource to delete, or its unique
      numeric identifier.
    project: Project ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalOperationsDeleteResponse(_messages.Message):
  r"""An empty ComputeGlobalOperationsDelete response."""


class ComputeGlobalOperationsGetRequest(_messages.Message):
  r"""A ComputeGlobalOperationsGetRequest object.

  Fields:
    operation: Name of the Operations resource to return, or its unique
      numeric identifier.
    project: Project ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalOperationsListRequest(_messages.Message):
  r"""A ComputeGlobalOperationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalOperationsWaitRequest(_messages.Message):
  r"""A ComputeGlobalOperationsWaitRequest object.

  Fields:
    operation: Name of the Operations resource to return, or its unique
      numeric identifier.
    project: Project ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalOrganizationOperationsDeleteRequest(_messages.Message):
  r"""A ComputeGlobalOrganizationOperationsDeleteRequest object.

  Fields:
    operation: Name of the Operations resource to delete, or its unique
      numeric identifier.
    parentId: Parent ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  parentId = _messages.StringField(2)


class ComputeGlobalOrganizationOperationsDeleteResponse(_messages.Message):
  r"""An empty ComputeGlobalOrganizationOperationsDelete response."""


class ComputeGlobalOrganizationOperationsGetRequest(_messages.Message):
  r"""A ComputeGlobalOrganizationOperationsGetRequest object.

  Fields:
    operation: Name of the Operations resource to return, or its unique
      numeric identifier.
    parentId: Parent ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  parentId = _messages.StringField(2)


class ComputeGlobalOrganizationOperationsListRequest(_messages.Message):
  r"""A ComputeGlobalOrganizationOperationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    parentId: Parent ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  parentId = _messages.StringField(5)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalPublicDelegatedPrefixesDeleteRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      delete.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalPublicDelegatedPrefixesGetRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesGetRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      return.
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)


class ComputeGlobalPublicDelegatedPrefixesInsertRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesInsertRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: A PublicDelegatedPrefix resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.MessageField('PublicDelegatedPrefix', 2)
  requestId = _messages.StringField(3)


class ComputeGlobalPublicDelegatedPrefixesListRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalPublicDelegatedPrefixesPatchRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesPatchRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      patch.
    publicDelegatedPrefixResource: A PublicDelegatedPrefix resource to be
      passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  publicDelegatedPrefixResource = _messages.MessageField('PublicDelegatedPrefix', 3)
  requestId = _messages.StringField(4)


class ComputeHealthChecksAggregatedListRequest(_messages.Message):
  r"""A ComputeHealthChecksAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeHealthChecksDeleteRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHealthChecksGetRequest(_messages.Message):
  r"""A ComputeHealthChecksGetRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to return.
    project: Project ID for this request.
  """

  healthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeHealthChecksInsertRequest object.

  Fields:
    healthCheck: A HealthCheck resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.MessageField('HealthCheck', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHealthChecksListRequest(_messages.Message):
  r"""A ComputeHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeHealthChecksPatchRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to patch.
    healthCheckResource: A HealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  healthCheckResource = _messages.MessageField('HealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeHealthChecksUpdateRequest(_messages.Message):
  r"""A ComputeHealthChecksUpdateRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to update.
    healthCheckResource: A HealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  healthCheckResource = _messages.MessageField('HealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHttpHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksDeleteRequest object.

  Fields:
    httpHealthCheck: Name of the HttpHealthCheck resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  httpHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHttpHealthChecksGetRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksGetRequest object.

  Fields:
    httpHealthCheck: Name of the HttpHealthCheck resource to return.
    project: Project ID for this request.
  """

  httpHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeHttpHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksInsertRequest object.

  Fields:
    httpHealthCheck: A HttpHealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  httpHealthCheck = _messages.MessageField('HttpHealthCheck', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHttpHealthChecksListRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeHttpHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksPatchRequest object.

  Fields:
    httpHealthCheck: Name of the HttpHealthCheck resource to patch.
    httpHealthCheckResource: A HttpHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  httpHealthCheck = _messages.StringField(1, required=True)
  httpHealthCheckResource = _messages.MessageField('HttpHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHttpHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeHttpHealthChecksUpdateRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksUpdateRequest object.

  Fields:
    httpHealthCheck: Name of the HttpHealthCheck resource to update.
    httpHealthCheckResource: A HttpHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  httpHealthCheck = _messages.StringField(1, required=True)
  httpHealthCheckResource = _messages.MessageField('HttpHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHttpsHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksDeleteRequest object.

  Fields:
    httpsHealthCheck: Name of the HttpsHealthCheck resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  httpsHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHttpsHealthChecksGetRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksGetRequest object.

  Fields:
    httpsHealthCheck: Name of the HttpsHealthCheck resource to return.
    project: Project ID for this request.
  """

  httpsHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeHttpsHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksInsertRequest object.

  Fields:
    httpsHealthCheck: A HttpsHealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  httpsHealthCheck = _messages.MessageField('HttpsHealthCheck', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHttpsHealthChecksListRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeHttpsHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksPatchRequest object.

  Fields:
    httpsHealthCheck: Name of the HttpsHealthCheck resource to patch.
    httpsHealthCheckResource: A HttpsHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  httpsHealthCheck = _messages.StringField(1, required=True)
  httpsHealthCheckResource = _messages.MessageField('HttpsHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHttpsHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeHttpsHealthChecksUpdateRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksUpdateRequest object.

  Fields:
    httpsHealthCheck: Name of the HttpsHealthCheck resource to update.
    httpsHealthCheckResource: A HttpsHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  httpsHealthCheck = _messages.StringField(1, required=True)
  httpsHealthCheckResource = _messages.MessageField('HttpsHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeImageFamilyViewsGetRequest(_messages.Message):
  r"""A ComputeImageFamilyViewsGetRequest object.

  Fields:
    family: Name of the image family to search for.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  family = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeImagesDeleteRequest(_messages.Message):
  r"""A ComputeImagesDeleteRequest object.

  Fields:
    image: Name of the image resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  image = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeImagesDeprecateRequest(_messages.Message):
  r"""A ComputeImagesDeprecateRequest object.

  Fields:
    deprecationStatus: A DeprecationStatus resource to be passed as the
      request body.
    image: Image name.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  deprecationStatus = _messages.MessageField('DeprecationStatus', 1)
  image = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeImagesGetFromFamilyRequest(_messages.Message):
  r"""A ComputeImagesGetFromFamilyRequest object.

  Fields:
    family: Name of the image family to search for.
    project: The image project that the image belongs to. For example, to get
      a CentOS image, specify centos-cloud as the image project.
  """

  family = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeImagesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeImagesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeImagesGetRequest(_messages.Message):
  r"""A ComputeImagesGetRequest object.

  Fields:
    image: Name of the image resource to return.
    project: Project ID for this request.
  """

  image = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeImagesInsertRequest(_messages.Message):
  r"""A ComputeImagesInsertRequest object.

  Fields:
    forceCreate: Force image creation if true.
    image: A Image resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  forceCreate = _messages.BooleanField(1)
  image = _messages.MessageField('Image', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeImagesListRequest(_messages.Message):
  r"""A ComputeImagesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The zone query parameter.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7)


class ComputeImagesPatchRequest(_messages.Message):
  r"""A ComputeImagesPatchRequest object.

  Fields:
    image: Name of the image resource to patch.
    imageResource: A Image resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  image = _messages.StringField(1, required=True)
  imageResource = _messages.MessageField('Image', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeImagesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeImagesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeImagesSetLabelsRequest(_messages.Message):
  r"""A ComputeImagesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeImagesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeImagesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInstanceGroupManagerResizeRequestsCancelRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagerResizeRequestsCancelRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. The name
      should conform to RFC1035 or be a resource ID.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resizeRequest: The name of the resize request to cancel. The name should
      conform to RFC1035 or be a resource ID.
    zone: The name of the zone where the managed instance group is located.
      The name should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resizeRequest = _messages.StringField(4, required=True)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagerResizeRequestsDeleteRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagerResizeRequestsDeleteRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. The name
      should conform to RFC1035 or be a resource ID.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resizeRequest: The name of the resize request to delete. The name should
      conform to RFC1035 or be a resource ID.
    zone: The name of the zone where the managed instance group is located.
      The name should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resizeRequest = _messages.StringField(4, required=True)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagerResizeRequestsGetRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagerResizeRequestsGetRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. Name should
      conform to RFC1035 or be a resource ID.
    project: Project ID for this request.
    resizeRequest: The name of the resize request. Name should conform to
      RFC1035 or be a resource ID.
    zone: Name of the href="/compute/docs/regions-zones/#available">zone
      scoping this request. Name should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  resizeRequest = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagerResizeRequestsInsertRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagerResizeRequestsInsertRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group to which the
      resize request will be added. Name should conform to RFC1035 or be a
      resource ID.
    instanceGroupManagerResizeRequest: A InstanceGroupManagerResizeRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located and
      where the resize request will be created. Name should conform to
      RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResizeRequest = _messages.MessageField('InstanceGroupManagerResizeRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagerResizeRequestsListRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagerResizeRequestsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroupManager: The name of the managed instance group. The name
      should conform to RFC1035.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the managed instance group is located.
      The name should conform to RFC1035.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstanceGroupManagersAbandonInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersAbandonInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersAbandonInstancesRequest: A
      InstanceGroupManagersAbandonInstancesRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersAbandonInstancesRequest = _messages.MessageField('InstanceGroupManagersAbandonInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersAggregatedListRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeInstanceGroupManagersApplyUpdatesToInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersApplyUpdatesToInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group, should
      conform to RFC1035.
    instanceGroupManagersApplyUpdatesRequest: A
      InstanceGroupManagersApplyUpdatesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    zone: The name of the zone where the managed instance group is located.
      Should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersApplyUpdatesRequest = _messages.MessageField('InstanceGroupManagersApplyUpdatesRequest', 2)
  project = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersCreateInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersCreateInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    instanceGroupManagersCreateInstancesRequest: A
      InstanceGroupManagersCreateInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. The request ID must
      be a valid UUID with the exception that zero UUID is not supported (
      00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersCreateInstancesRequest = _messages.MessageField('InstanceGroupManagersCreateInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersDeleteInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersDeleteInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersDeleteInstancesRequest: A
      InstanceGroupManagersDeleteInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersDeleteInstancesRequest = _messages.MessageField('InstanceGroupManagersDeleteInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersDeletePerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersDeletePerInstanceConfigsRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    instanceGroupManagersDeletePerInstanceConfigsReq: A
      InstanceGroupManagersDeletePerInstanceConfigsReq resource to be passed
      as the request body.
    project: Project ID for this request.
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersDeletePerInstanceConfigsReq = _messages.MessageField('InstanceGroupManagersDeletePerInstanceConfigsReq', 2)
  project = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersDeleteRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersDeleteRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersGetRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersGetRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    project: Project ID for this request.
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstanceGroupManagersInsertRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersInsertRequest object.

  Fields:
    instanceGroupManager: A InstanceGroupManager resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the managed instance
      group.
  """

  instanceGroupManager = _messages.MessageField('InstanceGroupManager', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersListErrorsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersListErrorsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroupManager: The name of the managed instance group. It must be a
      string that meets the requirements in RFC1035, or an unsigned long
      integer: must match regexp pattern:
      (?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?)|1-9{0,19}.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstanceGroupManagersListManagedInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersListManagedInstancesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroupManager: The name of the managed instance group.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the managed instance group is located.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstanceGroupManagersListPerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersListPerInstanceConfigsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstanceGroupManagersListRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the managed instance group is located.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeInstanceGroupManagersPatchPerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersPatchPerInstanceConfigsRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    instanceGroupManagersPatchPerInstanceConfigsReq: A
      InstanceGroupManagersPatchPerInstanceConfigsReq resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersPatchPerInstanceConfigsReq = _messages.MessageField('InstanceGroupManagersPatchPerInstanceConfigsReq', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersPatchRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersPatchRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagerResource: A InstanceGroupManager resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the managed instance
      group.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResource = _messages.MessageField('InstanceGroupManager', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersRecreateInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersRecreateInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersRecreateInstancesRequest: A
      InstanceGroupManagersRecreateInstancesRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersRecreateInstancesRequest = _messages.MessageField('InstanceGroupManagersRecreateInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersResizeAdvancedRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersResizeAdvancedRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersResizeAdvancedRequest: A
      InstanceGroupManagersResizeAdvancedRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersResizeAdvancedRequest = _messages.MessageField('InstanceGroupManagersResizeAdvancedRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersResizeRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersResizeRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    size: The number of running instances that the managed instance group
      should maintain at any given time. The group automatically adds or
      removes instances to maintain the number of instances specified by this
      parameter.
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  size = _messages.IntegerField(4, required=True, variant=_messages.Variant.INT32)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersResumeInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersResumeInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersResumeInstancesRequest: A
      InstanceGroupManagersResumeInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersResumeInstancesRequest = _messages.MessageField('InstanceGroupManagersResumeInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersSetAutoHealingPoliciesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersSetAutoHealingPoliciesRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagersSetAutoHealingRequest: A
      InstanceGroupManagersSetAutoHealingRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersSetAutoHealingRequest = _messages.MessageField('InstanceGroupManagersSetAutoHealingRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersSetInstanceTemplateRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersSetInstanceTemplateRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersSetInstanceTemplateRequest: A
      InstanceGroupManagersSetInstanceTemplateRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersSetInstanceTemplateRequest = _messages.MessageField('InstanceGroupManagersSetInstanceTemplateRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersSetTargetPoolsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersSetTargetPoolsRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersSetTargetPoolsRequest: A
      InstanceGroupManagersSetTargetPoolsRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersSetTargetPoolsRequest = _messages.MessageField('InstanceGroupManagersSetTargetPoolsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersStartInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersStartInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersStartInstancesRequest: A
      InstanceGroupManagersStartInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersStartInstancesRequest = _messages.MessageField('InstanceGroupManagersStartInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersStopInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersStopInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersStopInstancesRequest: A
      InstanceGroupManagersStopInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersStopInstancesRequest = _messages.MessageField('InstanceGroupManagersStopInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersSuspendInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersSuspendInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersSuspendInstancesRequest: A
      InstanceGroupManagersSuspendInstancesRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersSuspendInstancesRequest = _messages.MessageField('InstanceGroupManagersSuspendInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersUpdatePerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersUpdatePerInstanceConfigsRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    instanceGroupManagersUpdatePerInstanceConfigsReq: A
      InstanceGroupManagersUpdatePerInstanceConfigsReq resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersUpdatePerInstanceConfigsReq = _messages.MessageField('InstanceGroupManagersUpdatePerInstanceConfigsReq', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersUpdateRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersUpdateRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagerResource: A InstanceGroupManager resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the managed instance
      group.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResource = _messages.MessageField('InstanceGroupManager', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupsAddInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupsAddInstancesRequest object.

  Fields:
    instanceGroup: The name of the instance group where you are adding
      instances.
    instanceGroupsAddInstancesRequest: A InstanceGroupsAddInstancesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  instanceGroupsAddInstancesRequest = _messages.MessageField('InstanceGroupsAddInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupsAggregatedListRequest(_messages.Message):
  r"""A ComputeInstanceGroupsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeInstanceGroupsDeleteRequest(_messages.Message):
  r"""A ComputeInstanceGroupsDeleteRequest object.

  Fields:
    instanceGroup: The name of the instance group to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupsGetRequest(_messages.Message):
  r"""A ComputeInstanceGroupsGetRequest object.

  Fields:
    instanceGroup: The name of the instance group.
    project: Project ID for this request.
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstanceGroupsInsertRequest(_messages.Message):
  r"""A ComputeInstanceGroupsInsertRequest object.

  Fields:
    instanceGroup: A InstanceGroup resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the instance group.
  """

  instanceGroup = _messages.MessageField('InstanceGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupsListInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupsListInstancesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroup: The name of the instance group from which you want to
      generate a list of included instances.
    instanceGroupsListInstancesRequest: A InstanceGroupsListInstancesRequest
      resource to be passed as the request body.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the instance group is located.
  """

  filter = _messages.StringField(1)
  instanceGroup = _messages.StringField(2, required=True)
  instanceGroupsListInstancesRequest = _messages.MessageField('InstanceGroupsListInstancesRequest', 3)
  maxResults = _messages.IntegerField(4, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(5)
  pageToken = _messages.StringField(6)
  project = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)
  zone = _messages.StringField(9, required=True)


class ComputeInstanceGroupsListRequest(_messages.Message):
  r"""A ComputeInstanceGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the instance group is located.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeInstanceGroupsRemoveInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupsRemoveInstancesRequest object.

  Fields:
    instanceGroup: The name of the instance group where the specified
      instances will be removed.
    instanceGroupsRemoveInstancesRequest: A
      InstanceGroupsRemoveInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  instanceGroupsRemoveInstancesRequest = _messages.MessageField('InstanceGroupsRemoveInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupsSetNamedPortsRequest(_messages.Message):
  r"""A ComputeInstanceGroupsSetNamedPortsRequest object.

  Fields:
    instanceGroup: The name of the instance group where the named ports are
      updated.
    instanceGroupsSetNamedPortsRequest: A InstanceGroupsSetNamedPortsRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  instanceGroupsSetNamedPortsRequest = _messages.MessageField('InstanceGroupsSetNamedPortsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstanceGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceSettingsGetRequest(_messages.Message):
  r"""A ComputeInstanceSettingsGetRequest object.

  Fields:
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  zone = _messages.StringField(2, required=True)


class ComputeInstanceSettingsPatchRequest(_messages.Message):
  r"""A ComputeInstanceSettingsPatchRequest object.

  Fields:
    instanceSettings: A InstanceSettings resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: update_mask indicates fields to be updated as part of this
      request.
    zone: The zone scoping this request. It should conform to RFC1035.
  """

  instanceSettings = _messages.MessageField('InstanceSettings', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  updateMask = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceTemplatesAggregatedListRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeInstanceTemplatesDeleteRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesDeleteRequest object.

  Fields:
    instanceTemplate: The name of the instance template to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInstanceTemplatesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInstanceTemplatesGetRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesGetRequest object.

  Enums:
    ViewValueValuesEnum: View of the instance template.

  Fields:
    instanceTemplate: The name of the instance template.
    project: Project ID for this request.
    view: View of the instance template.
  """

  class ViewValueValuesEnum(_messages.Enum):
    r"""View of the instance template.

    Values:
      BASIC: Include everything except Partner Metadata.
      FULL: Include everything.
      INSTANCE_VIEW_UNSPECIFIED: The default / unset value. The API will
        default to the BASIC view.
    """
    BASIC = 0
    FULL = 1
    INSTANCE_VIEW_UNSPECIFIED = 2

  instanceTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  view = _messages.EnumField('ViewValueValuesEnum', 3)


class ComputeInstanceTemplatesInsertRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesInsertRequest object.

  Fields:
    instanceTemplate: A InstanceTemplate resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceTemplate = _messages.MessageField('InstanceTemplate', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInstanceTemplatesListRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesListRequest object.

  Enums:
    ViewValueValuesEnum: View of the instance template.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    view: View of the instance template.
  """

  class ViewValueValuesEnum(_messages.Enum):
    r"""View of the instance template.

    Values:
      BASIC: Include everything except Partner Metadata.
      FULL: Include everything.
      INSTANCE_VIEW_UNSPECIFIED: The default / unset value. The API will
        default to the BASIC view.
    """
    BASIC = 0
    FULL = 1
    INSTANCE_VIEW_UNSPECIFIED = 2

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  view = _messages.EnumField('ViewValueValuesEnum', 7)


class ComputeInstanceTemplatesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInstanceTemplatesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInstancesAddAccessConfigRequest(_messages.Message):
  r"""A ComputeInstancesAddAccessConfigRequest object.

  Fields:
    accessConfig: A AccessConfig resource to be passed as the request body.
    instance: The instance name for this request.
    networkInterface: The name of the network interface to add to this
      instance.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  accessConfig = _messages.MessageField('AccessConfig', 1)
  instance = _messages.StringField(2, required=True)
  networkInterface = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesAddNetworkInterfaceRequest(_messages.Message):
  r"""A ComputeInstancesAddNetworkInterfaceRequest object.

  Fields:
    instance: The instance name for this request stored as resource_id. Name
      should conform to RFC1035 or be an unsigned long integer.
    networkInterface: A NetworkInterface resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  networkInterface = _messages.MessageField('NetworkInterface', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesAddResourcePoliciesRequest(_messages.Message):
  r"""A ComputeInstancesAddResourcePoliciesRequest object.

  Fields:
    instance: The instance name for this request.
    instancesAddResourcePoliciesRequest: A InstancesAddResourcePoliciesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesAddResourcePoliciesRequest = _messages.MessageField('InstancesAddResourcePoliciesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesAggregatedListRequest(_messages.Message):
  r"""A ComputeInstancesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeInstancesAttachDiskRequest(_messages.Message):
  r"""A ComputeInstancesAttachDiskRequest object.

  Fields:
    attachedDisk: A AttachedDisk resource to be passed as the request body.
    forceAttach: Whether to force attach the regional disk even if it's
      currently attached to another instance. If you try to force attach a
      zonal disk to an instance, you will receive an error.
    instance: The instance name for this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  attachedDisk = _messages.MessageField('AttachedDisk', 1)
  forceAttach = _messages.BooleanField(2)
  instance = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesBulkInsertRequest(_messages.Message):
  r"""A ComputeInstancesBulkInsertRequest object.

  Fields:
    bulkInsertInstanceResource: A BulkInsertInstanceResource resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  bulkInsertInstanceResource = _messages.MessageField('BulkInsertInstanceResource', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesDeleteAccessConfigRequest(_messages.Message):
  r"""A ComputeInstancesDeleteAccessConfigRequest object.

  Fields:
    accessConfig: The name of the access config to delete.
    instance: The instance name for this request.
    networkInterface: The name of the network interface.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  accessConfig = _messages.StringField(1, required=True)
  instance = _messages.StringField(2, required=True)
  networkInterface = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesDeleteNetworkInterfaceRequest(_messages.Message):
  r"""A ComputeInstancesDeleteNetworkInterfaceRequest object.

  Fields:
    instance: The instance name for this request stored as resource_id. Name
      should conform to RFC1035 or be an unsigned long integer.
    networkInterfaceName: The name of the dynamic network interface to be
      deleted from the instance.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  networkInterfaceName = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesDeleteRequest(_messages.Message):
  r"""A ComputeInstancesDeleteRequest object.

  Fields:
    instance: Name of the instance resource to delete.
    noGracefulShutdown: If set to true, Graceful Shutdown is skipped.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  noGracefulShutdown = _messages.BooleanField(2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesDetachDiskRequest(_messages.Message):
  r"""A ComputeInstancesDetachDiskRequest object.

  Fields:
    deviceName: The device name of the disk to detach. Make a get() request on
      the instance to view currently attached disks and device names.
    instance: Instance name for this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  deviceName = _messages.StringField(1, required=True)
  instance = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesGetEffectiveFirewallsRequest(_messages.Message):
  r"""A ComputeInstancesGetEffectiveFirewallsRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    networkInterface: The name of the network interface to get the effective
      firewalls.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  networkInterface = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesGetGuestAttributesRequest(_messages.Message):
  r"""A ComputeInstancesGetGuestAttributesRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    queryPath: Specifies the guest attributes path to be queried.
    variableKey: Specifies the key for the guest attributes entry.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  queryPath = _messages.StringField(3)
  variableKey = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstancesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesGetPartnerMetadataRequest(_messages.Message):
  r"""A ComputeInstancesGetPartnerMetadataRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    namespaces: Comma separated partner metadata namespaces.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  namespaces = _messages.StringField(2)
  project = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesGetRequest(_messages.Message):
  r"""A ComputeInstancesGetRequest object.

  Enums:
    ViewValueValuesEnum: View of the instance.

  Fields:
    instance: Name of the instance resource to return.
    project: Project ID for this request.
    view: View of the instance.
    zone: The name of the zone for this request.
  """

  class ViewValueValuesEnum(_messages.Enum):
    r"""View of the instance.

    Values:
      BASIC: Include everything except Partner Metadata.
      FULL: Include everything.
      INSTANCE_VIEW_UNSPECIFIED: The default / unset value. The API will
        default to the BASIC view.
    """
    BASIC = 0
    FULL = 1
    INSTANCE_VIEW_UNSPECIFIED = 2

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  view = _messages.EnumField('ViewValueValuesEnum', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesGetScreenshotRequest(_messages.Message):
  r"""A ComputeInstancesGetScreenshotRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesGetSerialPortOutputRequest(_messages.Message):
  r"""A ComputeInstancesGetSerialPortOutputRequest object.

  Fields:
    instance: Name of the instance for this request.
    port: Specifies which COM or serial port to retrieve data from.
    project: Project ID for this request.
    start: Specifies the starting byte position of the output to return. To
      start with the first byte of output to the specified port, omit this
      field or set it to `0`. If the output for that byte position is
      available, this field matches the `start` parameter sent with the
      request. If the amount of serial console output exceeds the size of the
      buffer (1 MB), the oldest output is discarded and is no longer
      available. If the requested start position refers to discarded output,
      the start position is adjusted to the oldest output still available, and
      the adjusted start position is returned as the `start` property value.
      You can also provide a negative start position, which translates to the
      most recent number of bytes written to the serial port. For example, -3
      is interpreted as the most recent 3 bytes written to the serial console.
      Note that the negative start is bounded by the retained buffer size, and
      the returned serial console output will not exceed the max buffer size.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32, default=1)
  project = _messages.StringField(3, required=True)
  start = _messages.IntegerField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesGetShieldedInstanceIdentityRequest(_messages.Message):
  r"""A ComputeInstancesGetShieldedInstanceIdentityRequest object.

  Fields:
    instance: Name or id of the instance scoping this request.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesGetShieldedVmIdentityRequest(_messages.Message):
  r"""A ComputeInstancesGetShieldedVmIdentityRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesInsertRequest(_messages.Message):
  r"""A ComputeInstancesInsertRequest object.

  Fields:
    instance: A Instance resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceInstanceTemplate: Specifies instance template to create the
      instance. This field is optional. It can be a full or partial URL. For
      example, the following are all valid URLs to an instance template: -
      https://www.googleapis.com/compute/v1/projects/project
      /global/instanceTemplates/instanceTemplate -
      projects/project/global/instanceTemplates/instanceTemplate -
      global/instanceTemplates/instanceTemplate
    sourceMachineImage: Specifies the machine image to use to create the
      instance. This field is optional. It can be a full or partial URL. For
      example, the following are all valid URLs to a machine image: -
      https://www.googleapis.com/compute/v1/projects/project/global/global
      /machineImages/machineImage -
      projects/project/global/global/machineImages/machineImage -
      global/machineImages/machineImage
    zone: The name of the zone for this request.
  """

  instance = _messages.MessageField('Instance', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sourceInstanceTemplate = _messages.StringField(4)
  sourceMachineImage = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesListReferrersRequest(_messages.Message):
  r"""A ComputeInstancesListReferrersRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instance: Name of the target instance scoping this request, or '-' if the
      request should span over all instances in the container.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  instance = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstancesListRequest(_messages.Message):
  r"""A ComputeInstancesListRequest object.

  Enums:
    ViewValueValuesEnum: View of the instance.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    view: View of the instance.
    zone: The name of the zone for this request.
  """

  class ViewValueValuesEnum(_messages.Enum):
    r"""View of the instance.

    Values:
      BASIC: Include everything except Partner Metadata.
      FULL: Include everything.
      INSTANCE_VIEW_UNSPECIFIED: The default / unset value. The API will
        default to the BASIC view.
    """
    BASIC = 0
    FULL = 1
    INSTANCE_VIEW_UNSPECIFIED = 2

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  view = _messages.EnumField('ViewValueValuesEnum', 7)
  zone = _messages.StringField(8, required=True)


class ComputeInstancesPatchPartnerMetadataRequest(_messages.Message):
  r"""A ComputeInstancesPatchPartnerMetadataRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    partnerMetadata: A PartnerMetadata resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  partnerMetadata = _messages.MessageField('PartnerMetadata', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesPerformMaintenanceRequest(_messages.Message):
  r"""A ComputeInstancesPerformMaintenanceRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesRemoveResourcePoliciesRequest(_messages.Message):
  r"""A ComputeInstancesRemoveResourcePoliciesRequest object.

  Fields:
    instance: The instance name for this request.
    instancesRemoveResourcePoliciesRequest: A
      InstancesRemoveResourcePoliciesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesRemoveResourcePoliciesRequest = _messages.MessageField('InstancesRemoveResourcePoliciesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesReportHostAsFaultyRequest(_messages.Message):
  r"""A ComputeInstancesReportHostAsFaultyRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesReportHostAsFaultyRequest: A InstancesReportHostAsFaultyRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesReportHostAsFaultyRequest = _messages.MessageField('InstancesReportHostAsFaultyRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesResetRequest(_messages.Message):
  r"""A ComputeInstancesResetRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesResumeRequest(_messages.Message):
  r"""A ComputeInstancesResumeRequest object.

  Fields:
    instance: Name of the instance resource to resume.
    instancesResumeRequest: A InstancesResumeRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesResumeRequest = _messages.MessageField('InstancesResumeRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSendDiagnosticInterruptRequest(_messages.Message):
  r"""A ComputeInstancesSendDiagnosticInterruptRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesSendDiagnosticInterruptResponse(_messages.Message):
  r"""An empty ComputeInstancesSendDiagnosticInterrupt response."""


class ComputeInstancesSetDeletionProtectionRequest(_messages.Message):
  r"""A ComputeInstancesSetDeletionProtectionRequest object.

  Fields:
    deletionProtection: Whether the resource should be protected against
      deletion.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  deletionProtection = _messages.BooleanField(1, default=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resource = _messages.StringField(4, required=True)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetDiskAutoDeleteRequest(_messages.Message):
  r"""A ComputeInstancesSetDiskAutoDeleteRequest object.

  Fields:
    autoDelete: Whether to auto-delete the disk when the instance is deleted.
    deviceName: The device name of the disk to modify. Make a get() request on
      the instance to view currently attached disks and device names.
    instance: The instance name for this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  autoDelete = _messages.BooleanField(1, required=True)
  deviceName = _messages.StringField(2, required=True)
  instance = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstancesSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeInstancesSetLabelsRequest(_messages.Message):
  r"""A ComputeInstancesSetLabelsRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesSetLabelsRequest: A InstancesSetLabelsRequest resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetLabelsRequest = _messages.MessageField('InstancesSetLabelsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetMachineResourcesRequest(_messages.Message):
  r"""A ComputeInstancesSetMachineResourcesRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesSetMachineResourcesRequest: A InstancesSetMachineResourcesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetMachineResourcesRequest = _messages.MessageField('InstancesSetMachineResourcesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetMachineTypeRequest(_messages.Message):
  r"""A ComputeInstancesSetMachineTypeRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesSetMachineTypeRequest: A InstancesSetMachineTypeRequest resource
      to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetMachineTypeRequest = _messages.MessageField('InstancesSetMachineTypeRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetMetadataRequest(_messages.Message):
  r"""A ComputeInstancesSetMetadataRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    metadata: A Metadata resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  metadata = _messages.MessageField('Metadata', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetMinCpuPlatformRequest(_messages.Message):
  r"""A ComputeInstancesSetMinCpuPlatformRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesSetMinCpuPlatformRequest: A InstancesSetMinCpuPlatformRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetMinCpuPlatformRequest = _messages.MessageField('InstancesSetMinCpuPlatformRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetNameRequest(_messages.Message):
  r"""A ComputeInstancesSetNameRequest object.

  Fields:
    instance: The instance name for this request.
    instancesSetNameRequest: A InstancesSetNameRequest resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetNameRequest = _messages.MessageField('InstancesSetNameRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetSchedulingRequest(_messages.Message):
  r"""A ComputeInstancesSetSchedulingRequest object.

  Fields:
    instance: Instance name for this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    scheduling: A Scheduling resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  scheduling = _messages.MessageField('Scheduling', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetSecurityPolicyRequest(_messages.Message):
  r"""A ComputeInstancesSetSecurityPolicyRequest object.

  Fields:
    instance: Name of the Instance resource to which the security policy
      should be set. The name should conform to RFC1035.
    instancesSetSecurityPolicyRequest: A InstancesSetSecurityPolicyRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone scoping this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetSecurityPolicyRequest = _messages.MessageField('InstancesSetSecurityPolicyRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetServiceAccountRequest(_messages.Message):
  r"""A ComputeInstancesSetServiceAccountRequest object.

  Fields:
    instance: Name of the instance resource to start.
    instancesSetServiceAccountRequest: A InstancesSetServiceAccountRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetServiceAccountRequest = _messages.MessageField('InstancesSetServiceAccountRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetShieldedInstanceIntegrityPolicyRequest(_messages.Message):
  r"""A ComputeInstancesSetShieldedInstanceIntegrityPolicyRequest object.

  Fields:
    instance: Name or id of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    shieldedInstanceIntegrityPolicy: A ShieldedInstanceIntegrityPolicy
      resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  shieldedInstanceIntegrityPolicy = _messages.MessageField('ShieldedInstanceIntegrityPolicy', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetShieldedVmIntegrityPolicyRequest(_messages.Message):
  r"""A ComputeInstancesSetShieldedVmIntegrityPolicyRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    shieldedVmIntegrityPolicy: A ShieldedVmIntegrityPolicy resource to be
      passed as the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  shieldedVmIntegrityPolicy = _messages.MessageField('ShieldedVmIntegrityPolicy', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetTagsRequest(_messages.Message):
  r"""A ComputeInstancesSetTagsRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    tags: A Tags resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  tags = _messages.MessageField('Tags', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSimulateMaintenanceEventRequest(_messages.Message):
  r"""A ComputeInstancesSimulateMaintenanceEventRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    withExtendedNotifications: Determines whether the customers receive
      notifications before migration. Only applicable to SF vms.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  withExtendedNotifications = _messages.BooleanField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesStartRequest(_messages.Message):
  r"""A ComputeInstancesStartRequest object.

  Fields:
    instance: Name of the instance resource to start.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesStartWithEncryptionKeyRequest(_messages.Message):
  r"""A ComputeInstancesStartWithEncryptionKeyRequest object.

  Fields:
    instance: Name of the instance resource to start.
    instancesStartWithEncryptionKeyRequest: A
      InstancesStartWithEncryptionKeyRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesStartWithEncryptionKeyRequest = _messages.MessageField('InstancesStartWithEncryptionKeyRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesStopRequest(_messages.Message):
  r"""A ComputeInstancesStopRequest object.

  Fields:
    discardLocalSsd: This property is required if the instance has any
      attached Local SSD disks. If false, Local SSD data will be preserved
      when the instance is suspended. If true, the contents of any attached
      Local SSD disks will be discarded.
    instance: Name of the instance resource to stop.
    noGracefulShutdown: If set to true, Graceful Shutdown is skipped.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  discardLocalSsd = _messages.BooleanField(1)
  instance = _messages.StringField(2, required=True)
  noGracefulShutdown = _messages.BooleanField(3)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesSuspendRequest(_messages.Message):
  r"""A ComputeInstancesSuspendRequest object.

  Fields:
    discardLocalSsd: This property is required if the instance has any
      attached Local SSD disks. If false, Local SSD data will be preserved
      when the instance is suspended. If true, the contents of any attached
      Local SSD disks will be discarded.
    instance: Name of the instance resource to suspend.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  discardLocalSsd = _messages.BooleanField(1)
  instance = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstancesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesUpdateAccessConfigRequest(_messages.Message):
  r"""A ComputeInstancesUpdateAccessConfigRequest object.

  Fields:
    accessConfig: A AccessConfig resource to be passed as the request body.
    instance: The instance name for this request.
    networkInterface: The name of the network interface where the access
      config is attached.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  accessConfig = _messages.MessageField('AccessConfig', 1)
  instance = _messages.StringField(2, required=True)
  networkInterface = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesUpdateDisplayDeviceRequest(_messages.Message):
  r"""A ComputeInstancesUpdateDisplayDeviceRequest object.

  Fields:
    displayDevice: A DisplayDevice resource to be passed as the request body.
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  displayDevice = _messages.MessageField('DisplayDevice', 1)
  instance = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesUpdateNetworkInterfaceRequest(_messages.Message):
  r"""A ComputeInstancesUpdateNetworkInterfaceRequest object.

  Fields:
    instance: The instance name for this request.
    networkInterface: The name of the network interface to update.
    networkInterfaceResource: A NetworkInterface resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  networkInterface = _messages.StringField(2, required=True)
  networkInterfaceResource = _messages.MessageField('NetworkInterface', 3)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesUpdateRequest(_messages.Message):
  r"""A ComputeInstancesUpdateRequest object.

  Enums:
    MinimalActionValueValuesEnum: Specifies the action to take when updating
      an instance even if the updated properties do not require it. If not
      specified, then Compute Engine acts based on the minimum action that the
      updated properties require.
    MostDisruptiveAllowedActionValueValuesEnum: Specifies the most disruptive
      action that can be taken on the instance as part of the update. Compute
      Engine returns an error if the instance properties require a more
      disruptive action as part of the instance update. Valid options from
      lowest to highest are NO_EFFECT, REFRESH, and RESTART.

  Fields:
    clearSecureTag: Whether to clear secure tags from the instance. This
      property if set to true will clear secure tags regardless of the
      resource.secure_tags.
    instance: Name of the instance resource to update.
    instanceResource: A Instance resource to be passed as the request body.
    minimalAction: Specifies the action to take when updating an instance even
      if the updated properties do not require it. If not specified, then
      Compute Engine acts based on the minimum action that the updated
      properties require.
    mostDisruptiveAllowedAction: Specifies the most disruptive action that can
      be taken on the instance as part of the update. Compute Engine returns
      an error if the instance properties require a more disruptive action as
      part of the instance update. Valid options from lowest to highest are
      NO_EFFECT, REFRESH, and RESTART.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  class MinimalActionValueValuesEnum(_messages.Enum):
    r"""Specifies the action to take when updating an instance even if the
    updated properties do not require it. If not specified, then Compute
    Engine acts based on the minimum action that the updated properties
    require.

    Values:
      INVALID: <no description>
      NO_EFFECT: No changes can be made to the instance.
      REFRESH: The instance will not restart.
      RESTART: The instance will restart.
    """
    INVALID = 0
    NO_EFFECT = 1
    REFRESH = 2
    RESTART = 3

  class MostDisruptiveAllowedActionValueValuesEnum(_messages.Enum):
    r"""Specifies the most disruptive action that can be taken on the instance
    as part of the update. Compute Engine returns an error if the instance
    properties require a more disruptive action as part of the instance
    update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and
    RESTART.

    Values:
      INVALID: <no description>
      NO_EFFECT: No changes can be made to the instance.
      REFRESH: The instance will not restart.
      RESTART: The instance will restart.
    """
    INVALID = 0
    NO_EFFECT = 1
    REFRESH = 2
    RESTART = 3

  clearSecureTag = _messages.BooleanField(1)
  instance = _messages.StringField(2, required=True)
  instanceResource = _messages.MessageField('Instance', 3)
  minimalAction = _messages.EnumField('MinimalActionValueValuesEnum', 4)
  mostDisruptiveAllowedAction = _messages.EnumField('MostDisruptiveAllowedActionValueValuesEnum', 5)
  project = _messages.StringField(6, required=True)
  requestId = _messages.StringField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstancesUpdateShieldedInstanceConfigRequest(_messages.Message):
  r"""A ComputeInstancesUpdateShieldedInstanceConfigRequest object.

  Fields:
    instance: Name or id of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    shieldedInstanceConfig: A ShieldedInstanceConfig resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  shieldedInstanceConfig = _messages.MessageField('ShieldedInstanceConfig', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesUpdateShieldedVmConfigRequest(_messages.Message):
  r"""A ComputeInstancesUpdateShieldedVmConfigRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    shieldedVmConfig: A ShieldedVmConfig resource to be passed as the request
      body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  shieldedVmConfig = _messages.MessageField('ShieldedVmConfig', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstantSnapshotGroupsDeleteRequest(_messages.Message):
  r"""A ComputeInstantSnapshotGroupsDeleteRequest object.

  Fields:
    instantSnapshotGroup: Name of the InstantSnapshot resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instantSnapshotGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstantSnapshotGroupsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstantSnapshotGroupsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstantSnapshotGroupsGetRequest(_messages.Message):
  r"""A ComputeInstantSnapshotGroupsGetRequest object.

  Fields:
    instantSnapshotGroup: Name of the InstantSnapshotGroup resource to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instantSnapshotGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstantSnapshotGroupsInsertRequest(_messages.Message):
  r"""A ComputeInstantSnapshotGroupsInsertRequest object.

  Fields:
    instantSnapshotGroup: A InstantSnapshotGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceConsistencyGroup: begin_interface: MixerMutationRequestBuilder
    zone: Name of the zone for this request.
  """

  instantSnapshotGroup = _messages.MessageField('InstantSnapshotGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sourceConsistencyGroup = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstantSnapshotGroupsListRequest(_messages.Message):
  r"""A ComputeInstantSnapshotGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeInstantSnapshotGroupsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstantSnapshotGroupsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeInstantSnapshotGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstantSnapshotGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInstantSnapshotsAggregatedListRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeInstantSnapshotsDeleteRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsDeleteRequest object.

  Fields:
    instantSnapshot: Name of the InstantSnapshot resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instantSnapshot = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstantSnapshotsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstantSnapshotsGetRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsGetRequest object.

  Fields:
    instantSnapshot: Name of the InstantSnapshot resource to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instantSnapshot = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstantSnapshotsInsertRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsInsertRequest object.

  Fields:
    instantSnapshot: A InstantSnapshot resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  instantSnapshot = _messages.MessageField('InstantSnapshot', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstantSnapshotsListRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeInstantSnapshotsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeInstantSnapshotsSetLabelsRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetLabelsRequest: A ZoneSetLabelsRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)
  zoneSetLabelsRequest = _messages.MessageField('ZoneSetLabelsRequest', 5)


class ComputeInstantSnapshotsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstantSnapshotsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInterconnectAttachmentGroupsCreateMembersRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsCreateMembersRequest object.

  Fields:
    interconnectAttachmentGroup: Name of the group resource to create members
      for.
    interconnectAttachmentGroupsCreateMembersRequest: A
      InterconnectAttachmentGroupsCreateMembersRequest resource to be passed
      as the request body.
    project: Project ID for this request.
  """

  interconnectAttachmentGroup = _messages.StringField(1, required=True)
  interconnectAttachmentGroupsCreateMembersRequest = _messages.MessageField('InterconnectAttachmentGroupsCreateMembersRequest', 2)
  project = _messages.StringField(3, required=True)


class ComputeInterconnectAttachmentGroupsDeleteRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsDeleteRequest object.

  Fields:
    interconnectAttachmentGroup: Name of the InterconnectAttachmentGroup
      resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  interconnectAttachmentGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInterconnectAttachmentGroupsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectAttachmentGroupsGetOperationalStatusRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsGetOperationalStatusRequest object.

  Fields:
    interconnectAttachmentGroup: Name of the interconnectAttachmentGroup
      resource to query.
    project: Project ID for this request.
  """

  interconnectAttachmentGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectAttachmentGroupsGetRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsGetRequest object.

  Fields:
    interconnectAttachmentGroup: Name of the InterconnectAttachmentGroup
      resource to return.
    project: Project ID for this request.
  """

  interconnectAttachmentGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectAttachmentGroupsInsertRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsInsertRequest object.

  Fields:
    interconnectAttachmentGroup: A InterconnectAttachmentGroup resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  interconnectAttachmentGroup = _messages.MessageField('InterconnectAttachmentGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInterconnectAttachmentGroupsListRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeInterconnectAttachmentGroupsPatchRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsPatchRequest object.

  Fields:
    interconnectAttachmentGroup: Name of the InterconnectAttachmentGroup
      resource to patch.
    interconnectAttachmentGroupResource: A InterconnectAttachmentGroup
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
    updateMask: The list of fields to update.
  """

  interconnectAttachmentGroup = _messages.StringField(1, required=True)
  interconnectAttachmentGroupResource = _messages.MessageField('InterconnectAttachmentGroup', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  updateMask = _messages.StringField(5)


class ComputeInterconnectAttachmentGroupsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectAttachmentGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInterconnectAttachmentsAggregatedListRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeInterconnectAttachmentsDeleteRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsDeleteRequest object.

  Fields:
    interconnectAttachment: Name of the interconnect attachment to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  interconnectAttachment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeInterconnectAttachmentsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeInterconnectAttachmentsGetRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsGetRequest object.

  Fields:
    interconnectAttachment: Name of the interconnect attachment to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  interconnectAttachment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeInterconnectAttachmentsInsertRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsInsertRequest object.

  Fields:
    interconnectAttachment: A InterconnectAttachment resource to be passed as
      the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    validateOnly: If true, the request will not be committed.
  """

  interconnectAttachment = _messages.MessageField('InterconnectAttachment', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  validateOnly = _messages.BooleanField(5)


class ComputeInterconnectAttachmentsListRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeInterconnectAttachmentsPatchRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsPatchRequest object.

  Fields:
    interconnectAttachment: Name of the interconnect attachment to patch.
    interconnectAttachmentResource: A InterconnectAttachment resource to be
      passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  interconnectAttachment = _messages.StringField(1, required=True)
  interconnectAttachmentResource = _messages.MessageField('InterconnectAttachment', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeInterconnectAttachmentsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeInterconnectAttachmentsSetLabelsRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeInterconnectAttachmentsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeInterconnectGroupsCreateMembersRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsCreateMembersRequest object.

  Fields:
    interconnectGroup: Name of the group resource to create members for.
    interconnectGroupsCreateMembersRequest: A
      InterconnectGroupsCreateMembersRequest resource to be passed as the
      request body.
    project: Project ID for this request.
  """

  interconnectGroup = _messages.StringField(1, required=True)
  interconnectGroupsCreateMembersRequest = _messages.MessageField('InterconnectGroupsCreateMembersRequest', 2)
  project = _messages.StringField(3, required=True)


class ComputeInterconnectGroupsDeleteRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsDeleteRequest object.

  Fields:
    interconnectGroup: Name of the InterconnectGroup resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  interconnectGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInterconnectGroupsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectGroupsGetOperationalStatusRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsGetOperationalStatusRequest object.

  Fields:
    interconnectGroup: Name of the interconnectGroup resource to query.
    project: Project ID for this request.
  """

  interconnectGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectGroupsGetRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsGetRequest object.

  Fields:
    interconnectGroup: Name of the InterconnectGroup resource to return.
    project: Project ID for this request.
  """

  interconnectGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectGroupsInsertRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsInsertRequest object.

  Fields:
    interconnectGroup: A InterconnectGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  interconnectGroup = _messages.MessageField('InterconnectGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInterconnectGroupsListRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeInterconnectGroupsPatchRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsPatchRequest object.

  Fields:
    interconnectGroup: Name of the InterconnectGroup resource to patch.
    interconnectGroupResource: A InterconnectGroup resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
    updateMask: The list of fields to update.
  """

  interconnectGroup = _messages.StringField(1, required=True)
  interconnectGroupResource = _messages.MessageField('InterconnectGroup', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  updateMask = _messages.StringField(5)


class ComputeInterconnectGroupsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInterconnectLocationsGetRequest(_messages.Message):
  r"""A ComputeInterconnectLocationsGetRequest object.

  Fields:
    interconnectLocation: Name of the interconnect location to return.
    project: Project ID for this request.
  """

  interconnectLocation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectLocationsListRequest(_messages.Message):
  r"""A ComputeInterconnectLocationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeInterconnectLocationsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectLocationsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInterconnectRemoteLocationsGetRequest(_messages.Message):
  r"""A ComputeInterconnectRemoteLocationsGetRequest object.

  Fields:
    interconnectRemoteLocation: Name of the interconnect remote location to
      return.
    project: Project ID for this request.
  """

  interconnectRemoteLocation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectRemoteLocationsListRequest(_messages.Message):
  r"""A ComputeInterconnectRemoteLocationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeInterconnectRemoteLocationsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectRemoteLocationsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInterconnectsDeleteRequest(_messages.Message):
  r"""A ComputeInterconnectsDeleteRequest object.

  Fields:
    interconnect: Name of the interconnect to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  interconnect = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInterconnectsGetDiagnosticsRequest(_messages.Message):
  r"""A ComputeInterconnectsGetDiagnosticsRequest object.

  Fields:
    interconnect: Name of the interconnect resource to query.
    project: Project ID for this request.
  """

  interconnect = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectsGetMacsecConfigRequest(_messages.Message):
  r"""A ComputeInterconnectsGetMacsecConfigRequest object.

  Fields:
    interconnect: Name of the interconnect resource to query.
    project: Project ID for this request.
  """

  interconnect = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectsGetRequest(_messages.Message):
  r"""A ComputeInterconnectsGetRequest object.

  Fields:
    interconnect: Name of the interconnect to return.
    project: Project ID for this request.
  """

  interconnect = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectsInsertRequest(_messages.Message):
  r"""A ComputeInterconnectsInsertRequest object.

  Fields:
    interconnect: A Interconnect resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  interconnect = _messages.MessageField('Interconnect', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInterconnectsListRequest(_messages.Message):
  r"""A ComputeInterconnectsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeInterconnectsPatchRequest(_messages.Message):
  r"""A ComputeInterconnectsPatchRequest object.

  Fields:
    interconnect: Name of the interconnect to update.
    interconnectResource: A Interconnect resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  interconnect = _messages.StringField(1, required=True)
  interconnectResource = _messages.MessageField('Interconnect', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeInterconnectsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectsSetLabelsRequest(_messages.Message):
  r"""A ComputeInterconnectsSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeLicenseCodesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeLicenseCodesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeLicenseCodesGetRequest(_messages.Message):
  r"""A ComputeLicenseCodesGetRequest object.

  Fields:
    licenseCode: Number corresponding to the License code resource to return.
    project: Project ID for this request.
  """

  licenseCode = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeLicenseCodesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeLicenseCodesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeLicenseCodesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeLicenseCodesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeLicensesDeleteRequest(_messages.Message):
  r"""A ComputeLicensesDeleteRequest object.

  Fields:
    license: Name of the license resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  license = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeLicensesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeLicensesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeLicensesGetRequest(_messages.Message):
  r"""A ComputeLicensesGetRequest object.

  Fields:
    license: Name of the License resource to return.
    project: Project ID for this request.
  """

  license = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeLicensesInsertRequest(_messages.Message):
  r"""A ComputeLicensesInsertRequest object.

  Fields:
    license: A License resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  license = _messages.MessageField('License', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeLicensesListRequest(_messages.Message):
  r"""A ComputeLicensesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeLicensesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeLicensesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeLicensesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeLicensesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeLicensesUpdateRequest(_messages.Message):
  r"""A ComputeLicensesUpdateRequest object.

  Fields:
    license: The license name for this request.
    licenseResource: A License resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: update_mask indicates fields to be updated as part of this
      request.
  """

  license = _messages.StringField(1, required=True)
  licenseResource = _messages.MessageField('License', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  updateMask = _messages.StringField(5)


class ComputeMachineImagesDeleteRequest(_messages.Message):
  r"""A ComputeMachineImagesDeleteRequest object.

  Fields:
    machineImage: The name of the machine image to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  machineImage = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeMachineImagesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeMachineImagesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeMachineImagesGetRequest(_messages.Message):
  r"""A ComputeMachineImagesGetRequest object.

  Fields:
    machineImage: The name of the machine image.
    project: Project ID for this request.
  """

  machineImage = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeMachineImagesInsertRequest(_messages.Message):
  r"""A ComputeMachineImagesInsertRequest object.

  Fields:
    machineImage: A MachineImage resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceInstance: Required. Source instance that is used to create the
      machine image from.
  """

  machineImage = _messages.MessageField('MachineImage', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sourceInstance = _messages.StringField(4)


class ComputeMachineImagesListRequest(_messages.Message):
  r"""A ComputeMachineImagesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeMachineImagesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeMachineImagesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeMachineImagesSetLabelsRequest(_messages.Message):
  r"""A ComputeMachineImagesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeMachineImagesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeMachineImagesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeMachineTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeMachineTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeMachineTypesGetRequest(_messages.Message):
  r"""A ComputeMachineTypesGetRequest object.

  Fields:
    machineType: Name of the machine type to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  machineType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeMachineTypesListRequest(_messages.Message):
  r"""A ComputeMachineTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeNetworkAttachmentsAggregatedListRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeNetworkAttachmentsDeleteRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsDeleteRequest object.

  Fields:
    networkAttachment: Name of the NetworkAttachment resource to delete.
    project: Project ID for this request.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  networkAttachment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworkAttachmentsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeNetworkAttachmentsGetRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsGetRequest object.

  Fields:
    networkAttachment: Name of the NetworkAttachment resource to return.
    project: Project ID for this request.
    region: Name of the region of this request.
  """

  networkAttachment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeNetworkAttachmentsInsertRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsInsertRequest object.

  Fields:
    networkAttachment: A NetworkAttachment resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  networkAttachment = _messages.MessageField('NetworkAttachment', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworkAttachmentsListRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region of this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeNetworkAttachmentsPatchRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsPatchRequest object.

  Fields:
    networkAttachment: Name of the NetworkAttachment resource to patch.
    networkAttachmentResource: A NetworkAttachment resource to be passed as
      the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  networkAttachment = _messages.StringField(1, required=True)
  networkAttachmentResource = _messages.MessageField('NetworkAttachment', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeNetworkAttachmentsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeNetworkAttachmentsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNetworkAttachmentsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeNetworkEdgeSecurityServicesAggregatedListRequest(_messages.Message):
  r"""A ComputeNetworkEdgeSecurityServicesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeNetworkEdgeSecurityServicesDeleteRequest(_messages.Message):
  r"""A ComputeNetworkEdgeSecurityServicesDeleteRequest object.

  Fields:
    networkEdgeSecurityService: Name of the network edge security service to
      delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  networkEdgeSecurityService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworkEdgeSecurityServicesGetRequest(_messages.Message):
  r"""A ComputeNetworkEdgeSecurityServicesGetRequest object.

  Fields:
    networkEdgeSecurityService: Name of the network edge security service to
      get.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  networkEdgeSecurityService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeNetworkEdgeSecurityServicesInsertRequest(_messages.Message):
  r"""A ComputeNetworkEdgeSecurityServicesInsertRequest object.

  Fields:
    networkEdgeSecurityService: A NetworkEdgeSecurityService resource to be
      passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    validateOnly: If true, the request will not be committed.
  """

  networkEdgeSecurityService = _messages.MessageField('NetworkEdgeSecurityService', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  validateOnly = _messages.BooleanField(5)


class ComputeNetworkEdgeSecurityServicesPatchRequest(_messages.Message):
  r"""A ComputeNetworkEdgeSecurityServicesPatchRequest object.

  Fields:
    networkEdgeSecurityService: Name of the network edge security service to
      update.
    networkEdgeSecurityServiceResource: A NetworkEdgeSecurityService resource
      to be passed as the request body.
    paths: A string attribute.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: Indicates fields to be updated as part of this request.
  """

  networkEdgeSecurityService = _messages.StringField(1, required=True)
  networkEdgeSecurityServiceResource = _messages.MessageField('NetworkEdgeSecurityService', 2)
  paths = _messages.StringField(3, repeated=True)
  project = _messages.StringField(4, required=True)
  region = _messages.StringField(5, required=True)
  requestId = _messages.StringField(6)
  updateMask = _messages.StringField(7)


class ComputeNetworkEndpointGroupsAggregatedListRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeNetworkEndpointGroupsAttachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsAttachNetworkEndpointsRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group where you are
      attaching network endpoints to. It should comply with RFC1035.
    networkEndpointGroupsAttachEndpointsRequest: A
      NetworkEndpointGroupsAttachEndpointsRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  networkEndpointGroupsAttachEndpointsRequest = _messages.MessageField('NetworkEndpointGroupsAttachEndpointsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNetworkEndpointGroupsDeleteRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsDeleteRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group to delete. It
      should comply with RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeNetworkEndpointGroupsDetachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsDetachNetworkEndpointsRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group where you are
      removing network endpoints. It should comply with RFC1035.
    networkEndpointGroupsDetachEndpointsRequest: A
      NetworkEndpointGroupsDetachEndpointsRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  networkEndpointGroupsDetachEndpointsRequest = _messages.MessageField('NetworkEndpointGroupsDetachEndpointsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNetworkEndpointGroupsGetRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsGetRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group. It should
      comply with RFC1035.
    project: Project ID for this request.
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeNetworkEndpointGroupsInsertRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsInsertRequest object.

  Fields:
    networkEndpointGroup: A NetworkEndpointGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the network endpoint
      group. It should comply with RFC1035.
  """

  networkEndpointGroup = _messages.MessageField('NetworkEndpointGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeNetworkEndpointGroupsListNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsListNetworkEndpointsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    networkEndpointGroup: The name of the network endpoint group from which
      you want to generate a list of included network endpoints. It should
      comply with RFC1035.
    networkEndpointGroupsListEndpointsRequest: A
      NetworkEndpointGroupsListEndpointsRequest resource to be passed as the
      request body.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  networkEndpointGroup = _messages.StringField(3, required=True)
  networkEndpointGroupsListEndpointsRequest = _messages.MessageField('NetworkEndpointGroupsListEndpointsRequest', 4)
  orderBy = _messages.StringField(5)
  pageToken = _messages.StringField(6)
  project = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)
  zone = _messages.StringField(9, required=True)


class ComputeNetworkEndpointGroupsListRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeNetworkEndpointGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeNetworkFirewallPoliciesAddAssociationRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesAddAssociationRequest object.

  Fields:
    associatedPolicyToBeReplaced: Name of the firewall policy associated with
      the target network to swap association with. This field is mutually
      exclusive with 'replace_existing_association'.
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyAssociation: A FirewallPolicyAssociation resource to be
      passed as the request body.
    project: Project ID for this request.
    replaceExistingAssociation: Indicates whether or not to replace it if an
      association of the attachment already exists. This is false by default,
      in which case an error will be returned if an association already
      exists.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  associatedPolicyToBeReplaced = _messages.StringField(1)
  firewallPolicy = _messages.StringField(2, required=True)
  firewallPolicyAssociation = _messages.MessageField('FirewallPolicyAssociation', 3)
  project = _messages.StringField(4, required=True)
  replaceExistingAssociation = _messages.BooleanField(5)
  requestId = _messages.StringField(6)


class ComputeNetworkFirewallPoliciesAddPacketMirroringRuleRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesAddPacketMirroringRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    maxPriority: When rule.priority is not specified, auto choose a unused
      priority between minPriority and maxPriority>. This field is exclusive
      with rule.priority.
    minPriority: When rule.priority is not specified, auto choose a unused
      priority between minPriority and maxPriority>. This field is exclusive
      with rule.priority.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  maxPriority = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  minPriority = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  project = _messages.StringField(5, required=True)
  requestId = _messages.StringField(6)


class ComputeNetworkFirewallPoliciesAddRuleRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesAddRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    maxPriority: When rule.priority is not specified, auto choose a unused
      priority between minPriority and maxPriority>. This field is exclusive
      with rule.priority.
    minPriority: When rule.priority is not specified, auto choose a unused
      priority between minPriority and maxPriority>. This field is exclusive
      with rule.priority.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  maxPriority = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  minPriority = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  project = _messages.StringField(5, required=True)
  requestId = _messages.StringField(6)


class ComputeNetworkFirewallPoliciesAggregatedListRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeNetworkFirewallPoliciesCloneRulesRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesCloneRulesRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceFirewallPolicy: The firewall policy from which to copy rules.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sourceFirewallPolicy = _messages.StringField(4)


class ComputeNetworkFirewallPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesDeleteRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeNetworkFirewallPoliciesGetAssociationRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesGetAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to which the queried
      association belongs.
    name: The name of the association to get from the firewall policy.
    project: Project ID for this request.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  name = _messages.StringField(2)
  project = _messages.StringField(3, required=True)


class ComputeNetworkFirewallPoliciesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeNetworkFirewallPoliciesGetPacketMirroringRuleRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesGetPacketMirroringRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to which the queried rule
      belongs.
    priority: The priority of the rule to get from the firewall policy.
    project: Project ID for this request.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  project = _messages.StringField(3, required=True)


class ComputeNetworkFirewallPoliciesGetRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesGetRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to get.
    project: Project ID for this request.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeNetworkFirewallPoliciesGetRuleRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesGetRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to which the queried rule
      belongs.
    priority: The priority of the rule to get from the firewall policy.
    project: Project ID for this request.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  project = _messages.StringField(3, required=True)


class ComputeNetworkFirewallPoliciesInsertRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesInsertRequest object.

  Fields:
    firewallPolicy: A FirewallPolicy resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.MessageField('FirewallPolicy', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeNetworkFirewallPoliciesListRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeNetworkFirewallPoliciesPatchAssociationRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesPatchAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyAssociation: A FirewallPolicyAssociation resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyAssociation = _messages.MessageField('FirewallPolicyAssociation', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworkFirewallPoliciesPatchPacketMirroringRuleRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesPatchPacketMirroringRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    priority: The priority of the rule to patch.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  priority = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeNetworkFirewallPoliciesPatchRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesPatchRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyResource: A FirewallPolicy resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyResource = _messages.MessageField('FirewallPolicy', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworkFirewallPoliciesPatchRuleRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesPatchRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    priority: The priority of the rule to patch.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  priority = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeNetworkFirewallPoliciesRemoveAssociationRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesRemoveAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    name: Name for the attachment that will be removed.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  name = _messages.StringField(2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworkFirewallPoliciesRemovePacketMirroringRuleRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesRemovePacketMirroringRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    priority: The priority of the rule to remove from the firewall policy.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworkFirewallPoliciesRemoveRuleRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesRemoveRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    priority: The priority of the rule to remove from the firewall policy.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworkFirewallPoliciesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeNetworkFirewallPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNetworkFirewallPoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeNetworkProfilesGetRequest(_messages.Message):
  r"""A ComputeNetworkProfilesGetRequest object.

  Fields:
    networkProfile: Name of the network profile to return.
    project: Project ID for this request.
  """

  networkProfile = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeNetworkProfilesListRequest(_messages.Message):
  r"""A ComputeNetworkProfilesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeNetworksAddPeeringRequest(_messages.Message):
  r"""A ComputeNetworksAddPeeringRequest object.

  Fields:
    network: Name of the network resource to add peering to.
    networksAddPeeringRequest: A NetworksAddPeeringRequest resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  networksAddPeeringRequest = _messages.MessageField('NetworksAddPeeringRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworksDeleteRequest(_messages.Message):
  r"""A ComputeNetworksDeleteRequest object.

  Fields:
    network: Name of the network to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeNetworksGetEffectiveFirewallsRequest(_messages.Message):
  r"""A ComputeNetworksGetEffectiveFirewallsRequest object.

  Fields:
    network: Name of the network for this request.
    project: Project ID for this request.
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeNetworksGetRequest(_messages.Message):
  r"""A ComputeNetworksGetRequest object.

  Fields:
    network: Name of the network to return.
    project: Project ID for this request.
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeNetworksInsertRequest(_messages.Message):
  r"""A ComputeNetworksInsertRequest object.

  Fields:
    network: A Network resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  network = _messages.MessageField('Network', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeNetworksListIpAddressesRequest(_messages.Message):
  r"""A ComputeNetworksListIpAddressesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    network: Name of the network for this request.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    types: (Optional) types filter separate by comma, valid values are:
      SUBNETWORK, RESERVED, PEER_USED, PEER_RESERVED, REMOTE_USED,
      REMOTE_RESERVED.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  network = _messages.StringField(3, required=True)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  types = _messages.StringField(8)


class ComputeNetworksListIpOwnersRequest(_messages.Message):
  r"""A ComputeNetworksListIpOwnersRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    ipCidrRange: (Optional) IP CIDR range filter, example: "10.128.10.0/30".
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    network: Name of the network to return.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    ownerProjects: (Optional) Project IDs filter, example:
      "project-1,project-2".
    ownerTypes: (Optional) Owner types filter, example:
      "instance,forwardingRule".
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    subnetName: (Optional) Subnetwork name filter.
    subnetRegion: (Optional) Subnetwork region filter.
  """

  filter = _messages.StringField(1)
  ipCidrRange = _messages.StringField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  network = _messages.StringField(4, required=True)
  orderBy = _messages.StringField(5)
  ownerProjects = _messages.StringField(6)
  ownerTypes = _messages.StringField(7)
  pageToken = _messages.StringField(8)
  project = _messages.StringField(9, required=True)
  returnPartialSuccess = _messages.BooleanField(10)
  subnetName = _messages.StringField(11)
  subnetRegion = _messages.StringField(12)


class ComputeNetworksListPeeringRoutesRequest(_messages.Message):
  r"""A ComputeNetworksListPeeringRoutesRequest object.

  Enums:
    DirectionValueValuesEnum: The direction of the exchanged routes.

  Fields:
    direction: The direction of the exchanged routes.
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    network: Name of the network for this request.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    peeringName: The response will show routes exchanged over the given
      peering connection.
    project: Project ID for this request.
    region: The region of the request. The response will include all subnet
      routes, static routes and dynamic routes in the region.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  class DirectionValueValuesEnum(_messages.Enum):
    r"""The direction of the exchanged routes.

    Values:
      INCOMING: For routes exported from peer network.
      OUTGOING: For routes exported from local network.
    """
    INCOMING = 0
    OUTGOING = 1

  direction = _messages.EnumField('DirectionValueValuesEnum', 1)
  filter = _messages.StringField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  network = _messages.StringField(4, required=True)
  orderBy = _messages.StringField(5)
  pageToken = _messages.StringField(6)
  peeringName = _messages.StringField(7)
  project = _messages.StringField(8, required=True)
  region = _messages.StringField(9)
  returnPartialSuccess = _messages.BooleanField(10)


class ComputeNetworksListRequest(_messages.Message):
  r"""A ComputeNetworksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeNetworksPatchRequest(_messages.Message):
  r"""A ComputeNetworksPatchRequest object.

  Fields:
    network: Name of the network to update.
    networkResource: A Network resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  networkResource = _messages.MessageField('Network', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworksRemovePeeringRequest(_messages.Message):
  r"""A ComputeNetworksRemovePeeringRequest object.

  Fields:
    network: Name of the network resource to remove peering from.
    networksRemovePeeringRequest: A NetworksRemovePeeringRequest resource to
      be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  networksRemovePeeringRequest = _messages.MessageField('NetworksRemovePeeringRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworksSwitchToCustomModeRequest(_messages.Message):
  r"""A ComputeNetworksSwitchToCustomModeRequest object.

  Fields:
    network: Name of the network to be updated.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeNetworksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNetworksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeNetworksUpdatePeeringRequest(_messages.Message):
  r"""A ComputeNetworksUpdatePeeringRequest object.

  Fields:
    network: Name of the network resource which the updated peering is
      belonging to.
    networksUpdatePeeringRequest: A NetworksUpdatePeeringRequest resource to
      be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  networksUpdatePeeringRequest = _messages.MessageField('NetworksUpdatePeeringRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNodeGroupsAddNodesRequest(_messages.Message):
  r"""A ComputeNodeGroupsAddNodesRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource.
    nodeGroupsAddNodesRequest: A NodeGroupsAddNodesRequest resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupsAddNodesRequest = _messages.MessageField('NodeGroupsAddNodesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsAggregatedListRequest(_messages.Message):
  r"""A ComputeNodeGroupsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeNodeGroupsDeleteNodesRequest(_messages.Message):
  r"""A ComputeNodeGroupsDeleteNodesRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource whose nodes will be deleted.
    nodeGroupsDeleteNodesRequest: A NodeGroupsDeleteNodesRequest resource to
      be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupsDeleteNodesRequest = _messages.MessageField('NodeGroupsDeleteNodesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsDeleteRequest(_messages.Message):
  r"""A ComputeNodeGroupsDeleteRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeNodeGroupsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeNodeGroupsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeNodeGroupsGetRequest(_messages.Message):
  r"""A ComputeNodeGroupsGetRequest object.

  Fields:
    nodeGroup: Name of the node group to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeNodeGroupsInsertRequest(_messages.Message):
  r"""A ComputeNodeGroupsInsertRequest object.

  Fields:
    initialNodeCount: Initial count of nodes in the node group.
    nodeGroup: A NodeGroup resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  initialNodeCount = _messages.IntegerField(1, required=True, variant=_messages.Variant.INT32)
  nodeGroup = _messages.MessageField('NodeGroup', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsListNodesRequest(_messages.Message):
  r"""A ComputeNodeGroupsListNodesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    nodeGroup: Name of the NodeGroup resource whose nodes you want to list.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  nodeGroup = _messages.StringField(3, required=True)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeNodeGroupsListRequest(_messages.Message):
  r"""A ComputeNodeGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeNodeGroupsPatchRequest(_messages.Message):
  r"""A ComputeNodeGroupsPatchRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource to update.
    nodeGroupResource: A NodeGroup resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupResource = _messages.MessageField('NodeGroup', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsPerformMaintenanceRequest(_messages.Message):
  r"""A ComputeNodeGroupsPerformMaintenanceRequest object.

  Fields:
    nodeGroup: Name of the node group scoping this request.
    nodeGroupsPerformMaintenanceRequest: A NodeGroupsPerformMaintenanceRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupsPerformMaintenanceRequest = _messages.MessageField('NodeGroupsPerformMaintenanceRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeNodeGroupsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeNodeGroupsSetNodeTemplateRequest(_messages.Message):
  r"""A ComputeNodeGroupsSetNodeTemplateRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource to update.
    nodeGroupsSetNodeTemplateRequest: A NodeGroupsSetNodeTemplateRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupsSetNodeTemplateRequest = _messages.MessageField('NodeGroupsSetNodeTemplateRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsSimulateMaintenanceEventRequest(_messages.Message):
  r"""A ComputeNodeGroupsSimulateMaintenanceEventRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource whose nodes will go under
      maintenance simulation.
    nodeGroupsSimulateMaintenanceEventRequest: A
      NodeGroupsSimulateMaintenanceEventRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupsSimulateMaintenanceEventRequest = _messages.MessageField('NodeGroupsSimulateMaintenanceEventRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNodeGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeNodeTemplatesAggregatedListRequest(_messages.Message):
  r"""A ComputeNodeTemplatesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeNodeTemplatesDeleteRequest(_messages.Message):
  r"""A ComputeNodeTemplatesDeleteRequest object.

  Fields:
    nodeTemplate: Name of the NodeTemplate resource to delete.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  nodeTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNodeTemplatesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeNodeTemplatesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeNodeTemplatesGetRequest(_messages.Message):
  r"""A ComputeNodeTemplatesGetRequest object.

  Fields:
    nodeTemplate: Name of the node template to return.
    project: Project ID for this request.
    region: The name of the region for this request.
  """

  nodeTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeNodeTemplatesInsertRequest(_messages.Message):
  r"""A ComputeNodeTemplatesInsertRequest object.

  Fields:
    nodeTemplate: A NodeTemplate resource to be passed as the request body.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  nodeTemplate = _messages.MessageField('NodeTemplate', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNodeTemplatesListRequest(_messages.Message):
  r"""A ComputeNodeTemplatesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeNodeTemplatesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeNodeTemplatesSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeNodeTemplatesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNodeTemplatesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeNodeTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeNodeTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeNodeTypesGetRequest(_messages.Message):
  r"""A ComputeNodeTypesGetRequest object.

  Fields:
    nodeType: Name of the node type to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  nodeType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeNodeTypesListRequest(_messages.Message):
  r"""A ComputeNodeTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeOrganizationSecurityPoliciesAddAssociationRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesAddAssociationRequest object.

  Fields:
    replaceExistingAssociation: Indicates whether or not to replace it if an
      association of the attachment already exists. This is false by default,
      in which case an error will be returned if an association already
      exists.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyAssociation: A SecurityPolicyAssociation resource to be
      passed as the request body.
  """

  replaceExistingAssociation = _messages.BooleanField(1)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)
  securityPolicyAssociation = _messages.MessageField('SecurityPolicyAssociation', 4)


class ComputeOrganizationSecurityPoliciesAddRuleRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesAddRuleRequest object.

  Fields:
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
  """

  requestId = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 3)


class ComputeOrganizationSecurityPoliciesCopyRulesRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesCopyRulesRequest object.

  Fields:
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    sourceSecurityPolicy: The security policy from which to copy rules.
  """

  requestId = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)
  sourceSecurityPolicy = _messages.StringField(3)


class ComputeOrganizationSecurityPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesDeleteRequest object.

  Fields:
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to delete.
  """

  requestId = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)


class ComputeOrganizationSecurityPoliciesGetAssociationRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesGetAssociationRequest object.

  Fields:
    name: The name of the association to get from the security policy.
    securityPolicy: Name of the security policy to which the queried rule
      belongs.
  """

  name = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)


class ComputeOrganizationSecurityPoliciesGetRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesGetRequest object.

  Fields:
    securityPolicy: Name of the security policy to get.
  """

  securityPolicy = _messages.StringField(1, required=True)


class ComputeOrganizationSecurityPoliciesGetRuleRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesGetRuleRequest object.

  Fields:
    priority: The priority of the rule to get from the security policy.
    securityPolicy: Name of the security policy to which the queried rule
      belongs.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  securityPolicy = _messages.StringField(2, required=True)


class ComputeOrganizationSecurityPoliciesInsertRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesInsertRequest object.

  Fields:
    parentId: Parent ID for this request. The ID can be either be
      "folders/[FOLDER_ID]" if the parent is a folder or
      "organizations/[ORGANIZATION_ID]" if the parent is an organization.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: A SecurityPolicy resource to be passed as the request
      body.
  """

  parentId = _messages.StringField(1)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.MessageField('SecurityPolicy', 3)


class ComputeOrganizationSecurityPoliciesListAssociationsRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesListAssociationsRequest object.

  Fields:
    targetResource: The target resource to list associations. It is an
      organization, or a folder.
  """

  targetResource = _messages.StringField(1)


class ComputeOrganizationSecurityPoliciesListPreconfiguredExpressionSetsRequest(_messages.Message):
  r"""A
  ComputeOrganizationSecurityPoliciesListPreconfiguredExpressionSetsRequest
  object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    parentId: Parent ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  parentId = _messages.StringField(5)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeOrganizationSecurityPoliciesListRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    parentId: Parent ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  parentId = _messages.StringField(5)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeOrganizationSecurityPoliciesMoveRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesMoveRequest object.

  Fields:
    parentId: The new parent of the security policy.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
  """

  parentId = _messages.StringField(1)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeOrganizationSecurityPoliciesPatchRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesPatchRequest object.

  Fields:
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyResource: A SecurityPolicy resource to be passed as the
      request body.
  """

  requestId = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)
  securityPolicyResource = _messages.MessageField('SecurityPolicy', 3)


class ComputeOrganizationSecurityPoliciesPatchRuleRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesPatchRuleRequest object.

  Fields:
    priority: The priority of the rule to patch.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 4)


class ComputeOrganizationSecurityPoliciesRemoveAssociationRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesRemoveAssociationRequest object.

  Fields:
    name: Name for the attachment that will be removed.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
  """

  name = _messages.StringField(1)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeOrganizationSecurityPoliciesRemoveRuleRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesRemoveRuleRequest object.

  Fields:
    priority: The priority of the rule to remove from the security policy.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)


class ComputePacketMirroringsAggregatedListRequest(_messages.Message):
  r"""A ComputePacketMirroringsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputePacketMirroringsDeleteRequest(_messages.Message):
  r"""A ComputePacketMirroringsDeleteRequest object.

  Fields:
    packetMirroring: Name of the PacketMirroring resource to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  packetMirroring = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePacketMirroringsGetRequest(_messages.Message):
  r"""A ComputePacketMirroringsGetRequest object.

  Fields:
    packetMirroring: Name of the PacketMirroring resource to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  packetMirroring = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputePacketMirroringsInsertRequest(_messages.Message):
  r"""A ComputePacketMirroringsInsertRequest object.

  Fields:
    packetMirroring: A PacketMirroring resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  packetMirroring = _messages.MessageField('PacketMirroring', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePacketMirroringsListRequest(_messages.Message):
  r"""A ComputePacketMirroringsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputePacketMirroringsPatchRequest(_messages.Message):
  r"""A ComputePacketMirroringsPatchRequest object.

  Fields:
    packetMirroring: Name of the PacketMirroring resource to patch.
    packetMirroringResource: A PacketMirroring resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  packetMirroring = _messages.StringField(1, required=True)
  packetMirroringResource = _messages.MessageField('PacketMirroring', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputePacketMirroringsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputePacketMirroringsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeProjectsDisableXpnHostRequest(_messages.Message):
  r"""A ComputeProjectsDisableXpnHostRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)


class ComputeProjectsDisableXpnResourceRequest(_messages.Message):
  r"""A ComputeProjectsDisableXpnResourceRequest object.

  Fields:
    project: Project ID for this request.
    projectsDisableXpnResourceRequest: A ProjectsDisableXpnResourceRequest
      resource to be passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsDisableXpnResourceRequest = _messages.MessageField('ProjectsDisableXpnResourceRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsEnableXpnHostRequest(_messages.Message):
  r"""A ComputeProjectsEnableXpnHostRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)


class ComputeProjectsEnableXpnResourceRequest(_messages.Message):
  r"""A ComputeProjectsEnableXpnResourceRequest object.

  Fields:
    project: Project ID for this request.
    projectsEnableXpnResourceRequest: A ProjectsEnableXpnResourceRequest
      resource to be passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsEnableXpnResourceRequest = _messages.MessageField('ProjectsEnableXpnResourceRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsGetRequest(_messages.Message):
  r"""A ComputeProjectsGetRequest object.

  Fields:
    project: Project ID for this request.
  """

  project = _messages.StringField(1, required=True)


class ComputeProjectsGetXpnHostRequest(_messages.Message):
  r"""A ComputeProjectsGetXpnHostRequest object.

  Fields:
    project: Project ID for this request.
  """

  project = _messages.StringField(1, required=True)


class ComputeProjectsGetXpnResourcesRequest(_messages.Message):
  r"""A ComputeProjectsGetXpnResourcesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeProjectsListXpnHostsRequest(_messages.Message):
  r"""A ComputeProjectsListXpnHostsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    projectsListXpnHostsRequest: A ProjectsListXpnHostsRequest resource to be
      passed as the request body.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  projectsListXpnHostsRequest = _messages.MessageField('ProjectsListXpnHostsRequest', 6)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeProjectsMoveDiskRequest(_messages.Message):
  r"""A ComputeProjectsMoveDiskRequest object.

  Fields:
    diskMoveRequest: A DiskMoveRequest resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  diskMoveRequest = _messages.MessageField('DiskMoveRequest', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeProjectsMoveInstanceRequest(_messages.Message):
  r"""A ComputeProjectsMoveInstanceRequest object.

  Fields:
    instanceMoveRequest: A InstanceMoveRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceMoveRequest = _messages.MessageField('InstanceMoveRequest', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeProjectsSetCloudArmorTierRequest(_messages.Message):
  r"""A ComputeProjectsSetCloudArmorTierRequest object.

  Fields:
    project: Project ID for this request.
    projectsSetCloudArmorTierRequest: A ProjectsSetCloudArmorTierRequest
      resource to be passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsSetCloudArmorTierRequest = _messages.MessageField('ProjectsSetCloudArmorTierRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsSetCommonInstanceMetadataRequest(_messages.Message):
  r"""A ComputeProjectsSetCommonInstanceMetadataRequest object.

  Fields:
    metadata: A Metadata resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  metadata = _messages.MessageField('Metadata', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeProjectsSetDefaultNetworkTierRequest(_messages.Message):
  r"""A ComputeProjectsSetDefaultNetworkTierRequest object.

  Fields:
    project: Project ID for this request.
    projectsSetDefaultNetworkTierRequest: A
      ProjectsSetDefaultNetworkTierRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsSetDefaultNetworkTierRequest = _messages.MessageField('ProjectsSetDefaultNetworkTierRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsSetDefaultServiceAccountRequest(_messages.Message):
  r"""A ComputeProjectsSetDefaultServiceAccountRequest object.

  Fields:
    project: Project ID for this request.
    projectsSetDefaultServiceAccountRequest: A
      ProjectsSetDefaultServiceAccountRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsSetDefaultServiceAccountRequest = _messages.MessageField('ProjectsSetDefaultServiceAccountRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsSetManagedProtectionTierRequest(_messages.Message):
  r"""A ComputeProjectsSetManagedProtectionTierRequest object.

  Fields:
    project: Project ID for this request.
    projectsSetManagedProtectionTierRequest: A
      ProjectsSetManagedProtectionTierRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsSetManagedProtectionTierRequest = _messages.MessageField('ProjectsSetManagedProtectionTierRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsSetUsageExportBucketRequest(_messages.Message):
  r"""A ComputeProjectsSetUsageExportBucketRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    usageExportLocation: A UsageExportLocation resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  usageExportLocation = _messages.MessageField('UsageExportLocation', 3)


class ComputePublicAdvertisedPrefixesAnnounceRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesAnnounceRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: The name of the public advertised prefix. It
      should comply with RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputePublicAdvertisedPrefixesDeleteRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: Name of the PublicAdvertisedPrefix resource to
      delete.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputePublicAdvertisedPrefixesGetRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesGetRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: Name of the PublicAdvertisedPrefix resource to
      return.
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.StringField(2, required=True)


class ComputePublicAdvertisedPrefixesInsertRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesInsertRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: A PublicAdvertisedPrefix resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.MessageField('PublicAdvertisedPrefix', 2)
  requestId = _messages.StringField(3)


class ComputePublicAdvertisedPrefixesListRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputePublicAdvertisedPrefixesPatchRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesPatchRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: Name of the PublicAdvertisedPrefix resource to
      patch.
    publicAdvertisedPrefixResource: A PublicAdvertisedPrefix resource to be
      passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.StringField(2, required=True)
  publicAdvertisedPrefixResource = _messages.MessageField('PublicAdvertisedPrefix', 3)
  requestId = _messages.StringField(4)


class ComputePublicAdvertisedPrefixesWithdrawRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesWithdrawRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: The name of the public advertised prefix. It
      should comply with RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputePublicDelegatedPrefixesAggregatedListRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputePublicDelegatedPrefixesAnnounceRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesAnnounceRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: The name of the public delegated prefix. It should
      comply with RFC1035.
    region: The name of the region where the public delegated prefix is
      located. It should comply with RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePublicDelegatedPrefixesDeleteRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      delete.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePublicDelegatedPrefixesGetRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesGetRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      return.
    region: Name of the region of this request.
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputePublicDelegatedPrefixesInsertRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesInsertRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: A PublicDelegatedPrefix resource to be passed as
      the request body.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.MessageField('PublicDelegatedPrefix', 2)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePublicDelegatedPrefixesListRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region of this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputePublicDelegatedPrefixesPatchRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesPatchRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      patch.
    publicDelegatedPrefixResource: A PublicDelegatedPrefix resource to be
      passed as the request body.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  publicDelegatedPrefixResource = _messages.MessageField('PublicDelegatedPrefix', 3)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputePublicDelegatedPrefixesWithdrawRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesWithdrawRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: The name of the public delegated prefix. It should
      comply with RFC1035.
    region: The name of the region where the public delegated prefix is
      located. It should comply with RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionAutoscalersDeleteRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersDeleteRequest object.

  Fields:
    autoscaler: Name of the autoscaler to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  autoscaler = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionAutoscalersGetRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersGetRequest object.

  Fields:
    autoscaler: Name of the autoscaler to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  autoscaler = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionAutoscalersInsertRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersInsertRequest object.

  Fields:
    autoscaler: A Autoscaler resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  autoscaler = _messages.MessageField('Autoscaler', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionAutoscalersListRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionAutoscalersPatchRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersPatchRequest object.

  Fields:
    autoscaler: Name of the autoscaler to patch.
    autoscalerResource: A Autoscaler resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  autoscaler = _messages.StringField(1)
  autoscalerResource = _messages.MessageField('Autoscaler', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionAutoscalersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionAutoscalersUpdateRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersUpdateRequest object.

  Fields:
    autoscaler: Name of the autoscaler to update.
    autoscalerResource: A Autoscaler resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  autoscaler = _messages.StringField(1)
  autoscalerResource = _messages.MessageField('Autoscaler', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionBackendServicesDeleteRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesDeleteRequest object.

  Fields:
    backendService: Name of the BackendService resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionBackendServicesGetHealthRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesGetHealthRequest object.

  Fields:
    backendService: Name of the BackendService resource for which to get
      health.
    project: A string attribute.
    region: Name of the region scoping this request.
    resourceGroupReference: A ResourceGroupReference resource to be passed as
      the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resourceGroupReference = _messages.MessageField('ResourceGroupReference', 4)


class ComputeRegionBackendServicesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeRegionBackendServicesGetRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesGetRequest object.

  Fields:
    backendService: Name of the BackendService resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionBackendServicesInsertRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesInsertRequest object.

  Fields:
    backendService: A BackendService resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.MessageField('BackendService', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionBackendServicesListRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionBackendServicesListUsableRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesListUsableRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request. It must be a string that
      meets the requirements in RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionBackendServicesPatchRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesPatchRequest object.

  Fields:
    backendService: Name of the BackendService resource to patch.
    backendServiceResource: A BackendService resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  backendServiceResource = _messages.MessageField('BackendService', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionBackendServicesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeRegionBackendServicesSetSecurityPolicyRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesSetSecurityPolicyRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the security
      policy should be set. The name should conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicyReference: A SecurityPolicyReference resource to be passed
      as the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  securityPolicyReference = _messages.MessageField('SecurityPolicyReference', 5)


class ComputeRegionBackendServicesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionBackendServicesUpdateRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesUpdateRequest object.

  Fields:
    backendService: Name of the BackendService resource to update.
    backendServiceResource: A BackendService resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  backendServiceResource = _messages.MessageField('BackendService', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionCommitmentsAggregatedListRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeRegionCommitmentsCalculateCancellationFeeRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsCalculateCancellationFeeRequest object.

  Fields:
    commitment: Name of the commitment to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  commitment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionCommitmentsCancelRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsCancelRequest object.

  Fields:
    commitment: Name of the commitment to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  commitment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionCommitmentsGetRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsGetRequest object.

  Fields:
    commitment: Name of the commitment to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  commitment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionCommitmentsInsertRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsInsertRequest object.

  Fields:
    commitment: A Commitment resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  commitment = _messages.MessageField('Commitment', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionCommitmentsListRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionCommitmentsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionCommitmentsUpdateRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsUpdateRequest object.

  Fields:
    commitment: Name of the commitment that you want to update.
    commitmentResource: A Commitment resource to be passed as the request
      body.
    paths: A string attribute.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: update_mask indicates fields to be updated as part of this
      request.
  """

  commitment = _messages.StringField(1, required=True)
  commitmentResource = _messages.MessageField('Commitment', 2)
  paths = _messages.StringField(3, repeated=True)
  project = _messages.StringField(4, required=True)
  region = _messages.StringField(5, required=True)
  requestId = _messages.StringField(6)
  updateMask = _messages.StringField(7)


class ComputeRegionCommitmentsUpdateReservationsRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsUpdateReservationsRequest object.

  Fields:
    commitment: Name of the commitment for which the reservations are being
      updated.
    project: Project ID for this request.
    region: Name of the region for this request.
    regionCommitmentsUpdateReservationsRequest: A
      RegionCommitmentsUpdateReservationsRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  commitment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionCommitmentsUpdateReservationsRequest = _messages.MessageField('RegionCommitmentsUpdateReservationsRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionCompositeHealthChecksAggregatedListRequest(_messages.Message):
  r"""A ComputeRegionCompositeHealthChecksAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeRegionCompositeHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeRegionCompositeHealthChecksDeleteRequest object.

  Fields:
    compositeHealthCheck: Name of the CompositeHealthCheck resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  compositeHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionCompositeHealthChecksGetRequest(_messages.Message):
  r"""A ComputeRegionCompositeHealthChecksGetRequest object.

  Fields:
    compositeHealthCheck: Name of the CompositeHealthCheck resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  compositeHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionCompositeHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeRegionCompositeHealthChecksInsertRequest object.

  Fields:
    compositeHealthCheck: A CompositeHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  compositeHealthCheck = _messages.MessageField('CompositeHealthCheck', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionCompositeHealthChecksListRequest(_messages.Message):
  r"""A ComputeRegionCompositeHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionCompositeHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeRegionCompositeHealthChecksPatchRequest object.

  Fields:
    compositeHealthCheck: Name of the CompositeHealthCheck to update. The name
      must be 1-63 characters long, and comply with RFC1035.
    compositeHealthCheckResource: A CompositeHealthCheck resource to be passed
      as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  compositeHealthCheck = _messages.StringField(1, required=True)
  compositeHealthCheckResource = _messages.MessageField('CompositeHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionCompositeHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionCompositeHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionDiskSettingsGetRequest(_messages.Message):
  r"""A ComputeRegionDiskSettingsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)


class ComputeRegionDiskSettingsPatchRequest(_messages.Message):
  r"""A ComputeRegionDiskSettingsPatchRequest object.

  Fields:
    diskSettings: A DiskSettings resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: update_mask indicates fields to be updated as part of this
      request.
  """

  diskSettings = _messages.MessageField('DiskSettings', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  updateMask = _messages.StringField(5)


class ComputeRegionDiskTypesGetRequest(_messages.Message):
  r"""A ComputeRegionDiskTypesGetRequest object.

  Fields:
    diskType: Name of the disk type to return.
    project: Project ID for this request.
    region: The name of the region for this request.
  """

  diskType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionDiskTypesListRequest(_messages.Message):
  r"""A ComputeRegionDiskTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionDisksAddResourcePoliciesRequest(_messages.Message):
  r"""A ComputeRegionDisksAddResourcePoliciesRequest object.

  Fields:
    disk: The disk name for this request.
    project: Project ID for this request.
    region: The name of the region for this request.
    regionDisksAddResourcePoliciesRequest: A
      RegionDisksAddResourcePoliciesRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionDisksAddResourcePoliciesRequest = _messages.MessageField('RegionDisksAddResourcePoliciesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionDisksBulkInsertRequest(_messages.Message):
  r"""A ComputeRegionDisksBulkInsertRequest object.

  Fields:
    bulkInsertDiskResource: A BulkInsertDiskResource resource to be passed as
      the request body.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  bulkInsertDiskResource = _messages.MessageField('BulkInsertDiskResource', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionDisksCreateSnapshotRequest(_messages.Message):
  r"""A ComputeRegionDisksCreateSnapshotRequest object.

  Fields:
    disk: Name of the regional persistent disk to snapshot.
    guestFlush: [Input Only] Specifies to create an application consistent
      snapshot by informing the OS to prepare for the snapshot process.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshot: A Snapshot resource to be passed as the request body.
  """

  disk = _messages.StringField(1, required=True)
  guestFlush = _messages.BooleanField(2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  snapshot = _messages.MessageField('Snapshot', 6)


class ComputeRegionDisksDeleteRequest(_messages.Message):
  r"""A ComputeRegionDisksDeleteRequest object.

  Fields:
    disk: Name of the regional persistent disk to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionDisksGetAsyncReplicationStatusRequest(_messages.Message):
  r"""A ComputeRegionDisksGetAsyncReplicationStatusRequest object.

  Fields:
    disk: Name of the Disk resource whose Async replication details are
      requested. Name should conform to RFC1035 or be an unsigned long
      integer.
    project: Project ID for this request.
    region: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionDisksGetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionDisksGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeRegionDisksGetRequest(_messages.Message):
  r"""A ComputeRegionDisksGetRequest object.

  Fields:
    disk: Name of the regional persistent disk to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionDisksInsertRequest(_messages.Message):
  r"""A ComputeRegionDisksInsertRequest object.

  Fields:
    disk: A Disk resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceImage: Source image to restore onto a disk. This field is optional.
  """

  disk = _messages.MessageField('Disk', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  sourceImage = _messages.StringField(5)


class ComputeRegionDisksListRequest(_messages.Message):
  r"""A ComputeRegionDisksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionDisksRemoveResourcePoliciesRequest(_messages.Message):
  r"""A ComputeRegionDisksRemoveResourcePoliciesRequest object.

  Fields:
    disk: The disk name for this request.
    project: Project ID for this request.
    region: The name of the region for this request.
    regionDisksRemoveResourcePoliciesRequest: A
      RegionDisksRemoveResourcePoliciesRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionDisksRemoveResourcePoliciesRequest = _messages.MessageField('RegionDisksRemoveResourcePoliciesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionDisksResizeRequest(_messages.Message):
  r"""A ComputeRegionDisksResizeRequest object.

  Fields:
    disk: Name of the regional persistent disk.
    project: The project ID for this request.
    region: Name of the region for this request.
    regionDisksResizeRequest: A RegionDisksResizeRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionDisksResizeRequest = _messages.MessageField('RegionDisksResizeRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionDisksSetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionDisksSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeRegionDisksSetLabelsRequest(_messages.Message):
  r"""A ComputeRegionDisksSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeRegionDisksStartAsyncReplicationRequest(_messages.Message):
  r"""A ComputeRegionDisksStartAsyncReplicationRequest object.

  Fields:
    disk: The name of the persistent disk.
    project: Project ID for this request.
    region: The name of the region for this request.
    regionDisksStartAsyncReplicationRequest: A
      RegionDisksStartAsyncReplicationRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionDisksStartAsyncReplicationRequest = _messages.MessageField('RegionDisksStartAsyncReplicationRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionDisksStopAsyncReplicationRequest(_messages.Message):
  r"""A ComputeRegionDisksStopAsyncReplicationRequest object.

  Fields:
    disk: The name of the persistent disk.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionDisksStopGroupAsyncReplicationRequest(_messages.Message):
  r"""A ComputeRegionDisksStopGroupAsyncReplicationRequest object.

  Fields:
    disksStopGroupAsyncReplicationResource: A
      DisksStopGroupAsyncReplicationResource resource to be passed as the
      request body.
    project: Project ID for this request.
    region: The name of the region for this request. This must be the region
      of the primary or secondary disks in the consistency group.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  disksStopGroupAsyncReplicationResource = _messages.MessageField('DisksStopGroupAsyncReplicationResource', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionDisksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionDisksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionDisksUpdateRequest(_messages.Message):
  r"""A ComputeRegionDisksUpdateRequest object.

  Fields:
    disk: The disk name for this request.
    diskResource: A Disk resource to be passed as the request body.
    paths: A string attribute.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    updateMask: update_mask indicates fields to be updated as part of this
      request.
  """

  disk = _messages.StringField(1, required=True)
  diskResource = _messages.MessageField('Disk', 2)
  paths = _messages.StringField(3, repeated=True)
  project = _messages.StringField(4, required=True)
  region = _messages.StringField(5, required=True)
  requestId = _messages.StringField(6)
  updateMask = _messages.StringField(7)


class ComputeRegionDisksWaitForReplicationCatchUpRequest(_messages.Message):
  r"""A ComputeRegionDisksWaitForReplicationCatchUpRequest object.

  Fields:
    disk: The name of the persistent disk. Name should conform to RFC1035 or
      be an unsigned long integer.
    project: Project ID for this request.
    region: Name of the region for this request.
    regionWaitForReplicationCatchUpRequest: A
      RegionWaitForReplicationCatchUpRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionWaitForReplicationCatchUpRequest = _messages.MessageField('RegionWaitForReplicationCatchUpRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionHealthAggregationPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeRegionHealthAggregationPoliciesDeleteRequest object.

  Fields:
    healthAggregationPolicy: Name of the HealthAggregationPolicy resource to
      delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthAggregationPolicy = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthAggregationPoliciesGetRequest(_messages.Message):
  r"""A ComputeRegionHealthAggregationPoliciesGetRequest object.

  Fields:
    healthAggregationPolicy: Name of the HealthAggregationPolicy resource to
      return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  healthAggregationPolicy = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionHealthAggregationPoliciesInsertRequest(_messages.Message):
  r"""A ComputeRegionHealthAggregationPoliciesInsertRequest object.

  Fields:
    healthAggregationPolicy: A HealthAggregationPolicy resource to be passed
      as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthAggregationPolicy = _messages.MessageField('HealthAggregationPolicy', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthAggregationPoliciesListRequest(_messages.Message):
  r"""A ComputeRegionHealthAggregationPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionHealthAggregationPoliciesPatchRequest(_messages.Message):
  r"""A ComputeRegionHealthAggregationPoliciesPatchRequest object.

  Fields:
    healthAggregationPolicy: Name of the HealthAggregationPolicy to update.
      The name must be 1-63 characters long, and comply with RFC1035.
    healthAggregationPolicyResource: A HealthAggregationPolicy resource to be
      passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthAggregationPolicy = _messages.StringField(1, required=True)
  healthAggregationPolicyResource = _messages.MessageField('HealthAggregationPolicy', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionHealthAggregationPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionHealthAggregationPoliciesTestIamPermissionsRequest
  object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionHealthCheckServicesAggregatedListRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeRegionHealthCheckServicesDeleteRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesDeleteRequest object.

  Fields:
    healthCheckService: Name of the HealthCheckService to delete. The name
      must be 1-63 characters long, and comply with RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheckService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthCheckServicesGetRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesGetRequest object.

  Fields:
    healthCheckService: Name of the HealthCheckService to update. The name
      must be 1-63 characters long, and comply with RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  healthCheckService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionHealthCheckServicesInsertRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesInsertRequest object.

  Fields:
    healthCheckService: A HealthCheckService resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheckService = _messages.MessageField('HealthCheckService', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthCheckServicesListRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionHealthCheckServicesPatchRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesPatchRequest object.

  Fields:
    healthCheckService: Name of the HealthCheckService to update. The name
      must be 1-63 characters long, and comply with RFC1035.
    healthCheckServiceResource: A HealthCheckService resource to be passed as
      the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheckService = _messages.StringField(1, required=True)
  healthCheckServiceResource = _messages.MessageField('HealthCheckService', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionHealthCheckServicesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksDeleteRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthChecksGetRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksGetRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  healthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksInsertRequest object.

  Fields:
    healthCheck: A HealthCheck resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.MessageField('HealthCheck', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthChecksListRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksPatchRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to patch.
    healthCheckResource: A HealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  healthCheckResource = _messages.MessageField('HealthCheck', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionHealthChecksUpdateRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksUpdateRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to update.
    healthCheckResource: A HealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  healthCheckResource = _messages.MessageField('HealthCheck', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionHealthSourcesAggregatedListRequest(_messages.Message):
  r"""A ComputeRegionHealthSourcesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeRegionHealthSourcesDeleteRequest(_messages.Message):
  r"""A ComputeRegionHealthSourcesDeleteRequest object.

  Fields:
    healthSource: Name of the HealthSource resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthSource = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthSourcesGetRequest(_messages.Message):
  r"""A ComputeRegionHealthSourcesGetRequest object.

  Fields:
    healthSource: Name of the HealthSource resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  healthSource = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionHealthSourcesInsertRequest(_messages.Message):
  r"""A ComputeRegionHealthSourcesInsertRequest object.

  Fields:
    healthSource: A HealthSource resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthSource = _messages.MessageField('HealthSource', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthSourcesListRequest(_messages.Message):
  r"""A ComputeRegionHealthSourcesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionHealthSourcesPatchRequest(_messages.Message):
  r"""A ComputeRegionHealthSourcesPatchRequest object.

  Fields:
    healthSource: Name of the HealthSource to update. The name must be 1-63
      characters long, and comply with RFC1035.
    healthSourceResource: A HealthSource resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  healthSource = _messages.StringField(1, required=True)
  healthSourceResource = _messages.MessageField('HealthSource', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionHealthSourcesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionHealthSourcesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionInstanceGroupManagerResizeRequestsCancelRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagerResizeRequestsCancelRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. Name should
      conform to RFC1035 or be a resource ID.
    project: Project ID for this request.
    region: The name of the region scoping this request. Name should conform
      to RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resizeRequest: The name of the resize request to cancel. Name should
      conform to RFC1035 or be a resource ID.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  resizeRequest = _messages.StringField(5, required=True)


class ComputeRegionInstanceGroupManagerResizeRequestsDeleteRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagerResizeRequestsDeleteRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. Name should
      conform to RFC1035 or be a resource ID.
    project: Project ID for this request.
    region: The name of the region scoping this request. Name should conform
      to RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resizeRequest: The name of the resize request to delete. Name should
      conform to RFC1035 or be a resource ID.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  resizeRequest = _messages.StringField(5, required=True)


class ComputeRegionInstanceGroupManagerResizeRequestsGetRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagerResizeRequestsGetRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. Name should
      conform to RFC1035 or be a resource ID.
    project: Project ID for this request.
    region: The name of the region scoping this request. Name should conform
      to RFC1035.
    resizeRequest: The name of the resize request. Name should conform to
      RFC1035 or be a resource ID.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resizeRequest = _messages.StringField(4, required=True)


class ComputeRegionInstanceGroupManagerResizeRequestsInsertRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagerResizeRequestsInsertRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group to which the
      resize request is scoped. Name should conform to RFC1035 or be a
      resource ID.
    instanceGroupManagerResizeRequest: A InstanceGroupManagerResizeRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request. Name should conform to
      RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResizeRequest = _messages.MessageField('InstanceGroupManagerResizeRequest', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagerResizeRequestsListRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagerResizeRequestsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroupManager: The name of the managed instance group. The name
      should conform to RFC1035.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request. Name should conform to
      RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)


class ComputeRegionInstanceGroupManagersAbandonInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersAbandonInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersAbandonInstancesRequest: A
      RegionInstanceGroupManagersAbandonInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersAbandonInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersAbandonInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersApplyUpdatesToInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersApplyUpdatesToInstancesRequest
  object.

  Fields:
    instanceGroupManager: The name of the managed instance group, should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    regionInstanceGroupManagersApplyUpdatesRequest: A
      RegionInstanceGroupManagersApplyUpdatesRequest resource to be passed as
      the request body.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersApplyUpdatesRequest = _messages.MessageField('RegionInstanceGroupManagersApplyUpdatesRequest', 4)


class ComputeRegionInstanceGroupManagersCreateInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersCreateInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    project: Project ID for this request.
    region: The name of the region where the managed instance group is
      located. It should conform to RFC1035.
    regionInstanceGroupManagersCreateInstancesRequest: A
      RegionInstanceGroupManagersCreateInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. The request ID must
      be a valid UUID with the exception that zero UUID is not supported (
      00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersCreateInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersCreateInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersDeleteInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersDeleteInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersDeleteInstancesRequest: A
      RegionInstanceGroupManagersDeleteInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersDeleteInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersDeleteInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersDeletePerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersDeletePerInstanceConfigsRequest
  object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    regionInstanceGroupManagerDeleteInstanceConfigReq: A
      RegionInstanceGroupManagerDeleteInstanceConfigReq resource to be passed
      as the request body.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagerDeleteInstanceConfigReq = _messages.MessageField('RegionInstanceGroupManagerDeleteInstanceConfigReq', 4)


class ComputeRegionInstanceGroupManagersDeleteRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersDeleteRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstanceGroupManagersGetRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersGetRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionInstanceGroupManagersInsertRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersInsertRequest object.

  Fields:
    instanceGroupManager: A InstanceGroupManager resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.MessageField('InstanceGroupManager', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstanceGroupManagersListErrorsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersListErrorsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroupManager: The name of the managed instance group. It must be a
      string that meets the requirements in RFC1035, or an unsigned long
      integer: must match regexp pattern:
      (?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?)|1-9{0,19}.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request. This should conform to
      RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)


class ComputeRegionInstanceGroupManagersListManagedInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersListManagedInstancesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroupManager: The name of the managed instance group.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)


class ComputeRegionInstanceGroupManagersListPerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersListPerInstanceConfigsRequest
  object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)


class ComputeRegionInstanceGroupManagersListRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionInstanceGroupManagersPatchPerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersPatchPerInstanceConfigsRequest
  object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    regionInstanceGroupManagerPatchInstanceConfigReq: A
      RegionInstanceGroupManagerPatchInstanceConfigReq resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagerPatchInstanceConfigReq = _messages.MessageField('RegionInstanceGroupManagerPatchInstanceConfigReq', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersPatchRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersPatchRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagerResource: A InstanceGroupManager resource to be passed
      as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResource = _messages.MessageField('InstanceGroupManager', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersRecreateInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersRecreateInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersRecreateRequest: A
      RegionInstanceGroupManagersRecreateRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersRecreateRequest = _messages.MessageField('RegionInstanceGroupManagersRecreateRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersResizeAdvancedRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersResizeAdvancedRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It must be a
      string that meets the requirements in RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request. It must be a string that
      meets the requirements in RFC1035.
    regionInstanceGroupManagersResizeAdvancedRequest: A
      RegionInstanceGroupManagersResizeAdvancedRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersResizeAdvancedRequest = _messages.MessageField('RegionInstanceGroupManagersResizeAdvancedRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersResizeRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersResizeRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    size: Number of instances that should exist in this instance group
      manager.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  size = _messages.IntegerField(5, required=True, variant=_messages.Variant.INT32)


class ComputeRegionInstanceGroupManagersResumeInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersResumeInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersResumeInstancesRequest: A
      RegionInstanceGroupManagersResumeInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersResumeInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersResumeInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersSetAutoHealingPoliciesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersSetAutoHealingPoliciesRequest
  object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersSetAutoHealingRequest: A
      RegionInstanceGroupManagersSetAutoHealingRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersSetAutoHealingRequest = _messages.MessageField('RegionInstanceGroupManagersSetAutoHealingRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersSetInstanceTemplateRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersSetInstanceTemplateRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersSetTemplateRequest: A
      RegionInstanceGroupManagersSetTemplateRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersSetTemplateRequest = _messages.MessageField('RegionInstanceGroupManagersSetTemplateRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersSetTargetPoolsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersSetTargetPoolsRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersSetTargetPoolsRequest: A
      RegionInstanceGroupManagersSetTargetPoolsRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersSetTargetPoolsRequest = _messages.MessageField('RegionInstanceGroupManagersSetTargetPoolsRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersStartInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersStartInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersStartInstancesRequest: A
      RegionInstanceGroupManagersStartInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersStartInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersStartInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersStopInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersStopInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersStopInstancesRequest: A
      RegionInstanceGroupManagersStopInstancesRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersStopInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersStopInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersSuspendInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersSuspendInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersSuspendInstancesRequest: A
      RegionInstanceGroupManagersSuspendInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersSuspendInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersSuspendInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionInstanceGroupManagersUpdatePerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersUpdatePerInstanceConfigsRequest
  object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    regionInstanceGroupManagerUpdateInstanceConfigReq: A
      RegionInstanceGroupManagerUpdateInstanceConfigReq resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagerUpdateInstanceConfigReq = _messages.MessageField('RegionInstanceGroupManagerUpdateInstanceConfigReq', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersUpdateRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersUpdateRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagerResource: A InstanceGroupManager resource to be passed
      as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResource = _messages.MessageField('InstanceGroupManager', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupsGetRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsGetRequest object.

  Fields:
    instanceGroup: Name of the instance group resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  instanceGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionInstanceGroupsListInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsListInstancesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    instanceGroup: Name of the regional instance group for which we want to
      list the instances.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupsListInstancesRequest: A
      RegionInstanceGroupsListInstancesRequest resource to be passed as the
      request body.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  instanceGroup = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  regionInstanceGroupsListInstancesRequest = _messages.MessageField('RegionInstanceGroupsListInstancesRequest', 8)
  returnPartialSuccess = _messages.BooleanField(9)


class ComputeRegionInstanceGroupsListRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionInstanceGroupsSetNamedPortsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsSetNamedPortsRequest object.

  Fields:
    instanceGroup: The name of the regional instance group where the named
      ports are updated.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupsSetNamedPortsRequest: A
      RegionInstanceGroupsSetNamedPortsRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupsSetNamedPortsRequest = _messages.MessageField('RegionInstanceGroupsSetNamedPortsRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionInstanceTemplatesDeleteRequest(_messages.Message):
  r"""A ComputeRegionInstanceTemplatesDeleteRequest object.

  Fields:
    instanceTemplate: The name of the instance template to delete.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstanceTemplatesGetRequest(_messages.Message):
  r"""A ComputeRegionInstanceTemplatesGetRequest object.

  Enums:
    ViewValueValuesEnum: View of the instance template.

  Fields:
    instanceTemplate: The name of the instance template.
    project: Project ID for this request.
    region: The name of the region for this request.
    view: View of the instance template.
  """

  class ViewValueValuesEnum(_messages.Enum):
    r"""View of the instance template.

    Values:
      BASIC: Include everything except Partner Metadata.
      FULL: Include everything.
      INSTANCE_VIEW_UNSPECIFIED: The default / unset value. The API will
        default to the BASIC view.
    """
    BASIC = 0
    FULL = 1
    INSTANCE_VIEW_UNSPECIFIED = 2

  instanceTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  view = _messages.EnumField('ViewValueValuesEnum', 4)


class ComputeRegionInstanceTemplatesInsertRequest(_messages.Message):
  r"""A ComputeRegionInstanceTemplatesInsertRequest object.

  Fields:
    instanceTemplate: A InstanceTemplate resource to be passed as the request
      body.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instanceTemplate = _messages.MessageField('InstanceTemplate', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstanceTemplatesListRequest(_messages.Message):
  r"""A ComputeRegionInstanceTemplatesListRequest object.

  Enums:
    ViewValueValuesEnum: View of the instance template.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the regions for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    view: View of the instance template.
  """

  class ViewValueValuesEnum(_messages.Enum):
    r"""View of the instance template.

    Values:
      BASIC: Include everything except Partner Metadata.
      FULL: Include everything.
      INSTANCE_VIEW_UNSPECIFIED: The default / unset value. The API will
        default to the BASIC view.
    """
    BASIC = 0
    FULL = 1
    INSTANCE_VIEW_UNSPECIFIED = 2

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  view = _messages.EnumField('ViewValueValuesEnum', 8)


class ComputeRegionInstancesBulkInsertRequest(_messages.Message):
  r"""A ComputeRegionInstancesBulkInsertRequest object.

  Fields:
    bulkInsertInstanceResource: A BulkInsertInstanceResource resource to be
      passed as the request body.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  bulkInsertInstanceResource = _messages.MessageField('BulkInsertInstanceResource', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstantSnapshotGroupsDeleteRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotGroupsDeleteRequest object.

  Fields:
    instantSnapshotGroup: Name of the InstantSnapshotGroup resource to delete.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instantSnapshotGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstantSnapshotGroupsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotGroupsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeRegionInstantSnapshotGroupsGetRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotGroupsGetRequest object.

  Fields:
    instantSnapshotGroup: Name of the InstantSnapshotGroup resource to return.
    project: Project ID for this request.
    region: The name of the region for this request.
  """

  instantSnapshotGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionInstantSnapshotGroupsInsertRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotGroupsInsertRequest object.

  Fields:
    instantSnapshotGroup: A InstantSnapshotGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceConsistencyGroup: begin_interface: MixerMutationRequestBuilder
  """

  instantSnapshotGroup = _messages.MessageField('InstantSnapshotGroup', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  sourceConsistencyGroup = _messages.StringField(5)


class ComputeRegionInstantSnapshotGroupsListRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionInstantSnapshotGroupsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotGroupsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeRegionInstantSnapshotGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionInstantSnapshotsDeleteRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotsDeleteRequest object.

  Fields:
    instantSnapshot: Name of the InstantSnapshot resource to delete.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instantSnapshot = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstantSnapshotsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeRegionInstantSnapshotsGetRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotsGetRequest object.

  Fields:
    instantSnapshot: Name of the InstantSnapshot resource to return.
    project: Project ID for this request.
    region: The name of the region for this request.
  """

  instantSnapshot = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionInstantSnapshotsInsertRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotsInsertRequest object.

  Fields:
    instantSnapshot: A InstantSnapshot resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  instantSnapshot = _messages.MessageField('InstantSnapshot', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstantSnapshotsListRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionInstantSnapshotsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeRegionInstantSnapshotsSetLabelsRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeRegionInstantSnapshotsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionInstantSnapshotsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionMultiMigMembersGetRequest(_messages.Message):
  r"""A ComputeRegionMultiMigMembersGetRequest object.

  Fields:
    multiMig: The name of the multi-MIG. Name should conform to RFC1035 or be
      a resource ID.
    multiMigMember: The name of the multi-MIG member. Name should conform to
      RFC1035 or be a resource ID.
    project: Project ID for this request.
    region: Name of the region for this request. Region name should conform to
      RFC1035.
  """

  multiMig = _messages.StringField(1, required=True)
  multiMigMember = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)


class ComputeRegionMultiMigMembersListRequest(_messages.Message):
  r"""A ComputeRegionMultiMigMembersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    multiMig: The name of the multi-MIG. Name should conform to RFC1035 or be
      a resource ID.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request. Region name should conform to
      RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  multiMig = _messages.StringField(3, required=True)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)


class ComputeRegionMultiMigsDeleteRequest(_messages.Message):
  r"""A ComputeRegionMultiMigsDeleteRequest object.

  Fields:
    multiMig: Name of the multi-MIG to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  multiMig = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionMultiMigsGetRequest(_messages.Message):
  r"""A ComputeRegionMultiMigsGetRequest object.

  Fields:
    multiMig: Name of the multi-MIG resource to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  multiMig = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionMultiMigsInsertRequest(_messages.Message):
  r"""A ComputeRegionMultiMigsInsertRequest object.

  Fields:
    multiMig: A MultiMig resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents you
      from accidentally creating duplicate commitments. The request ID must be
      a valid UUID with the exception that zero UUID is not supported (
      00000000-0000-0000-0000-000000000000).
  """

  multiMig = _messages.MessageField('MultiMig', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionMultiMigsListRequest(_messages.Message):
  r"""A ComputeRegionMultiMigsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionNetworkEndpointGroupsAttachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsAttachNetworkEndpointsRequest
  object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group where you are
      attaching network endpoints to. It should comply with RFC1035.
    project: Project ID for this request.
    region: The name of the region where you want to create the network
      endpoint group. It should comply with RFC1035.
    regionNetworkEndpointGroupsAttachEndpointsRequest: A
      RegionNetworkEndpointGroupsAttachEndpointsRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionNetworkEndpointGroupsAttachEndpointsRequest = _messages.MessageField('RegionNetworkEndpointGroupsAttachEndpointsRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionNetworkEndpointGroupsDeleteRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsDeleteRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group to delete. It
      should comply with RFC1035.
    project: Project ID for this request.
    region: The name of the region where the network endpoint group is
      located. It should comply with RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNetworkEndpointGroupsDetachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsDetachNetworkEndpointsRequest
  object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group you are
      detaching network endpoints from. It should comply with RFC1035.
    project: Project ID for this request.
    region: The name of the region where the network endpoint group is
      located. It should comply with RFC1035.
    regionNetworkEndpointGroupsDetachEndpointsRequest: A
      RegionNetworkEndpointGroupsDetachEndpointsRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionNetworkEndpointGroupsDetachEndpointsRequest = _messages.MessageField('RegionNetworkEndpointGroupsDetachEndpointsRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionNetworkEndpointGroupsGetRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsGetRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group. It should
      comply with RFC1035.
    project: Project ID for this request.
    region: The name of the region where the network endpoint group is
      located. It should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionNetworkEndpointGroupsInsertRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsInsertRequest object.

  Fields:
    networkEndpointGroup: A NetworkEndpointGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    region: The name of the region where you want to create the network
      endpoint group. It should comply with RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.MessageField('NetworkEndpointGroup', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNetworkEndpointGroupsListNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsListNetworkEndpointsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    networkEndpointGroup: The name of the network endpoint group from which
      you want to generate a list of included network endpoints. It should
      comply with RFC1035.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region where the network endpoint group is
      located. It should comply with RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  networkEndpointGroup = _messages.StringField(3, required=True)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)


class ComputeRegionNetworkEndpointGroupsListRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region where the network endpoint group is
      located. It should comply with RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionNetworkFirewallPoliciesAddAssociationRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesAddAssociationRequest object.

  Fields:
    associatedPolicyToBeReplaced: Name of the firewall policy associated with
      the target network to swap association with. This field is mutually
      exclusive with 'replace_existing_association'.
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyAssociation: A FirewallPolicyAssociation resource to be
      passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    replaceExistingAssociation: Indicates whether or not to replace it if an
      association already exists. This is false by default, in which case an
      error will be returned if an association already exists.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  associatedPolicyToBeReplaced = _messages.StringField(1)
  firewallPolicy = _messages.StringField(2, required=True)
  firewallPolicyAssociation = _messages.MessageField('FirewallPolicyAssociation', 3)
  project = _messages.StringField(4, required=True)
  region = _messages.StringField(5, required=True)
  replaceExistingAssociation = _messages.BooleanField(6)
  requestId = _messages.StringField(7)


class ComputeRegionNetworkFirewallPoliciesAddRuleRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesAddRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    maxPriority: When rule.priority is not specified, auto choose a unused
      priority between minPriority and maxPriority>. This field is exclusive
      with rule.priority.
    minPriority: When rule.priority is not specified, auto choose a unused
      priority between minPriority and maxPriority>. This field is exclusive
      with rule.priority.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  maxPriority = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  minPriority = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  requestId = _messages.StringField(7)


class ComputeRegionNetworkFirewallPoliciesCloneRulesRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesCloneRulesRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sourceFirewallPolicy: The firewall policy from which to copy rules.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  sourceFirewallPolicy = _messages.StringField(5)


class ComputeRegionNetworkFirewallPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesDeleteRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNetworkFirewallPoliciesGetAssociationRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesGetAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to which the queried
      association belongs.
    name: The name of the association to get from the firewall policy.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  name = _messages.StringField(2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)


class ComputeRegionNetworkFirewallPoliciesGetEffectiveFirewallsRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesGetEffectiveFirewallsRequest
  object.

  Fields:
    network: Network reference
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionNetworkFirewallPoliciesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeRegionNetworkFirewallPoliciesGetRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesGetRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to get.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionNetworkFirewallPoliciesGetRuleRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesGetRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to which the queried rule
      belongs.
    priority: The priority of the rule to get from the firewall policy.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)


class ComputeRegionNetworkFirewallPoliciesInsertRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesInsertRequest object.

  Fields:
    firewallPolicy: A FirewallPolicy resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.MessageField('FirewallPolicy', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNetworkFirewallPoliciesListRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionNetworkFirewallPoliciesPatchAssociationRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesPatchAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyAssociation: A FirewallPolicyAssociation resource to be
      passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyAssociation = _messages.MessageField('FirewallPolicyAssociation', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionNetworkFirewallPoliciesPatchRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesPatchRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyResource: A FirewallPolicy resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyResource = _messages.MessageField('FirewallPolicy', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionNetworkFirewallPoliciesPatchRuleRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesPatchRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    firewallPolicyRule: A FirewallPolicyRule resource to be passed as the
      request body.
    priority: The priority of the rule to patch.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  firewallPolicyRule = _messages.MessageField('FirewallPolicyRule', 2)
  priority = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  project = _messages.StringField(4, required=True)
  region = _messages.StringField(5, required=True)
  requestId = _messages.StringField(6)


class ComputeRegionNetworkFirewallPoliciesRemoveAssociationRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesRemoveAssociationRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    name: Name for the association that will be removed.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  name = _messages.StringField(2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionNetworkFirewallPoliciesRemoveRuleRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesRemoveRuleRequest object.

  Fields:
    firewallPolicy: Name of the firewall policy to update.
    priority: The priority of the rule to remove from the firewall policy.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  firewallPolicy = _messages.StringField(1, required=True)
  priority = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionNetworkFirewallPoliciesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeRegionNetworkFirewallPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionNetworkFirewallPoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionNotificationEndpointsAggregatedListRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeRegionNotificationEndpointsDeleteRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsDeleteRequest object.

  Fields:
    notificationEndpoint: Name of the NotificationEndpoint resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  notificationEndpoint = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNotificationEndpointsGetRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsGetRequest object.

  Fields:
    notificationEndpoint: Name of the NotificationEndpoint resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  notificationEndpoint = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionNotificationEndpointsInsertRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsInsertRequest object.

  Fields:
    notificationEndpoint: A NotificationEndpoint resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
  """

  notificationEndpoint = _messages.MessageField('NotificationEndpoint', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNotificationEndpointsListRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionNotificationEndpointsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionOperationsDeleteRequest(_messages.Message):
  r"""A ComputeRegionOperationsDeleteRequest object.

  Fields:
    operation: Name of the Operations resource to delete, or its unique
      numeric identifier.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionOperationsDeleteResponse(_messages.Message):
  r"""An empty ComputeRegionOperationsDelete response."""


class ComputeRegionOperationsGetRequest(_messages.Message):
  r"""A ComputeRegionOperationsGetRequest object.

  Fields:
    operation: Name of the Operations resource to return, or its unique
      numeric identifier.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionOperationsListRequest(_messages.Message):
  r"""A ComputeRegionOperationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionOperationsWaitRequest(_messages.Message):
  r"""A ComputeRegionOperationsWaitRequest object.

  Fields:
    operation: Name of the Operations resource to return, or its unique
      numeric identifier.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionSecurityPoliciesAddRuleRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesAddRuleRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
    validateOnly: If true, the request will not be committed.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  securityPolicy = _messages.StringField(3, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 4)
  validateOnly = _messages.BooleanField(5)


class ComputeRegionSecurityPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  securityPolicy = _messages.StringField(4, required=True)


class ComputeRegionSecurityPoliciesGetRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    securityPolicy: Name of the security policy to get.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeRegionSecurityPoliciesGetRuleRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesGetRuleRequest object.

  Fields:
    priority: The priority of the rule to get from the security policy.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    securityPolicy: Name of the security policy to which the queried rule
      belongs.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  securityPolicy = _messages.StringField(4, required=True)


class ComputeRegionSecurityPoliciesInsertRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: A SecurityPolicy resource to be passed as the request
      body.
    validateOnly: If true, the request will not be committed.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  securityPolicy = _messages.MessageField('SecurityPolicy', 4)
  validateOnly = _messages.BooleanField(5)


class ComputeRegionSecurityPoliciesListRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionSecurityPoliciesPatchRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesPatchRequest object.

  Fields:
    paths: A string attribute.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyResource: A SecurityPolicy resource to be passed as the
      request body.
    updateMask: Indicates fields to be cleared as part of this request.
  """

  paths = _messages.StringField(1, repeated=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  securityPolicy = _messages.StringField(5, required=True)
  securityPolicyResource = _messages.MessageField('SecurityPolicy', 6)
  updateMask = _messages.StringField(7)


class ComputeRegionSecurityPoliciesPatchRuleRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesPatchRuleRequest object.

  Fields:
    priority: The priority of the rule to patch.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
    updateMask: Indicates fields to be cleared as part of this request.
    validateOnly: If true, the request will not be committed.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  securityPolicy = _messages.StringField(4, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 5)
  updateMask = _messages.StringField(6)
  validateOnly = _messages.BooleanField(7)


class ComputeRegionSecurityPoliciesRemoveRuleRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesRemoveRuleRequest object.

  Fields:
    priority: The priority of the rule to remove from the security policy.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    securityPolicy: Name of the security policy to update.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  securityPolicy = _messages.StringField(4, required=True)


class ComputeRegionSecurityPoliciesSetLabelsRequest(_messages.Message):
  r"""A ComputeRegionSecurityPoliciesSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeRegionSnapshotSettingsGetRequest(_messages.Message):
  r"""A ComputeRegionSnapshotSettingsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)


class ComputeRegionSnapshotSettingsPatchRequest(_messages.Message):
  r"""A ComputeRegionSnapshotSettingsPatchRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshotSettings: A SnapshotSettings resource to be passed as the request
      body.
    updateMask: update_mask indicates fields to be updated as part of this
      request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  snapshotSettings = _messages.MessageField('SnapshotSettings', 4)
  updateMask = _messages.StringField(5)


class ComputeRegionSnapshotsDeleteRequest(_messages.Message):
  r"""A ComputeRegionSnapshotsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshot: Name of the snapshot resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  snapshot = _messages.StringField(4, required=True)


class ComputeRegionSnapshotsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionSnapshotsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeRegionSnapshotsGetRequest(_messages.Message):
  r"""A ComputeRegionSnapshotsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    snapshot: Name of the Snapshot resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  snapshot = _messages.StringField(3, required=True)


class ComputeRegionSnapshotsInsertRequest(_messages.Message):
  r"""A ComputeRegionSnapshotsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshot: A Snapshot resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  snapshot = _messages.MessageField('Snapshot', 4)


class ComputeRegionSnapshotsListRequest(_messages.Message):
  r"""A ComputeRegionSnapshotsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionSnapshotsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionSnapshotsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeRegionSnapshotsSetLabelsRequest(_messages.Message):
  r"""A ComputeRegionSnapshotsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeRegionSnapshotsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionSnapshotsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionSslCertificatesDeleteRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslCertificate: Name of the SslCertificate resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sslCertificate = _messages.StringField(4, required=True)


class ComputeRegionSslCertificatesGetRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    sslCertificate: Name of the SslCertificate resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  sslCertificate = _messages.StringField(3, required=True)


class ComputeRegionSslCertificatesInsertRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslCertificate: A SslCertificate resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sslCertificate = _messages.MessageField('SslCertificate', 4)


class ComputeRegionSslCertificatesListRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionSslCertificatesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionSslPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeRegionSslPoliciesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslPolicy: Name of the SSL policy to delete. The name must be 1-63
      characters long, and comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sslPolicy = _messages.StringField(4, required=True)


class ComputeRegionSslPoliciesGetRequest(_messages.Message):
  r"""A ComputeRegionSslPoliciesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    sslPolicy: Name of the SSL policy to update. The name must be 1-63
      characters long, and comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  sslPolicy = _messages.StringField(3, required=True)


class ComputeRegionSslPoliciesInsertRequest(_messages.Message):
  r"""A ComputeRegionSslPoliciesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslPolicy: A SslPolicy resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sslPolicy = _messages.MessageField('SslPolicy', 4)


class ComputeRegionSslPoliciesListAvailableFeaturesRequest(_messages.Message):
  r"""A ComputeRegionSslPoliciesListAvailableFeaturesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionSslPoliciesListRequest(_messages.Message):
  r"""A ComputeRegionSslPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionSslPoliciesPatchRequest(_messages.Message):
  r"""A ComputeRegionSslPoliciesPatchRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslPolicy: Name of the SSL policy to update. The name must be 1-63
      characters long, and comply with RFC1035.
    sslPolicyResource: A SslPolicy resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sslPolicy = _messages.StringField(4, required=True)
  sslPolicyResource = _messages.MessageField('SslPolicy', 5)


class ComputeRegionSslPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionSslPoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionTargetHttpProxiesDeleteRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpProxy = _messages.StringField(4, required=True)


class ComputeRegionTargetHttpProxiesGetRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetHttpProxy: Name of the TargetHttpProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetHttpProxy = _messages.StringField(3, required=True)


class ComputeRegionTargetHttpProxiesInsertRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpProxy: A TargetHttpProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpProxy = _messages.MessageField('TargetHttpProxy', 4)


class ComputeRegionTargetHttpProxiesListRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionTargetHttpProxiesSetUrlMapRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesSetUrlMapRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy to set a URL map for.
    urlMapReference: A UrlMapReference resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpProxy = _messages.StringField(4, required=True)
  urlMapReference = _messages.MessageField('UrlMapReference', 5)


class ComputeRegionTargetHttpProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionTargetHttpsProxiesDeleteRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeRegionTargetHttpsProxiesGetRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetHttpsProxy: Name of the TargetHttpsProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetHttpsProxy = _messages.StringField(3, required=True)


class ComputeRegionTargetHttpsProxiesInsertRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: A TargetHttpsProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpsProxy = _messages.MessageField('TargetHttpsProxy', 4)


class ComputeRegionTargetHttpsProxiesListRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionTargetHttpsProxiesPatchRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesPatchRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource to patch.
    targetHttpsProxyResource: A TargetHttpsProxy resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpsProxy = _messages.StringField(4, required=True)
  targetHttpsProxyResource = _messages.MessageField('TargetHttpsProxy', 5)


class ComputeRegionTargetHttpsProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesSetSslCertificatesRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionTargetHttpsProxiesSetSslCertificatesRequest: A
      RegionTargetHttpsProxiesSetSslCertificatesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource to set an
      SslCertificates resource for.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionTargetHttpsProxiesSetSslCertificatesRequest = _messages.MessageField('RegionTargetHttpsProxiesSetSslCertificatesRequest', 3)
  requestId = _messages.StringField(4)
  targetHttpsProxy = _messages.StringField(5, required=True)


class ComputeRegionTargetHttpsProxiesSetUrlMapRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesSetUrlMapRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy to set a URL map for.
    urlMapReference: A UrlMapReference resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpsProxy = _messages.StringField(4, required=True)
  urlMapReference = _messages.MessageField('UrlMapReference', 5)


class ComputeRegionTargetHttpsProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionTargetTcpProxiesDeleteRequest(_messages.Message):
  r"""A ComputeRegionTargetTcpProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetTcpProxy: Name of the TargetTcpProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetTcpProxy = _messages.StringField(4, required=True)


class ComputeRegionTargetTcpProxiesGetRequest(_messages.Message):
  r"""A ComputeRegionTargetTcpProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetTcpProxy: Name of the TargetTcpProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetTcpProxy = _messages.StringField(3, required=True)


class ComputeRegionTargetTcpProxiesInsertRequest(_messages.Message):
  r"""A ComputeRegionTargetTcpProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetTcpProxy: A TargetTcpProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetTcpProxy = _messages.MessageField('TargetTcpProxy', 4)


class ComputeRegionTargetTcpProxiesListRequest(_messages.Message):
  r"""A ComputeRegionTargetTcpProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionTargetTcpProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionTargetTcpProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionUrlMapsDeleteRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: Name of the UrlMap resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.StringField(4, required=True)


class ComputeRegionUrlMapsGetRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    urlMap: Name of the UrlMap resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  urlMap = _messages.StringField(3, required=True)


class ComputeRegionUrlMapsInsertRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.MessageField('UrlMap', 4)


class ComputeRegionUrlMapsInvalidateCacheRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsInvalidateCacheRequest object.

  Fields:
    cacheInvalidationRule: A CacheInvalidationRule resource to be passed as
      the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: Name of the UrlMap scoping this request.
  """

  cacheInvalidationRule = _messages.MessageField('CacheInvalidationRule', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  urlMap = _messages.StringField(5, required=True)


class ComputeRegionUrlMapsListRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionUrlMapsPatchRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsPatchRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: Name of the UrlMap resource to patch.
    urlMapResource: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.StringField(4, required=True)
  urlMapResource = _messages.MessageField('UrlMap', 5)


class ComputeRegionUrlMapsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionUrlMapsUpdateRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsUpdateRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: Name of the UrlMap resource to update.
    urlMapResource: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.StringField(4, required=True)
  urlMapResource = _messages.MessageField('UrlMap', 5)


class ComputeRegionUrlMapsValidateRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsValidateRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionUrlMapsValidateRequest: A RegionUrlMapsValidateRequest resource to
      be passed as the request body.
    urlMap: Name of the UrlMap resource to be validated as.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionUrlMapsValidateRequest = _messages.MessageField('RegionUrlMapsValidateRequest', 3)
  urlMap = _messages.StringField(4, required=True)


class ComputeRegionZonesListRequest(_messages.Message):
  r"""A ComputeRegionZonesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionsGetRequest(_messages.Message):
  r"""A ComputeRegionsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)


class ComputeRegionsListRequest(_messages.Message):
  r"""A ComputeRegionsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeReliabilityRisksGetRequest(_messages.Message):
  r"""A ComputeReliabilityRisksGetRequest object.

  Fields:
    project: Project ID for this request.
    reliabilityRisk: Name of the ReliabilityRisk resource to return.
  """

  project = _messages.StringField(1, required=True)
  reliabilityRisk = _messages.StringField(2, required=True)


class ComputeReliabilityRisksListRequest(_messages.Message):
  r"""A ComputeReliabilityRisksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeReservationBlocksGetRequest(_messages.Message):
  r"""A ComputeReservationBlocksGetRequest object.

  Fields:
    project: Project ID for this request.
    reservation: The name of the reservation. Name should conform to RFC1035
      or be a resource ID.
    reservationBlock: The name of the reservation block. Name should conform
      to RFC1035 or be a resource ID.
    zone: Name of the zone for this request. Zone name should conform to
      RFC1035.
  """

  project = _messages.StringField(1, required=True)
  reservation = _messages.StringField(2, required=True)
  reservationBlock = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeReservationBlocksListRequest(_messages.Message):
  r"""A ComputeReservationBlocksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    reservation: The name of the reservation. Name should conform to RFC1035
      or be a resource ID.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: Name of the zone for this request. Zone name should conform to
      RFC1035.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  reservation = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeReservationBlocksPerformMaintenanceRequest(_messages.Message):
  r"""A ComputeReservationBlocksPerformMaintenanceRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    reservation: The name of the reservation. Name should conform to RFC1035
      or be a resource ID.
    reservationBlock: The name of the reservation block. Name should conform
      to RFC1035 or be a resource ID.
    reservationsBlocksPerformMaintenanceRequest: A
      ReservationsBlocksPerformMaintenanceRequest resource to be passed as the
      request body.
    zone: Name of the zone for this request. Zone name should conform to
      RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  reservation = _messages.StringField(3, required=True)
  reservationBlock = _messages.StringField(4, required=True)
  reservationsBlocksPerformMaintenanceRequest = _messages.MessageField('ReservationsBlocksPerformMaintenanceRequest', 5)
  zone = _messages.StringField(6, required=True)


class ComputeReservationsAggregatedListRequest(_messages.Message):
  r"""A ComputeReservationsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeReservationsDeleteRequest(_messages.Message):
  r"""A ComputeReservationsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    reservation: Name of the reservation to delete.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  reservation = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeReservationsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeReservationsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeReservationsGetRequest(_messages.Message):
  r"""A ComputeReservationsGetRequest object.

  Fields:
    project: Project ID for this request.
    reservation: Name of the reservation to retrieve.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  reservation = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeReservationsInsertRequest(_messages.Message):
  r"""A ComputeReservationsInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    reservation: A Reservation resource to be passed as the request body.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  reservation = _messages.MessageField('Reservation', 3)
  zone = _messages.StringField(4, required=True)


class ComputeReservationsListRequest(_messages.Message):
  r"""A ComputeReservationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: Name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeReservationsPerformMaintenanceRequest(_messages.Message):
  r"""A ComputeReservationsPerformMaintenanceRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    reservation: The name of the reservation. Name should conform to RFC1035
      or be a resource ID.
    reservationsPerformMaintenanceRequest: A
      ReservationsPerformMaintenanceRequest resource to be passed as the
      request body.
    zone: Name of the zone for this request. Zone name should conform to
      RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  reservation = _messages.StringField(3, required=True)
  reservationsPerformMaintenanceRequest = _messages.MessageField('ReservationsPerformMaintenanceRequest', 4)
  zone = _messages.StringField(5, required=True)


class ComputeReservationsResizeRequest(_messages.Message):
  r"""A ComputeReservationsResizeRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    reservation: Name of the reservation to update.
    reservationsResizeRequest: A ReservationsResizeRequest resource to be
      passed as the request body.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  reservation = _messages.StringField(3, required=True)
  reservationsResizeRequest = _messages.MessageField('ReservationsResizeRequest', 4)
  zone = _messages.StringField(5, required=True)


class ComputeReservationsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeReservationsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeReservationsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeReservationsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeReservationsUpdateRequest(_messages.Message):
  r"""A ComputeReservationsUpdateRequest object.

  Fields:
    paths: A string attribute.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    reservation: Name of the reservation to update.
    reservationResource: A Reservation resource to be passed as the request
      body.
    updateMask: Update_mask indicates fields to be updated as part of this
      request.
    zone: Name of the zone for this request.
  """

  paths = _messages.StringField(1, repeated=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  reservation = _messages.StringField(4, required=True)
  reservationResource = _messages.MessageField('Reservation', 5)
  updateMask = _messages.StringField(6)
  zone = _messages.StringField(7, required=True)


class ComputeResourcePoliciesAggregatedListRequest(_messages.Message):
  r"""A ComputeResourcePoliciesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeResourcePoliciesDeleteRequest(_messages.Message):
  r"""A ComputeResourcePoliciesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resourcePolicy: Name of the resource policy to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resourcePolicy = _messages.StringField(4, required=True)


class ComputeResourcePoliciesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeResourcePoliciesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeResourcePoliciesGetRequest(_messages.Message):
  r"""A ComputeResourcePoliciesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    resourcePolicy: Name of the resource policy to retrieve.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resourcePolicy = _messages.StringField(3, required=True)


class ComputeResourcePoliciesInsertRequest(_messages.Message):
  r"""A ComputeResourcePoliciesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resourcePolicy: A ResourcePolicy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resourcePolicy = _messages.MessageField('ResourcePolicy', 4)


class ComputeResourcePoliciesListRequest(_messages.Message):
  r"""A ComputeResourcePoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeResourcePoliciesPatchRequest(_messages.Message):
  r"""A ComputeResourcePoliciesPatchRequest object.

  Fields:
    paths: A string attribute.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resourcePolicy: Id of the resource policy to patch.
    resourcePolicyResource: A ResourcePolicy resource to be passed as the
      request body.
    updateMask: update_mask indicates fields to be updated as part of this
      request.
  """

  paths = _messages.StringField(1, repeated=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  resourcePolicy = _messages.StringField(5, required=True)
  resourcePolicyResource = _messages.MessageField('ResourcePolicy', 6)
  updateMask = _messages.StringField(7)


class ComputeResourcePoliciesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeResourcePoliciesSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeResourcePoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeResourcePoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRoutersAggregatedListRequest(_messages.Message):
  r"""A ComputeRoutersAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeRoutersDeleteNamedSetRequest(_messages.Message):
  r"""A ComputeRoutersDeleteNamedSetRequest object.

  Fields:
    namedSet: The Named Set name for this request. Name must conform to
      RFC1035
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource where Named Set is defined.
  """

  namedSet = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  router = _messages.StringField(5, required=True)


class ComputeRoutersDeleteRequest(_messages.Message):
  r"""A ComputeRoutersDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  router = _messages.StringField(4, required=True)


class ComputeRoutersDeleteRoutePolicyRequest(_messages.Message):
  r"""A ComputeRoutersDeleteRoutePolicyRequest object.

  Fields:
    policy: The Policy name for this request. Name must conform to RFC1035
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource where Route Policy is defined.
  """

  policy = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  router = _messages.StringField(5, required=True)


class ComputeRoutersGetNamedSetRequest(_messages.Message):
  r"""A ComputeRoutersGetNamedSetRequest object.

  Fields:
    namedSet: The Named Set name for this request. Name must conform to
      RFC1035
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to query for the named set. The name
      should conform to RFC1035.
  """

  namedSet = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  router = _messages.StringField(4, required=True)


class ComputeRoutersGetNatIpInfoRequest(_messages.Message):
  r"""A ComputeRoutersGetNatIpInfoRequest object.

  Fields:
    natName: Name of the nat service to filter the NAT IP information. If it
      is omitted, all nats for this router will be returned. Name should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to query for Nat IP information. The
      name should conform to RFC1035.
  """

  natName = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  router = _messages.StringField(4, required=True)


class ComputeRoutersGetNatMappingInfoRequest(_messages.Message):
  r"""A ComputeRoutersGetNatMappingInfoRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    natName: Name of the nat service to filter the Nat Mapping information. If
      it is omitted, all nats for this router will be returned. Name should
      conform to RFC1035.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    router: Name of the Router resource to query for Nat Mapping information
      of VM endpoints.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  natName = _messages.StringField(3)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)
  router = _messages.StringField(9, required=True)


class ComputeRoutersGetRequest(_messages.Message):
  r"""A ComputeRoutersGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  router = _messages.StringField(3, required=True)


class ComputeRoutersGetRoutePolicyRequest(_messages.Message):
  r"""A ComputeRoutersGetRoutePolicyRequest object.

  Fields:
    policy: The Policy name for this request. Name must conform to RFC1035
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to query for the route policy. The
      name should conform to RFC1035.
  """

  policy = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  router = _messages.StringField(4, required=True)


class ComputeRoutersGetRouterStatusRequest(_messages.Message):
  r"""A ComputeRoutersGetRouterStatusRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to query.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  router = _messages.StringField(3, required=True)


class ComputeRoutersInsertRequest(_messages.Message):
  r"""A ComputeRoutersInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    router: A Router resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  router = _messages.MessageField('Router', 4)


class ComputeRoutersListBgpRoutesRequest(_messages.Message):
  r"""A ComputeRoutersListBgpRoutesRequest object.

  Enums:
    AddressFamilyValueValuesEnum: (Required) limit results to this address
      family (either IPv4 or IPv6)
    RouteTypeValueValuesEnum: (Required) limit results to this type of route
      (either LEARNED or ADVERTISED)

  Fields:
    addressFamily: (Required) limit results to this address family (either
      IPv4 or IPv6)
    destinationPrefix: Limit results to destinations that are subnets of this
      CIDR range
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    peer: (Required) limit results to the BGP peer with the given name. Name
      should conform to RFC1035.
    policyApplied: When true, the method returns post-policy routes.
      Otherwise, it returns pre-policy routes.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    routeType: (Required) limit results to this type of route (either LEARNED
      or ADVERTISED)
    router: Name or id of the resource for this request. Name should conform
      to RFC1035.
  """

  class AddressFamilyValueValuesEnum(_messages.Enum):
    r"""(Required) limit results to this address family (either IPv4 or IPv6)

    Values:
      IPV4: <no description>
      IPV6: <no description>
      UNSPECIFIED_IP_VERSION: <no description>
    """
    IPV4 = 0
    IPV6 = 1
    UNSPECIFIED_IP_VERSION = 2

  class RouteTypeValueValuesEnum(_messages.Enum):
    r"""(Required) limit results to this type of route (either LEARNED or
    ADVERTISED)

    Values:
      ADVERTISED: <no description>
      LEARNED: <no description>
      UNSPECIFIED_ROUTE_TYPE: <no description>
    """
    ADVERTISED = 0
    LEARNED = 1
    UNSPECIFIED_ROUTE_TYPE = 2

  addressFamily = _messages.EnumField('AddressFamilyValueValuesEnum', 1, default='UNSPECIFIED_IP_VERSION')
  destinationPrefix = _messages.StringField(2)
  filter = _messages.StringField(3)
  maxResults = _messages.IntegerField(4, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(5)
  pageToken = _messages.StringField(6)
  peer = _messages.StringField(7)
  policyApplied = _messages.BooleanField(8, default=True)
  project = _messages.StringField(9, required=True)
  region = _messages.StringField(10, required=True)
  returnPartialSuccess = _messages.BooleanField(11)
  routeType = _messages.EnumField('RouteTypeValueValuesEnum', 12, default='UNSPECIFIED_ROUTE_TYPE')
  router = _messages.StringField(13, required=True)


class ComputeRoutersListNamedSetsRequest(_messages.Message):
  r"""A ComputeRoutersListNamedSetsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    router: Name or id of the resource for this request. Name should conform
      to RFC1035.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  router = _messages.StringField(8, required=True)


class ComputeRoutersListRequest(_messages.Message):
  r"""A ComputeRoutersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRoutersListRoutePoliciesRequest(_messages.Message):
  r"""A ComputeRoutersListRoutePoliciesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    router: Name or id of the resource for this request. Name should conform
      to RFC1035.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  router = _messages.StringField(8, required=True)


class ComputeRoutersPatchNamedSetRequest(_messages.Message):
  r"""A ComputeRoutersPatchNamedSetRequest object.

  Fields:
    namedSet: A NamedSet resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource where Named Set is defined.
  """

  namedSet = _messages.MessageField('NamedSet', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  router = _messages.StringField(5, required=True)


class ComputeRoutersPatchRequest(_messages.Message):
  r"""A ComputeRoutersPatchRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource to patch.
    routerResource: A Router resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  router = _messages.StringField(4, required=True)
  routerResource = _messages.MessageField('Router', 5)


class ComputeRoutersPatchRoutePolicyRequest(_messages.Message):
  r"""A ComputeRoutersPatchRoutePolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    routePolicy: A RoutePolicy resource to be passed as the request body.
    router: Name of the Router resource where Route Policy is defined.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  routePolicy = _messages.MessageField('RoutePolicy', 4)
  router = _messages.StringField(5, required=True)


class ComputeRoutersPreviewRequest(_messages.Message):
  r"""A ComputeRoutersPreviewRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to query.
    routerResource: A Router resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  router = _messages.StringField(3, required=True)
  routerResource = _messages.MessageField('Router', 4)


class ComputeRoutersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRoutersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRoutersUpdateNamedSetRequest(_messages.Message):
  r"""A ComputeRoutersUpdateNamedSetRequest object.

  Fields:
    namedSet: A NamedSet resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource where Named Set is defined.
  """

  namedSet = _messages.MessageField('NamedSet', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  router = _messages.StringField(5, required=True)


class ComputeRoutersUpdateRequest(_messages.Message):
  r"""A ComputeRoutersUpdateRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource to update.
    routerResource: A Router resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  router = _messages.StringField(4, required=True)
  routerResource = _messages.MessageField('Router', 5)


class ComputeRoutersUpdateRoutePolicyRequest(_messages.Message):
  r"""A ComputeRoutersUpdateRoutePolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    routePolicy: A RoutePolicy resource to be passed as the request body.
    router: Name of the Router resource where Route Policy is defined.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  routePolicy = _messages.MessageField('RoutePolicy', 4)
  router = _messages.StringField(5, required=True)


class ComputeRoutesDeleteRequest(_messages.Message):
  r"""A ComputeRoutesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    route: Name of the Route resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  route = _messages.StringField(3, required=True)


class ComputeRoutesGetRequest(_messages.Message):
  r"""A ComputeRoutesGetRequest object.

  Fields:
    project: Project ID for this request.
    route: Name of the Route resource to return.
  """

  project = _messages.StringField(1, required=True)
  route = _messages.StringField(2, required=True)


class ComputeRoutesInsertRequest(_messages.Message):
  r"""A ComputeRoutesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    route: A Route resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  route = _messages.MessageField('Route', 3)


class ComputeRoutesListRequest(_messages.Message):
  r"""A ComputeRoutesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeRoutesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRoutesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeSecurityPoliciesAddRuleRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesAddRuleRequest object.

  Fields:
    project: Project ID for this request.
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
    validateOnly: If true, the request will not be committed.
  """

  project = _messages.StringField(1, required=True)
  securityPolicy = _messages.StringField(2, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 3)
  validateOnly = _messages.BooleanField(4)


class ComputeSecurityPoliciesAggregatedListRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeSecurityPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeSecurityPoliciesGetRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesGetRequest object.

  Fields:
    project: Project ID for this request.
    securityPolicy: Name of the security policy to get.
  """

  project = _messages.StringField(1, required=True)
  securityPolicy = _messages.StringField(2, required=True)


class ComputeSecurityPoliciesGetRuleRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesGetRuleRequest object.

  Fields:
    priority: The priority of the rule to get from the security policy.
    project: Project ID for this request.
    securityPolicy: Name of the security policy to which the queried rule
      belongs.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeSecurityPoliciesInsertRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: A SecurityPolicy resource to be passed as the request
      body.
    validateOnly: If true, the request will not be committed.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.MessageField('SecurityPolicy', 3)
  validateOnly = _messages.BooleanField(4)


class ComputeSecurityPoliciesListPreconfiguredExpressionSetsRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesListPreconfiguredExpressionSetsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSecurityPoliciesListRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSecurityPoliciesPatchRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesPatchRequest object.

  Fields:
    paths: A string attribute.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyResource: A SecurityPolicy resource to be passed as the
      request body.
    updateMask: Indicates fields to be cleared as part of this request.
  """

  paths = _messages.StringField(1, repeated=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  securityPolicy = _messages.StringField(4, required=True)
  securityPolicyResource = _messages.MessageField('SecurityPolicy', 5)
  updateMask = _messages.StringField(6)


class ComputeSecurityPoliciesPatchRuleRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesPatchRuleRequest object.

  Fields:
    priority: The priority of the rule to patch.
    project: Project ID for this request.
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
    updateMask: Indicates fields to be cleared as part of this request.
    validateOnly: If true, the request will not be committed.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  securityPolicy = _messages.StringField(3, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 4)
  updateMask = _messages.StringField(5)
  validateOnly = _messages.BooleanField(6)


class ComputeSecurityPoliciesRemoveRuleRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesRemoveRuleRequest object.

  Fields:
    priority: The priority of the rule to remove from the security policy.
    project: Project ID for this request.
    securityPolicy: Name of the security policy to update.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeSecurityPoliciesSetLabelsRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSecurityPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeServiceAttachmentsAggregatedListRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeServiceAttachmentsDeleteRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    serviceAttachment: Name of the ServiceAttachment resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  serviceAttachment = _messages.StringField(4, required=True)


class ComputeServiceAttachmentsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeServiceAttachmentsGetRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region of this request.
    serviceAttachment: Name of the ServiceAttachment resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  serviceAttachment = _messages.StringField(3, required=True)


class ComputeServiceAttachmentsInsertRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    serviceAttachment: A ServiceAttachment resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  serviceAttachment = _messages.MessageField('ServiceAttachment', 4)


class ComputeServiceAttachmentsListRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region of this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeServiceAttachmentsPatchRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsPatchRequest object.

  Fields:
    project: Project ID for this request.
    region: The region scoping this request and should conform to RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    serviceAttachment: The resource id of the ServiceAttachment to patch. It
      should conform to RFC1035 resource name or be a string form on an
      unsigned long number.
    serviceAttachmentResource: A ServiceAttachment resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  serviceAttachment = _messages.StringField(4, required=True)
  serviceAttachmentResource = _messages.MessageField('ServiceAttachment', 5)


class ComputeServiceAttachmentsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeServiceAttachmentsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeSnapshotGroupsDeleteRequest(_messages.Message):
  r"""A ComputeSnapshotGroupsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshotGroup: Name of the SnapshotGroup resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  snapshotGroup = _messages.StringField(3, required=True)


class ComputeSnapshotGroupsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeSnapshotGroupsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSnapshotGroupsGetRequest(_messages.Message):
  r"""A ComputeSnapshotGroupsGetRequest object.

  Fields:
    project: Project ID for this request.
    snapshotGroup: Name of the SnapshotGroup resource to return.
  """

  project = _messages.StringField(1, required=True)
  snapshotGroup = _messages.StringField(2, required=True)


class ComputeSnapshotGroupsInsertRequest(_messages.Message):
  r"""A ComputeSnapshotGroupsInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshotGroup: A SnapshotGroup resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  snapshotGroup = _messages.MessageField('SnapshotGroup', 3)


class ComputeSnapshotGroupsListRequest(_messages.Message):
  r"""A ComputeSnapshotGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSnapshotGroupsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeSnapshotGroupsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSnapshotGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSnapshotGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeSnapshotSettingsGetRequest(_messages.Message):
  r"""A ComputeSnapshotSettingsGetRequest object.

  Fields:
    project: Project ID for this request.
  """

  project = _messages.StringField(1, required=True)


class ComputeSnapshotSettingsPatchRequest(_messages.Message):
  r"""A ComputeSnapshotSettingsPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshotSettings: A SnapshotSettings resource to be passed as the request
      body.
    updateMask: update_mask indicates fields to be updated as part of this
      request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  snapshotSettings = _messages.MessageField('SnapshotSettings', 3)
  updateMask = _messages.StringField(4)


class ComputeSnapshotsAggregatedListRequest(_messages.Message):
  r"""A ComputeSnapshotsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeSnapshotsDeleteRequest(_messages.Message):
  r"""A ComputeSnapshotsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshot: Name of the Snapshot resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  snapshot = _messages.StringField(3, required=True)


class ComputeSnapshotsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeSnapshotsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSnapshotsGetRequest(_messages.Message):
  r"""A ComputeSnapshotsGetRequest object.

  Fields:
    project: Project ID for this request.
    snapshot: Name of the Snapshot resource to return.
  """

  project = _messages.StringField(1, required=True)
  snapshot = _messages.StringField(2, required=True)


class ComputeSnapshotsInsertRequest(_messages.Message):
  r"""A ComputeSnapshotsInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    snapshot: A Snapshot resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  snapshot = _messages.MessageField('Snapshot', 3)


class ComputeSnapshotsListRequest(_messages.Message):
  r"""A ComputeSnapshotsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSnapshotsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeSnapshotsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSnapshotsSetLabelsRequest(_messages.Message):
  r"""A ComputeSnapshotsSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSnapshotsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSnapshotsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeSslCertificatesAggregatedListRequest(_messages.Message):
  r"""A ComputeSslCertificatesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeSslCertificatesDeleteRequest(_messages.Message):
  r"""A ComputeSslCertificatesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslCertificate: Name of the SslCertificate resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslCertificate = _messages.StringField(3, required=True)


class ComputeSslCertificatesGetRequest(_messages.Message):
  r"""A ComputeSslCertificatesGetRequest object.

  Fields:
    project: Project ID for this request.
    sslCertificate: Name of the SslCertificate resource to return.
  """

  project = _messages.StringField(1, required=True)
  sslCertificate = _messages.StringField(2, required=True)


class ComputeSslCertificatesInsertRequest(_messages.Message):
  r"""A ComputeSslCertificatesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslCertificate: A SslCertificate resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslCertificate = _messages.MessageField('SslCertificate', 3)


class ComputeSslCertificatesListRequest(_messages.Message):
  r"""A ComputeSslCertificatesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSslCertificatesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSslCertificatesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeSslPoliciesAggregatedListRequest(_messages.Message):
  r"""A ComputeSslPoliciesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeSslPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeSslPoliciesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslPolicy: Name of the SSL policy to delete. The name must be 1-63
      characters long, and comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicy = _messages.StringField(3, required=True)


class ComputeSslPoliciesGetRequest(_messages.Message):
  r"""A ComputeSslPoliciesGetRequest object.

  Fields:
    project: Project ID for this request.
    sslPolicy: Name of the SSL policy to update. The name must be 1-63
      characters long, and comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  sslPolicy = _messages.StringField(2, required=True)


class ComputeSslPoliciesInsertRequest(_messages.Message):
  r"""A ComputeSslPoliciesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslPolicy: A SslPolicy resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicy = _messages.MessageField('SslPolicy', 3)


class ComputeSslPoliciesListAvailableFeaturesRequest(_messages.Message):
  r"""A ComputeSslPoliciesListAvailableFeaturesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSslPoliciesListRequest(_messages.Message):
  r"""A ComputeSslPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSslPoliciesPatchRequest(_messages.Message):
  r"""A ComputeSslPoliciesPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslPolicy: Name of the SSL policy to update. The name must be 1-63
      characters long, and comply with RFC1035.
    sslPolicyResource: A SslPolicy resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicy = _messages.StringField(3, required=True)
  sslPolicyResource = _messages.MessageField('SslPolicy', 4)


class ComputeSslPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSslPoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeStoragePoolTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeStoragePoolTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeStoragePoolTypesGetRequest(_messages.Message):
  r"""A ComputeStoragePoolTypesGetRequest object.

  Fields:
    project: Project ID for this request.
    storagePoolType: Name of the storage pool type to return.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  storagePoolType = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeStoragePoolTypesListRequest(_messages.Message):
  r"""A ComputeStoragePoolTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeStoragePoolsAggregatedListRequest(_messages.Message):
  r"""A ComputeStoragePoolsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeStoragePoolsDeleteRequest(_messages.Message):
  r"""A ComputeStoragePoolsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    storagePool: Name of the storage pool to delete.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  storagePool = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeStoragePoolsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeStoragePoolsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeStoragePoolsGetRequest(_messages.Message):
  r"""A ComputeStoragePoolsGetRequest object.

  Fields:
    project: Project ID for this request.
    storagePool: Name of the storage pool to return.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  storagePool = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeStoragePoolsInsertRequest(_messages.Message):
  r"""A ComputeStoragePoolsInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    storagePool: A StoragePool resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  storagePool = _messages.MessageField('StoragePool', 3)
  zone = _messages.StringField(4, required=True)


class ComputeStoragePoolsListDisksRequest(_messages.Message):
  r"""A ComputeStoragePoolsListDisksRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    storagePool: Name of the storage pool to list disks of.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  storagePool = _messages.StringField(7, required=True)
  zone = _messages.StringField(8, required=True)


class ComputeStoragePoolsListRequest(_messages.Message):
  r"""A ComputeStoragePoolsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeStoragePoolsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeStoragePoolsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeStoragePoolsSetLabelsRequest(_messages.Message):
  r"""A ComputeStoragePoolsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetLabelsRequest: A ZoneSetLabelsRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)
  zoneSetLabelsRequest = _messages.MessageField('ZoneSetLabelsRequest', 5)


class ComputeStoragePoolsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeStoragePoolsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeStoragePoolsUpdateRequest(_messages.Message):
  r"""A ComputeStoragePoolsUpdateRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    storagePool: The storagePool name for this request.
    storagePoolResource: A StoragePool resource to be passed as the request
      body.
    updateMask: update_mask indicates fields to be updated as part of this
      request.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  storagePool = _messages.StringField(3, required=True)
  storagePoolResource = _messages.MessageField('StoragePool', 4)
  updateMask = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeSubnetworksAggregatedListRequest(_messages.Message):
  r"""A ComputeSubnetworksAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeSubnetworksDeleteRequest(_messages.Message):
  r"""A ComputeSubnetworksDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    subnetwork: Name of the Subnetwork resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  subnetwork = _messages.StringField(4, required=True)


class ComputeSubnetworksExpandIpCidrRangeRequest(_messages.Message):
  r"""A ComputeSubnetworksExpandIpCidrRangeRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    subnetwork: Name of the Subnetwork resource to update.
    subnetworksExpandIpCidrRangeRequest: A SubnetworksExpandIpCidrRangeRequest
      resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  subnetwork = _messages.StringField(4, required=True)
  subnetworksExpandIpCidrRangeRequest = _messages.MessageField('SubnetworksExpandIpCidrRangeRequest', 5)


class ComputeSubnetworksGetIamPolicyRequest(_messages.Message):
  r"""A ComputeSubnetworksGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeSubnetworksGetRequest(_messages.Message):
  r"""A ComputeSubnetworksGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    subnetwork: Name of the Subnetwork resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  subnetwork = _messages.StringField(3, required=True)


class ComputeSubnetworksInsertRequest(_messages.Message):
  r"""A ComputeSubnetworksInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    subnetwork: A Subnetwork resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  subnetwork = _messages.MessageField('Subnetwork', 4)


class ComputeSubnetworksListRequest(_messages.Message):
  r"""A ComputeSubnetworksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeSubnetworksListUsableRequest(_messages.Message):
  r"""A ComputeSubnetworksListUsableRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProject: The project id or project number in which the subnetwork
      is intended to be used. Only applied for Shared VPC. See [Shared VPC
      documentation](https://cloud.google.com/vpc/docs/shared-vpc/)
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  serviceProject = _messages.StringField(7)


class ComputeSubnetworksPatchRequest(_messages.Message):
  r"""A ComputeSubnetworksPatchRequest object.

  Fields:
    drainTimeoutSeconds: The drain timeout specifies the upper bound in
      seconds on the amount of time allowed to drain connections from the
      current ACTIVE subnetwork to the current BACKUP subnetwork. The drain
      timeout is only applicable when the following conditions are true: - the
      subnetwork being patched has purpose = INTERNAL_HTTPS_LOAD_BALANCER -
      the subnetwork being patched has role = BACKUP - the patch request is
      setting the role to ACTIVE. Note that after this patch operation the
      roles of the ACTIVE and BACKUP subnetworks will be swapped.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    subnetwork: Name of the Subnetwork resource to patch.
    subnetworkResource: A Subnetwork resource to be passed as the request
      body.
  """

  drainTimeoutSeconds = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  subnetwork = _messages.StringField(5, required=True)
  subnetworkResource = _messages.MessageField('Subnetwork', 6)


class ComputeSubnetworksSetIamPolicyRequest(_messages.Message):
  r"""A ComputeSubnetworksSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeSubnetworksSetPrivateIpGoogleAccessRequest(_messages.Message):
  r"""A ComputeSubnetworksSetPrivateIpGoogleAccessRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    subnetwork: Name of the Subnetwork resource.
    subnetworksSetPrivateIpGoogleAccessRequest: A
      SubnetworksSetPrivateIpGoogleAccessRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  subnetwork = _messages.StringField(4, required=True)
  subnetworksSetPrivateIpGoogleAccessRequest = _messages.MessageField('SubnetworksSetPrivateIpGoogleAccessRequest', 5)


class ComputeSubnetworksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSubnetworksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeTargetGrpcProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetGrpcProxy: Name of the TargetGrpcProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetGrpcProxy = _messages.StringField(3, required=True)


class ComputeTargetGrpcProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetGrpcProxy: Name of the TargetGrpcProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetGrpcProxy = _messages.StringField(2, required=True)


class ComputeTargetGrpcProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetGrpcProxy: A TargetGrpcProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetGrpcProxy = _messages.MessageField('TargetGrpcProxy', 3)


class ComputeTargetGrpcProxiesListRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetGrpcProxiesPatchRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetGrpcProxy: Name of the TargetGrpcProxy resource to patch.
    targetGrpcProxyResource: A TargetGrpcProxy resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetGrpcProxy = _messages.StringField(3, required=True)
  targetGrpcProxyResource = _messages.MessageField('TargetGrpcProxy', 4)


class ComputeTargetGrpcProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetHttpProxiesAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeTargetHttpProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpProxy = _messages.StringField(3, required=True)


class ComputeTargetHttpProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetHttpProxy: Name of the TargetHttpProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetHttpProxy = _messages.StringField(2, required=True)


class ComputeTargetHttpProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpProxy: A TargetHttpProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpProxy = _messages.MessageField('TargetHttpProxy', 3)


class ComputeTargetHttpProxiesListRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetHttpProxiesPatchRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy resource to patch.
    targetHttpProxyResource: A TargetHttpProxy resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpProxy = _messages.StringField(3, required=True)
  targetHttpProxyResource = _messages.MessageField('TargetHttpProxy', 4)


class ComputeTargetHttpProxiesSetUrlMapRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesSetUrlMapRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy to set a URL map for.
    urlMapReference: A UrlMapReference resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpProxy = _messages.StringField(3, required=True)
  urlMapReference = _messages.MessageField('UrlMapReference', 4)


class ComputeTargetHttpProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetHttpsProxiesAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeTargetHttpsProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxy = _messages.StringField(3, required=True)


class ComputeTargetHttpsProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetHttpsProxy: Name of the TargetHttpsProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetHttpsProxy = _messages.StringField(2, required=True)


class ComputeTargetHttpsProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: A TargetHttpsProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxy = _messages.MessageField('TargetHttpsProxy', 3)


class ComputeTargetHttpsProxiesListRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetHttpsProxiesPatchRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource to patch.
    targetHttpsProxyResource: A TargetHttpsProxy resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxy = _messages.StringField(3, required=True)
  targetHttpsProxyResource = _messages.MessageField('TargetHttpsProxy', 4)


class ComputeTargetHttpsProxiesSetCertificateMapRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetCertificateMapRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxiesSetCertificateMapRequest: A
      TargetHttpsProxiesSetCertificateMapRequest resource to be passed as the
      request body.
    targetHttpsProxy: Name of the TargetHttpsProxy resource whose
      CertificateMap is to be set. The name must be 1-63 characters long, and
      comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxiesSetCertificateMapRequest = _messages.MessageField('TargetHttpsProxiesSetCertificateMapRequest', 3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeTargetHttpsProxiesSetQuicOverrideRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetQuicOverrideRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxiesSetQuicOverrideRequest: A
      TargetHttpsProxiesSetQuicOverrideRequest resource to be passed as the
      request body.
    targetHttpsProxy: Name of the TargetHttpsProxy resource to set the QUIC
      override policy for. The name should conform to RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxiesSetQuicOverrideRequest = _messages.MessageField('TargetHttpsProxiesSetQuicOverrideRequest', 3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeTargetHttpsProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetSslCertificatesRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxiesSetSslCertificatesRequest: A
      TargetHttpsProxiesSetSslCertificatesRequest resource to be passed as the
      request body.
    targetHttpsProxy: Name of the TargetHttpsProxy resource to set an
      SslCertificates resource for.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxiesSetSslCertificatesRequest = _messages.MessageField('TargetHttpsProxiesSetSslCertificatesRequest', 3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeTargetHttpsProxiesSetSslPolicyRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetSslPolicyRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslPolicyReference: A SslPolicyReference resource to be passed as the
      request body.
    targetHttpsProxy: Name of the TargetHttpsProxy resource whose SSL policy
      is to be set. The name must be 1-63 characters long, and comply with
      RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicyReference = _messages.MessageField('SslPolicyReference', 3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeTargetHttpsProxiesSetUrlMapRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetUrlMapRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource whose URL map is
      to be set.
    urlMapReference: A UrlMapReference resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxy = _messages.StringField(3, required=True)
  urlMapReference = _messages.MessageField('UrlMapReference', 4)


class ComputeTargetHttpsProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetInstancesAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetInstancesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeTargetInstancesDeleteRequest(_messages.Message):
  r"""A ComputeTargetInstancesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetInstance: Name of the TargetInstance resource to delete.
    zone: Name of the zone scoping this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetInstance = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeTargetInstancesGetRequest(_messages.Message):
  r"""A ComputeTargetInstancesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetInstance: Name of the TargetInstance resource to return.
    zone: Name of the zone scoping this request.
  """

  project = _messages.StringField(1, required=True)
  targetInstance = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeTargetInstancesInsertRequest(_messages.Message):
  r"""A ComputeTargetInstancesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetInstance: A TargetInstance resource to be passed as the request
      body.
    zone: Name of the zone scoping this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetInstance = _messages.MessageField('TargetInstance', 3)
  zone = _messages.StringField(4, required=True)


class ComputeTargetInstancesListRequest(_messages.Message):
  r"""A ComputeTargetInstancesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: Name of the zone scoping this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeTargetInstancesSetSecurityPolicyRequest(_messages.Message):
  r"""A ComputeTargetInstancesSetSecurityPolicyRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicyReference: A SecurityPolicyReference resource to be passed
      as the request body.
    targetInstance: Name of the TargetInstance resource to which the security
      policy should be set. The name should conform to RFC1035.
    zone: Name of the zone scoping this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  securityPolicyReference = _messages.MessageField('SecurityPolicyReference', 3)
  targetInstance = _messages.StringField(4, required=True)
  zone = _messages.StringField(5, required=True)


class ComputeTargetInstancesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetInstancesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeTargetPoolsAddHealthCheckRequest(_messages.Message):
  r"""A ComputeTargetPoolsAddHealthCheckRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetPool: Name of the target pool to add a health check to.
    targetPoolsAddHealthCheckRequest: A TargetPoolsAddHealthCheckRequest
      resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)
  targetPoolsAddHealthCheckRequest = _messages.MessageField('TargetPoolsAddHealthCheckRequest', 5)


class ComputeTargetPoolsAddInstanceRequest(_messages.Message):
  r"""A ComputeTargetPoolsAddInstanceRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetPool: Name of the TargetPool resource to add instances to.
    targetPoolsAddInstanceRequest: A TargetPoolsAddInstanceRequest resource to
      be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)
  targetPoolsAddInstanceRequest = _messages.MessageField('TargetPoolsAddInstanceRequest', 5)


class ComputeTargetPoolsAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetPoolsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeTargetPoolsDeleteRequest(_messages.Message):
  r"""A ComputeTargetPoolsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetPool: Name of the TargetPool resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)


class ComputeTargetPoolsGetHealthRequest(_messages.Message):
  r"""A ComputeTargetPoolsGetHealthRequest object.

  Fields:
    instanceReference: A InstanceReference resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetPool: Name of the TargetPool resource to which the queried instance
      belongs.
  """

  instanceReference = _messages.MessageField('InstanceReference', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  targetPool = _messages.StringField(4, required=True)


class ComputeTargetPoolsGetRequest(_messages.Message):
  r"""A ComputeTargetPoolsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetPool: Name of the TargetPool resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetPool = _messages.StringField(3, required=True)


class ComputeTargetPoolsInsertRequest(_messages.Message):
  r"""A ComputeTargetPoolsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetPool: A TargetPool resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.MessageField('TargetPool', 4)


class ComputeTargetPoolsListRequest(_messages.Message):
  r"""A ComputeTargetPoolsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetPoolsRemoveHealthCheckRequest(_messages.Message):
  r"""A ComputeTargetPoolsRemoveHealthCheckRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetPool: Name of the target pool to remove health checks from.
    targetPoolsRemoveHealthCheckRequest: A TargetPoolsRemoveHealthCheckRequest
      resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)
  targetPoolsRemoveHealthCheckRequest = _messages.MessageField('TargetPoolsRemoveHealthCheckRequest', 5)


class ComputeTargetPoolsRemoveInstanceRequest(_messages.Message):
  r"""A ComputeTargetPoolsRemoveInstanceRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetPool: Name of the TargetPool resource to remove instances from.
    targetPoolsRemoveInstanceRequest: A TargetPoolsRemoveInstanceRequest
      resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)
  targetPoolsRemoveInstanceRequest = _messages.MessageField('TargetPoolsRemoveInstanceRequest', 5)


class ComputeTargetPoolsSetBackupRequest(_messages.Message):
  r"""A ComputeTargetPoolsSetBackupRequest object.

  Fields:
    failoverRatio: New failoverRatio value for the target pool.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetPool: Name of the TargetPool resource to set a backup pool for.
    targetReference: A TargetReference resource to be passed as the request
      body.
  """

  failoverRatio = _messages.FloatField(1, variant=_messages.Variant.FLOAT)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  targetPool = _messages.StringField(5, required=True)
  targetReference = _messages.MessageField('TargetReference', 6)


class ComputeTargetPoolsSetSecurityPolicyRequest(_messages.Message):
  r"""A ComputeTargetPoolsSetSecurityPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    securityPolicyReference: A SecurityPolicyReference resource to be passed
      as the request body.
    targetPool: Name of the TargetPool resource to which the security policy
      should be set. The name should conform to RFC1035.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  securityPolicyReference = _messages.MessageField('SecurityPolicyReference', 4)
  targetPool = _messages.StringField(5, required=True)


class ComputeTargetPoolsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetPoolsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeTargetSslProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetSslProxy: Name of the TargetSslProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxy = _messages.StringField(3, required=True)


class ComputeTargetSslProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetSslProxy: Name of the TargetSslProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetSslProxy = _messages.StringField(2, required=True)


class ComputeTargetSslProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetSslProxy: A TargetSslProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxy = _messages.MessageField('TargetSslProxy', 3)


class ComputeTargetSslProxiesListRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetSslProxiesSetBackendServiceRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetBackendServiceRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetSslProxiesSetBackendServiceRequest: A
      TargetSslProxiesSetBackendServiceRequest resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose BackendService
      resource is to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxiesSetBackendServiceRequest = _messages.MessageField('TargetSslProxiesSetBackendServiceRequest', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesSetCertificateMapRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetCertificateMapRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetSslProxiesSetCertificateMapRequest: A
      TargetSslProxiesSetCertificateMapRequest resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose CertificateMap
      is to be set. The name must be 1-63 characters long, and comply with
      RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxiesSetCertificateMapRequest = _messages.MessageField('TargetSslProxiesSetCertificateMapRequest', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesSetProxyHeaderRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetProxyHeaderRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetSslProxiesSetProxyHeaderRequest: A
      TargetSslProxiesSetProxyHeaderRequest resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose ProxyHeader is
      to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxiesSetProxyHeaderRequest = _messages.MessageField('TargetSslProxiesSetProxyHeaderRequest', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetSslCertificatesRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetSslProxiesSetSslCertificatesRequest: A
      TargetSslProxiesSetSslCertificatesRequest resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose SslCertificate
      resource is to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxiesSetSslCertificatesRequest = _messages.MessageField('TargetSslProxiesSetSslCertificatesRequest', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesSetSslPolicyRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetSslPolicyRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    sslPolicyReference: A SslPolicyReference resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose SSL policy is to
      be set. The name must be 1-63 characters long, and comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicyReference = _messages.MessageField('SslPolicyReference', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetTcpProxiesAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeTargetTcpProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetTcpProxy: Name of the TargetTcpProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetTcpProxy = _messages.StringField(3, required=True)


class ComputeTargetTcpProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetTcpProxy: Name of the TargetTcpProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetTcpProxy = _messages.StringField(2, required=True)


class ComputeTargetTcpProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetTcpProxy: A TargetTcpProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetTcpProxy = _messages.MessageField('TargetTcpProxy', 3)


class ComputeTargetTcpProxiesListRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetTcpProxiesSetBackendServiceRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesSetBackendServiceRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetTcpProxiesSetBackendServiceRequest: A
      TargetTcpProxiesSetBackendServiceRequest resource to be passed as the
      request body.
    targetTcpProxy: Name of the TargetTcpProxy resource whose BackendService
      resource is to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetTcpProxiesSetBackendServiceRequest = _messages.MessageField('TargetTcpProxiesSetBackendServiceRequest', 3)
  targetTcpProxy = _messages.StringField(4, required=True)


class ComputeTargetTcpProxiesSetProxyHeaderRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesSetProxyHeaderRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetTcpProxiesSetProxyHeaderRequest: A
      TargetTcpProxiesSetProxyHeaderRequest resource to be passed as the
      request body.
    targetTcpProxy: Name of the TargetTcpProxy resource whose ProxyHeader is
      to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetTcpProxiesSetProxyHeaderRequest = _messages.MessageField('TargetTcpProxiesSetProxyHeaderRequest', 3)
  targetTcpProxy = _messages.StringField(4, required=True)


class ComputeTargetTcpProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetVpnGatewaysAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeTargetVpnGatewaysDeleteRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetVpnGateway: Name of the target VPN gateway to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetVpnGateway = _messages.StringField(4, required=True)


class ComputeTargetVpnGatewaysGetRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    targetVpnGateway: Name of the target VPN gateway to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetVpnGateway = _messages.StringField(3, required=True)


class ComputeTargetVpnGatewaysInsertRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    targetVpnGateway: A TargetVpnGateway resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetVpnGateway = _messages.MessageField('TargetVpnGateway', 4)


class ComputeTargetVpnGatewaysListRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetVpnGatewaysSetLabelsRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeTargetVpnGatewaysTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeUrlMapsAggregatedListRequest(_messages.Message):
  r"""A ComputeUrlMapsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeUrlMapsDeleteRequest(_messages.Message):
  r"""A ComputeUrlMapsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    urlMap: Name of the UrlMap resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  urlMap = _messages.StringField(3, required=True)


class ComputeUrlMapsGetRequest(_messages.Message):
  r"""A ComputeUrlMapsGetRequest object.

  Fields:
    project: Project ID for this request.
    urlMap: Name of the UrlMap resource to return.
  """

  project = _messages.StringField(1, required=True)
  urlMap = _messages.StringField(2, required=True)


class ComputeUrlMapsInsertRequest(_messages.Message):
  r"""A ComputeUrlMapsInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    urlMap: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  urlMap = _messages.MessageField('UrlMap', 3)


class ComputeUrlMapsInvalidateCacheRequest(_messages.Message):
  r"""A ComputeUrlMapsInvalidateCacheRequest object.

  Fields:
    cacheInvalidationRule: A CacheInvalidationRule resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    urlMap: Name of the UrlMap scoping this request.
  """

  cacheInvalidationRule = _messages.MessageField('CacheInvalidationRule', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.StringField(4, required=True)


class ComputeUrlMapsListRequest(_messages.Message):
  r"""A ComputeUrlMapsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeUrlMapsPatchRequest(_messages.Message):
  r"""A ComputeUrlMapsPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    urlMap: Name of the UrlMap resource to patch.
    urlMapResource: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  urlMap = _messages.StringField(3, required=True)
  urlMapResource = _messages.MessageField('UrlMap', 4)


class ComputeUrlMapsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeUrlMapsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeUrlMapsUpdateRequest(_messages.Message):
  r"""A ComputeUrlMapsUpdateRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    urlMap: Name of the UrlMap resource to update.
    urlMapResource: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  urlMap = _messages.StringField(3, required=True)
  urlMapResource = _messages.MessageField('UrlMap', 4)


class ComputeUrlMapsValidateRequest(_messages.Message):
  r"""A ComputeUrlMapsValidateRequest object.

  Fields:
    project: Project ID for this request.
    urlMap: Name of the UrlMap resource to be validated as.
    urlMapsValidateRequest: A UrlMapsValidateRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  urlMap = _messages.StringField(2, required=True)
  urlMapsValidateRequest = _messages.MessageField('UrlMapsValidateRequest', 3)


class ComputeVpnGatewaysAggregatedListRequest(_messages.Message):
  r"""A ComputeVpnGatewaysAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeVpnGatewaysDeleteRequest(_messages.Message):
  r"""A ComputeVpnGatewaysDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    vpnGateway: Name of the VPN gateway to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  vpnGateway = _messages.StringField(4, required=True)


class ComputeVpnGatewaysGetRequest(_messages.Message):
  r"""A ComputeVpnGatewaysGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    vpnGateway: Name of the VPN gateway to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  vpnGateway = _messages.StringField(3, required=True)


class ComputeVpnGatewaysGetStatusRequest(_messages.Message):
  r"""A ComputeVpnGatewaysGetStatusRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    vpnGateway: Name of the VPN gateway to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  vpnGateway = _messages.StringField(3, required=True)


class ComputeVpnGatewaysInsertRequest(_messages.Message):
  r"""A ComputeVpnGatewaysInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    vpnGateway: A VpnGateway resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  vpnGateway = _messages.MessageField('VpnGateway', 4)


class ComputeVpnGatewaysListRequest(_messages.Message):
  r"""A ComputeVpnGatewaysListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeVpnGatewaysSetLabelsRequest(_messages.Message):
  r"""A ComputeVpnGatewaysSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeVpnGatewaysTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeVpnGatewaysTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeVpnTunnelsAggregatedListRequest(_messages.Message):
  r"""A ComputeVpnTunnelsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeVpnTunnelsDeleteRequest(_messages.Message):
  r"""A ComputeVpnTunnelsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    vpnTunnel: Name of the VpnTunnel resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  vpnTunnel = _messages.StringField(4, required=True)


class ComputeVpnTunnelsGetRequest(_messages.Message):
  r"""A ComputeVpnTunnelsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    vpnTunnel: Name of the VpnTunnel resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  vpnTunnel = _messages.StringField(3, required=True)


class ComputeVpnTunnelsInsertRequest(_messages.Message):
  r"""A ComputeVpnTunnelsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    vpnTunnel: A VpnTunnel resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  vpnTunnel = _messages.MessageField('VpnTunnel', 4)


class ComputeVpnTunnelsListRequest(_messages.Message):
  r"""A ComputeVpnTunnelsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeVpnTunnelsSetLabelsRequest(_messages.Message):
  r"""A ComputeVpnTunnelsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeVpnTunnelsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeVpnTunnelsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeWireGroupsDeleteRequest(_messages.Message):
  r"""A ComputeWireGroupsDeleteRequest object.

  Fields:
    crossSiteNetwork: A string attribute.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
    wireGroup: Name of the wire group resource to delete.
  """

  crossSiteNetwork = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  wireGroup = _messages.StringField(4, required=True)


class ComputeWireGroupsGetRequest(_messages.Message):
  r"""A ComputeWireGroupsGetRequest object.

  Fields:
    crossSiteNetwork: A string attribute.
    project: Project ID for this request.
    wireGroup: Name of the wire group resource to return.
  """

  crossSiteNetwork = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  wireGroup = _messages.StringField(3, required=True)


class ComputeWireGroupsInsertRequest(_messages.Message):
  r"""A ComputeWireGroupsInsertRequest object.

  Fields:
    crossSiteNetwork: A string attribute.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
    validateOnly: [Input Only] Validate the new configuration, but don't
      create it.
    wireGroup: A WireGroup resource to be passed as the request body.
  """

  crossSiteNetwork = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  validateOnly = _messages.BooleanField(4)
  wireGroup = _messages.MessageField('WireGroup', 5)


class ComputeWireGroupsListRequest(_messages.Message):
  r"""A ComputeWireGroupsListRequest object.

  Fields:
    crossSiteNetwork: A string attribute.
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  crossSiteNetwork = _messages.StringField(1, required=True)
  filter = _messages.StringField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeWireGroupsPatchRequest(_messages.Message):
  r"""A ComputeWireGroupsPatchRequest object.

  Fields:
    crossSiteNetwork: A string attribute.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000). end_interface:
      MixerMutationRequestBuilder
    updateMask: update_mask indicates fields to be updated as part of this
      request.
    validateOnly: [Input Only] Validate the new configuration, but don't
      update it.
    wireGroup: Name of the WireGroups resource to patch.
    wireGroupResource: A WireGroup resource to be passed as the request body.
  """

  crossSiteNetwork = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  updateMask = _messages.StringField(4)
  validateOnly = _messages.BooleanField(5)
  wireGroup = _messages.StringField(6, required=True)
  wireGroupResource = _messages.MessageField('WireGroup', 7)


class ComputeZoneOperationsDeleteRequest(_messages.Message):
  r"""A ComputeZoneOperationsDeleteRequest object.

  Fields:
    operation: Name of the Operations resource to delete, or its unique
      numeric identifier.
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeZoneOperationsDeleteResponse(_messages.Message):
  r"""An empty ComputeZoneOperationsDelete response."""


class ComputeZoneOperationsGetRequest(_messages.Message):
  r"""A ComputeZoneOperationsGetRequest object.

  Fields:
    operation: Name of the Operations resource to return, or its unique
      numeric identifier.
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeZoneOperationsListRequest(_messages.Message):
  r"""A ComputeZoneOperationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: Name of the zone for request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeZoneOperationsWaitRequest(_messages.Message):
  r"""A ComputeZoneOperationsWaitRequest object.

  Fields:
    operation: Name of the Operations resource to return, or its unique
      numeric identifier.
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeZoneQueuedResourcesAggregatedListRequest(_messages.Message):
  r"""A ComputeZoneQueuedResourcesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    serviceProjectNumber: The Shared VPC service project id or service project
      number for which aggregated list request is invoked for subnetworks
      list-usable api.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  serviceProjectNumber = _messages.IntegerField(8)


class ComputeZoneQueuedResourcesCancelRequest(_messages.Message):
  r"""A ComputeZoneQueuedResourcesCancelRequest object.

  Fields:
    project: Project ID for this request.
    queuedResource: Name of the QueuedResource to cancel.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  queuedResource = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeZoneQueuedResourcesDeleteRequest(_messages.Message):
  r"""A ComputeZoneQueuedResourcesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    queuedResource: Name of the QueuedResource to delete.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  queuedResource = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeZoneQueuedResourcesGetRequest(_messages.Message):
  r"""A ComputeZoneQueuedResourcesGetRequest object.

  Fields:
    project: Project ID for this request.
    queuedResource: Name of the QueuedResource resource to return.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  queuedResource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeZoneQueuedResourcesInsertRequest(_messages.Message):
  r"""A ComputeZoneQueuedResourcesInsertRequest object.

  Fields:
    project: Project ID for this request.
    queuedResource: A QueuedResource resource to be passed as the request
      body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed. For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments. The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      ( 00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  queuedResource = _messages.MessageField('QueuedResource', 2)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeZoneQueuedResourcesListRequest(_messages.Message):
  r"""A ComputeZoneQueuedResourcesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
    zone: Name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeZonesGetRequest(_messages.Message):
  r"""A ComputeZonesGetRequest object.

  Fields:
    project: Project ID for this request.
    zone: Name of the zone resource to return.
  """

  project = _messages.StringField(1, required=True)
  zone = _messages.StringField(2, required=True)


class ComputeZonesListRequest(_messages.Message):
  r"""A ComputeZonesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      Most Compute resources support two types of filter expressions:
      expressions that support regular expressions and expressions that follow
      API improvement proposal AIP-160. These two types of filter expressions
      cannot be mixed in one request. If you want to use AIP-160, your
      expression must specify the field name, an operator, and the value that
      you want to use for filtering. The value must be a string, a number, or
      a boolean. The operator must be either `=`, `!=`, `>`, `<`, `<=`, `>=`
      or `:`. For example, if you are filtering Compute Engine instances, you
      can exclude instances named `example-instance` by specifying `name !=
      example-instance`. The `:*` comparison can be used to test whether a key
      has been defined. For example, to find all objects with `owner` label
      use: ``` labels.owner:* ``` You can also filter nested fields. For
      example, you could specify `scheduling.automaticRestart = false` to
      include instances only if they are not scheduled for automatic restarts.
      You can use filtering on nested fields to filter based on resource
      labels. To filter on multiple expressions, provide each separate
      expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ``` If you want to use a regular
      expression, use the `eq` (equal) or `ne` (not equal) operator against a
      single un-parenthesized expression with or without quotes or against
      multiple parenthesized expressions. Examples: `fieldname eq unquoted
      literal` `fieldname eq 'single quoted literal'` `fieldname eq "double
      quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The
      literal value is interpreted as a regular expression using Google RE2
      library syntax. The literal value must match the entire field. For
      example, to filter for instances that do not end with name "instance",
      you would use `name ne .*instance`. You cannot combine constraints on
      multiple fields using regular expressions.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name. You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first. Currently, only sorting by `name` or
      `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false. For
      example, when partial success behavior is enabled, aggregatedList for a
      single zone scope either returns all resources in the zone or no
      resources, with an error code.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ConfidentialInstanceConfig(_messages.Message):
  r"""A set of Confidential Instance options.

  Enums:
    ConfidentialInstanceTypeValueValuesEnum: Defines the type of technology
      used by the confidential instance.

  Fields:
    confidentialInstanceType: Defines the type of technology used by the
      confidential instance.
    confidentialParavisorConfig: Defines a set of Confidential Paravisor
      (SVSM) options.
    enableConfidentialCompute: Defines whether the instance should have
      confidential compute enabled.
  """

  class ConfidentialInstanceTypeValueValuesEnum(_messages.Enum):
    r"""Defines the type of technology used by the confidential instance.

    Values:
      CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED: No type specified. Do not use
        this value.
      SEV: AMD Secure Encrypted Virtualization.
      SEV_SNP: AMD Secure Encrypted Virtualization - Secure Nested Paging.
      TDX: Intel Trust Domain eXtension.
    """
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0
    SEV = 1
    SEV_SNP = 2
    TDX = 3

  confidentialInstanceType = _messages.EnumField('ConfidentialInstanceTypeValueValuesEnum', 1)
  confidentialParavisorConfig = _messages.MessageField('ConfidentialParavisorConfig', 2)
  enableConfidentialCompute = _messages.BooleanField(3)


class ConfidentialParavisorConfig(_messages.Message):
  r"""A set of Confidential Paravisor (SVSM) options.

  Enums:
    ConfidentialTpmTypeValueValuesEnum:
    SevSnpIrqModeValueValuesEnum:

  Fields:
    confidentialTpmType: A ConfidentialTpmTypeValueValuesEnum attribute.
    sevSnpIrqMode: A SevSnpIrqModeValueValuesEnum attribute.
  """

  class ConfidentialTpmTypeValueValuesEnum(_messages.Enum):
    r"""ConfidentialTpmTypeValueValuesEnum enum type.

    Values:
      CONFIDENTIAL_TPM_TYPE_UNSPECIFIED: <no description>
      EPHEMERAL: <no description>
      NO_CC_TPM: <no description>
    """
    CONFIDENTIAL_TPM_TYPE_UNSPECIFIED = 0
    EPHEMERAL = 1
    NO_CC_TPM = 2

  class SevSnpIrqModeValueValuesEnum(_messages.Enum):
    r"""SevSnpIrqModeValueValuesEnum enum type.

    Values:
      RESTRICTED: <no description>
      SEV_SNP_IRQ_MODE_UNSPECIFIED: <no description>
      UNRESTRICTED: <no description>
    """
    RESTRICTED = 0
    SEV_SNP_IRQ_MODE_UNSPECIFIED = 1
    UNRESTRICTED = 2

  confidentialTpmType = _messages.EnumField('ConfidentialTpmTypeValueValuesEnum', 1)
  sevSnpIrqMode = _messages.EnumField('SevSnpIrqModeValueValuesEnum', 2)


class ConnectionDraining(_messages.Message):
  r"""Message containing connection draining configuration.

  Fields:
    drainingTimeoutSec: Configures a duration timeout for existing requests on
      a removed backend instance. For supported load balancers and protocols,
      as described in Enabling connection draining.
  """

  drainingTimeoutSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)


class ConsistentHashLoadBalancerSettings(_messages.Message):
  r"""This message defines settings for a consistent hash style load balancer.

  Fields:
    httpCookie: Hash is based on HTTP Cookie. This field describes a HTTP
      cookie that will be used as the hash key for the consistent hash load
      balancer. If the cookie is not present, it will be generated. This field
      is applicable if the sessionAffinity is set to HTTP_COOKIE. Not
      supported when the backend service is referenced by a URL map that is
      bound to target gRPC proxy that has validateForProxyless field set to
      true.
    httpHeaderName: The hash based on the value of the specified header field.
      This field is applicable if the sessionAffinity is set to HEADER_FIELD.
    minimumRingSize: The minimum number of virtual nodes to use for the hash
      ring. Defaults to 1024. Larger ring sizes result in more granular load
      distributions. If the number of hosts in the load balancing pool is
      larger than the ring size, each host will be assigned a single virtual
      node.
  """

  httpCookie = _messages.MessageField('ConsistentHashLoadBalancerSettingsHttpCookie', 1)
  httpHeaderName = _messages.StringField(2)
  minimumRingSize = _messages.IntegerField(3)


class ConsistentHashLoadBalancerSettingsHttpCookie(_messages.Message):
  r"""The information about the HTTP Cookie on which the hash function is
  based for load balancing policies that use a consistent hash.

  Fields:
    name: Name of the cookie.
    path: Path to set for the cookie.
    ttl: Lifetime of the cookie.
  """

  name = _messages.StringField(1)
  path = _messages.StringField(2)
  ttl = _messages.MessageField('Duration', 3)


class CorsPolicy(_messages.Message):
  r"""The specification for allowing client-side cross-origin requests. For
  more information about the W3C recommendation for cross-origin resource
  sharing (CORS), see Fetch API Living Standard.

  Fields:
    allowCredentials: In response to a preflight request, setting this to true
      indicates that the actual request can include user credentials. This
      field translates to the Access-Control-Allow-Credentials header. Default
      is false.
    allowHeaders: Specifies the content for the Access-Control-Allow-Headers
      header.
    allowMethods: Specifies the content for the Access-Control-Allow-Methods
      header.
    allowOriginRegexes: Specifies a regular expression that matches allowed
      origins. For more information, see regular expression syntax . An origin
      is allowed if it matches either an item in allowOrigins or an item in
      allowOriginRegexes. Regular expressions can only be used when the
      loadBalancingScheme is set to INTERNAL_SELF_MANAGED.
    allowOrigins: Specifies the list of origins that is allowed to do CORS
      requests. An origin is allowed if it matches either an item in
      allowOrigins or an item in allowOriginRegexes.
    disabled: If true, disables the CORS policy. The default value is false,
      which indicates that the CORS policy is in effect.
    exposeHeaders: Specifies the content for the Access-Control-Expose-Headers
      header.
    maxAge: Specifies how long results of a preflight request can be cached in
      seconds. This field translates to the Access-Control-Max-Age header.
  """

  allowCredentials = _messages.BooleanField(1)
  allowHeaders = _messages.StringField(2, repeated=True)
  allowMethods = _messages.StringField(3, repeated=True)
  allowOriginRegexes = _messages.StringField(4, repeated=True)
  allowOrigins = _messages.StringField(5, repeated=True)
  disabled = _messages.BooleanField(6)
  exposeHeaders = _messages.StringField(7, repeated=True)
  maxAge = _messages.IntegerField(8, variant=_messages.Variant.INT32)


class CrossSiteNetwork(_messages.Message):
  r"""A resource that represents a cross-site network. You can use cross-site
  networks to connect your on-premises networks to each other through
  Interconnect connections.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of the cross-site network.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always compute#crossSiteNetwork
      for cross-site networks.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default='compute#crossSiteNetwork')
  name = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  selfLinkWithId = _messages.StringField(7)


class CrossSiteNetworkList(_messages.Message):
  r"""Response to the list request that contains a list of cross-site
  networks.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of CrossSiteNetwork resources.
    kind: [Output Only] Type of the resource. Always compute#crossSiteNetwork
      for cross-site networks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('CrossSiteNetwork', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#crossSiteNetwork')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class CustomErrorResponsePolicy(_messages.Message):
  r"""Specifies the custom error response policy that must be applied when the
  backend service or backend bucket responds with an error.

  Fields:
    errorResponseRules: Specifies rules for returning error responses. In a
      given policy, if you specify rules for both a range of error codes as
      well as rules for specific error codes then rules with specific error
      codes have a higher priority. For example, assume that you configure a
      rule for 401 (Un-authorized) code, and another for all 4 series error
      codes (4XX). If the backend service returns a 401, then the rule for 401
      will be applied. However if the backend service returns a 403, the rule
      for 4xx takes effect.
    errorService: The full or partial URL to the BackendBucket resource that
      contains the custom error content. Examples are: - https://www.googleapi
      s.com/compute/v1/projects/project/global/backendBuckets/myBackendBucket
      - compute/v1/projects/project/global/backendBuckets/myBackendBucket -
      global/backendBuckets/myBackendBucket If errorService is not specified
      at lower levels like pathMatcher, pathRule and routeRule, an
      errorService specified at a higher level in the UrlMap will be used. If
      UrlMap.defaultCustomErrorResponsePolicy contains one or more
      errorResponseRules[], it must specify errorService. If load balancer
      cannot reach the backendBucket, a simple Not Found Error will be
      returned, with the original response code (or overrideResponseCode if
      configured). errorService is not supported for internal or regional
      HTTP/HTTPS load balancers.
  """

  errorResponseRules = _messages.MessageField('CustomErrorResponsePolicyCustomErrorResponseRule', 1, repeated=True)
  errorService = _messages.StringField(2)


class CustomErrorResponsePolicyCustomErrorResponseRule(_messages.Message):
  r"""Specifies the mapping between the response code that will be returned
  along with the custom error content and the response code returned by the
  backend service.

  Fields:
    matchResponseCodes: Valid values include: - A number between 400 and 599:
      For example 401 or 503, in which case the load balancer applies the
      policy if the error code exactly matches this value. - 5xx: Load
      Balancer will apply the policy if the backend service responds with any
      response code in the range of 500 to 599. - 4xx: Load Balancer will
      apply the policy if the backend service responds with any response code
      in the range of 400 to 499. Values must be unique within
      matchResponseCodes and across all errorResponseRules of
      CustomErrorResponsePolicy.
    overrideResponseCode: The HTTP status code returned with the response
      containing the custom error content. If overrideResponseCode is not
      supplied, the same response code returned by the original backend bucket
      or backend service is returned to the client.
    path: The full path to a file within backendBucket . For example:
      /errors/defaultError.html path must start with a leading slash. path
      cannot have trailing slashes. If the file is not available in
      backendBucket or the load balancer cannot reach the BackendBucket, a
      simple Not Found Error is returned to the client. The value must be from
      1 to 1024 characters
  """

  matchResponseCodes = _messages.StringField(1, repeated=True)
  overrideResponseCode = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  path = _messages.StringField(3)


class CustomerEncryptionKey(_messages.Message):
  r"""A CustomerEncryptionKey object.

  Fields:
    kmsKeyName: The name of the encryption key that is stored in Google Cloud
      KMS. For example: "kmsKeyName":
      "projects/kms_project_id/locations/region/keyRings/
      key_region/cryptoKeys/key The fully-qualifed key name may be returned
      for resource GET requests. For example: "kmsKeyName":
      "projects/kms_project_id/locations/region/keyRings/
      key_region/cryptoKeys/key /cryptoKeyVersions/1
    kmsKeyServiceAccount: The service account being used for the encryption
      request for the given KMS key. If absent, the Compute Engine default
      service account is used. For example: "kmsKeyServiceAccount":
      "name@project_id.iam.gserviceaccount.com/
    rawKey: Specifies a 256-bit customer-supplied encryption key, encoded in
      RFC 4648 base64 to either encrypt or decrypt this resource. You can
      provide either the rawKey or the rsaEncryptedKey. For example: "rawKey":
      "SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0="
    rsaEncryptedKey: Specifies an RFC 4648 base64 encoded, RSA-wrapped
      2048-bit customer-supplied encryption key to either encrypt or decrypt
      this resource. You can provide either the rawKey or the rsaEncryptedKey.
      For example: "rsaEncryptedKey":
      "ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH
      z0mBibXUInrC/jEk014kCK/NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFo
      D
      D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEMMoNUXMCZEIpg9Vtp9x2oe=="
      The key must meet the following requirements before you can provide it
      to Compute Engine: 1. The key is wrapped using a RSA public key
      certificate provided by Google. 2. After being wrapped, the key must be
      encoded in RFC 4648 base64 encoding. Gets the RSA public key certificate
      provided by Google at: https://cloud-
      certs.storage.googleapis.com/google-cloud-csek-ingress.pem
    sha256: [Output only] The RFC 4648 base64 encoded SHA-256 hash of the
      customer-supplied encryption key that protects this resource.
  """

  kmsKeyName = _messages.StringField(1)
  kmsKeyServiceAccount = _messages.StringField(2)
  rawKey = _messages.StringField(3)
  rsaEncryptedKey = _messages.StringField(4)
  sha256 = _messages.StringField(5)


class CustomerEncryptionKeyProtectedDisk(_messages.Message):
  r"""A CustomerEncryptionKeyProtectedDisk object.

  Fields:
    diskEncryptionKey: Decrypts data associated with the disk with a customer-
      supplied encryption key.
    source: Specifies a valid partial or full URL to an existing Persistent
      Disk resource. This field is only applicable for persistent disks. For
      example: "source": "/compute/v1/projects/project_id/zones/zone/disks/
      disk_name
  """

  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 1)
  source = _messages.StringField(2)


class DeprecationStatus(_messages.Message):
  r"""Deprecation status for a public resource.

  Enums:
    StateValueValuesEnum: The deprecation state of this resource. This can be
      ACTIVE, DEPRECATED, OBSOLETE, or DELETED. Operations which communicate
      the end of life date for an image, can use ACTIVE. Operations which
      create a new resource using a DEPRECATED resource will return
      successfully, but with a warning indicating the deprecated resource and
      recommending its replacement. Operations which use OBSOLETE or DELETED
      resources will be rejected and result in an error.

  Fields:
    deleted: An optional RFC3339 timestamp on or after which the state of this
      resource is intended to change to DELETED. This is only informational
      and the status will not change unless the client explicitly changes it.
    deprecated: An optional RFC3339 timestamp on or after which the state of
      this resource is intended to change to DEPRECATED. This is only
      informational and the status will not change unless the client
      explicitly changes it.
    obsolete: An optional RFC3339 timestamp on or after which the state of
      this resource is intended to change to OBSOLETE. This is only
      informational and the status will not change unless the client
      explicitly changes it.
    replacement: The URL of the suggested replacement for a deprecated
      resource. The suggested replacement resource must be the same kind of
      resource as the deprecated resource.
    state: The deprecation state of this resource. This can be ACTIVE,
      DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end
      of life date for an image, can use ACTIVE. Operations which create a new
      resource using a DEPRECATED resource will return successfully, but with
      a warning indicating the deprecated resource and recommending its
      replacement. Operations which use OBSOLETE or DELETED resources will be
      rejected and result in an error.
    stateOverride: The rollout policy for this deprecation. This policy is
      only enforced by image family views. The rollout policy restricts the
      zones where the associated resource is considered in a deprecated state.
      When the rollout policy does not include the user specified zone, or if
      the zone is rolled out, the associated resource is considered in a
      deprecated state. The rollout policy for this deprecation is read-only,
      except for allowlisted users. This field might not be configured. To
      view the latest non-deprecated image in a specific zone, use the
      imageFamilyViews.get method.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""The deprecation state of this resource. This can be ACTIVE,
    DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of
    life date for an image, can use ACTIVE. Operations which create a new
    resource using a DEPRECATED resource will return successfully, but with a
    warning indicating the deprecated resource and recommending its
    replacement. Operations which use OBSOLETE or DELETED resources will be
    rejected and result in an error.

    Values:
      ACTIVE: <no description>
      DELETED: <no description>
      DEPRECATED: <no description>
      OBSOLETE: <no description>
    """
    ACTIVE = 0
    DELETED = 1
    DEPRECATED = 2
    OBSOLETE = 3

  deleted = _messages.StringField(1)
  deprecated = _messages.StringField(2)
  obsolete = _messages.StringField(3)
  replacement = _messages.StringField(4)
  state = _messages.EnumField('StateValueValuesEnum', 5)
  stateOverride = _messages.MessageField('RolloutPolicy', 6)


class Disk(_messages.Message):
  r"""Represents a Persistent Disk resource. Google Compute Engine has two
  Disk resources: * [Zonal](/compute/docs/reference/rest/alpha/disks) *
  [Regional](/compute/docs/reference/rest/alpha/regionDisks) Persistent disks
  are required for running your VM instances. Create both boot and non-boot
  (data) persistent disks. For more information, read Persistent Disks. For
  more storage options, read Storage options. The disks resource represents a
  zonal persistent disk. For more information, read Zonal persistent disks.
  The regionDisks resource represents a regional persistent disk. For more
  information, read Regional resources.

  Enums:
    AccessModeValueValuesEnum: The access mode of the disk. -
      READ_WRITE_SINGLE: The default AccessMode, means the disk can be
      attached to single instance in RW mode. - READ_WRITE_MANY: The
      AccessMode means the disk can be attached to multiple instances in RW
      mode. - READ_ONLY_MANY: The AccessMode means the disk can be attached to
      multiple instances in RO mode. The AccessMode is only valid for
      Hyperdisk disk types.
    ArchitectureValueValuesEnum: The architecture of the disk. Valid values
      are ARM64 or X86_64.
    InterfaceValueValuesEnum: [Deprecated] Specifies the disk interface to use
      for attaching this disk, which is either SCSI or NVME. The default is
      SCSI.
    StatusValueValuesEnum: [Output Only] The status of disk creation. -
      CREATING: Disk is provisioning. - RESTORING: Source data is being copied
      into the disk. - FAILED: Disk creation failed. - READY: Disk is ready
      for use. - DELETING: Disk is deleting.
    StorageTypeValueValuesEnum: [Deprecated] Storage type of the persistent
      disk.

  Messages:
    AsyncSecondaryDisksValue: [Output Only] A list of disks this disk is
      asynchronously replicated to.
    LabelsValue: Labels to apply to this disk. These can be later modified by
      the setLabels method.

  Fields:
    accessMode: The access mode of the disk. - READ_WRITE_SINGLE: The default
      AccessMode, means the disk can be attached to single instance in RW
      mode. - READ_WRITE_MANY: The AccessMode means the disk can be attached
      to multiple instances in RW mode. - READ_ONLY_MANY: The AccessMode means
      the disk can be attached to multiple instances in RO mode. The
      AccessMode is only valid for Hyperdisk disk types.
    architecture: The architecture of the disk. Valid values are ARM64 or
      X86_64.
    asyncPrimaryDisk: Disk asynchronously replicated into this disk.
    asyncSecondaryDisks: [Output Only] A list of disks this disk is
      asynchronously replicated to.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    diskEncryptionKey: Encrypts the disk using a customer-supplied encryption
      key or a customer-managed encryption key. Encryption keys do not protect
      access to metadata of the disk. After you encrypt a disk with a
      customer-supplied key, you must provide the same key if you use the disk
      later. For example, to create a disk snapshot, to create a disk image,
      to create a machine image, or to attach the disk to a virtual machine.
      After you encrypt a disk with a customer-managed key, the
      diskEncryptionKey.kmsKeyName is set to a key *version* name once the
      disk is created. The disk is encrypted with this version of the key. In
      the response, diskEncryptionKey.kmsKeyName appears in the following
      format: "diskEncryptionKey.kmsKeyName":
      "projects/kms_project_id/locations/region/keyRings/
      key_region/cryptoKeys/key /cryptoKeysVersions/version If you do not
      provide an encryption key when creating the disk, then the disk is
      encrypted using an automatically generated key and you don't need to
      provide a key to use the disk later.
    enableConfidentialCompute: Whether this disk is using confidential compute
      mode.
    eraseWindowsVssSignature: Specifies whether the disk restored from a
      source snapshot should erase Windows specific VSS signature.
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read Enabling guest
      operating system features to see a list of available options.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interface: [Deprecated] Specifies the disk interface to use for attaching
      this disk, which is either SCSI or NVME. The default is SCSI.
    kind: [Output Only] Type of the resource. Always compute#disk for disks.
    labelFingerprint: A fingerprint for the labels being applied to this disk,
      which is essentially a hash of the labels set used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update labels. You must always
      provide an up-to-date fingerprint hash in order to update or change
      labels, otherwise the request will fail with error 412 conditionNotMet.
      To see the latest fingerprint, make a get() request to retrieve a disk.
    labels: Labels to apply to this disk. These can be later modified by the
      setLabels method.
    lastAttachTimestamp: [Output Only] Last attach timestamp in RFC3339 text
      format.
    lastDetachTimestamp: [Output Only] Last detach timestamp in RFC3339 text
      format.
    licenseCodes: Integer license codes indicating which licenses are attached
      to this disk.
    licenses: A list of publicly visible licenses. Reserved for Google's use.
    locationHint: An opaque location hint used to place the disk close to
      other resources. This field is for use by internal tools that use the
      public API.
    locked: [Output Only] The field indicates if the disk is created from a
      locked source image. Attachment of a disk created from a locked source
      image will cause the following operations to become irreversibly
      prohibited: - R/W or R/O disk attachment to any other instance - Disk
      detachment. And the disk can only be deleted when the instance is
      deleted - Creation of images or snapshots - Disk cloning Furthermore,
      the instance with at least one disk with locked flag set to true will be
      prohibited from performing the operations below: - Further attachment of
      secondary disks. - Detachment of any disks - Create machine images -
      Create instance template - Delete the instance with --keep-disk
      parameter set to true for locked disks - Attach a locked disk with
      --auto-delete parameter set to false
    multiWriter: Indicates whether or not the disk can be read/write attached
      to more than one instance.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    options: Internal use only.
    params: Input only. [Input Only] Additional params passed with the
      request, but not persisted as part of resource payload.
    physicalBlockSizeBytes: Physical block size of the persistent disk, in
      bytes. If not present in a request, a default value is used. The
      currently supported size is 4096, other sizes may be added in the
      future. If an unsupported value is requested, the error message will
      list the supported values for the caller's project.
    provisionedIops: Indicates how many IOPS to provision for the disk. This
      sets the number of I/O operations per second that the disk can handle.
      Values must be between 10,000 and 120,000. For more details, see the
      Extreme persistent disk documentation.
    provisionedThroughput: Indicates how much throughput to provision for the
      disk. This sets the number of throughput mb per second that the disk can
      handle. Values must be greater than or equal to 1.
    region: [Output Only] URL of the region where the disk resides. Only
      applicable for regional resources. You must specify this field as part
      of the HTTP request URL. It is not settable as a field in the request
      body.
    replicaZones: URLs of the zones where the disk should be replicated to.
      Only applicable for regional resources.
    resourcePolicies: Resource policies applied to this disk for automatic
      snapshot creations.
    resourceStatus: [Output Only] Status information for the disk resource.
    satisfiesPzi: Output only. Reserved for future use.
    satisfiesPzs: [Output Only] Reserved for future use.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    sizeGb: Size, in GB, of the persistent disk. You can specify this field
      when creating a persistent disk using the sourceImage, sourceSnapshot,
      or sourceDisk parameter, or specify it alone to create an empty
      persistent disk. If you specify this field along with a source, the
      value of sizeGb must not be less than the size of the source. Acceptable
      values are greater than 0.
    sourceConsistencyGroupPolicy: [Output Only] URL of the
      DiskConsistencyGroupPolicy for a secondary disk that was created using a
      consistency group.
    sourceConsistencyGroupPolicyId: [Output Only] ID of the
      DiskConsistencyGroupPolicy for a secondary disk that was created using a
      consistency group.
    sourceDisk: The source disk used to create this disk. You can provide this
      as a partial or full URL to the resource. For example, the following are
      valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /disks/disk -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /disks/disk - projects/project/zones/zone/disks/disk -
      projects/project/regions/region/disks/disk - zones/zone/disks/disk -
      regions/region/disks/disk
    sourceDiskId: [Output Only] The unique ID of the disk used to create this
      disk. This value identifies the exact disk that was used to create this
      persistent disk. For example, if you created the persistent disk from a
      disk that was later deleted and recreated under the same name, the
      source disk ID would identify the exact version of the disk that was
      used.
    sourceImage: The source image used to create this disk. If the source
      image is deleted, this field will not be set. To create a disk with one
      of the public operating system images, specify the image by its family
      name. For example, specify family/debian-9 to use the latest Debian 9
      image: projects/debian-cloud/global/images/family/debian-9
      Alternatively, use a specific version of a public operating system
      image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To
      create a disk with a custom image that you created, specify the image
      name in the following format: global/images/my-custom-image You can also
      specify a custom image by its image family, which returns the latest
      version of the image in that family. Replace the image name with
      family/family-name: global/images/family/my-image-family
    sourceImageEncryptionKey: The customer-supplied encryption key of the
      source image. Required if the source image is protected by a customer-
      supplied encryption key.
    sourceImageId: [Output Only] The ID value of the image used to create this
      disk. This value identifies the exact image that was used to create this
      persistent disk. For example, if you created the persistent disk from an
      image that was later deleted and recreated under the same name, the
      source image ID would identify the exact version of the image that was
      used.
    sourceInstantSnapshot: The source instant snapshot used to create this
      disk. You can provide this as a partial or full URL to the resource. For
      example, the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /instantSnapshots/instantSnapshot -
      projects/project/zones/zone/instantSnapshots/instantSnapshot -
      zones/zone/instantSnapshots/instantSnapshot
    sourceInstantSnapshotId: [Output Only] The unique ID of the instant
      snapshot used to create this disk. This value identifies the exact
      instant snapshot that was used to create this persistent disk. For
      example, if you created the persistent disk from an instant snapshot
      that was later deleted and recreated under the same name, the source
      instant snapshot ID would identify the exact version of the instant
      snapshot that was used.
    sourceSnapshot: The source snapshot used to create this disk. You can
      provide this as a partial or full URL to the resource. For example, the
      following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project
      /global/snapshots/snapshot - projects/project/global/snapshots/snapshot
      - global/snapshots/snapshot
    sourceSnapshotEncryptionKey: The customer-supplied encryption key of the
      source snapshot. Required if the source snapshot is protected by a
      customer-supplied encryption key.
    sourceSnapshotId: [Output Only] The unique ID of the snapshot used to
      create this disk. This value identifies the exact snapshot that was used
      to create this persistent disk. For example, if you created the
      persistent disk from a snapshot that was later deleted and recreated
      under the same name, the source snapshot ID would identify the exact
      version of the snapshot that was used.
    sourceStorageObject: The full Google Cloud Storage URI where the disk
      image is stored. This file must be a gzip-compressed tarball whose name
      ends in .tar.gz or virtual machine disk whose name ends in vmdk. Valid
      URIs may start with gs:// or https://storage.googleapis.com/. This flag
      is not optimized for creating multiple disks from a source storage
      object. To create many disks from a source storage object, use gcloud
      compute images import instead.
    status: [Output Only] The status of disk creation. - CREATING: Disk is
      provisioning. - RESTORING: Source data is being copied into the disk. -
      FAILED: Disk creation failed. - READY: Disk is ready for use. -
      DELETING: Disk is deleting.
    storagePool: The storage pool in which the new disk is created. You can
      provide this as a partial or full URL to the resource. For example, the
      following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /storagePools/storagePool -
      projects/project/zones/zone/storagePools/storagePool -
      zones/zone/storagePools/storagePool
    storageType: [Deprecated] Storage type of the persistent disk.
    type: URL of the disk type resource describing which disk type to use to
      create the disk. Provide this when creating the disk. For example:
      projects/project /zones/zone/diskTypes/pd-ssd . See Persistent disk
      types.
    userLicenses: A list of publicly visible user-licenses. Unlike regular
      licenses, user provided licenses can be modified after the disk is
      created. This includes a list of URLs to the license resource. For
      example, to provide a debian license:
      https://www.googleapis.com/compute/v1/projects/debian-
      cloud/global/licenses/debian-9-stretch
    users: [Output Only] Links to the users of the disk (attached instances)
      in form: projects/project/zones/zone/instances/instance
    zone: [Output Only] URL of the zone where the disk resides. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
  """

  class AccessModeValueValuesEnum(_messages.Enum):
    r"""The access mode of the disk. - READ_WRITE_SINGLE: The default
    AccessMode, means the disk can be attached to single instance in RW mode.
    - READ_WRITE_MANY: The AccessMode means the disk can be attached to
    multiple instances in RW mode. - READ_ONLY_MANY: The AccessMode means the
    disk can be attached to multiple instances in RO mode. The AccessMode is
    only valid for Hyperdisk disk types.

    Values:
      READ_ONLY_MANY: The AccessMode means the disk can be attached to
        multiple instances in RO mode.
      READ_WRITE_MANY: The AccessMode means the disk can be attached to
        multiple instances in RW mode.
      READ_WRITE_SINGLE: The default AccessMode, means the disk can be
        attached to single instance in RW mode.
    """
    READ_ONLY_MANY = 0
    READ_WRITE_MANY = 1
    READ_WRITE_SINGLE = 2

  class ArchitectureValueValuesEnum(_messages.Enum):
    r"""The architecture of the disk. Valid values are ARM64 or X86_64.

    Values:
      ARCHITECTURE_UNSPECIFIED: Default value indicating Architecture is not
        set.
      ARM64: Machines with architecture ARM64
      X86_64: Machines with architecture X86_64
    """
    ARCHITECTURE_UNSPECIFIED = 0
    ARM64 = 1
    X86_64 = 2

  class InterfaceValueValuesEnum(_messages.Enum):
    r"""[Deprecated] Specifies the disk interface to use for attaching this
    disk, which is either SCSI or NVME. The default is SCSI.

    Values:
      NVME: <no description>
      SCSI: <no description>
      UNSPECIFIED: <no description>
    """
    NVME = 0
    SCSI = 1
    UNSPECIFIED = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of disk creation. - CREATING: Disk is
    provisioning. - RESTORING: Source data is being copied into the disk. -
    FAILED: Disk creation failed. - READY: Disk is ready for use. - DELETING:
    Disk is deleting.

    Values:
      CREATING: Disk is provisioning
      DELETING: Disk is deleting.
      FAILED: Disk creation failed.
      READY: Disk is ready for use.
      RESTORING: Source data is being copied into the disk.
      UNAVAILABLE: Disk is currently unavailable and cannot be accessed,
        attached or detached.
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3
    RESTORING = 4
    UNAVAILABLE = 5

  class StorageTypeValueValuesEnum(_messages.Enum):
    r"""[Deprecated] Storage type of the persistent disk.

    Values:
      HDD: <no description>
      SSD: <no description>
    """
    HDD = 0
    SSD = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AsyncSecondaryDisksValue(_messages.Message):
    r"""[Output Only] A list of disks this disk is asynchronously replicated
    to.

    Messages:
      AdditionalProperty: An additional property for a
        AsyncSecondaryDisksValue object.

    Fields:
      additionalProperties: Additional properties of type
        AsyncSecondaryDisksValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AsyncSecondaryDisksValue object.

      Fields:
        key: Name of the additional property.
        value: A DiskAsyncReplicationList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('DiskAsyncReplicationList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this disk. These can be later modified by the
    setLabels method.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  accessMode = _messages.EnumField('AccessModeValueValuesEnum', 1)
  architecture = _messages.EnumField('ArchitectureValueValuesEnum', 2)
  asyncPrimaryDisk = _messages.MessageField('DiskAsyncReplication', 3)
  asyncSecondaryDisks = _messages.MessageField('AsyncSecondaryDisksValue', 4)
  creationTimestamp = _messages.StringField(5)
  description = _messages.StringField(6)
  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 7)
  enableConfidentialCompute = _messages.BooleanField(8)
  eraseWindowsVssSignature = _messages.BooleanField(9)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 10, repeated=True)
  id = _messages.IntegerField(11, variant=_messages.Variant.UINT64)
  interface = _messages.EnumField('InterfaceValueValuesEnum', 12)
  kind = _messages.StringField(13, default='compute#disk')
  labelFingerprint = _messages.BytesField(14)
  labels = _messages.MessageField('LabelsValue', 15)
  lastAttachTimestamp = _messages.StringField(16)
  lastDetachTimestamp = _messages.StringField(17)
  licenseCodes = _messages.IntegerField(18, repeated=True)
  licenses = _messages.StringField(19, repeated=True)
  locationHint = _messages.StringField(20)
  locked = _messages.BooleanField(21)
  multiWriter = _messages.BooleanField(22)
  name = _messages.StringField(23)
  options = _messages.StringField(24)
  params = _messages.MessageField('DiskParams', 25)
  physicalBlockSizeBytes = _messages.IntegerField(26)
  provisionedIops = _messages.IntegerField(27)
  provisionedThroughput = _messages.IntegerField(28)
  region = _messages.StringField(29)
  replicaZones = _messages.StringField(30, repeated=True)
  resourcePolicies = _messages.StringField(31, repeated=True)
  resourceStatus = _messages.MessageField('DiskResourceStatus', 32)
  satisfiesPzi = _messages.BooleanField(33)
  satisfiesPzs = _messages.BooleanField(34)
  selfLink = _messages.StringField(35)
  selfLinkWithId = _messages.StringField(36)
  sizeGb = _messages.IntegerField(37)
  sourceConsistencyGroupPolicy = _messages.StringField(38)
  sourceConsistencyGroupPolicyId = _messages.StringField(39)
  sourceDisk = _messages.StringField(40)
  sourceDiskId = _messages.StringField(41)
  sourceImage = _messages.StringField(42)
  sourceImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 43)
  sourceImageId = _messages.StringField(44)
  sourceInstantSnapshot = _messages.StringField(45)
  sourceInstantSnapshotId = _messages.StringField(46)
  sourceSnapshot = _messages.StringField(47)
  sourceSnapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 48)
  sourceSnapshotId = _messages.StringField(49)
  sourceStorageObject = _messages.StringField(50)
  status = _messages.EnumField('StatusValueValuesEnum', 51)
  storagePool = _messages.StringField(52)
  storageType = _messages.EnumField('StorageTypeValueValuesEnum', 53)
  type = _messages.StringField(54)
  userLicenses = _messages.StringField(55, repeated=True)
  users = _messages.StringField(56, repeated=True)
  zone = _messages.StringField(57)


class DiskAggregatedList(_messages.Message):
  r"""A DiskAggregatedList object.

  Messages:
    ItemsValue: A list of DisksScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of DisksScopedList resources.
    kind: [Output Only] Type of resource. Always compute#diskAggregatedList
      for aggregated lists of persistent disks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of DisksScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of disks.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A DisksScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('DisksScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#diskAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class DiskAsyncReplication(_messages.Message):
  r"""A DiskAsyncReplication object.

  Fields:
    consistencyGroupPolicy: [Output Only] URL of the
      DiskConsistencyGroupPolicy if replication was started on the disk as a
      member of a group.
    consistencyGroupPolicyId: [Output Only] ID of the
      DiskConsistencyGroupPolicy if replication was started on the disk as a
      member of a group.
    disk: The other disk asynchronously replicated to or from the current
      disk. You can provide this as a partial or full URL to the resource. For
      example, the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /disks/disk - projects/project/zones/zone/disks/disk -
      zones/zone/disks/disk
    diskId: [Output Only] The unique ID of the other disk asynchronously
      replicated to or from the current disk. This value identifies the exact
      disk that was used to create this replication. For example, if you
      started replicating the persistent disk from a disk that was later
      deleted and recreated under the same name, the disk ID would identify
      the exact version of the disk that was used.
  """

  consistencyGroupPolicy = _messages.StringField(1)
  consistencyGroupPolicyId = _messages.StringField(2)
  disk = _messages.StringField(3)
  diskId = _messages.StringField(4)


class DiskAsyncReplicationList(_messages.Message):
  r"""A DiskAsyncReplicationList object.

  Fields:
    asyncReplicationDisk: A DiskAsyncReplication attribute.
  """

  asyncReplicationDisk = _messages.MessageField('DiskAsyncReplication', 1)


class DiskInstantiationConfig(_messages.Message):
  r"""A specification of the desired way to instantiate a disk in the instance
  template when its created from a source instance.

  Enums:
    InstantiateFromValueValuesEnum: Specifies whether to include the disk and
      what image to use. Possible values are: - source-image: to use the same
      image that was used to create the source instance's corresponding disk.
      Applicable to the boot disk and additional read-write disks. - source-
      image-family: to use the same image family that was used to create the
      source instance's corresponding disk. Applicable to the boot disk and
      additional read-write disks. - custom-image: to use a user-provided
      image url for disk creation. Applicable to the boot disk and additional
      read-write disks. - attach-read-only: to attach a read-only disk.
      Applicable to read-only disks. - do-not-include: to exclude a disk from
      the template. Applicable to additional read-write disks, local SSDs, and
      read-only disks.

  Fields:
    autoDelete: Specifies whether the disk will be auto-deleted when the
      instance is deleted (but not when the disk is detached from the
      instance).
    customImage: The custom source image to be used to restore this disk when
      instantiating this instance template.
    deviceName: Specifies the device name of the disk to which the
      configurations apply to.
    instantiateFrom: Specifies whether to include the disk and what image to
      use. Possible values are: - source-image: to use the same image that was
      used to create the source instance's corresponding disk. Applicable to
      the boot disk and additional read-write disks. - source-image-family: to
      use the same image family that was used to create the source instance's
      corresponding disk. Applicable to the boot disk and additional read-
      write disks. - custom-image: to use a user-provided image url for disk
      creation. Applicable to the boot disk and additional read-write disks. -
      attach-read-only: to attach a read-only disk. Applicable to read-only
      disks. - do-not-include: to exclude a disk from the template. Applicable
      to additional read-write disks, local SSDs, and read-only disks.
  """

  class InstantiateFromValueValuesEnum(_messages.Enum):
    r"""Specifies whether to include the disk and what image to use. Possible
    values are: - source-image: to use the same image that was used to create
    the source instance's corresponding disk. Applicable to the boot disk and
    additional read-write disks. - source-image-family: to use the same image
    family that was used to create the source instance's corresponding disk.
    Applicable to the boot disk and additional read-write disks. - custom-
    image: to use a user-provided image url for disk creation. Applicable to
    the boot disk and additional read-write disks. - attach-read-only: to
    attach a read-only disk. Applicable to read-only disks. - do-not-include:
    to exclude a disk from the template. Applicable to additional read-write
    disks, local SSDs, and read-only disks.

    Values:
      ATTACH_READ_ONLY: Attach the existing disk in read-only mode. The
        request will fail if the disk was attached in read-write mode on the
        source instance. Applicable to: read-only disks.
      BLANK: Create a blank disk. The disk will be created unformatted.
        Applicable to: additional read-write disks, local SSDs.
      CUSTOM_IMAGE: Use the custom image specified in the custom_image field.
        Applicable to: boot disk, additional read-write disks.
      DEFAULT: Use the default instantiation option for the corresponding type
        of disk. For boot disk and any other R/W disks, new custom images will
        be created from each disk. For read-only disks, they will be attached
        in read-only mode. Local SSD disks will be created as blank volumes.
      DO_NOT_INCLUDE: Do not include the disk in the instance template.
        Applicable to: additional read-write disks, local SSDs, read-only
        disks.
      SOURCE_IMAGE: Use the same source image used for creation of the source
        instance's corresponding disk. The request will fail if the source
        VM's disk was created from a snapshot. Applicable to: boot disk,
        additional read-write disks.
      SOURCE_IMAGE_FAMILY: Use the same source image family used for creation
        of the source instance's corresponding disk. The request will fail if
        the source image of the source disk does not belong to any image
        family. Applicable to: boot disk, additional read-write disks.
    """
    ATTACH_READ_ONLY = 0
    BLANK = 1
    CUSTOM_IMAGE = 2
    DEFAULT = 3
    DO_NOT_INCLUDE = 4
    SOURCE_IMAGE = 5
    SOURCE_IMAGE_FAMILY = 6

  autoDelete = _messages.BooleanField(1)
  customImage = _messages.StringField(2)
  deviceName = _messages.StringField(3)
  instantiateFrom = _messages.EnumField('InstantiateFromValueValuesEnum', 4)


class DiskList(_messages.Message):
  r"""A list of Disk resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Disk resources.
    kind: [Output Only] Type of resource. Always compute#diskList for lists of
      disks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Disk', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#diskList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class DiskMoveRequest(_messages.Message):
  r"""A DiskMoveRequest object.

  Fields:
    destinationZone: The URL of the destination zone to move the disk. This
      can be a full or partial URL. For example, the following are all valid
      URLs to a zone: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone -
      projects/project/zones/zone - zones/zone
    targetDisk: The URL of the target disk to move. This can be a full or
      partial URL. For example, the following are all valid URLs to a disk: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /disks/disk - projects/project/zones/zone/disks/disk -
      zones/zone/disks/disk
  """

  destinationZone = _messages.StringField(1)
  targetDisk = _messages.StringField(2)


class DiskPairReplicationState(_messages.Message):
  r"""A DiskPairReplicationState object.

  Enums:
    DataReplicationStateValueValuesEnum: [Output Only] The status of disk
      creation. - ASYNC_REPLICATION_STATE_INITIALIZING: The device is doing
      the initial replication after starting the replication. -
      ASYNC_REPLICATION_STATE_REPLICATING_HEALTHY: The primary disk is
      healthily replicating to the secondary device i.e. last_replication_time
      is within RPO. - ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_HIGH_CHURN:
      The replication is lagging above the SLO limit due to the disk's change
      rate being above the supported limit. -
      ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_SYSTEM_LAGGING: The
      replication is lagging, and the RPO is not being met due to some
      internal issue. - ASYNC_REPLICATION_STATE_REPLICATION_STUCK: The
      replication is completely stuck due to some internal error. -
      ASYNC_REPLICATION_STATE_STOPPING: The replication is under the process
      of being stopped. This is a transient state. -
      ASYNC_REPLICATION_STATE_STOPPED: The replication between the disk-pairs
      have stopped. -
      ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_CG_HIGH_CHURN: The
      replication is lagging above the SLO limit for the disk in the
      consistency group due to disk's change rate being above the supported
      limit.

  Fields:
    dataReplicationState: [Output Only] The status of disk creation. -
      ASYNC_REPLICATION_STATE_INITIALIZING: The device is doing the initial
      replication after starting the replication. -
      ASYNC_REPLICATION_STATE_REPLICATING_HEALTHY: The primary disk is
      healthily replicating to the secondary device i.e. last_replication_time
      is within RPO. - ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_HIGH_CHURN:
      The replication is lagging above the SLO limit due to the disk's change
      rate being above the supported limit. -
      ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_SYSTEM_LAGGING: The
      replication is lagging, and the RPO is not being met due to some
      internal issue. - ASYNC_REPLICATION_STATE_REPLICATION_STUCK: The
      replication is completely stuck due to some internal error. -
      ASYNC_REPLICATION_STATE_STOPPING: The replication is under the process
      of being stopped. This is a transient state. -
      ASYNC_REPLICATION_STATE_STOPPED: The replication between the disk-pairs
      have stopped. -
      ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_CG_HIGH_CHURN: The
      replication is lagging above the SLO limit for the disk in the
      consistency group due to disk's change rate being above the supported
      limit.
    replicationDiskPair: A ReplicationDiskPair attribute.
  """

  class DataReplicationStateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of disk creation. -
    ASYNC_REPLICATION_STATE_INITIALIZING: The device is doing the initial
    replication after starting the replication. -
    ASYNC_REPLICATION_STATE_REPLICATING_HEALTHY: The primary disk is healthily
    replicating to the secondary device i.e. last_replication_time is within
    RPO. - ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_HIGH_CHURN: The
    replication is lagging above the SLO limit due to the disk's change rate
    being above the supported limit. -
    ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_SYSTEM_LAGGING: The replication
    is lagging, and the RPO is not being met due to some internal issue. -
    ASYNC_REPLICATION_STATE_REPLICATION_STUCK: The replication is completely
    stuck due to some internal error. - ASYNC_REPLICATION_STATE_STOPPING: The
    replication is under the process of being stopped. This is a transient
    state. - ASYNC_REPLICATION_STATE_STOPPED: The replication between the
    disk-pairs have stopped. -
    ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_CG_HIGH_CHURN: The replication
    is lagging above the SLO limit for the disk in the consistency group due
    to disk's change rate being above the supported limit.

    Values:
      ASYNC_REPLICATION_STATE_INITIALIZING: The device is doing the initial
        replication after starting the replication.
      ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_CG_HIGH_CHURN: The
        replication is lagging behind (last_replication_time > RPO) for the
        disk in a consistency group because some other disk is writing the
        data at a rate above the supported limit.
      ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_HIGH_CHURN: The replication
        is lagging behind (last_replication_time > RPO), because the disk's
        change rate is above the supported limit.
      ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_SYSTEM_LAGGING: The
        replication is lagging, and the RPO is not being met due to some
        internal issue.
      ASYNC_REPLICATION_STATE_REPLICATING_HEALTHY: The primary disk is
        healthily replicating to the secondary device i.e.
        last_replication_time is within RPO.
      ASYNC_REPLICATION_STATE_REPLICATION_STUCK: The replication is completely
        stuck due to some internal error.
      ASYNC_REPLICATION_STATE_STOPPED: The replication between the disk-pairs
        have stopped.
      ASYNC_REPLICATION_STATE_STOPPING: The replication is under the process
        of being stopped. This is a transient sate.
      ASYNC_REPLICATION_STATE_UNSPECIFIED: <no description>
    """
    ASYNC_REPLICATION_STATE_INITIALIZING = 0
    ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_CG_HIGH_CHURN = 1
    ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_HIGH_CHURN = 2
    ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_SYSTEM_LAGGING = 3
    ASYNC_REPLICATION_STATE_REPLICATING_HEALTHY = 4
    ASYNC_REPLICATION_STATE_REPLICATION_STUCK = 5
    ASYNC_REPLICATION_STATE_STOPPED = 6
    ASYNC_REPLICATION_STATE_STOPPING = 7
    ASYNC_REPLICATION_STATE_UNSPECIFIED = 8

  dataReplicationState = _messages.EnumField('DataReplicationStateValueValuesEnum', 1)
  replicationDiskPair = _messages.MessageField('ReplicationDiskPair', 2)


class DiskParams(_messages.Message):
  r"""Additional disk params.

  Messages:
    ResourceManagerTagsValue: Resource manager tags to be bound to the disk.
      Tag keys and values have the same definition as resource manager tags.
      Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the
      format `tagValues/456`. The field is ignored (both PUT & PATCH) when
      empty.

  Fields:
    resourceManagerTags: Resource manager tags to be bound to the disk. Tag
      keys and values have the same definition as resource manager tags. Keys
      must be in the format `tagKeys/{tag_key_id}`, and values are in the
      format `tagValues/456`. The field is ignored (both PUT & PATCH) when
      empty.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ResourceManagerTagsValue(_messages.Message):
    r"""Resource manager tags to be bound to the disk. Tag keys and values
    have the same definition as resource manager tags. Keys must be in the
    format `tagKeys/{tag_key_id}`, and values are in the format
    `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.

    Messages:
      AdditionalProperty: An additional property for a
        ResourceManagerTagsValue object.

    Fields:
      additionalProperties: Additional properties of type
        ResourceManagerTagsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ResourceManagerTagsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  resourceManagerTags = _messages.MessageField('ResourceManagerTagsValue', 1)


class DiskResourceStatus(_messages.Message):
  r"""A DiskResourceStatus object.

  Messages:
    AsyncSecondaryDisksValue: Key: disk, value: AsyncReplicationStatus message

  Fields:
    asyncPrimaryDisk: A DiskResourceStatusAsyncReplicationStatus attribute.
    asyncSecondaryDisks: Key: disk, value: AsyncReplicationStatus message
    usedBytes: [Output Only] Space used by data stored in the disk (in bytes).
      Note that this field is set only when the disk is in a storage pool.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AsyncSecondaryDisksValue(_messages.Message):
    r"""Key: disk, value: AsyncReplicationStatus message

    Messages:
      AdditionalProperty: An additional property for a
        AsyncSecondaryDisksValue object.

    Fields:
      additionalProperties: Additional properties of type
        AsyncSecondaryDisksValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AsyncSecondaryDisksValue object.

      Fields:
        key: Name of the additional property.
        value: A DiskResourceStatusAsyncReplicationStatus attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('DiskResourceStatusAsyncReplicationStatus', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  asyncPrimaryDisk = _messages.MessageField('DiskResourceStatusAsyncReplicationStatus', 1)
  asyncSecondaryDisks = _messages.MessageField('AsyncSecondaryDisksValue', 2)
  usedBytes = _messages.IntegerField(3)


class DiskResourceStatusAsyncReplicationStatus(_messages.Message):
  r"""A DiskResourceStatusAsyncReplicationStatus object.

  Enums:
    StateValueValuesEnum:

  Fields:
    state: A StateValueValuesEnum attribute.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""StateValueValuesEnum enum type.

    Values:
      ACTIVE: Replication is active.
      CREATED: Secondary disk is created and is waiting for replication to
        start.
      STARTING: Replication is starting.
      STATE_UNSPECIFIED: <no description>
      STOPPED: Replication is stopped.
      STOPPING: Replication is stopping.
    """
    ACTIVE = 0
    CREATED = 1
    STARTING = 2
    STATE_UNSPECIFIED = 3
    STOPPED = 4
    STOPPING = 5

  state = _messages.EnumField('StateValueValuesEnum', 1)


class DiskSettings(_messages.Message):
  r"""A DiskSettings object.

  Messages:
    DefaultResourcePoliciesValue: An optional parameter for storing the
      default resource policies that will be used for the Disks created in the
      given scope. The Key is a string type, provided by customers to uniquely
      identify the default Resource Policy entry. The Value is a Default
      ResourcePolicyDetails Object used to represent the detailed information
      of the Resource Policy entry.

  Fields:
    accessLocation: Policy of which locations are allowed to create regional
      snapshots.
    defaultResourcePolicies: An optional parameter for storing the default
      resource policies that will be used for the Disks created in the given
      scope. The Key is a string type, provided by customers to uniquely
      identify the default Resource Policy entry. The Value is a Default
      ResourcePolicyDetails Object used to represent the detailed information
      of the Resource Policy entry.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DefaultResourcePoliciesValue(_messages.Message):
    r"""An optional parameter for storing the default resource policies that
    will be used for the Disks created in the given scope. The Key is a string
    type, provided by customers to uniquely identify the default Resource
    Policy entry. The Value is a Default ResourcePolicyDetails Object used to
    represent the detailed information of the Resource Policy entry.

    Messages:
      AdditionalProperty: An additional property for a
        DefaultResourcePoliciesValue object.

    Fields:
      additionalProperties: Additional properties of type
        DefaultResourcePoliciesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DefaultResourcePoliciesValue object.

      Fields:
        key: Name of the additional property.
        value: A DiskSettingsResourcePolicyDetails attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('DiskSettingsResourcePolicyDetails', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  accessLocation = _messages.MessageField('DiskSettingsAccessLocation', 1)
  defaultResourcePolicies = _messages.MessageField('DefaultResourcePoliciesValue', 2)


class DiskSettingsAccessLocation(_messages.Message):
  r"""AccessLocation is only used for regional snapshot. It contains which
  regions are allowed to create a regional snapshot from disks located in the
  given region/zone. It includes key-value pairs designed to store the
  following structure. The keys should match their corresponding values, which
  must be provided: access_location: { locations { us-central1 { region: "us-
  central1" }, asia-west2 { region: "asia-west2" } } }

  Enums:
    PolicyValueValuesEnum: Policy of which location is allowed to access
      snapshot.

  Messages:
    LocationsValue: List of regions that can create a regional snapshot from
      the current region

  Fields:
    locations: List of regions that can create a regional snapshot from the
      current region
    policy: Policy of which location is allowed to access snapshot.
  """

  class PolicyValueValuesEnum(_messages.Enum):
    r"""Policy of which location is allowed to access snapshot.

    Values:
      ALL_REGIONS: Any regions will be able to access the source location.
      POLICY_UNSPECIFIED: <no description>
      SPECIFIC_REGIONS: Only allowlisted regions will be able to create region
        scoped snapshots
    """
    ALL_REGIONS = 0
    POLICY_UNSPECIFIED = 1
    SPECIFIC_REGIONS = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LocationsValue(_messages.Message):
    r"""List of regions that can create a regional snapshot from the current
    region

    Messages:
      AdditionalProperty: An additional property for a LocationsValue object.

    Fields:
      additionalProperties: Additional properties of type LocationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LocationsValue object.

      Fields:
        key: Name of the additional property.
        value: A DiskSettingsAccessLocationAccessLocationPreference attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('DiskSettingsAccessLocationAccessLocationPreference', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  locations = _messages.MessageField('LocationsValue', 1)
  policy = _messages.EnumField('PolicyValueValuesEnum', 2)


class DiskSettingsAccessLocationAccessLocationPreference(_messages.Message):
  r"""A structure for specifying an allowed target region to create snapshot.

  Fields:
    region: Accessible region name
  """

  region = _messages.StringField(1)


class DiskSettingsResourcePolicyDetails(_messages.Message):
  r"""This is the object for storing the detail information about the Resource
  Policy that will be set as default ones for the Disks that is using the
  DiskSettings. It contains: - one target Resource Policy referenced by its
  Fully-Qualified URL, - [output only] Disk Types that will be excluded from
  using this Resource Policy, - Other filtering support (e.g. Label filtering)
  for Default Resource Policy can be added here as well

  Fields:
    excludedDiskTypes: [Output Only] A list of Disk Types that will be
      excluded from applying the Resource Policy referenced here. If absent,
      Disks created in any DiskType can use the referenced default Resource
      Policy.
    resourcePolicy: The target Resource Policies identified by their Fully-
      Qualified URL.
  """

  excludedDiskTypes = _messages.StringField(1, repeated=True)
  resourcePolicy = _messages.StringField(2)


class DiskType(_messages.Message):
  r"""Represents a Disk Type resource. Google Compute Engine has two Disk Type
  resources: * [Regional](/compute/docs/reference/rest/alpha/regionDiskTypes)
  * [Zonal](/compute/docs/reference/rest/alpha/diskTypes) You can choose from
  a variety of disk types based on your needs. For more information, read
  Storage options. The diskTypes resource represents disk types for a zonal
  persistent disk. For more information, read Zonal persistent disks. The
  regionDiskTypes resource represents disk types for a regional persistent
  disk. For more information, read Regional persistent disks.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    defaultDiskSizeGb: [Output Only] Server-defined default disk size in GB.
    deprecated: [Output Only] The deprecation status associated with this disk
      type.
    description: [Output Only] An optional description of this resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#diskType for disk
      types.
    name: [Output Only] Name of the resource.
    region: [Output Only] URL of the region where the disk type resides. Only
      applicable for regional resources. You must specify this field as part
      of the HTTP request URL. It is not settable as a field in the request
      body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    validDiskSize: [Output Only] An optional textual description of the valid
      disk size, such as "10GB-10TB".
    zone: [Output Only] URL of the zone where the disk type resides. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
  """

  creationTimestamp = _messages.StringField(1)
  defaultDiskSizeGb = _messages.IntegerField(2)
  deprecated = _messages.MessageField('DeprecationStatus', 3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default='compute#diskType')
  name = _messages.StringField(7)
  region = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)
  validDiskSize = _messages.StringField(11)
  zone = _messages.StringField(12)


class DiskTypeAggregatedList(_messages.Message):
  r"""A DiskTypeAggregatedList object.

  Messages:
    ItemsValue: A list of DiskTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of DiskTypesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#diskTypeAggregatedList.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of DiskTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of disk types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A DiskTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('DiskTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#diskTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class DiskTypeList(_messages.Message):
  r"""Contains a list of disk types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of DiskType resources.
    kind: [Output Only] Type of resource. Always compute#diskTypeList for disk
      types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('DiskType', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#diskTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class DiskTypesScopedList(_messages.Message):
  r"""A DiskTypesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of disk types when the list is empty.

  Fields:
    diskTypes: [Output Only] A list of disk types contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      disk types when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of disk
    types when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  diskTypes = _messages.MessageField('DiskType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class DisksAddResourcePoliciesRequest(_messages.Message):
  r"""A DisksAddResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Full or relative path to the resource policy to be added
      to this disk. You can only specify one resource policy.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class DisksRemoveResourcePoliciesRequest(_messages.Message):
  r"""A DisksRemoveResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be removed from this disk.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class DisksResizeRequest(_messages.Message):
  r"""A DisksResizeRequest object.

  Fields:
    sizeGb: The new size of the persistent disk, which is specified in GB.
  """

  sizeGb = _messages.IntegerField(1)


class DisksScopedList(_messages.Message):
  r"""A DisksScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of disks when the list is empty.

  Fields:
    disks: [Output Only] A list of disks contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      disks when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of disks
    when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  disks = _messages.MessageField('Disk', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class DisksStartAsyncReplicationRequest(_messages.Message):
  r"""A DisksStartAsyncReplicationRequest object.

  Fields:
    asyncSecondaryDisk: The secondary disk to start asynchronous replication
      to. You can provide this as a partial or full URL to the resource. For
      example, the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /disks/disk -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /disks/disk - projects/project/zones/zone/disks/disk -
      projects/project/regions/region/disks/disk - zones/zone/disks/disk -
      regions/region/disks/disk
  """

  asyncSecondaryDisk = _messages.StringField(1)


class DisksStopGroupAsyncReplicationResource(_messages.Message):
  r"""A transient resource used in compute.disks.stopGroupAsyncReplication and
  compute.regionDisks.stopGroupAsyncReplication. It is only used to process
  requests and is not persisted.

  Fields:
    resourcePolicy: The URL of the DiskConsistencyGroupPolicy for the group of
      disks to stop. This may be a full or partial URL, such as: -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /resourcePolicies/resourcePolicy -
      projects/project/regions/region/resourcePolicies/resourcePolicy -
      regions/region/resourcePolicies/resourcePolicy
  """

  resourcePolicy = _messages.StringField(1)


class DisplayDevice(_messages.Message):
  r"""A set of Display Device options

  Fields:
    enableDisplay: Defines whether the instance has Display enabled.
  """

  enableDisplay = _messages.BooleanField(1)


class DistributionPolicy(_messages.Message):
  r"""A DistributionPolicy object.

  Enums:
    TargetShapeValueValuesEnum: The distribution shape to which the group
      converges either proactively or on resize events (depending on the value
      set in updatePolicy.instanceRedistributionType).

  Fields:
    targetShape: The distribution shape to which the group converges either
      proactively or on resize events (depending on the value set in
      updatePolicy.instanceRedistributionType).
    zones: Zones where the regional managed instance group will create and
      manage its instances.
  """

  class TargetShapeValueValuesEnum(_messages.Enum):
    r"""The distribution shape to which the group converges either proactively
    or on resize events (depending on the value set in
    updatePolicy.instanceRedistributionType).

    Values:
      ANY: The group picks zones for creating VM instances to fulfill the
        requested number of VMs within present resource constraints and to
        maximize utilization of unused zonal reservations. Recommended for
        batch workloads that do not require high availability.
      ANY_SINGLE_ZONE: The group creates all VM instances within a single
        zone. The zone is selected based on the present resource constraints
        and to maximize utilization of unused zonal reservations. Recommended
        for batch workloads with heavy interprocess communication.
      BALANCED: The group prioritizes acquisition of resources, scheduling VMs
        in zones where resources are available while distributing VMs as
        evenly as possible across selected zones to minimize the impact of
        zonal failure. Recommended for highly available serving workloads.
      EVEN: The group schedules VM instance creation and deletion to achieve
        and maintain an even number of managed instances across the selected
        zones. The distribution is even when the number of managed instances
        does not differ by more than 1 between any two zones. Recommended for
        highly available serving workloads.
    """
    ANY = 0
    ANY_SINGLE_ZONE = 1
    BALANCED = 2
    EVEN = 3

  targetShape = _messages.EnumField('TargetShapeValueValuesEnum', 1)
  zones = _messages.MessageField('DistributionPolicyZoneConfiguration', 2, repeated=True)


class DistributionPolicyZoneConfiguration(_messages.Message):
  r"""A DistributionPolicyZoneConfiguration object.

  Fields:
    zone: The URL of the zone. The zone must exist in the region where the
      managed instance group is located.
  """

  zone = _messages.StringField(1)


class Duration(_messages.Message):
  r"""A Duration represents a fixed-length span of time represented as a count
  of seconds and fractions of seconds at nanosecond resolution. It is
  independent of any calendar and concepts like "day" or "month". Range is
  approximately 10,000 years.

  Fields:
    nanos: Span of time that's a fraction of a second at nanosecond
      resolution. Durations less than one second are represented with a 0
      `seconds` field and a positive `nanos` field. Must be from 0 to
      999,999,999 inclusive.
    seconds: Span of time at a resolution of a second. Must be from 0 to
      315,576,000,000 inclusive. Note: these bounds are computed from: 60
      sec/min * 60 min/hr * 24 hr/day * 365.25 days/year * 10000 years
  """

  nanos = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  seconds = _messages.IntegerField(2)


class ErrorInfo(_messages.Message):
  r"""Describes the cause of the error with structured details. Example of an
  error when contacting the "pubsub.googleapis.com" API when it is not
  enabled: { "reason": "API_DISABLED" "domain": "googleapis.com" "metadata": {
  "resource": "projects/123", "service": "pubsub.googleapis.com" } } This
  response indicates that the pubsub.googleapis.com API is not enabled.
  Example of an error that is returned when attempting to create a Spanner
  instance in a region that is out of stock: { "reason": "STOCKOUT" "domain":
  "spanner.googleapis.com", "metadata": { "availableRegions": "us-central1,us-
  east2" } }

  Messages:
    MetadatasValue: Additional structured details about this error. Keys must
      match a regular expression of `a-z+` but should ideally be
      lowerCamelCase. Also, they must be limited to 64 characters in length.
      When identifying the current value of an exceeded limit, the units
      should be contained in the key, not the value. For example, rather than
      `{"instanceLimit": "100/request"}`, should be returned as,
      `{"instanceLimitPerRequest": "100"}`, if the client exceeds the number
      of instances that can be created in a single (batch) request.

  Fields:
    domain: The logical grouping to which the "reason" belongs. The error
      domain is typically the registered service name of the tool or product
      that generates the error. Example: "pubsub.googleapis.com". If the error
      is generated by some common infrastructure, the error domain must be a
      globally unique value that identifies the infrastructure. For Google API
      infrastructure, the error domain is "googleapis.com".
    metadatas: Additional structured details about this error. Keys must match
      a regular expression of `a-z+` but should ideally be lowerCamelCase.
      Also, they must be limited to 64 characters in length. When identifying
      the current value of an exceeded limit, the units should be contained in
      the key, not the value. For example, rather than `{"instanceLimit":
      "100/request"}`, should be returned as, `{"instanceLimitPerRequest":
      "100"}`, if the client exceeds the number of instances that can be
      created in a single (batch) request.
    reason: The reason of the error. This is a constant value that identifies
      the proximate cause of the error. Error reasons are unique within a
      particular domain of errors. This should be at most 63 characters and
      match a regular expression of `A-Z+[A-Z0-9]`, which represents
      UPPER_SNAKE_CASE.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class MetadatasValue(_messages.Message):
    r"""Additional structured details about this error. Keys must match a
    regular expression of `a-z+` but should ideally be lowerCamelCase. Also,
    they must be limited to 64 characters in length. When identifying the
    current value of an exceeded limit, the units should be contained in the
    key, not the value. For example, rather than `{"instanceLimit":
    "100/request"}`, should be returned as, `{"instanceLimitPerRequest":
    "100"}`, if the client exceeds the number of instances that can be created
    in a single (batch) request.

    Messages:
      AdditionalProperty: An additional property for a MetadatasValue object.

    Fields:
      additionalProperties: Additional properties of type MetadatasValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a MetadatasValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  domain = _messages.StringField(1)
  metadatas = _messages.MessageField('MetadatasValue', 2)
  reason = _messages.StringField(3)


class ExchangedPeeringRoute(_messages.Message):
  r"""A ExchangedPeeringRoute object.

  Enums:
    TypeValueValuesEnum: The type of the peering route.

  Fields:
    destRange: The destination range of the route.
    imported: True if the peering route has been imported from a peer. The
      actual import happens if the field networkPeering.importCustomRoutes is
      true for this network, and networkPeering.exportCustomRoutes is true for
      the peer network, and the import does not result in a route conflict.
    nextHopRegion: The region of peering route next hop, only applies to
      dynamic routes.
    priority: The priority of the peering route.
    type: The type of the peering route.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of the peering route.

    Values:
      DYNAMIC_PEERING_ROUTE: For routes exported from local network.
      STATIC_PEERING_ROUTE: The peering route.
      SUBNET_PEERING_ROUTE: The peering route corresponding to subnetwork
        range.
    """
    DYNAMIC_PEERING_ROUTE = 0
    STATIC_PEERING_ROUTE = 1
    SUBNET_PEERING_ROUTE = 2

  destRange = _messages.StringField(1)
  imported = _messages.BooleanField(2)
  nextHopRegion = _messages.StringField(3)
  priority = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  type = _messages.EnumField('TypeValueValuesEnum', 5)


class ExchangedPeeringRoutesList(_messages.Message):
  r"""A ExchangedPeeringRoutesList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ExchangedPeeringRoute resources.
    kind: [Output Only] Type of resource. Always
      compute#exchangedPeeringRoutesList for exchanged peering routes lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ExchangedPeeringRoute', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#exchangedPeeringRoutesList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class Expr(_messages.Message):
  r"""Represents a textual expression in the Common Expression Language (CEL)
  syntax. CEL is a C-like expression language. The syntax and semantics of CEL
  are documented at https://github.com/google/cel-spec. Example (Comparison):
  title: "Summary size limit" description: "Determines if a summary is less
  than 100 chars" expression: "document.summary.size() < 100" Example
  (Equality): title: "Requestor is owner" description: "Determines if
  requestor is the document owner" expression: "document.owner ==
  request.auth.claims.email" Example (Logic): title: "Public documents"
  description: "Determine whether the document should be publicly visible"
  expression: "document.type != 'private' && document.type != 'internal'"
  Example (Data Manipulation): title: "Notification string" description:
  "Create a notification string with a timestamp." expression: "'New message
  received at ' + string(document.create_time)" The exact variables and
  functions that may be referenced within an expression are determined by the
  service that evaluates it. See the service documentation for additional
  information.

  Fields:
    description: Optional. Description of the expression. This is a longer
      text which describes the expression, e.g. when hovered over it in a UI.
    expression: Textual representation of an expression in Common Expression
      Language syntax.
    location: Optional. String indicating the location of the expression for
      error reporting, e.g. a file name and a position in the file.
    title: Optional. Title for the expression, i.e. a short string describing
      its purpose. This can be used e.g. in UIs which allow to enter the
      expression.
  """

  description = _messages.StringField(1)
  expression = _messages.StringField(2)
  location = _messages.StringField(3)
  title = _messages.StringField(4)


class ExternalVpnGateway(_messages.Message):
  r"""Represents an external VPN gateway. External VPN gateway is the on-
  premises VPN gateway(s) or another cloud provider's VPN gateway that
  connects to your Google Cloud VPN gateway. To create a highly available VPN
  from Google Cloud Platform to your VPN gateway or another cloud provider's
  VPN gateway, you must create a external VPN gateway resource with
  information about the other gateway. For more information about using
  external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a
  peer VPN.

  Enums:
    RedundancyTypeValueValuesEnum: Indicates the user-supplied redundancy type
      of this external VPN gateway.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interfaces: A list of interfaces for this external VPN gateway. If your
      peer-side gateway is an on-premises gateway and non-AWS cloud providers'
      gateway, at most two interfaces can be provided for an external VPN
      gateway. If your peer side is an AWS virtual private gateway, four
      interfaces should be provided for an external VPN gateway.
    kind: [Output Only] Type of the resource. Always
      compute#externalVpnGateway for externalVpnGateways.
    labelFingerprint: A fingerprint for the labels being applied to this
      ExternalVpnGateway, which is essentially a hash of the labels set used
      for optimistic locking. The fingerprint is initially generated by
      Compute Engine and changes after every request to modify or update
      labels. You must always provide an up-to-date fingerprint hash in order
      to update or change labels, otherwise the request will fail with error
      412 conditionNotMet. To see the latest fingerprint, make a get() request
      to retrieve an ExternalVpnGateway.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    redundancyType: Indicates the user-supplied redundancy type of this
      external VPN gateway.
    selfLink: [Output Only] Server-defined URL for the resource.
  """

  class RedundancyTypeValueValuesEnum(_messages.Enum):
    r"""Indicates the user-supplied redundancy type of this external VPN
    gateway.

    Values:
      FOUR_IPS_REDUNDANCY: The external VPN gateway has four public IP
        addresses; at the time of writing this API, the AWS virtual private
        gateway is an example which has four public IP addresses for high
        availability connections; there should be two VPN connections in the
        AWS virtual private gateway , each AWS VPN connection has two public
        IP addresses; please make sure to put two public IP addresses from one
        AWS VPN connection into interfaces 0 and 1 of this external VPN
        gateway, and put the other two public IP addresses from another AWS
        VPN connection into interfaces 2 and 3 of this external VPN gateway.
        When displaying highly available configuration status for the VPN
        tunnels connected to FOUR_IPS_REDUNDANCY external VPN gateway, Google
        will always detect whether interfaces 0 and 1 are connected on one
        interface of HA Cloud VPN gateway, and detect whether interfaces 2 and
        3 are connected to another interface of the HA Cloud VPN gateway.
      SINGLE_IP_INTERNALLY_REDUNDANT: The external VPN gateway has only one
        public IP address which internally provide redundancy or failover.
      TWO_IPS_REDUNDANCY: The external VPN gateway has two public IP addresses
        which are redundant with each other, the following two types of setup
        on your on-premises side would have this type of redundancy: (1) Two
        separate on-premises gateways, each with one public IP address, the
        two on-premises gateways are redundant with each other. (2) A single
        on-premise gateway with two public IP addresses that are redundant
        with eatch other.
    """
    FOUR_IPS_REDUNDANCY = 0
    SINGLE_IP_INTERNALLY_REDUNDANT = 1
    TWO_IPS_REDUNDANCY = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  interfaces = _messages.MessageField('ExternalVpnGatewayInterface', 4, repeated=True)
  kind = _messages.StringField(5, default='compute#externalVpnGateway')
  labelFingerprint = _messages.BytesField(6)
  labels = _messages.MessageField('LabelsValue', 7)
  name = _messages.StringField(8)
  redundancyType = _messages.EnumField('RedundancyTypeValueValuesEnum', 9)
  selfLink = _messages.StringField(10)


class ExternalVpnGatewayInterface(_messages.Message):
  r"""The interface for the external VPN gateway.

  Fields:
    id: The numeric ID of this interface. The allowed input values for this id
      for different redundancy types of external VPN gateway: -
      SINGLE_IP_INTERNALLY_REDUNDANT - 0 - TWO_IPS_REDUNDANCY - 0, 1 -
      FOUR_IPS_REDUNDANCY - 0, 1, 2, 3
    ipAddress: IP address of the interface in the external VPN gateway. Only
      IPv4 is supported. This IP address can be either from your on-premise
      gateway or another Cloud provider's VPN gateway, it cannot be an IP
      address from Google Compute Engine.
    ipv6Address: IPv6 address of the interface in the external VPN gateway.
      This IPv6 address can be either from your on-premise gateway or another
      Cloud provider's VPN gateway, it cannot be an IP address from Google
      Compute Engine. Must specify an IPv6 address (not IPV4-mapped) using any
      format described in RFC 4291 (e.g. 2001:db8:0:0:2d9:51:0:0). The output
      format is RFC 5952 format (e.g. 2001:db8::2d9:51:0:0).
  """

  id = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  ipAddress = _messages.StringField(2)
  ipv6Address = _messages.StringField(3)


class ExternalVpnGatewayList(_messages.Message):
  r"""Response to the list request, and contains a list of
  externalVpnGateways.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ExternalVpnGateway resources.
    kind: [Output Only] Type of resource. Always
      compute#externalVpnGatewayList for lists of externalVpnGateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ExternalVpnGateway', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#externalVpnGatewayList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  warning = _messages.MessageField('WarningValue', 7)


class FileContentBuffer(_messages.Message):
  r"""A FileContentBuffer object.

  Enums:
    FileTypeValueValuesEnum: The file type of source file.

  Fields:
    content: The raw content in the secure keys file.
    fileType: The file type of source file.
  """

  class FileTypeValueValuesEnum(_messages.Enum):
    r"""The file type of source file.

    Values:
      BIN: <no description>
      UNDEFINED: <no description>
      X509: <no description>
    """
    BIN = 0
    UNDEFINED = 1
    X509 = 2

  content = _messages.BytesField(1)
  fileType = _messages.EnumField('FileTypeValueValuesEnum', 2)


class Firewall(_messages.Message):
  r"""Represents a Firewall Rule resource. Firewall rules allow or deny
  ingress traffic to, and egress traffic from your instances. For more
  information, read Firewall rules.

  Enums:
    DirectionValueValuesEnum: Direction of traffic to which this firewall
      applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For
      `EGRESS` traffic, you cannot specify the sourceTags fields.

  Messages:
    AllowedValueListEntry: A AllowedValueListEntry object.
    DeniedValueListEntry: A DeniedValueListEntry object.

  Fields:
    allowed: The list of ALLOW rules specified by this firewall. Each rule
      specifies a protocol and port-range tuple that describes a permitted
      connection.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    denied: The list of DENY rules specified by this firewall. Each rule
      specifies a protocol and port-range tuple that describes a denied
      connection.
    description: An optional description of this resource. Provide this field
      when you create the resource.
    destinationRanges: If destination ranges are specified, the firewall rule
      applies only to traffic that has destination IP address in these ranges.
      These ranges must be expressed in CIDR format. Both IPv4 and IPv6 are
      supported.
    direction: Direction of traffic to which this firewall applies, either
      `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic,
      you cannot specify the sourceTags fields.
    disabled: Denotes whether the firewall rule is disabled. When set to true,
      the firewall rule is not enforced and the network behaves as if it did
      not exist. If this is unspecified, the firewall rule will be enabled.
    enableLogging: Deprecated in favor of enable in LogConfig. This field
      denotes whether to enable logging for a particular firewall rule. If
      logging is enabled, logs will be exported t Cloud Logging.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#firewall for
      firewall rules.
    logConfig: This field denotes the logging options for a particular
      firewall rule. If logging is enabled, logs will be exported to Cloud
      Logging.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character
      must be a lowercase letter, and all following characters (except for the
      last character) must be a dash, lowercase letter, or digit. The last
      character must be a lowercase letter or digit.
    network: URL of the network resource for this firewall rule. If not
      specified when creating a firewall rule, the default network is used:
      global/networks/default If you choose to specify this field, you can
      specify the network as a full or partial URL. For example, the following
      are all valid URLs: - https://www.googleapis.com/compute/v1/projects/myp
      roject/global/networks/my-network -
      projects/myproject/global/networks/my-network - global/networks/default
    priority: Priority for this rule. This is an integer between `0` and
      `65535`, both inclusive. The default value is `1000`. Relative
      priorities determine which rule takes effect if multiple rules apply.
      Lower values indicate higher priority. For example, a rule with priority
      `0` has higher precedence than a rule with priority `1`. DENY rules take
      precedence over ALLOW rules if they have equal priority. Note that VPC
      networks have implied rules with a priority of `65535`. To avoid
      conflicts with the implied rules, use a priority number less than
      `65535`.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sourceRanges: If source ranges are specified, the firewall rule applies
      only to traffic that has a source IP address in these ranges. These
      ranges must be expressed in CIDR format. One or both of sourceRanges and
      sourceTags may be set. If both fields are set, the rule applies to
      traffic that has a source IP address within sourceRanges OR a source IP
      from a resource with a matching tag listed in the sourceTags field. The
      connection does not need to match both fields for the rule to apply.
      Both IPv4 and IPv6 are supported.
    sourceServiceAccounts: If source service accounts are specified, the
      firewall rules apply only to traffic originating from an instance with a
      service account in this list. Source service accounts cannot be used to
      control traffic to an instance's external IP address because service
      accounts are associated with an instance, not an IP address.
      sourceRanges can be set at the same time as sourceServiceAccounts. If
      both are set, the firewall applies to traffic that has a source IP
      address within the sourceRanges OR a source IP that belongs to an
      instance with service account listed in sourceServiceAccount. The
      connection does not need to match both fields for the firewall to apply.
      sourceServiceAccounts cannot be used at the same time as sourceTags or
      targetTags.
    sourceTags: If source tags are specified, the firewall rule applies only
      to traffic with source IPs that match the primary network interfaces of
      VM instances that have the tag and are in the same VPC network. Source
      tags cannot be used to control traffic to an instance's external IP
      address, it only applies to traffic between instances in the same
      virtual network. Because tags are associated with instances, not IP
      addresses. One or both of sourceRanges and sourceTags may be set. If
      both fields are set, the firewall applies to traffic that has a source
      IP address within sourceRanges OR a source IP from a resource with a
      matching tag listed in the sourceTags field. The connection does not
      need to match both fields for the firewall to apply.
    targetServiceAccounts: A list of service accounts indicating sets of
      instances located in the network that may make network connections as
      specified in allowed[]. targetServiceAccounts cannot be used at the same
      time as targetTags or sourceTags. If neither targetServiceAccounts nor
      targetTags are specified, the firewall rule applies to all instances on
      the specified network.
    targetTags: A list of tags that controls which instances the firewall rule
      applies to. If targetTags are specified, then the firewall rule applies
      only to instances in the VPC network that have one of those tags. If no
      targetTags are specified, the firewall rule applies to all instances on
      the specified network.
  """

  class DirectionValueValuesEnum(_messages.Enum):
    r"""Direction of traffic to which this firewall applies, either `INGRESS`
    or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot
    specify the sourceTags fields.

    Values:
      EGRESS: Indicates that firewall should apply to outgoing traffic.
      INGRESS: Indicates that firewall should apply to incoming traffic.
    """
    EGRESS = 0
    INGRESS = 1

  class AllowedValueListEntry(_messages.Message):
    r"""A AllowedValueListEntry object.

    Fields:
      IPProtocol: The IP protocol to which this rule applies. The protocol
        type is required when creating a firewall rule. This value can either
        be one of the following well known protocol strings (tcp, udp, icmp,
        esp, ah, ipip, sctp) or the IP protocol number.
      ports: An optional list of ports to which this rule applies. This field
        is only applicable for the UDP or TCP protocol. Each entry must be
        either an integer or a range. If not specified, this rule applies to
        connections through any port. Example inputs include: ["22"],
        ["80","443"], and ["12345-12349"].
    """

    IPProtocol = _messages.StringField(1)
    ports = _messages.StringField(2, repeated=True)

  class DeniedValueListEntry(_messages.Message):
    r"""A DeniedValueListEntry object.

    Fields:
      IPProtocol: The IP protocol to which this rule applies. The protocol
        type is required when creating a firewall rule. This value can either
        be one of the following well known protocol strings (tcp, udp, icmp,
        esp, ah, ipip, sctp) or the IP protocol number.
      ports: An optional list of ports to which this rule applies. This field
        is only applicable for the UDP or TCP protocol. Each entry must be
        either an integer or a range. If not specified, this rule applies to
        connections through any port. Example inputs include: ["22"],
        ["80","443"], and ["12345-12349"].
    """

    IPProtocol = _messages.StringField(1)
    ports = _messages.StringField(2, repeated=True)

  allowed = _messages.MessageField('AllowedValueListEntry', 1, repeated=True)
  creationTimestamp = _messages.StringField(2)
  denied = _messages.MessageField('DeniedValueListEntry', 3, repeated=True)
  description = _messages.StringField(4)
  destinationRanges = _messages.StringField(5, repeated=True)
  direction = _messages.EnumField('DirectionValueValuesEnum', 6)
  disabled = _messages.BooleanField(7)
  enableLogging = _messages.BooleanField(8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(10, default='compute#firewall')
  logConfig = _messages.MessageField('FirewallLogConfig', 11)
  name = _messages.StringField(12)
  network = _messages.StringField(13)
  priority = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  sourceRanges = _messages.StringField(17, repeated=True)
  sourceServiceAccounts = _messages.StringField(18, repeated=True)
  sourceTags = _messages.StringField(19, repeated=True)
  targetServiceAccounts = _messages.StringField(20, repeated=True)
  targetTags = _messages.StringField(21, repeated=True)


class FirewallList(_messages.Message):
  r"""Contains a list of firewalls.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Firewall resources.
    kind: [Output Only] Type of resource. Always compute#firewallList for
      lists of firewalls.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Firewall', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#firewallList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class FirewallLogConfig(_messages.Message):
  r"""The available logging options for a firewall rule.

  Enums:
    MetadataValueValuesEnum: This field can only be specified for a particular
      firewall rule if logging is enabled for that rule. This field denotes
      whether to include or exclude metadata for firewall logs.

  Fields:
    enable: This field denotes whether to enable logging for a particular
      firewall rule.
    metadata: This field can only be specified for a particular firewall rule
      if logging is enabled for that rule. This field denotes whether to
      include or exclude metadata for firewall logs.
  """

  class MetadataValueValuesEnum(_messages.Enum):
    r"""This field can only be specified for a particular firewall rule if
    logging is enabled for that rule. This field denotes whether to include or
    exclude metadata for firewall logs.

    Values:
      EXCLUDE_ALL_METADATA: <no description>
      INCLUDE_ALL_METADATA: <no description>
    """
    EXCLUDE_ALL_METADATA = 0
    INCLUDE_ALL_METADATA = 1

  enable = _messages.BooleanField(1)
  metadata = _messages.EnumField('MetadataValueValuesEnum', 2)


class FirewallPoliciesListAssociationsResponse(_messages.Message):
  r"""A FirewallPoliciesListAssociationsResponse object.

  Fields:
    associations: A list of associations.
    kind: [Output Only] Type of firewallPolicy associations. Always
      compute#FirewallPoliciesListAssociations for lists of firewallPolicy
      associations.
  """

  associations = _messages.MessageField('FirewallPolicyAssociation', 1, repeated=True)
  kind = _messages.StringField(2, default='compute#firewallPoliciesListAssociationsResponse')


class FirewallPoliciesScopedList(_messages.Message):
  r"""A FirewallPoliciesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of firewall
      policies when the list is empty.

  Fields:
    firewallPolicies: A list of firewall policies contained in this scope.
    warning: Informational warning which replaces the list of firewall
      policies when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of firewall policies
    when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  firewallPolicies = _messages.MessageField('FirewallPolicy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class FirewallPolicy(_messages.Message):
  r"""Represents a Firewall Policy resource.

  Enums:
    VpcNetworkScopeValueValuesEnum: The scope of networks allowed to be
      associated with the firewall policy. This field can be either
      GLOBAL_VPC_NETWORK or REGIONAL_VPC_NETWORK. A firewall policy with the
      VPC scope set to GLOBAL_VPC_NETWORK is allowed to be attached only to
      global networks. When the VPC scope is set to REGIONAL_VPC_NETWORK the
      firewall policy is allowed to be attached only to regional networks in
      the same scope as the firewall policy. Note: if not specified then
      GLOBAL_VPC_NETWORK will be used.

  Fields:
    associations: A list of associations that belong to this firewall policy.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    displayName: Deprecated, please use short name instead. User-provided name
      of the Organization firewall policy. The name should be unique in the
      organization in which the firewall policy is created. This field is not
      applicable to network firewall policies. This name must be set on
      creation and cannot be changed. The name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    fingerprint: Specifies a fingerprint for this resource, which is
      essentially a hash of the metadata's contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update metadata. You must
      always provide an up-to-date fingerprint hash in order to update or
      change metadata, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make get() request to
      the firewall policy.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output only] Type of the resource. Always compute#firewallPolicyfor
      firewall policies
    name: Name of the resource. For Organization Firewall Policies it's a
      [Output Only] numeric ID allocated by Google Cloud which uniquely
      identifies the Organization Firewall Policy.
    packetMirroringRules: A list of packet mirroring rules that belong to this
      policy.
    parent: [Output Only] The parent of the firewall policy. This field is not
      applicable to network firewall policies.
    region: [Output Only] URL of the region where the regional firewall policy
      resides. This field is not applicable to global firewall policies. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    ruleTupleCount: [Output Only] Total count of all firewall policy rule
      tuples. A firewall policy can not exceed a set number of tuples.
    rules: A list of rules that belong to this policy. There must always be a
      default rule (rule with priority 2147483647 and match "*"). If no rules
      are provided when creating a firewall policy, a default rule with action
      "allow" will be added.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    shortName: User-provided name of the Organization firewall policy. The
      name should be unique in the organization in which the firewall policy
      is created. This field is not applicable to network firewall policies.
      This name must be set on creation and cannot be changed. The name must
      be 1-63 characters long, and comply with RFC1035. Specifically, the name
      must be 1-63 characters long and match the regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a
      lowercase letter, and all following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash.
    vpcNetworkScope: The scope of networks allowed to be associated with the
      firewall policy. This field can be either GLOBAL_VPC_NETWORK or
      REGIONAL_VPC_NETWORK. A firewall policy with the VPC scope set to
      GLOBAL_VPC_NETWORK is allowed to be attached only to global networks.
      When the VPC scope is set to REGIONAL_VPC_NETWORK the firewall policy is
      allowed to be attached only to regional networks in the same scope as
      the firewall policy. Note: if not specified then GLOBAL_VPC_NETWORK will
      be used.
  """

  class VpcNetworkScopeValueValuesEnum(_messages.Enum):
    r"""The scope of networks allowed to be associated with the firewall
    policy. This field can be either GLOBAL_VPC_NETWORK or
    REGIONAL_VPC_NETWORK. A firewall policy with the VPC scope set to
    GLOBAL_VPC_NETWORK is allowed to be attached only to global networks. When
    the VPC scope is set to REGIONAL_VPC_NETWORK the firewall policy is
    allowed to be attached only to regional networks in the same scope as the
    firewall policy. Note: if not specified then GLOBAL_VPC_NETWORK will be
    used.

    Values:
      GLOBAL_VPC_NETWORK: The firewall policy is allowed to be attached only
        to global networks.
      REGIONAL_VPC_NETWORK: The firewall policy is allowed to be attached only
        to regional networks in the same scope as the firewall policy. This
        option is applicable only to regional firewall policies.
    """
    GLOBAL_VPC_NETWORK = 0
    REGIONAL_VPC_NETWORK = 1

  associations = _messages.MessageField('FirewallPolicyAssociation', 1, repeated=True)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  displayName = _messages.StringField(4)
  fingerprint = _messages.BytesField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#firewallPolicy')
  name = _messages.StringField(8)
  packetMirroringRules = _messages.MessageField('FirewallPolicyRule', 9, repeated=True)
  parent = _messages.StringField(10)
  region = _messages.StringField(11)
  ruleTupleCount = _messages.IntegerField(12, variant=_messages.Variant.INT32)
  rules = _messages.MessageField('FirewallPolicyRule', 13, repeated=True)
  selfLink = _messages.StringField(14)
  selfLinkWithId = _messages.StringField(15)
  shortName = _messages.StringField(16)
  vpcNetworkScope = _messages.EnumField('VpcNetworkScopeValueValuesEnum', 17)


class FirewallPolicyAssociation(_messages.Message):
  r"""A FirewallPolicyAssociation object.

  Fields:
    attachmentTarget: The target that the firewall policy is attached to.
    displayName: [Output Only] Deprecated, please use short name instead. The
      display name of the firewall policy of the association.
    firewallPolicyId: [Output Only] The firewall policy ID of the association.
    name: The name for an association.
    priority: An integer indicating the priority of an association. The
      priority must be a positive value between 1 and 2147483647. Firewall
      Policies are evaluated from highest to lowest priority where 1 is the
      highest priority and 2147483647 is the lowest priority. The default
      value is `1000`. If two associations have the same priority then
      lexicographical order on association names is applied.
    shortName: [Output Only] The short name of the firewall policy of the
      association.
  """

  attachmentTarget = _messages.StringField(1)
  displayName = _messages.StringField(2)
  firewallPolicyId = _messages.StringField(3)
  name = _messages.StringField(4)
  priority = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  shortName = _messages.StringField(6)


class FirewallPolicyList(_messages.Message):
  r"""A FirewallPolicyList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of FirewallPolicy resources.
    kind: [Output Only] Type of resource. Always compute#firewallPolicyList
      for listsof FirewallPolicies
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('FirewallPolicy', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#firewallPolicyList')
  nextPageToken = _messages.StringField(4)
  warning = _messages.MessageField('WarningValue', 5)


class FirewallPolicyRule(_messages.Message):
  r"""Represents a rule that describes one or more match conditions along with
  the action to be taken when traffic matches this condition (allow or deny).

  Enums:
    DirectionValueValuesEnum: The direction in which this rule applies.
    TargetTypeValueValuesEnum: Target types of the firewall policy rule.
      Default value is INSTANCES.

  Fields:
    action: The Action to perform when the client connection triggers the
      rule. Valid actions for firewall rules are: "allow", "deny",
      "apply_security_profile_group" and "goto_next". Valid actions for packet
      mirroring rules are: "mirror", "do_not_mirror" and "goto_next".
    description: An optional description for this resource.
    direction: The direction in which this rule applies.
    disabled: Denotes whether the firewall policy rule is disabled. When set
      to true, the firewall policy rule is not enforced and traffic behaves as
      if it did not exist. If this is unspecified, the firewall policy rule
      will be enabled.
    enableLogging: Denotes whether to enable logging for a particular rule. If
      logging is enabled, logs will be exported to the configured export
      destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub.
      Note: you cannot enable logging on "goto_next" rules.
    kind: [Output only] Type of the resource. Returns
      compute#firewallPolicyRule for firewall rules and
      compute#packetMirroringRule for packet mirroring rules.
    match: A match condition that incoming traffic is evaluated against. If it
      evaluates to true, the corresponding 'action' is enforced.
    priority: An integer indicating the priority of a rule in the list. The
      priority must be a positive value between 0 and 2147483647. Rules are
      evaluated from highest to lowest priority where 0 is the highest
      priority and 2147483647 is the lowest priority.
    ruleName: An optional name for the rule. This field is not a unique
      identifier and can be updated.
    ruleTupleCount: [Output Only] Calculation of the complexity of a single
      firewall policy rule.
    securityProfileGroup: A fully-qualified URL of a SecurityProfile resource
      instance. Example: https://networksecurity.googleapis.com/v1/projects/{p
      roject}/locations/{location}/securityProfileGroups/my-security-profile-
      group Must be specified if action is one of
      'apply_security_profile_group' or 'mirror'. Cannot be specified for
      other actions.
    targetForwardingRules: A list of forwarding rules to which this rule
      applies. This field allows you to control which load balancers get this
      rule. For example, the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project
      /global/forwardingRules/forwardingRule -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /forwardingRules/forwardingRule - projects/project/global/
      forwardingRules/forwardingRule -
      projects/project/regions/region/forwardingRules/ forwardingRule
    targetResources: A list of network resource URLs to which this rule
      applies. This field allows you to control which network's VMs get this
      rule. If this field is left blank, all VMs within the organization will
      receive the rule.
    targetSecureTags: A list of secure tags that controls which instances the
      firewall rule applies to. If targetSecureTag are specified, then the
      firewall rule applies only to instances in the VPC network that have one
      of those EFFECTIVE secure tags, if all the target_secure_tag are in
      INEFFECTIVE state, then this rule will be ignored. targetSecureTag may
      not be set at the same time as targetServiceAccounts. If neither
      targetServiceAccounts nor targetSecureTag are specified, the firewall
      rule applies to all instances on the specified network. Maximum number
      of target label tags allowed is 256.
    targetServiceAccounts: A list of service accounts indicating the sets of
      instances that are applied with this rule.
    targetType: Target types of the firewall policy rule. Default value is
      INSTANCES.
    tlsInspect: Boolean flag indicating if the traffic should be TLS
      decrypted. Can be set only if action = 'apply_security_profile_group'
      and cannot be set for other actions.
  """

  class DirectionValueValuesEnum(_messages.Enum):
    r"""The direction in which this rule applies.

    Values:
      EGRESS: <no description>
      INGRESS: <no description>
    """
    EGRESS = 0
    INGRESS = 1

  class TargetTypeValueValuesEnum(_messages.Enum):
    r"""Target types of the firewall policy rule. Default value is INSTANCES.

    Values:
      INSTANCES: <no description>
      INTERNAL_MANAGED_LB: <no description>
    """
    INSTANCES = 0
    INTERNAL_MANAGED_LB = 1

  action = _messages.StringField(1)
  description = _messages.StringField(2)
  direction = _messages.EnumField('DirectionValueValuesEnum', 3)
  disabled = _messages.BooleanField(4)
  enableLogging = _messages.BooleanField(5)
  kind = _messages.StringField(6, default='compute#firewallPolicyRule')
  match = _messages.MessageField('FirewallPolicyRuleMatcher', 7)
  priority = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  ruleName = _messages.StringField(9)
  ruleTupleCount = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  securityProfileGroup = _messages.StringField(11)
  targetForwardingRules = _messages.StringField(12, repeated=True)
  targetResources = _messages.StringField(13, repeated=True)
  targetSecureTags = _messages.MessageField('FirewallPolicyRuleSecureTag', 14, repeated=True)
  targetServiceAccounts = _messages.StringField(15, repeated=True)
  targetType = _messages.EnumField('TargetTypeValueValuesEnum', 16)
  tlsInspect = _messages.BooleanField(17)


class FirewallPolicyRuleMatcher(_messages.Message):
  r"""Represents a match condition that incoming traffic is evaluated against.
  Exactly one field must be specified.

  Enums:
    DestNetworkScopeValueValuesEnum: Network scope of the traffic destination.
    SrcNetworkScopeValueValuesEnum: Network scope of the traffic source.

  Fields:
    destAddressGroups: Address groups which should be matched against the
      traffic destination. Maximum number of destination address groups is 10.
    destFqdns: Fully Qualified Domain Name (FQDN) which should be matched
      against traffic destination. Maximum number of destination fqdn allowed
      is 100.
    destIpRanges: CIDR IP address range. Maximum number of destination CIDR IP
      ranges allowed is 5000.
    destNetworkScope: Network scope of the traffic destination.
    destRegionCodes: Region codes whose IP addresses will be used to match for
      destination of traffic. Should be specified as 2 letter country code
      defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of
      dest region codes allowed is 5000.
    destThreatIntelligences: Names of Network Threat Intelligence lists. The
      IPs in these lists will be matched against traffic destination.
    layer4Configs: Pairs of IP protocols and ports that the rule should match.
    srcAddressGroups: Address groups which should be matched against the
      traffic source. Maximum number of source address groups is 10.
    srcFqdns: Fully Qualified Domain Name (FQDN) which should be matched
      against traffic source. Maximum number of source fqdn allowed is 100.
    srcIpRanges: CIDR IP address range. Maximum number of source CIDR IP
      ranges allowed is 5000.
    srcNetworkScope: Network scope of the traffic source.
    srcNetworks: Networks of the traffic source. It can be either a full or
      partial url.
    srcRegionCodes: Region codes whose IP addresses will be used to match for
      source of traffic. Should be specified as 2 letter country code defined
      as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of source
      region codes allowed is 5000.
    srcSecureTags: List of secure tag values, which should be matched at the
      source of the traffic. For INGRESS rule, if all the srcSecureTag are
      INEFFECTIVE, and there is no srcIpRange, this rule will be ignored.
      Maximum number of source tag values allowed is 256.
    srcThreatIntelligences: Names of Network Threat Intelligence lists. The
      IPs in these lists will be matched against traffic source.
  """

  class DestNetworkScopeValueValuesEnum(_messages.Enum):
    r"""Network scope of the traffic destination.

    Values:
      INTERNET: <no description>
      INTRA_VPC: <no description>
      NON_INTERNET: <no description>
      UNSPECIFIED: <no description>
      VPC_NETWORKS: <no description>
    """
    INTERNET = 0
    INTRA_VPC = 1
    NON_INTERNET = 2
    UNSPECIFIED = 3
    VPC_NETWORKS = 4

  class SrcNetworkScopeValueValuesEnum(_messages.Enum):
    r"""Network scope of the traffic source.

    Values:
      INTERNET: <no description>
      INTRA_VPC: <no description>
      NON_INTERNET: <no description>
      UNSPECIFIED: <no description>
      VPC_NETWORKS: <no description>
    """
    INTERNET = 0
    INTRA_VPC = 1
    NON_INTERNET = 2
    UNSPECIFIED = 3
    VPC_NETWORKS = 4

  destAddressGroups = _messages.StringField(1, repeated=True)
  destFqdns = _messages.StringField(2, repeated=True)
  destIpRanges = _messages.StringField(3, repeated=True)
  destNetworkScope = _messages.EnumField('DestNetworkScopeValueValuesEnum', 4)
  destRegionCodes = _messages.StringField(5, repeated=True)
  destThreatIntelligences = _messages.StringField(6, repeated=True)
  layer4Configs = _messages.MessageField('FirewallPolicyRuleMatcherLayer4Config', 7, repeated=True)
  srcAddressGroups = _messages.StringField(8, repeated=True)
  srcFqdns = _messages.StringField(9, repeated=True)
  srcIpRanges = _messages.StringField(10, repeated=True)
  srcNetworkScope = _messages.EnumField('SrcNetworkScopeValueValuesEnum', 11)
  srcNetworks = _messages.StringField(12, repeated=True)
  srcRegionCodes = _messages.StringField(13, repeated=True)
  srcSecureTags = _messages.MessageField('FirewallPolicyRuleSecureTag', 14, repeated=True)
  srcThreatIntelligences = _messages.StringField(15, repeated=True)


class FirewallPolicyRuleMatcherLayer4Config(_messages.Message):
  r"""A FirewallPolicyRuleMatcherLayer4Config object.

  Fields:
    ipProtocol: The IP protocol to which this rule applies. The protocol type
      is required when creating a firewall rule. This value can either be one
      of the following well known protocol strings (tcp, udp, icmp, esp, ah,
      ipip, sctp), or the IP protocol number.
    ports: An optional list of ports to which this rule applies. This field is
      only applicable for UDP or TCP protocol. Each entry must be either an
      integer or a range. If not specified, this rule applies to connections
      through any port. Example inputs include: ["22"], ["80","443"], and
      ["12345-12349"].
  """

  ipProtocol = _messages.StringField(1)
  ports = _messages.StringField(2, repeated=True)


class FirewallPolicyRuleSecureTag(_messages.Message):
  r"""A FirewallPolicyRuleSecureTag object.

  Enums:
    StateValueValuesEnum: [Output Only] State of the secure tag, either
      `EFFECTIVE` or `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is
      deleted or its network is deleted.

  Fields:
    name: Name of the secure tag, created with TagManager's TagValue API.
    state: [Output Only] State of the secure tag, either `EFFECTIVE` or
      `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted or its
      network is deleted.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] State of the secure tag, either `EFFECTIVE` or
    `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted or its
    network is deleted.

    Values:
      EFFECTIVE: <no description>
      INEFFECTIVE: <no description>
    """
    EFFECTIVE = 0
    INEFFECTIVE = 1

  name = _messages.StringField(1)
  state = _messages.EnumField('StateValueValuesEnum', 2)


class FixedOrPercent(_messages.Message):
  r"""Encapsulates numeric value that can be either absolute or relative.

  Fields:
    calculated: [Output Only] Absolute value of VM instances calculated based
      on the specific mode. - If the value is fixed, then the calculated value
      is equal to the fixed value. - If the value is a percent, then the
      calculated value is percent/100 * targetSize. For example, the
      calculated value of a 80% of a managed instance group with 150 instances
      would be (80/100 * 150) = 120 VM instances. If there is a remainder, the
      number is rounded.
    fixed: Specifies a fixed number of VM instances. This must be a positive
      integer.
    percent: Specifies a percentage of instances between 0 to 100%, inclusive.
      For example, specify 80 for 80%.
  """

  calculated = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  fixed = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  percent = _messages.IntegerField(3, variant=_messages.Variant.INT32)


class FlexibleTimeRange(_messages.Message):
  r"""A flexible specification of a time range that has 3 points of
  flexibility: (1) a flexible start time, (2) a flexible end time, (3) a
  flexible duration. It is possible to specify a contradictory time range that
  cannot be matched by any Interval. This causes a validation error.

  Fields:
    endTimeNotEarlierThan: A string attribute.
    endTimeNotLaterThan: A string attribute.
    maxDuration: A string attribute.
    minDuration: A string attribute.
    startTimeNotEarlierThan: A string attribute.
    startTimeNotLaterThan: A string attribute.
  """

  endTimeNotEarlierThan = _messages.StringField(1)
  endTimeNotLaterThan = _messages.StringField(2)
  maxDuration = _messages.StringField(3)
  minDuration = _messages.StringField(4)
  startTimeNotEarlierThan = _messages.StringField(5)
  startTimeNotLaterThan = _messages.StringField(6)


class ForwardingRule(_messages.Message):
  r"""Represents a Forwarding Rule resource. Forwarding rule resources in
  Google Cloud can be either regional or global in scope: * [Global](https://c
  loud.google.com/compute/docs/reference/rest/alpha/globalForwardingRules) * [
  Regional](https://cloud.google.com/compute/docs/reference/rest/alpha/forward
  ingRules) A forwarding rule and its corresponding IP address represent the
  frontend configuration of a Google Cloud load balancer. Forwarding rules can
  also reference target instances and Cloud VPN Classic gateways
  (targetVpnGateway). For more information, read Forwarding rule concepts and
  Using protocol forwarding.

  Enums:
    IPProtocolValueValuesEnum: The IP protocol to which this rule applies. For
      protocol forwarding, valid options are TCP, UDP, ESP, AH, SCTP, ICMP and
      L3_DEFAULT. The valid IP protocols are different for different load
      balancing products as described in [Load balancing
      features](https://cloud.google.com/load-balancing/docs/features#protocol
      s_from_the_load_balancer_to_the_backends).
    ExternalManagedBackendBucketMigrationStateValueValuesEnum: Specifies the
      canary migration state for the backend buckets attached to this
      forwarding rule. Possible values are PREPARE, TEST_BY_PERCENTAGE, and
      TEST_ALL_TRAFFIC. To begin the migration from EXTERNAL to
      EXTERNAL_MANAGED, the state must be changed to PREPARE. The state must
      be changed to TEST_ALL_TRAFFIC before the loadBalancingScheme can be
      changed to EXTERNAL_MANAGED. Optionally, the TEST_BY_PERCENTAGE state
      can be used to migrate traffic to backend buckets attached to this
      forwarding rule by percentage using
      externalManagedBackendBucketMigrationTestingPercentage. Rolling back a
      migration requires the states to be set in reverse order. So changing
      the scheme from EXTERNAL_MANAGED to EXTERNAL requires the state to be
      set to TEST_ALL_TRAFFIC at the same time. Optionally, the
      TEST_BY_PERCENTAGE state can be used to migrate some traffic back to
      EXTERNAL or PREPARE can be used to migrate all traffic back to EXTERNAL.
    IpVersionValueValuesEnum: The IP Version that will be used by this
      forwarding rule. Valid options are IPV4 or IPV6.
    LoadBalancingSchemeValueValuesEnum: Specifies the forwarding rule type.
      For more information about forwarding rules, refer to Forwarding rule
      concepts.
    NetworkTierValueValuesEnum: This signifies the networking tier used for
      configuring this load balancer and can only take the following values:
      PREMIUM, STANDARD. For regional ForwardingRule, the valid values are
      PREMIUM and STANDARD. For GlobalForwardingRule, the valid value is
      PREMIUM. If this field is not specified, it is assumed to be PREMIUM. If
      IPAddress is specified, this value must be equal to the networkTier of
      the Address.
    PscConnectionStatusValueValuesEnum:

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    IPAddress: IP address for which this forwarding rule accepts traffic. When
      a client sends traffic to this IP address, the forwarding rule directs
      the traffic to the referenced target or backendService. While creating a
      forwarding rule, specifying an IPAddress is required under the following
      circumstances: - When the target is set to targetGrpcProxy and
      validateForProxyless is set to true, the IPAddress should be set to
      0.0.0.0. - When the target is a Private Service Connect Google APIs
      bundle, you must specify an IPAddress. Otherwise, you can optionally
      specify an IP address that references an existing static (reserved) IP
      address resource. When omitted, Google Cloud assigns an ephemeral IP
      address. Use one of the following formats to specify an IP address while
      creating a forwarding rule: * IP address number, as in `100.1.2.3` *
      IPv6 address range, as in `2600:1234::/96` * Full resource URL, as in
      https://www.googleapis.com/compute/v1/projects/
      project_id/regions/region/addresses/address-name * Partial URL or by
      name, as in: - projects/project_id/regions/region/addresses/address-name
      - regions/region/addresses/address-name - global/addresses/address-name
      - address-name The forwarding rule's target or backendService, and in
      most cases, also the loadBalancingScheme, determine the type of IP
      address that you can use. For detailed information, see [IP address
      specifications](https://cloud.google.com/load-balancing/docs/forwarding-
      rule-concepts#ip_address_specifications). When reading an IPAddress, the
      API always returns the IP address number.
    IPProtocol: The IP protocol to which this rule applies. For protocol
      forwarding, valid options are TCP, UDP, ESP, AH, SCTP, ICMP and
      L3_DEFAULT. The valid IP protocols are different for different load
      balancing products as described in [Load balancing
      features](https://cloud.google.com/load-balancing/docs/features#protocol
      s_from_the_load_balancer_to_the_backends).
    allPorts: The ports, portRange, and allPorts fields are mutually
      exclusive. Only packets addressed to ports in the specified range will
      be forwarded to the backends configured with this forwarding rule. The
      allPorts field has the following limitations: - It requires that the
      forwarding rule IPProtocol be TCP, UDP, SCTP, or L3_DEFAULT. - It's
      applicable only to the following products: internal passthrough Network
      Load Balancers, backend service-based external passthrough Network Load
      Balancers, and internal and external protocol forwarding. - Set this
      field to true to allow packets addressed to any port or packets lacking
      destination port information (for example, UDP fragments after the first
      fragment) to be forwarded to the backends configured with this
      forwarding rule. The L3_DEFAULT protocol requires allPorts be set to
      true.
    allowGlobalAccess: If set to true, clients can access the internal
      passthrough Network Load Balancers, the regional internal Application
      Load Balancer, and the regional internal proxy Network Load Balancer
      from all regions. If false, only allows access from the local region the
      load balancer is located at. Note that for INTERNAL_MANAGED forwarding
      rules, this field cannot be changed after the forwarding rule is
      created.
    allowPscGlobalAccess: This is used in PSC consumer ForwardingRule to
      control whether the PSC endpoint can be accessed from another region.
    allowPscPacketInjection: This is used in PSC consumer ForwardingRule to
      control whether the producer is allowed to inject packets into the
      consumer's network. If set to true, the target service attachment must
      have tunneling enabled and TunnelingConfig.RoutingMode set to
      PACKET_INJECTION Non-PSC forwarding rules should not use this field.
    backendService: Identifies the backend service to which the forwarding
      rule sends traffic. Required for internal and external passthrough
      Network Load Balancers; must be omitted for all other load balancer
      types.
    baseForwardingRule: [Output Only] The URL for the corresponding base
      forwarding rule. By base forwarding rule, we mean the forwarding rule
      that has the same IP address, protocol, and port settings with the
      current forwarding rule, but without sourceIPRanges specified. Always
      empty if the current forwarding rule does not have sourceIPRanges
      specified.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    externalManagedBackendBucketMigrationState: Specifies the canary migration
      state for the backend buckets attached to this forwarding rule. Possible
      values are PREPARE, TEST_BY_PERCENTAGE, and TEST_ALL_TRAFFIC. To begin
      the migration from EXTERNAL to EXTERNAL_MANAGED, the state must be
      changed to PREPARE. The state must be changed to TEST_ALL_TRAFFIC before
      the loadBalancingScheme can be changed to EXTERNAL_MANAGED. Optionally,
      the TEST_BY_PERCENTAGE state can be used to migrate traffic to backend
      buckets attached to this forwarding rule by percentage using
      externalManagedBackendBucketMigrationTestingPercentage. Rolling back a
      migration requires the states to be set in reverse order. So changing
      the scheme from EXTERNAL_MANAGED to EXTERNAL requires the state to be
      set to TEST_ALL_TRAFFIC at the same time. Optionally, the
      TEST_BY_PERCENTAGE state can be used to migrate some traffic back to
      EXTERNAL or PREPARE can be used to migrate all traffic back to EXTERNAL.
    externalManagedBackendBucketMigrationTestingPercentage: Determines the
      fraction of requests to backend buckets that should be processed by the
      global external Application Load Balancer. The value of this field must
      be in the range [0, 100]. This value can only be set if the
      loadBalancingScheme in the BackendService is set to EXTERNAL (when using
      the classic Application Load Balancer) and the migration state is
      TEST_BY_PERCENTAGE.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a ForwardingRule. Include the fingerprint
      in patch request to ensure that you do not overwrite changes that were
      applied from another concurrent request. To see the latest fingerprint,
      make a get() request to retrieve a ForwardingRule.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ipCollection: Resource reference of a PublicDelegatedPrefix. The PDP must
      be a sub-PDP in EXTERNAL_IPV6_FORWARDING_RULE_CREATION mode. Use one of
      the following formats to specify a sub-PDP when creating an IPv6 NetLB
      forwarding rule using BYOIP: Full resource URL, as in
      https://www.googleapis.com/compute/v1/projects/project_id/regions/region
      /publicDelegatedPrefixes/sub-pdp-name Partial URL, as in: -
      projects/project_id/regions/region/publicDelegatedPrefixes/sub-pdp-name
      - regions/region/publicDelegatedPrefixes/sub-pdp-name
    ipVersion: The IP Version that will be used by this forwarding rule. Valid
      options are IPV4 or IPV6.
    isMirroringCollector: Indicates whether or not this load balancer can be
      used as a collector for packet mirroring. To prevent mirroring loops,
      instances behind this load balancer will not have their traffic mirrored
      even if a PacketMirroring rule applies to them. This can only be set to
      true for load balancers that have their loadBalancingScheme set to
      INTERNAL.
    kind: [Output Only] Type of the resource. Always compute#forwardingRule
      for forwarding rule resources.
    labelFingerprint: A fingerprint for the labels being applied to this
      resource, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a ForwardingRule.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    loadBalancingScheme: Specifies the forwarding rule type. For more
      information about forwarding rules, refer to Forwarding rule concepts.
    metadataFilters: Opaque filter criteria used by load balancer to restrict
      routing configuration to a limited set of xDS compliant clients. In
      their xDS requests to load balancer, xDS clients present node metadata.
      When there is a match, the relevant configuration is made available to
      those proxies. Otherwise, all the resources (e.g. TargetHttpProxy,
      UrlMap) referenced by the ForwardingRule are not visible to those
      proxies. For each metadataFilter in this list, if its
      filterMatchCriteria is set to MATCH_ANY, at least one of the
      filterLabels must match the corresponding label provided in the
      metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of
      its filterLabels must match with corresponding labels provided in the
      metadata. If multiple metadataFilters are specified, all of them need to
      be satisfied in order to be considered a match. metadataFilters
      specified here will be applifed before those specified in the UrlMap
      that this ForwardingRule references. metadataFilters only applies to
      Loadbalancers that have their loadBalancingScheme set to
      INTERNAL_SELF_MANAGED.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash. For Private Service Connect forwarding rules that
      forward traffic to Google APIs, the forwarding rule name must be a 1-20
      characters string with lowercase letters and numbers and must start with
      a letter.
    network: This field is not used for global external load balancing. For
      internal passthrough Network Load Balancers, this field identifies the
      network that the load balanced IP should belong to for this forwarding
      rule. If the subnetwork is specified, the network of the subnetwork will
      be used. If neither subnetwork nor this field is specified, the default
      network will be used. For Private Service Connect forwarding rules that
      forward traffic to Google APIs, a network must be provided.
    networkTier: This signifies the networking tier used for configuring this
      load balancer and can only take the following values: PREMIUM, STANDARD.
      For regional ForwardingRule, the valid values are PREMIUM and STANDARD.
      For GlobalForwardingRule, the valid value is PREMIUM. If this field is
      not specified, it is assumed to be PREMIUM. If IPAddress is specified,
      this value must be equal to the networkTier of the Address.
    noAutomateDnsZone: This is used in PSC consumer ForwardingRule to control
      whether it should try to auto-generate a DNS zone or not. Non-PSC
      forwarding rules do not use this field. Once set, this field is not
      mutable.
    portRange: The ports, portRange, and allPorts fields are mutually
      exclusive. Only packets addressed to ports in the specified range will
      be forwarded to the backends configured with this forwarding rule. The
      portRange field has the following limitations: - It requires that the
      forwarding rule IPProtocol be TCP, UDP, or SCTP, and - It's applicable
      only to the following products: external passthrough Network Load
      Balancers, internal and external proxy Network Load Balancers, internal
      and external Application Load Balancers, external protocol forwarding,
      and Classic VPN. - Some products have restrictions on what ports can be
      used. See port specifications for details. For external forwarding
      rules, two or more forwarding rules cannot use the same [IPAddress,
      IPProtocol] pair, and cannot have overlapping portRanges. For internal
      forwarding rules within the same VPC network, two or more forwarding
      rules cannot use the same [IPAddress, IPProtocol] pair, and cannot have
      overlapping portRanges. @pattern: \\d+(?:-\\d+)?
    ports: The ports, portRange, and allPorts fields are mutually exclusive.
      Only packets addressed to ports in the specified range will be forwarded
      to the backends configured with this forwarding rule. The ports field
      has the following limitations: - It requires that the forwarding rule
      IPProtocol be TCP, UDP, or SCTP, and - It's applicable only to the
      following products: internal passthrough Network Load Balancers, backend
      service-based external passthrough Network Load Balancers, and internal
      protocol forwarding. - You can specify a list of up to five ports by
      number, separated by commas. The ports can be contiguous or
      discontiguous. For external forwarding rules, two or more forwarding
      rules cannot use the same [IPAddress, IPProtocol] pair if they share at
      least one port number. For internal forwarding rules within the same VPC
      network, two or more forwarding rules cannot use the same [IPAddress,
      IPProtocol] pair if they share at least one port number. @pattern:
      \\d+(?:-\\d+)?
    pscConnectionId: [Output Only] The PSC connection id of the PSC forwarding
      rule.
    pscConnectionStatus: A PscConnectionStatusValueValuesEnum attribute.
    region: [Output Only] URL of the region where the regional forwarding rule
      resides. This field is not applicable to global forwarding rules. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serviceDirectoryRegistrations: Service Directory resources to register
      this forwarding rule with. Currently, only supports a single Service
      Directory resource.
    serviceLabel: An optional prefix to the service name for this forwarding
      rule. If specified, the prefix is the first label of the fully qualified
      service name. The label must be 1-63 characters long, and comply with
      RFC1035. Specifically, the label must be 1-63 characters long and match
      the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the
      first character must be a lowercase letter, and all following characters
      must be a dash, lowercase letter, or digit, except the last character,
      which cannot be a dash. This field is only used for internal load
      balancing.
    serviceName: [Output Only] The internal fully qualified service name for
      this forwarding rule. This field is only used for internal load
      balancing.
    sourceIpRanges: If not empty, this forwarding rule will only forward the
      traffic when the source IP address matches one of the IP addresses or
      CIDR ranges set here. Note that a forwarding rule can only have up to 64
      source IP ranges, and this field can only be used with a regional
      forwarding rule whose scheme is EXTERNAL. Each source_ip_range entry
      should be either an IP address (for example, 1.2.3.4) or a CIDR range
      (for example, 1.2.3.0/24).
    subnetwork: This field identifies the subnetwork that the load balanced IP
      should belong to for this forwarding rule, used with internal load
      balancers and external passthrough Network Load Balancers with IPv6. If
      the network specified is in auto subnet mode, this field is optional.
      However, a subnetwork must be specified if the network is in custom
      subnet mode or when creating external forwarding rule with IPv6.
    target: The URL of the target resource to receive the matched traffic. For
      regional forwarding rules, this target must be in the same region as the
      forwarding rule. For global forwarding rules, this target must be a
      global load balancing resource. The forwarded traffic must be of a type
      appropriate to the target object. - For load balancers, see the "Target"
      column in [Port specifications](https://cloud.google.com/load-
      balancing/docs/forwarding-rule-concepts#ip_address_specifications). -
      For Private Service Connect forwarding rules that forward traffic to
      Google APIs, provide the name of a supported Google API bundle: - vpc-sc
      - APIs that support VPC Service Controls. - all-apis - All supported
      Google APIs. - For Private Service Connect forwarding rules that forward
      traffic to managed services, the target must be a service attachment.
      The target is not mutable once set as a service attachment.
  """

  class ExternalManagedBackendBucketMigrationStateValueValuesEnum(_messages.Enum):
    r"""Specifies the canary migration state for the backend buckets attached
    to this forwarding rule. Possible values are PREPARE, TEST_BY_PERCENTAGE,
    and TEST_ALL_TRAFFIC. To begin the migration from EXTERNAL to
    EXTERNAL_MANAGED, the state must be changed to PREPARE. The state must be
    changed to TEST_ALL_TRAFFIC before the loadBalancingScheme can be changed
    to EXTERNAL_MANAGED. Optionally, the TEST_BY_PERCENTAGE state can be used
    to migrate traffic to backend buckets attached to this forwarding rule by
    percentage using externalManagedBackendBucketMigrationTestingPercentage.
    Rolling back a migration requires the states to be set in reverse order.
    So changing the scheme from EXTERNAL_MANAGED to EXTERNAL requires the
    state to be set to TEST_ALL_TRAFFIC at the same time. Optionally, the
    TEST_BY_PERCENTAGE state can be used to migrate some traffic back to
    EXTERNAL or PREPARE can be used to migrate all traffic back to EXTERNAL.

    Values:
      PREPARE: <no description>
      TEST_ALL_TRAFFIC: <no description>
      TEST_BY_PERCENTAGE: <no description>
    """
    PREPARE = 0
    TEST_ALL_TRAFFIC = 1
    TEST_BY_PERCENTAGE = 2

  class IPProtocolValueValuesEnum(_messages.Enum):
    r"""The IP protocol to which this rule applies. For protocol forwarding,
    valid options are TCP, UDP, ESP, AH, SCTP, ICMP and L3_DEFAULT. The valid
    IP protocols are different for different load balancing products as
    described in [Load balancing features](https://cloud.google.com/load-
    balancing/docs/features#protocols_from_the_load_balancer_to_the_backends).

    Values:
      AH: <no description>
      ALL: <no description>
      ESP: <no description>
      ICMP: <no description>
      L3_DEFAULT: <no description>
      SCTP: <no description>
      TCP: <no description>
      UDP: <no description>
    """
    AH = 0
    ALL = 1
    ESP = 2
    ICMP = 3
    L3_DEFAULT = 4
    SCTP = 5
    TCP = 6
    UDP = 7

  class IpVersionValueValuesEnum(_messages.Enum):
    r"""The IP Version that will be used by this forwarding rule. Valid
    options are IPV4 or IPV6.

    Values:
      IPV4: <no description>
      IPV6: <no description>
      UNSPECIFIED_VERSION: <no description>
    """
    IPV4 = 0
    IPV6 = 1
    UNSPECIFIED_VERSION = 2

  class LoadBalancingSchemeValueValuesEnum(_messages.Enum):
    r"""Specifies the forwarding rule type. For more information about
    forwarding rules, refer to Forwarding rule concepts.

    Values:
      EXTERNAL: <no description>
      EXTERNAL_MANAGED: <no description>
      INTERNAL: <no description>
      INTERNAL_MANAGED: <no description>
      INTERNAL_SELF_MANAGED: <no description>
      INVALID: <no description>
    """
    EXTERNAL = 0
    EXTERNAL_MANAGED = 1
    INTERNAL = 2
    INTERNAL_MANAGED = 3
    INTERNAL_SELF_MANAGED = 4
    INVALID = 5

  class NetworkTierValueValuesEnum(_messages.Enum):
    r"""This signifies the networking tier used for configuring this load
    balancer and can only take the following values: PREMIUM, STANDARD. For
    regional ForwardingRule, the valid values are PREMIUM and STANDARD. For
    GlobalForwardingRule, the valid value is PREMIUM. If this field is not
    specified, it is assumed to be PREMIUM. If IPAddress is specified, this
    value must be equal to the networkTier of the Address.

    Values:
      FIXED_STANDARD: Public internet quality with fixed bandwidth.
      PREMIUM: High quality, Google-grade network tier, support for all
        networking products.
      SELECT: Price competitive network tier, support for all networking
        products.
      STANDARD: Public internet quality, only limited support for other
        networking products.
      STANDARD_OVERRIDES_FIXED_STANDARD: (Output only) Temporary tier for
        FIXED_STANDARD when fixed standard tier is expired or not configured.
    """
    FIXED_STANDARD = 0
    PREMIUM = 1
    SELECT = 2
    STANDARD = 3
    STANDARD_OVERRIDES_FIXED_STANDARD = 4

  class PscConnectionStatusValueValuesEnum(_messages.Enum):
    r"""PscConnectionStatusValueValuesEnum enum type.

    Values:
      ACCEPTED: The connection has been accepted by the producer.
      CLOSED: The connection has been closed by the producer and will not
        serve traffic going forward.
      NEEDS_ATTENTION: The connection has been accepted by the producer, but
        the producer needs to take further action before the forwarding rule
        can serve traffic.
      PENDING: The connection is pending acceptance by the producer.
      REJECTED: The connection has been rejected by the producer.
      STATUS_UNSPECIFIED: <no description>
    """
    ACCEPTED = 0
    CLOSED = 1
    NEEDS_ATTENTION = 2
    PENDING = 3
    REJECTED = 4
    STATUS_UNSPECIFIED = 5

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  IPAddress = _messages.StringField(1)
  IPProtocol = _messages.EnumField('IPProtocolValueValuesEnum', 2)
  allPorts = _messages.BooleanField(3)
  allowGlobalAccess = _messages.BooleanField(4)
  allowPscGlobalAccess = _messages.BooleanField(5)
  allowPscPacketInjection = _messages.BooleanField(6)
  backendService = _messages.StringField(7)
  baseForwardingRule = _messages.StringField(8)
  creationTimestamp = _messages.StringField(9)
  description = _messages.StringField(10)
  externalManagedBackendBucketMigrationState = _messages.EnumField('ExternalManagedBackendBucketMigrationStateValueValuesEnum', 11)
  externalManagedBackendBucketMigrationTestingPercentage = _messages.FloatField(12, variant=_messages.Variant.FLOAT)
  fingerprint = _messages.BytesField(13)
  id = _messages.IntegerField(14, variant=_messages.Variant.UINT64)
  ipCollection = _messages.StringField(15)
  ipVersion = _messages.EnumField('IpVersionValueValuesEnum', 16)
  isMirroringCollector = _messages.BooleanField(17)
  kind = _messages.StringField(18, default='compute#forwardingRule')
  labelFingerprint = _messages.BytesField(19)
  labels = _messages.MessageField('LabelsValue', 20)
  loadBalancingScheme = _messages.EnumField('LoadBalancingSchemeValueValuesEnum', 21)
  metadataFilters = _messages.MessageField('MetadataFilter', 22, repeated=True)
  name = _messages.StringField(23)
  network = _messages.StringField(24)
  networkTier = _messages.EnumField('NetworkTierValueValuesEnum', 25)
  noAutomateDnsZone = _messages.BooleanField(26)
  portRange = _messages.StringField(27)
  ports = _messages.StringField(28, repeated=True)
  pscConnectionId = _messages.IntegerField(29, variant=_messages.Variant.UINT64)
  pscConnectionStatus = _messages.EnumField('PscConnectionStatusValueValuesEnum', 30)
  region = _messages.StringField(31)
  selfLink = _messages.StringField(32)
  selfLinkWithId = _messages.StringField(33)
  serviceDirectoryRegistrations = _messages.MessageField('ForwardingRuleServiceDirectoryRegistration', 34, repeated=True)
  serviceLabel = _messages.StringField(35)
  serviceName = _messages.StringField(36)
  sourceIpRanges = _messages.StringField(37, repeated=True)
  subnetwork = _messages.StringField(38)
  target = _messages.StringField(39)


class ForwardingRuleAggregatedList(_messages.Message):
  r"""A ForwardingRuleAggregatedList object.

  Messages:
    ItemsValue: A list of ForwardingRulesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ForwardingRulesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#forwardingRuleAggregatedList for lists of forwarding rules.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of ForwardingRulesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        addresses.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A ForwardingRulesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ForwardingRulesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#forwardingRuleAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class ForwardingRuleList(_messages.Message):
  r"""Contains a list of ForwardingRule resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ForwardingRule resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ForwardingRule', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#forwardingRuleList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ForwardingRuleReference(_messages.Message):
  r"""A ForwardingRuleReference object.

  Fields:
    forwardingRule: A string attribute.
  """

  forwardingRule = _messages.StringField(1)


class ForwardingRuleServiceDirectoryRegistration(_messages.Message):
  r"""Describes the auto-registration of the forwarding rule to Service
  Directory. The region and project of the Service Directory resource
  generated from this registration will be the same as this forwarding rule.

  Fields:
    namespace: Service Directory namespace to register the forwarding rule
      under.
    service: Service Directory service to register the forwarding rule under.
    serviceDirectoryRegion: [Optional] Service Directory region to register
      this global forwarding rule under. Default to "us-central1". Only used
      for PSC for Google APIs. All PSC for Google APIs forwarding rules on the
      same network should use the same Service Directory region.
  """

  namespace = _messages.StringField(1)
  service = _messages.StringField(2)
  serviceDirectoryRegion = _messages.StringField(3)


class ForwardingRulesScopedList(_messages.Message):
  r"""A ForwardingRulesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of forwarding
      rules when the list is empty.

  Fields:
    forwardingRules: A list of forwarding rules contained in this scope.
    warning: Informational warning which replaces the list of forwarding rules
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of forwarding rules when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  forwardingRules = _messages.MessageField('ForwardingRule', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class FutureReservation(_messages.Message):
  r"""A FutureReservation object.

  Enums:
    DeploymentTypeValueValuesEnum: Type of the deployment requested as part of
      future reservation.
    PlanningStatusValueValuesEnum: Planning state before being submitted for
      evaluation
    ReservationModeValueValuesEnum: The reservation mode which determines
      reservation-termination behavior and expected pricing.
    SchedulingTypeValueValuesEnum: Maintenance information for this
      reservation

  Fields:
    aggregateReservation: Aggregate reservation details for the future
      reservation.
    autoCreatedReservationsDeleteTime: Future timestamp when the FR auto-
      created reservations will be deleted by Compute Engine. Format of this
      field must be a valid
      href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value.
    autoCreatedReservationsDuration: Specifies the duration of auto-created
      reservations. It represents relative time to future reservation
      start_time when auto-created reservations will be automatically deleted
      by Compute Engine. Duration time unit is represented as a count of
      seconds and fractions of seconds at nanosecond resolution.
    autoDeleteAutoCreatedReservations: Setting for enabling or disabling
      automatic deletion for auto-created reservation. If set to true, auto-
      created reservations will be deleted at Future Reservation's end time
      (default) or at user's defined timestamp if any of the
      [auto_created_reservations_delete_time,
      auto_created_reservations_duration] values is specified. For keeping
      auto-created reservation indefinitely, this value should be set to
      false.
    commitmentInfo: If not present, then FR will not deliver a new commitment
      or update an existing commitment.
    creationTimestamp: [Output Only] The creation timestamp for this future
      reservation in RFC3339 text format.
    deploymentType: Type of the deployment requested as part of future
      reservation.
    description: An optional description of this resource. Provide this
      property when you create the future reservation.
    enableEmergentMaintenance: Indicates if this group of VMs have emergent
      maintenance enabled.
    id: [Output Only] A unique identifier for this future reservation. The
      server defines this identifier.
    kind: [Output Only] Type of the resource. Always compute#futureReservation
      for future reservations.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    namePrefix: Name prefix for the reservations to be created at the time of
      delivery. The name prefix must comply with RFC1035. Maximum allowed
      length for name prefix is 20. Automatically created reservations name
      format will be -date-####.
    planningStatus: Planning state before being submitted for evaluation
    reservationMode: The reservation mode which determines reservation-
      termination behavior and expected pricing.
    reservationName: Name of reservations where the capacity is provisioned at
      the time of delivery of future reservations. If the reservation with the
      given name does not exist already, it is created automatically at the
      time of Approval with INACTIVE state till specified start-time. Either
      provide the reservation_name or a name_prefix.
    schedulingType: Maintenance information for this reservation
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    shareSettings: List of Projects/Folders to share with.
    specificReservationRequired: Indicates whether the auto-created
      reservation can be consumed by VMs with affinity for "any" reservation.
      If the field is set, then only VMs that target the reservation by name
      can consume from the delivered reservation.
    specificSkuProperties: Future Reservation configuration to indicate
      instance properties and total count.
    status: [Output only] Status of the Future Reservation
    timeWindow: Time window for this Future Reservation.
    zone: [Output Only] URL of the Zone where this future reservation resides.
  """

  class DeploymentTypeValueValuesEnum(_messages.Enum):
    r"""Type of the deployment requested as part of future reservation.

    Values:
      DENSE: The reserved capacity is made up of densely deployed reservation
        blocks.
      DEPLOYMENT_TYPE_UNSPECIFIED: <no description>
      FLEXIBLE: The reserved capacity is made up of highly flexible, logical
        reservation blocks.
    """
    DENSE = 0
    DEPLOYMENT_TYPE_UNSPECIFIED = 1
    FLEXIBLE = 2

  class PlanningStatusValueValuesEnum(_messages.Enum):
    r"""Planning state before being submitted for evaluation

    Values:
      DRAFT: Future Reservation is being drafted.
      PLANNING_STATUS_UNSPECIFIED: <no description>
      SUBMITTED: Future Reservation has been submitted for evaluation by GCP.
    """
    DRAFT = 0
    PLANNING_STATUS_UNSPECIFIED = 1
    SUBMITTED = 2

  class ReservationModeValueValuesEnum(_messages.Enum):
    r"""The reservation mode which determines reservation-termination behavior
    and expected pricing.

    Values:
      CALENDAR: The delivered reservations will delivered at specified start
        time and terminated at specified end time along with terminating the
        VMs running on it.
      DEFAULT: The delivered reservations do not terminate VMs at the end of
        reservations. This is default mode.
      RESERVATION_MODE_UNSPECIFIED: <no description>
    """
    CALENDAR = 0
    DEFAULT = 1
    RESERVATION_MODE_UNSPECIFIED = 2

  class SchedulingTypeValueValuesEnum(_messages.Enum):
    r"""Maintenance information for this reservation

    Values:
      GROUPED: Maintenance on all reserved instances in the reservation is
        synchronized.
      GROUP_MAINTENANCE_TYPE_UNSPECIFIED: Unknown maintenance type.
      INDEPENDENT: Maintenance is not synchronized for this reservation.
        Instead, each instance has its own maintenance window.
    """
    GROUPED = 0
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 1
    INDEPENDENT = 2

  aggregateReservation = _messages.MessageField('AllocationAggregateReservation', 1)
  autoCreatedReservationsDeleteTime = _messages.StringField(2)
  autoCreatedReservationsDuration = _messages.MessageField('Duration', 3)
  autoDeleteAutoCreatedReservations = _messages.BooleanField(4)
  commitmentInfo = _messages.MessageField('FutureReservationCommitmentInfo', 5)
  creationTimestamp = _messages.StringField(6)
  deploymentType = _messages.EnumField('DeploymentTypeValueValuesEnum', 7)
  description = _messages.StringField(8)
  enableEmergentMaintenance = _messages.BooleanField(9)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(11, default='compute#futureReservation')
  name = _messages.StringField(12)
  namePrefix = _messages.StringField(13)
  planningStatus = _messages.EnumField('PlanningStatusValueValuesEnum', 14)
  reservationMode = _messages.EnumField('ReservationModeValueValuesEnum', 15)
  reservationName = _messages.StringField(16)
  schedulingType = _messages.EnumField('SchedulingTypeValueValuesEnum', 17)
  selfLink = _messages.StringField(18)
  selfLinkWithId = _messages.StringField(19)
  shareSettings = _messages.MessageField('ShareSettings', 20)
  specificReservationRequired = _messages.BooleanField(21)
  specificSkuProperties = _messages.MessageField('FutureReservationSpecificSKUProperties', 22)
  status = _messages.MessageField('FutureReservationStatus', 23)
  timeWindow = _messages.MessageField('FutureReservationTimeWindow', 24)
  zone = _messages.StringField(25)


class FutureReservationCommitmentInfo(_messages.Message):
  r"""A FutureReservationCommitmentInfo object.

  Enums:
    CommitmentPlanValueValuesEnum: Indicates if a Commitment needs to be
      created as part of FR delivery. If this field is not present, then no
      commitment needs to be created.
    PreviousCommitmentTermsValueValuesEnum: Only applicable if FR is
      delivering to the same reservation. If set, all parent commitments will
      be extended to match the end date of the plan for this commitment.

  Fields:
    commitmentName: name of the commitment where capacity is being delivered
      to.
    commitmentPlan: Indicates if a Commitment needs to be created as part of
      FR delivery. If this field is not present, then no commitment needs to
      be created.
    previousCommitmentTerms: Only applicable if FR is delivering to the same
      reservation. If set, all parent commitments will be extended to match
      the end date of the plan for this commitment.
  """

  class CommitmentPlanValueValuesEnum(_messages.Enum):
    r"""Indicates if a Commitment needs to be created as part of FR delivery.
    If this field is not present, then no commitment needs to be created.

    Values:
      INVALID: <no description>
      THIRTY_SIX_MONTH: <no description>
      TWELVE_MONTH: <no description>
    """
    INVALID = 0
    THIRTY_SIX_MONTH = 1
    TWELVE_MONTH = 2

  class PreviousCommitmentTermsValueValuesEnum(_messages.Enum):
    r"""Only applicable if FR is delivering to the same reservation. If set,
    all parent commitments will be extended to match the end date of the plan
    for this commitment.

    Values:
      EXTEND: All associated parent Committed Used Discount(s) end-date/term
        will be extended to the end-time of this future reservation. Default
        is to extend previous commitment(s) time to the end_time of the
        reservation.
      PREVIOUSCOMMITMENTTERM_UNSPECIFIED: No changes to associated parents
        Committed Used Discount(s) terms.
    """
    EXTEND = 0
    PREVIOUSCOMMITMENTTERM_UNSPECIFIED = 1

  commitmentName = _messages.StringField(1)
  commitmentPlan = _messages.EnumField('CommitmentPlanValueValuesEnum', 2)
  previousCommitmentTerms = _messages.EnumField('PreviousCommitmentTermsValueValuesEnum', 3)


class FutureReservationSpecificSKUProperties(_messages.Message):
  r"""A FutureReservationSpecificSKUProperties object.

  Fields:
    instanceProperties: Properties of the SKU instances being reserved.
    sourceInstanceTemplate: The instance template that will be used to
      populate the ReservedInstanceProperties of the future reservation
    totalCount: Total number of instances for which capacity assurance is
      requested at a future time period.
  """

  instanceProperties = _messages.MessageField('AllocationSpecificSKUAllocationReservedInstanceProperties', 1)
  sourceInstanceTemplate = _messages.StringField(2)
  totalCount = _messages.IntegerField(3)


class FutureReservationStatus(_messages.Message):
  r"""[Output only] Represents status related to the future reservation.

  Enums:
    AmendmentStatusValueValuesEnum: [Output Only] The current status of the
      requested amendment.
    ProcurementStatusValueValuesEnum: Current state of this Future Reservation

  Fields:
    amendmentStatus: [Output Only] The current status of the requested
      amendment.
    autoCreatedReservations: Fully qualified urls of the automatically created
      reservations at start_time.
    existingMatchingUsageInfo: [Output Only] Represents the existing matching
      usage for the future reservation.
    fulfilledCount: This count indicates the fulfilled capacity so far. This
      is set during "PROVISIONING" state. This count also includes capacity
      delivered as part of existing matching reservations.
    lastKnownGoodState: [Output Only] This field represents the future
      reservation before an amendment was requested. If the amendment is
      declined, the Future Reservation will be reverted to the last known good
      state. The last known good state is not set when updating a future
      reservation whose Procurement Status is DRAFTING.
    lockTime: Time when Future Reservation would become LOCKED, after which no
      modifications to Future Reservation will be allowed. Applicable only
      after the Future Reservation is in the APPROVED state. The lock_time is
      an RFC3339 string. The procurement_status will transition to PROCURING
      state at this time.
    procurementStatus: Current state of this Future Reservation
    specificSkuProperties: A FutureReservationStatusSpecificSKUProperties
      attribute.
  """

  class AmendmentStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current status of the requested amendment.

    Values:
      AMENDMENT_APPROVED: The requested amendment to the Future Resevation has
        been approved and applied by GCP.
      AMENDMENT_DECLINED: The requested amendment to the Future Reservation
        has been declined by GCP and the original state was restored.
      AMENDMENT_IN_REVIEW: The requested amendment to the Future Reservation
        is currently being reviewd by GCP.
      AMENDMENT_STATUS_UNSPECIFIED: <no description>
    """
    AMENDMENT_APPROVED = 0
    AMENDMENT_DECLINED = 1
    AMENDMENT_IN_REVIEW = 2
    AMENDMENT_STATUS_UNSPECIFIED = 3

  class ProcurementStatusValueValuesEnum(_messages.Enum):
    r"""Current state of this Future Reservation

    Values:
      APPROVED: Future reservation is approved by GCP.
      CANCELLED: Future reservation is cancelled by the customer.
      COMMITTED: Future reservation is committed by the customer.
      DECLINED: Future reservation is rejected by GCP.
      DRAFTING: Related status for PlanningStatus.Draft. Transitions to
        PENDING_APPROVAL upon user submitting FR.
      FAILED: Future reservation failed. No additional reservations were
        provided.
      FAILED_PARTIALLY_FULFILLED: Future reservation is partially fulfilled.
        Additional reservations were provided but did not reach total_count
        reserved instance slots.
      FULFILLED: Future reservation is fulfilled completely.
      PENDING_AMENDMENT_APPROVAL: An Amendment to the Future Reservation has
        been requested. If the Amendment is declined, the Future Reservation
        will be restored to the last known good state.
      PENDING_APPROVAL: Future reservation is pending approval by GCP.
      PROCUREMENT_STATUS_UNSPECIFIED: <no description>
      PROCURING: Future reservation is being procured by GCP. Beyond this
        point, Future reservation is locked and no further modifications are
        allowed.
      PROVISIONING: Future reservation capacity is being provisioned. This
        state will be entered after start_time, while reservations are being
        created to provide total_count reserved instance slots. This state
        will not persist past start_time + 24h.
    """
    APPROVED = 0
    CANCELLED = 1
    COMMITTED = 2
    DECLINED = 3
    DRAFTING = 4
    FAILED = 5
    FAILED_PARTIALLY_FULFILLED = 6
    FULFILLED = 7
    PENDING_AMENDMENT_APPROVAL = 8
    PENDING_APPROVAL = 9
    PROCUREMENT_STATUS_UNSPECIFIED = 10
    PROCURING = 11
    PROVISIONING = 12

  amendmentStatus = _messages.EnumField('AmendmentStatusValueValuesEnum', 1)
  autoCreatedReservations = _messages.StringField(2, repeated=True)
  existingMatchingUsageInfo = _messages.MessageField('FutureReservationStatusExistingMatchingUsageInfo', 3)
  fulfilledCount = _messages.IntegerField(4)
  lastKnownGoodState = _messages.MessageField('FutureReservationStatusLastKnownGoodState', 5)
  lockTime = _messages.StringField(6)
  procurementStatus = _messages.EnumField('ProcurementStatusValueValuesEnum', 7)
  specificSkuProperties = _messages.MessageField('FutureReservationStatusSpecificSKUProperties', 8)


class FutureReservationStatusExistingMatchingUsageInfo(_messages.Message):
  r"""[Output Only] Represents the existing matching usage for the future
  reservation.

  Fields:
    count: Count to represent min(FR total_count,
      matching_reserved_capacity+matching_unreserved_instances)
    timestamp: Timestamp when the matching usage was calculated
  """

  count = _messages.IntegerField(1)
  timestamp = _messages.StringField(2)


class FutureReservationStatusLastKnownGoodState(_messages.Message):
  r"""The state that the future reservation will be reverted to should the
  amendment be declined.

  Enums:
    ProcurementStatusValueValuesEnum: [Output Only] The status of the last
      known good state for the Future Reservation.

  Fields:
    description: [Output Only] The description of the FutureReservation before
      an amendment was requested.
    existingMatchingUsageInfo: [Output Only] Represents the matching usage for
      the future reservation before an amendment was requested.
    futureReservationSpecs: A
      FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
      attribute.
    lockTime: [Output Only] The lock time of the FutureReservation before an
      amendment was requested.
    namePrefix: [Output Only] The name prefix of the Future Reservation before
      an amendment was requested.
    procurementStatus: [Output Only] The status of the last known good state
      for the Future Reservation.
  """

  class ProcurementStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the last known good state for the Future
    Reservation.

    Values:
      APPROVED: Future reservation is approved by GCP.
      CANCELLED: Future reservation is cancelled by the customer.
      COMMITTED: Future reservation is committed by the customer.
      DECLINED: Future reservation is rejected by GCP.
      DRAFTING: Related status for PlanningStatus.Draft. Transitions to
        PENDING_APPROVAL upon user submitting FR.
      FAILED: Future reservation failed. No additional reservations were
        provided.
      FAILED_PARTIALLY_FULFILLED: Future reservation is partially fulfilled.
        Additional reservations were provided but did not reach total_count
        reserved instance slots.
      FULFILLED: Future reservation is fulfilled completely.
      PENDING_AMENDMENT_APPROVAL: An Amendment to the Future Reservation has
        been requested. If the Amendment is declined, the Future Reservation
        will be restored to the last known good state.
      PENDING_APPROVAL: Future reservation is pending approval by GCP.
      PROCUREMENT_STATUS_UNSPECIFIED: <no description>
      PROCURING: Future reservation is being procured by GCP. Beyond this
        point, Future reservation is locked and no further modifications are
        allowed.
      PROVISIONING: Future reservation capacity is being provisioned. This
        state will be entered after start_time, while reservations are being
        created to provide total_count reserved instance slots. This state
        will not persist past start_time + 24h.
    """
    APPROVED = 0
    CANCELLED = 1
    COMMITTED = 2
    DECLINED = 3
    DRAFTING = 4
    FAILED = 5
    FAILED_PARTIALLY_FULFILLED = 6
    FULFILLED = 7
    PENDING_AMENDMENT_APPROVAL = 8
    PENDING_APPROVAL = 9
    PROCUREMENT_STATUS_UNSPECIFIED = 10
    PROCURING = 11
    PROVISIONING = 12

  description = _messages.StringField(1)
  existingMatchingUsageInfo = _messages.MessageField('FutureReservationStatusExistingMatchingUsageInfo', 2)
  futureReservationSpecs = _messages.MessageField('FutureReservationStatusLastKnownGoodStateFutureReservationSpecs', 3)
  lockTime = _messages.StringField(4)
  namePrefix = _messages.StringField(5)
  procurementStatus = _messages.EnumField('ProcurementStatusValueValuesEnum', 6)


class FutureReservationStatusLastKnownGoodStateFutureReservationSpecs(_messages.Message):
  r"""The properties of the last known good state for the Future Reservation.

  Fields:
    shareSettings: [Output Only] The previous share settings of the Future
      Reservation.
    specificSkuProperties: [Output Only] The previous instance related
      properties of the Future Reservation.
    timeWindow: [Output Only] The previous time window of the Future
      Reservation.
  """

  shareSettings = _messages.MessageField('ShareSettings', 1)
  specificSkuProperties = _messages.MessageField('FutureReservationSpecificSKUProperties', 2)
  timeWindow = _messages.MessageField('FutureReservationTimeWindow', 3)


class FutureReservationStatusSpecificSKUProperties(_messages.Message):
  r"""Properties to be set for the Future Reservation.

  Fields:
    sourceInstanceTemplateId: ID of the instance template used to populate the
      Future Reservation properties.
  """

  sourceInstanceTemplateId = _messages.StringField(1)


class FutureReservationTimeWindow(_messages.Message):
  r"""A FutureReservationTimeWindow object.

  Fields:
    duration: A Duration attribute.
    endTime: A string attribute.
    startTime: Start time of the Future Reservation. The start_time is an
      RFC3339 string.
  """

  duration = _messages.MessageField('Duration', 1)
  endTime = _messages.StringField(2)
  startTime = _messages.StringField(3)


class FutureReservationsAggregatedListResponse(_messages.Message):
  r"""Contains a list of future reservations.

  Messages:
    ItemsValue: A list of Future reservation resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Future reservation resources.
    kind: [Output Only] Type of resource. Always
      compute#futureReservationsAggregatedListResponse for future resevation
      aggregated list response.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of Future reservation resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of future
        reservations.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A FutureReservationsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('FutureReservationsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#futureReservationsAggregatedListResponse')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class FutureReservationsListResponse(_messages.Message):
  r"""A FutureReservationsListResponse object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A list of future reservation resources.
    kind: [Output Only] Type of resource.Always
      compute#FutureReservationsListResponse for lists of reservations
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('FutureReservation', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#futureReservationsListResponse')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class FutureReservationsScopedList(_messages.Message):
  r"""A FutureReservationsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of future
      reservations when the list is empty.

  Fields:
    futureReservations: A list of future reservations contained in this scope.
    warning: Informational warning which replaces the list of future
      reservations when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of future reservations
    when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  futureReservations = _messages.MessageField('FutureReservation', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class FutureResourcesRecommendation(_messages.Message):
  r"""Recommendation for single resources specification, to be created in the
  future.

  Enums:
    RecommendationTypeValueValuesEnum: Type of recommendation. Currently only
      FUTURE_RESERVATION is supported.

  Messages:
    OtherLocationsValue: List of locations in the request scope that were not
      recommended. Keys of the map are zones, in format 'zones/'. The values
      are status information indicating the recommendation status.

  Fields:
    endTime: A string attribute.
    location: The advised location for resource usage. When a zone, in format
      'zones/'. If not set, it means that no location is recommended - see
      other_locations for details.
    otherLocations: List of locations in the request scope that were not
      recommended. Keys of the map are zones, in format 'zones/'. The values
      are status information indicating the recommendation status.
    recommendationId: Unique id of the recommendation, a UUID string generated
      by the API.
    recommendationType: Type of recommendation. Currently only
      FUTURE_RESERVATION is supported.
    startTime: A string attribute.
  """

  class RecommendationTypeValueValuesEnum(_messages.Enum):
    r"""Type of recommendation. Currently only FUTURE_RESERVATION is
    supported.

    Values:
      FUTURE_RESERVATION: A Future Reservation is recommended.
      RECOMMENDATION_TYPE_UNSPECIFIED: Default value, unused.
    """
    FUTURE_RESERVATION = 0
    RECOMMENDATION_TYPE_UNSPECIFIED = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class OtherLocationsValue(_messages.Message):
    r"""List of locations in the request scope that were not recommended. Keys
    of the map are zones, in format 'zones/'. The values are status
    information indicating the recommendation status.

    Messages:
      AdditionalProperty: An additional property for a OtherLocationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type OtherLocationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a OtherLocationsValue object.

      Fields:
        key: Name of the additional property.
        value: A FutureResourcesRecommendationOtherLocation attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('FutureResourcesRecommendationOtherLocation', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  endTime = _messages.StringField(1)
  location = _messages.StringField(2)
  otherLocations = _messages.MessageField('OtherLocationsValue', 3)
  recommendationId = _messages.StringField(4)
  recommendationType = _messages.EnumField('RecommendationTypeValueValuesEnum', 5)
  startTime = _messages.StringField(6)


class FutureResourcesRecommendationOtherLocation(_messages.Message):
  r"""Information about recommendation status for locations that were allowed
  but not used by the response.

  Enums:
    StatusValueValuesEnum: Status of recommendation in this location.

  Fields:
    details: Details (human readable) describing the situation. For example,
      if status is CONDITION_NOT_MET, then details contain information about
      the parameters of the time window that did not meet the required
      conditions.
    status: Status of recommendation in this location.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""Status of recommendation in this location.

    Values:
      CONDITIONS_NOT_MET: The requested resources are offered in this location
        but the requested time window is does not meet the required
        conditions.
      NOT_SUPPORTED: The requested resources are not offered in this location.
        Retrying the request will not change this status.
      NO_CAPACITY: The requested resources are offered in this location and
        the requested time window is accepted but there is no capacity within
        the requested time window.
      OTHER_LOCATION_STATUS_UNDEFINED: Default value, unused.
      RECOMMENDED: The requested resources are offered in this location and it
        is possible to request them. However, another location was better and
        was recommended.
    """
    CONDITIONS_NOT_MET = 0
    NOT_SUPPORTED = 1
    NO_CAPACITY = 2
    OTHER_LOCATION_STATUS_UNDEFINED = 3
    RECOMMENDED = 4

  details = _messages.StringField(1)
  status = _messages.EnumField('StatusValueValuesEnum', 2)


class FutureResourcesSpec(_messages.Message):
  r"""Specification of resources to be created at some time in the future
  within an optionally specified set of locations, and within the specified
  time range.

  Enums:
    DeploymentTypeValueValuesEnum: Indicates if the reservation allocation
      strategy is static (DENSE) or dynamic (STANDARD). Defaults to DENSE.

  Fields:
    deploymentType: Indicates if the reservation allocation strategy is static
      (DENSE) or dynamic (STANDARD). Defaults to DENSE.
    locationPolicy: Optional location policy allowing to exclude some zone(s)
      in which the resources must not be created.
    targetResources: Specification of the reserved resources.
    timeRangeSpec: Specification of a time range in which the resources may be
      created. The time range specifies start of resource use and planned end
      of resource use.
  """

  class DeploymentTypeValueValuesEnum(_messages.Enum):
    r"""Indicates if the reservation allocation strategy is static (DENSE) or
    dynamic (STANDARD). Defaults to DENSE.

    Values:
      DENSE: The reserved capacity is made up of densely deployed reservation
        blocks.
      DEPLOYMENT_TYPE_UNSPECIFIED: <no description>
      FLEXIBLE: The reserved capacity is made up of highly flexible, logical
        reservation blocks.
    """
    DENSE = 0
    DEPLOYMENT_TYPE_UNSPECIFIED = 1
    FLEXIBLE = 2

  deploymentType = _messages.EnumField('DeploymentTypeValueValuesEnum', 1)
  locationPolicy = _messages.MessageField('FutureResourcesSpecLocationPolicy', 2)
  targetResources = _messages.MessageField('FutureResourcesSpecTargetResources', 3)
  timeRangeSpec = _messages.MessageField('FlexibleTimeRange', 4)


class FutureResourcesSpecAggregateResources(_messages.Message):
  r"""A FutureResourcesSpecAggregateResources object.

  Enums:
    VmFamilyValueValuesEnum: The VM family that all instances scheduled
      against this reservation must belong to. Use for TPU reservations.
    WorkloadTypeValueValuesEnum: Workload type. Use for TPU reservations.

  Fields:
    acceleratorCount: Size of the request, in accelerator (chip) count.
    vmFamily: The VM family that all instances scheduled against this
      reservation must belong to. Use for TPU reservations.
    workloadType: Workload type. Use for TPU reservations.
  """

  class VmFamilyValueValuesEnum(_messages.Enum):
    r"""The VM family that all instances scheduled against this reservation
    must belong to. Use for TPU reservations.

    Values:
      VM_FAMILY_CLOUD_TPU_DEVICE_CT3: <no description>
      VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L: <no description>
      VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP: <no description>
      VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E: <no description>
      VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P: <no description>
      VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P: <no description>
      VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P: <no description>
    """
    VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 0
    VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 1
    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 2
    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 3
    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 4
    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 5
    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 6

  class WorkloadTypeValueValuesEnum(_messages.Enum):
    r"""Workload type. Use for TPU reservations.

    Values:
      BATCH: Reserved resources will be optimized for BATCH workloads, such as
        ML training.
      SERVING: Reserved resources will be optimized for SERVING workloads,
        such as ML inference.
      UNSPECIFIED: <no description>
    """
    BATCH = 0
    SERVING = 1
    UNSPECIFIED = 2

  acceleratorCount = _messages.IntegerField(1)
  vmFamily = _messages.EnumField('VmFamilyValueValuesEnum', 2)
  workloadType = _messages.EnumField('WorkloadTypeValueValuesEnum', 3)


class FutureResourcesSpecLocalSsdPartition(_messages.Message):
  r"""A FutureResourcesSpecLocalSsdPartition object.

  Enums:
    DiskInterfaceValueValuesEnum: Disk interface. Defaults to SCSI.

  Fields:
    diskInterface: Disk interface. Defaults to SCSI.
    diskSizeGb: The size of the disk in GB.
  """

  class DiskInterfaceValueValuesEnum(_messages.Enum):
    r"""Disk interface. Defaults to SCSI.

    Values:
      NVDIMM: <no description>
      NVME: <no description>
      SCSI: <no description>
    """
    NVDIMM = 0
    NVME = 1
    SCSI = 2

  diskInterface = _messages.EnumField('DiskInterfaceValueValuesEnum', 1)
  diskSizeGb = _messages.IntegerField(2)


class FutureResourcesSpecLocationPolicy(_messages.Message):
  r"""Specification of locations to create resources in.

  Messages:
    LocationsValue: Preferences for specified locations. Keys of the map are
      locations - zones, in format of 'zones/'. Values are preferences for the
      zones. If a zone is not specified in this map, it is ALLOWed.

  Fields:
    locations: Preferences for specified locations. Keys of the map are
      locations - zones, in format of 'zones/'. Values are preferences for the
      zones. If a zone is not specified in this map, it is ALLOWed.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LocationsValue(_messages.Message):
    r"""Preferences for specified locations. Keys of the map are locations -
    zones, in format of 'zones/'. Values are preferences for the zones. If a
    zone is not specified in this map, it is ALLOWed.

    Messages:
      AdditionalProperty: An additional property for a LocationsValue object.

    Fields:
      additionalProperties: Additional properties of type LocationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LocationsValue object.

      Fields:
        key: Name of the additional property.
        value: A FutureResourcesSpecLocationPolicyLocation attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('FutureResourcesSpecLocationPolicyLocation', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  locations = _messages.MessageField('LocationsValue', 1)


class FutureResourcesSpecLocationPolicyLocation(_messages.Message):
  r"""Preference for a single specified location.

  Enums:
    PreferenceValueValuesEnum: Preference for this location.

  Fields:
    preference: Preference for this location.
  """

  class PreferenceValueValuesEnum(_messages.Enum):
    r"""Preference for this location.

    Values:
      ALLOW: Location is allowed for use.
      DENY: Location is prohibited.
      PREFERENCE_UNSPECIFIED: Default value, unused.
    """
    ALLOW = 0
    DENY = 1
    PREFERENCE_UNSPECIFIED = 2

  preference = _messages.EnumField('PreferenceValueValuesEnum', 1)


class FutureResourcesSpecSpecificSKUResources(_messages.Message):
  r"""A FutureResourcesSpecSpecificSKUResources object.

  Fields:
    instanceCount: Size of the request, in instance count.
    localSsdPartitions: Local SSD partitions. You do not have to include SSD
      partitions that are built in the machine type.
    machineType: The machine type to use for instances that will use the
      reservation. This field only accepts machine type names. e.g.
      n2-standard-4 and does not accept machine type full or partial url. e.g.
      projects/my-l7ilb-project/zones/us-
      central1-a/machineTypes/n2-standard-4. Use for GPU reservations.
  """

  instanceCount = _messages.IntegerField(1)
  localSsdPartitions = _messages.MessageField('FutureResourcesSpecLocalSsdPartition', 2, repeated=True)
  machineType = _messages.StringField(3)


class FutureResourcesSpecTargetResources(_messages.Message):
  r"""Specification of reserved resources.

  Fields:
    aggregateResources: A FutureResourcesSpecAggregateResources attribute.
    specificSkuResources: A FutureResourcesSpecSpecificSKUResources attribute.
  """

  aggregateResources = _messages.MessageField('FutureResourcesSpecAggregateResources', 1)
  specificSkuResources = _messages.MessageField('FutureResourcesSpecSpecificSKUResources', 2)


class GRPCHealthCheck(_messages.Message):
  r"""A GRPCHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how a port is selected for
      health checking. Can be one of the following values: USE_FIXED_PORT:
      Specifies a port number explicitly using the port field in the health
      check. Supported by backend services for passthrough load balancers and
      backend services for proxy load balancers. Not supported by target
      pools. The health check supports all backends supported by the backend
      service provided the backend can be health checked. For example,
      GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint
      groups, and instance group backends. USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: Provides an indirect method of specifying the health
      check port by referring to the backend service. Only supported by
      backend services for proxy load balancers. Not supported by target
      pools. Not supported by backend services for passthrough load balancers.
      Supports all backends that can be health checked; for example,
      GCE_VM_IP_PORT network endpoint groups and instance group backends. For
      GCE_VM_IP_PORT network endpoint group backends, the health check uses
      the port number specified for each endpoint in the network endpoint
      group. For instance group backends, the health check uses the port
      number determined by looking up the backend service's named port in the
      instance group's list of named ports.

  Fields:
    grpcServiceName: The gRPC service name for the health check. This field is
      optional. The value of grpc_service_name has the following meanings by
      convention: - Empty service_name means the overall status of all
      services at the backend. - Non-empty service_name means the health of
      that gRPC service, as defined by the owner of the service. The
      grpc_service_name can only be ASCII.
    port: The TCP port number to which the health check prober sends packets.
      Valid values are 1 through 65535.
    portName: Not supported.
    portSpecification: Specifies how a port is selected for health checking.
      Can be one of the following values: USE_FIXED_PORT: Specifies a port
      number explicitly using the port field in the health check. Supported by
      backend services for passthrough load balancers and backend services for
      proxy load balancers. Not supported by target pools. The health check
      supports all backends supported by the backend service provided the
      backend can be health checked. For example, GCE_VM_IP network endpoint
      groups, GCE_VM_IP_PORT network endpoint groups, and instance group
      backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an
      indirect method of specifying the health check port by referring to the
      backend service. Only supported by backend services for proxy load
      balancers. Not supported by target pools. Not supported by backend
      services for passthrough load balancers. Supports all backends that can
      be health checked; for example, GCE_VM_IP_PORT network endpoint groups
      and instance group backends. For GCE_VM_IP_PORT network endpoint group
      backends, the health check uses the port number specified for each
      endpoint in the network endpoint group. For instance group backends, the
      health check uses the port number determined by looking up the backend
      service's named port in the instance group's list of named ports.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how a port is selected for health checking. Can be one of
    the following values: USE_FIXED_PORT: Specifies a port number explicitly
    using the port field in the health check. Supported by backend services
    for passthrough load balancers and backend services for proxy load
    balancers. Not supported by target pools. The health check supports all
    backends supported by the backend service provided the backend can be
    health checked. For example, GCE_VM_IP network endpoint groups,
    GCE_VM_IP_PORT network endpoint groups, and instance group backends.
    USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect
    method of specifying the health check port by referring to the backend
    service. Only supported by backend services for proxy load balancers. Not
    supported by target pools. Not supported by backend services for
    passthrough load balancers. Supports all backends that can be health
    checked; for example, GCE_VM_IP_PORT network endpoint groups and instance
    group backends. For GCE_VM_IP_PORT network endpoint group backends, the
    health check uses the port number specified for each endpoint in the
    network endpoint group. For instance group backends, the health check uses
    the port number determined by looking up the backend service's named port
    in the instance group's list of named ports.

    Values:
      USE_FIXED_PORT: The port number in the health check's port is used for
        health checking. Applies to network endpoint group and instance group
        backends.
      USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: For network endpoint group backends, the health check
        uses the port number specified on each endpoint in the network
        endpoint group. For instance group backends, the health check uses the
        port number specified for the backend service's named port defined in
        the instance group's named ports.
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  grpcServiceName = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portName = _messages.StringField(3)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 4)


class GRPCTLSHealthCheck(_messages.Message):
  r"""A GRPCTLSHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how a port is selected for
      health checking. Can be one of the following values: USE_FIXED_PORT:
      Specifies a port number explicitly using the port field in the health
      check. Supported by backend services for passthrough load balancers and
      backend services for proxy load balancers. Not supported by target
      pools. The health check supports all backends supported by the backend
      service provided the backend can be health checked. For example,
      GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint
      groups, and instance group backends. USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: Provides an indirect method of specifying the health
      check port by referring to the backend service. Only supported by
      backend services for proxy load balancers. Not supported by target
      pools. Not supported by backend services for passthrough load balancers.
      Supports all backends that can be health checked; for example,
      GCE_VM_IP_PORT network endpoint groups and instance group backends. For
      GCE_VM_IP_PORT network endpoint group backends, the health check uses
      the port number specified for each endpoint in the network endpoint
      group. For instance group backends, the health check uses the port
      number determined by looking up the backend service's named port in the
      instance group's list of named ports.

  Fields:
    grpcServiceName: The gRPC service name for the health check. This field is
      optional. The value of grpc_service_name has the following meanings by
      convention: - Empty service_name means the overall status of all
      services at the backend. - Non-empty service_name means the health of
      that gRPC service, as defined by the owner of the service. The
      grpc_service_name can only be ASCII.
    port: The TCP port number to which the health check prober sends packets.
      Valid values are 1 through 65535.
    portSpecification: Specifies how a port is selected for health checking.
      Can be one of the following values: USE_FIXED_PORT: Specifies a port
      number explicitly using the port field in the health check. Supported by
      backend services for passthrough load balancers and backend services for
      proxy load balancers. Not supported by target pools. The health check
      supports all backends supported by the backend service provided the
      backend can be health checked. For example, GCE_VM_IP network endpoint
      groups, GCE_VM_IP_PORT network endpoint groups, and instance group
      backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an
      indirect method of specifying the health check port by referring to the
      backend service. Only supported by backend services for proxy load
      balancers. Not supported by target pools. Not supported by backend
      services for passthrough load balancers. Supports all backends that can
      be health checked; for example, GCE_VM_IP_PORT network endpoint groups
      and instance group backends. For GCE_VM_IP_PORT network endpoint group
      backends, the health check uses the port number specified for each
      endpoint in the network endpoint group. For instance group backends, the
      health check uses the port number determined by looking up the backend
      service's named port in the instance group's list of named ports.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how a port is selected for health checking. Can be one of
    the following values: USE_FIXED_PORT: Specifies a port number explicitly
    using the port field in the health check. Supported by backend services
    for passthrough load balancers and backend services for proxy load
    balancers. Not supported by target pools. The health check supports all
    backends supported by the backend service provided the backend can be
    health checked. For example, GCE_VM_IP network endpoint groups,
    GCE_VM_IP_PORT network endpoint groups, and instance group backends.
    USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect
    method of specifying the health check port by referring to the backend
    service. Only supported by backend services for proxy load balancers. Not
    supported by target pools. Not supported by backend services for
    passthrough load balancers. Supports all backends that can be health
    checked; for example, GCE_VM_IP_PORT network endpoint groups and instance
    group backends. For GCE_VM_IP_PORT network endpoint group backends, the
    health check uses the port number specified for each endpoint in the
    network endpoint group. For instance group backends, the health check uses
    the port number determined by looking up the backend service's named port
    in the instance group's list of named ports.

    Values:
      USE_FIXED_PORT: The port number in the health check's port is used for
        health checking. Applies to network endpoint group and instance group
        backends.
      USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: For network endpoint group backends, the health check
        uses the port number specified on each endpoint in the network
        endpoint group. For instance group backends, the health check uses the
        port number specified for the backend service's named port defined in
        the instance group's named ports.
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  grpcServiceName = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 3)


class GetAsyncReplicationStatusResponse(_messages.Message):
  r"""A GetAsyncReplicationStatusResponse object.

  Fields:
    asyncReplicationStatus: A AsyncReplicationStatus attribute.
    etag: end_interface: MixerGetResponseWithEtagBuilder
  """

  asyncReplicationStatus = _messages.MessageField('AsyncReplicationStatus', 1)
  etag = _messages.StringField(2)


class GetOwnerInstanceResponse(_messages.Message):
  r"""A GetOwnerInstanceResponse object.

  Fields:
    instance: Full instance resource URL.
  """

  instance = _messages.StringField(1)


class GlobalAddressesMoveRequest(_messages.Message):
  r"""A GlobalAddressesMoveRequest object.

  Fields:
    description: An optional destination address description if intended to be
      different from the source.
    destinationAddress: The URL of the destination address to move to. This
      can be a full or partial URL. For example, the following are all valid
      URLs to a address: -
      https://www.googleapis.com/compute/v1/projects/project
      /global/addresses/address - projects/project/global/addresses/address
      Note that destination project must be different from the source project.
      So /global/addresses/address is not valid partial url.
  """

  description = _messages.StringField(1)
  destinationAddress = _messages.StringField(2)


class GlobalNetworkEndpointGroupsAttachEndpointsRequest(_messages.Message):
  r"""A GlobalNetworkEndpointGroupsAttachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be attached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class GlobalNetworkEndpointGroupsDetachEndpointsRequest(_messages.Message):
  r"""A GlobalNetworkEndpointGroupsDetachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be detached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class GlobalOrganizationSetPolicyRequest(_messages.Message):
  r"""A GlobalOrganizationSetPolicyRequest object.

  Fields:
    bindings: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify bindings.
    etag: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify the etag.
    policy: REQUIRED: The complete policy to be applied to the 'resource'. The
      size of the policy is limited to a few 10s of KB. An empty policy is in
      general a valid policy but certain services (like Projects) might reject
      them.
  """

  bindings = _messages.MessageField('Binding', 1, repeated=True)
  etag = _messages.BytesField(2)
  policy = _messages.MessageField('Policy', 3)


class GlobalSetLabelsRequest(_messages.Message):
  r"""A GlobalSetLabelsRequest object.

  Messages:
    LabelsValue: A list of labels to apply for this resource. Each label must
      comply with the requirements for labels. For example, "webserver-
      frontend": "images". A label value can also be empty (e.g. "my-label":
      "").

  Fields:
    labelFingerprint: The fingerprint of the previous set of labels for this
      resource, used to detect conflicts. The fingerprint is initially
      generated by Compute Engine and changes after every request to modify or
      update labels. You must always provide an up-to-date fingerprint hash
      when updating or changing labels, otherwise the request will fail with
      error 412 conditionNotMet. Make a get() request to the resource to get
      the latest fingerprint.
    labels: A list of labels to apply for this resource. Each label must
      comply with the requirements for labels. For example, "webserver-
      frontend": "images". A label value can also be empty (e.g. "my-label":
      "").
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""A list of labels to apply for this resource. Each label must comply
    with the requirements for labels. For example, "webserver-frontend":
    "images". A label value can also be empty (e.g. "my-label": "").

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class GlobalSetPolicyRequest(_messages.Message):
  r"""A GlobalSetPolicyRequest object.

  Fields:
    bindings: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify bindings.
    etag: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify the etag.
    policy: REQUIRED: The complete policy to be applied to the 'resource'. The
      size of the policy is limited to a few 10s of KB. An empty policy is in
      general a valid policy but certain services (like Projects) might reject
      them.
  """

  bindings = _messages.MessageField('Binding', 1, repeated=True)
  etag = _messages.BytesField(2)
  policy = _messages.MessageField('Policy', 3)


class GroupMaintenanceInfo(_messages.Message):
  r"""Maintenance Info for ReservationBlocks.

  Enums:
    SchedulingTypeValueValuesEnum: The type of maintenance for the
      reservation.

  Fields:
    maintenanceOngoingCount: Progress for ongoing maintenance for this group
      of VMs/hosts. Describes number of hosts in the block that have ongoing
      maintenance.
    maintenancePendingCount: Progress for ongoing maintenance for this group
      of VMs/hosts. Describes number of hosts in the block that have pending
      maintenance.
    schedulingType: The type of maintenance for the reservation.
    upcomingGroupMaintenance: Maintenance information on this group of VMs.
  """

  class SchedulingTypeValueValuesEnum(_messages.Enum):
    r"""The type of maintenance for the reservation.

    Values:
      GROUPED: Maintenance on all reserved instances in the reservation is
        synchronized.
      GROUP_MAINTENANCE_TYPE_UNSPECIFIED: Unknown maintenance type.
      INDEPENDENT: Maintenance is not synchronized for this reservation.
        Instead, each instance has its own maintenance window.
    """
    GROUPED = 0
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 1
    INDEPENDENT = 2

  maintenanceOngoingCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  maintenancePendingCount = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  schedulingType = _messages.EnumField('SchedulingTypeValueValuesEnum', 3)
  upcomingGroupMaintenance = _messages.MessageField('UpcomingMaintenance', 4)


class GrpcServiceConfig(_messages.Message):
  r"""[Deprecated] gRPC config to access the SDS server. gRPC config to access
  the SDS server.

  Fields:
    callCredentials: The call credentials to access the SDS server.
    channelCredentials: The channel credentials to access the SDS server.
    targetUri: The target URI of the SDS server.
  """

  callCredentials = _messages.MessageField('CallCredentials', 1)
  channelCredentials = _messages.MessageField('ChannelCredentials', 2)
  targetUri = _messages.StringField(3)


class GuestAttributes(_messages.Message):
  r"""A guest attributes entry.

  Fields:
    kind: [Output Only] Type of the resource. Always compute#guestAttributes
      for guest attributes entry.
    queryPath: The path to be queried. This can be the default namespace ('')
      or a nested namespace ('\/') or a specified key ('\/\').
    queryValue: [Output Only] The value of the requested queried path.
    selfLink: [Output Only] Server-defined URL for this resource.
    variableKey: The key to search for.
    variableValue: [Output Only] The value found for the requested key.
  """

  kind = _messages.StringField(1, default='compute#guestAttributes')
  queryPath = _messages.StringField(2)
  queryValue = _messages.MessageField('GuestAttributesValue', 3)
  selfLink = _messages.StringField(4)
  variableKey = _messages.StringField(5)
  variableValue = _messages.StringField(6)


class GuestAttributesEntry(_messages.Message):
  r"""A guest attributes namespace/key/value entry.

  Fields:
    key: Key for the guest attribute entry.
    namespace: Namespace for the guest attribute entry.
    value: Value for the guest attribute entry.
  """

  key = _messages.StringField(1)
  namespace = _messages.StringField(2)
  value = _messages.StringField(3)


class GuestAttributesValue(_messages.Message):
  r"""Array of guest attribute namespace/key/value tuples.

  Fields:
    items: A GuestAttributesEntry attribute.
  """

  items = _messages.MessageField('GuestAttributesEntry', 1, repeated=True)


class GuestOsFeature(_messages.Message):
  r"""Guest OS features.

  Enums:
    TypeValueValuesEnum: The ID of a supported feature. To add multiple
      values, use commas to separate values. Set to one or more of the
      following values: - VIRTIO_SCSI_MULTIQUEUE - WINDOWS - MULTI_IP_SUBNET -
      UEFI_COMPATIBLE - GVNIC - SEV_CAPABLE - SUSPEND_RESUME_COMPATIBLE -
      SEV_LIVE_MIGRATABLE_V2 - SEV_SNP_CAPABLE - TDX_CAPABLE - IDPF For more
      information, see Enabling guest operating system features.

  Fields:
    type: The ID of a supported feature. To add multiple values, use commas to
      separate values. Set to one or more of the following values: -
      VIRTIO_SCSI_MULTIQUEUE - WINDOWS - MULTI_IP_SUBNET - UEFI_COMPATIBLE -
      GVNIC - SEV_CAPABLE - SUSPEND_RESUME_COMPATIBLE - SEV_LIVE_MIGRATABLE_V2
      - SEV_SNP_CAPABLE - TDX_CAPABLE - IDPF For more information, see
      Enabling guest operating system features.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The ID of a supported feature. To add multiple values, use commas to
    separate values. Set to one or more of the following values: -
    VIRTIO_SCSI_MULTIQUEUE - WINDOWS - MULTI_IP_SUBNET - UEFI_COMPATIBLE -
    GVNIC - SEV_CAPABLE - SUSPEND_RESUME_COMPATIBLE - SEV_LIVE_MIGRATABLE_V2 -
    SEV_SNP_CAPABLE - TDX_CAPABLE - IDPF For more information, see Enabling
    guest operating system features.

    Values:
      BARE_METAL_LINUX_COMPATIBLE: <no description>
      FEATURE_TYPE_UNSPECIFIED: <no description>
      GVNIC: <no description>
      IDPF: <no description>
      MULTI_IP_SUBNET: <no description>
      SECURE_BOOT: <no description>
      SEV_CAPABLE: <no description>
      SEV_LIVE_MIGRATABLE: <no description>
      SEV_LIVE_MIGRATABLE_V2: <no description>
      SEV_SNP_CAPABLE: <no description>
      TDX_CAPABLE: <no description>
      UEFI_COMPATIBLE: <no description>
      VIRTIO_SCSI_MULTIQUEUE: <no description>
      WINDOWS: <no description>
    """
    BARE_METAL_LINUX_COMPATIBLE = 0
    FEATURE_TYPE_UNSPECIFIED = 1
    GVNIC = 2
    IDPF = 3
    MULTI_IP_SUBNET = 4
    SECURE_BOOT = 5
    SEV_CAPABLE = 6
    SEV_LIVE_MIGRATABLE = 7
    SEV_LIVE_MIGRATABLE_V2 = 8
    SEV_SNP_CAPABLE = 9
    TDX_CAPABLE = 10
    UEFI_COMPATIBLE = 11
    VIRTIO_SCSI_MULTIQUEUE = 12
    WINDOWS = 13

  type = _messages.EnumField('TypeValueValuesEnum', 1)


class HTTP2HealthCheck(_messages.Message):
  r"""A HTTP2HealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how a port is selected for
      health checking. Can be one of the following values: USE_FIXED_PORT:
      Specifies a port number explicitly using the port field in the health
      check. Supported by backend services for passthrough load balancers and
      backend services for proxy load balancers. Not supported by target
      pools. The health check supports all backends supported by the backend
      service provided the backend can be health checked. For example,
      GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint
      groups, and instance group backends. USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: Provides an indirect method of specifying the health
      check port by referring to the backend service. Only supported by
      backend services for proxy load balancers. Not supported by target
      pools. Not supported by backend services for passthrough load balancers.
      Supports all backends that can be health checked; for example,
      GCE_VM_IP_PORT network endpoint groups and instance group backends. For
      GCE_VM_IP_PORT network endpoint group backends, the health check uses
      the port number specified for each endpoint in the network endpoint
      group. For instance group backends, the health check uses the port
      number determined by looking up the backend service's named port in the
      instance group's list of named ports.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.
    WeightReportModeValueValuesEnum: Weight report mode. used for weighted
      Load Balancing.

  Fields:
    host: The value of the host header in the HTTP/2 health check request. If
      left empty (default value), the host header is set to the destination IP
      address to which health check packets are sent. The destination IP
      address depends on the type of load balancer. For details, see:
      https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-
      packet-dest
    port: The TCP port number to which the health check prober sends packets.
      The default value is 443. Valid values are 1 through 65535.
    portName: Not supported.
    portSpecification: Specifies how a port is selected for health checking.
      Can be one of the following values: USE_FIXED_PORT: Specifies a port
      number explicitly using the port field in the health check. Supported by
      backend services for passthrough load balancers and backend services for
      proxy load balancers. Not supported by target pools. The health check
      supports all backends supported by the backend service provided the
      backend can be health checked. For example, GCE_VM_IP network endpoint
      groups, GCE_VM_IP_PORT network endpoint groups, and instance group
      backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an
      indirect method of specifying the health check port by referring to the
      backend service. Only supported by backend services for proxy load
      balancers. Not supported by target pools. Not supported by backend
      services for passthrough load balancers. Supports all backends that can
      be health checked; for example, GCE_VM_IP_PORT network endpoint groups
      and instance group backends. For GCE_VM_IP_PORT network endpoint group
      backends, the health check uses the port number specified for each
      endpoint in the network endpoint group. For instance group backends, the
      health check uses the port number determined by looking up the backend
      service's named port in the instance group's list of named ports.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    requestPath: The request path of the HTTP/2 health check request. The
      default value is /. Must comply with RFC3986.
    response: Creates a content-based HTTP/2 health check. In addition to the
      required HTTP 200 (OK) status code, you can configure the health check
      to pass only when the backend sends this specific ASCII response string
      within the first 1024 bytes of the HTTP response body. For details, see:
      https://cloud.google.com/load-balancing/docs/health-check-
      concepts#criteria-protocol-http
    weightReportMode: Weight report mode. used for weighted Load Balancing.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how a port is selected for health checking. Can be one of
    the following values: USE_FIXED_PORT: Specifies a port number explicitly
    using the port field in the health check. Supported by backend services
    for passthrough load balancers and backend services for proxy load
    balancers. Not supported by target pools. The health check supports all
    backends supported by the backend service provided the backend can be
    health checked. For example, GCE_VM_IP network endpoint groups,
    GCE_VM_IP_PORT network endpoint groups, and instance group backends.
    USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect
    method of specifying the health check port by referring to the backend
    service. Only supported by backend services for proxy load balancers. Not
    supported by target pools. Not supported by backend services for
    passthrough load balancers. Supports all backends that can be health
    checked; for example, GCE_VM_IP_PORT network endpoint groups and instance
    group backends. For GCE_VM_IP_PORT network endpoint group backends, the
    health check uses the port number specified for each endpoint in the
    network endpoint group. For instance group backends, the health check uses
    the port number determined by looking up the backend service's named port
    in the instance group's list of named ports.

    Values:
      USE_FIXED_PORT: The port number in the health check's port is used for
        health checking. Applies to network endpoint group and instance group
        backends.
      USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: For network endpoint group backends, the health check
        uses the port number specified on each endpoint in the network
        endpoint group. For instance group backends, the health check uses the
        port number specified for the backend service's named port defined in
        the instance group's named ports.
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  class WeightReportModeValueValuesEnum(_messages.Enum):
    r"""Weight report mode. used for weighted Load Balancing.

    Values:
      DISABLE: Health Checker will not parse the header field.
      DRY_RUN: Health Checker will parse and report the weight in the header
        field, but load balancing will not be based on the weights and will
        use equal weights.
      ENABLE: Health Checker will try to parse and report the weight in the
        header field, and load balancing will be based on the weights as long
        as all backends have a valid weight or only a subset of backends has
        the UNAVAILABLE_WEIGHT WeightError. The latter case is to continue the
        weighted load balancing while some backends are in TIMEOUT or UNKNOWN
        health status.
    """
    DISABLE = 0
    DRY_RUN = 1
    ENABLE = 2

  host = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portName = _messages.StringField(3)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 4)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 5)
  requestPath = _messages.StringField(6)
  response = _messages.StringField(7)
  weightReportMode = _messages.EnumField('WeightReportModeValueValuesEnum', 8)


class HTTPHealthCheck(_messages.Message):
  r"""A HTTPHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how a port is selected for
      health checking. Can be one of the following values: USE_FIXED_PORT:
      Specifies a port number explicitly using the port field in the health
      check. Supported by backend services for passthrough load balancers and
      backend services for proxy load balancers. Also supported in legacy HTTP
      health checks for target pools. The health check supports all backends
      supported by the backend service provided the backend can be health
      checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT
      network endpoint groups, and instance group backends. USE_NAMED_PORT:
      Not supported. USE_SERVING_PORT: Provides an indirect method of
      specifying the health check port by referring to the backend service.
      Only supported by backend services for proxy load balancers. Not
      supported by target pools. Not supported by backend services for pass-
      through load balancers. Supports all backends that can be health
      checked; for example, GCE_VM_IP_PORT network endpoint groups and
      instance group backends. For GCE_VM_IP_PORT network endpoint group
      backends, the health check uses the port number specified for each
      endpoint in the network endpoint group. For instance group backends, the
      health check uses the port number determined by looking up the backend
      service's named port in the instance group's list of named ports.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.
    WeightReportModeValueValuesEnum: Weight report mode. used for weighted
      Load Balancing.

  Fields:
    host: The value of the host header in the HTTP health check request. If
      left empty (default value), the host header is set to the destination IP
      address to which health check packets are sent. The destination IP
      address depends on the type of load balancer. For details, see:
      https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-
      packet-dest
    port: The TCP port number to which the health check prober sends packets.
      The default value is 80. Valid values are 1 through 65535.
    portName: Not supported.
    portSpecification: Specifies how a port is selected for health checking.
      Can be one of the following values: USE_FIXED_PORT: Specifies a port
      number explicitly using the port field in the health check. Supported by
      backend services for passthrough load balancers and backend services for
      proxy load balancers. Also supported in legacy HTTP health checks for
      target pools. The health check supports all backends supported by the
      backend service provided the backend can be health checked. For example,
      GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint
      groups, and instance group backends. USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: Provides an indirect method of specifying the health
      check port by referring to the backend service. Only supported by
      backend services for proxy load balancers. Not supported by target
      pools. Not supported by backend services for pass-through load
      balancers. Supports all backends that can be health checked; for
      example, GCE_VM_IP_PORT network endpoint groups and instance group
      backends. For GCE_VM_IP_PORT network endpoint group backends, the health
      check uses the port number specified for each endpoint in the network
      endpoint group. For instance group backends, the health check uses the
      port number determined by looking up the backend service's named port in
      the instance group's list of named ports.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    requestPath: The request path of the HTTP health check request. The
      default value is /. Must comply with RFC3986.
    response: Creates a content-based HTTP health check. In addition to the
      required HTTP 200 (OK) status code, you can configure the health check
      to pass only when the backend sends this specific ASCII response string
      within the first 1024 bytes of the HTTP response body. For details, see:
      https://cloud.google.com/load-balancing/docs/health-check-
      concepts#criteria-protocol-http
    weightReportMode: Weight report mode. used for weighted Load Balancing.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how a port is selected for health checking. Can be one of
    the following values: USE_FIXED_PORT: Specifies a port number explicitly
    using the port field in the health check. Supported by backend services
    for passthrough load balancers and backend services for proxy load
    balancers. Also supported in legacy HTTP health checks for target pools.
    The health check supports all backends supported by the backend service
    provided the backend can be health checked. For example, GCE_VM_IP network
    endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance
    group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides
    an indirect method of specifying the health check port by referring to the
    backend service. Only supported by backend services for proxy load
    balancers. Not supported by target pools. Not supported by backend
    services for pass-through load balancers. Supports all backends that can
    be health checked; for example, GCE_VM_IP_PORT network endpoint groups and
    instance group backends. For GCE_VM_IP_PORT network endpoint group
    backends, the health check uses the port number specified for each
    endpoint in the network endpoint group. For instance group backends, the
    health check uses the port number determined by looking up the backend
    service's named port in the instance group's list of named ports.

    Values:
      USE_FIXED_PORT: The port number in the health check's port is used for
        health checking. Applies to network endpoint group and instance group
        backends.
      USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: For network endpoint group backends, the health check
        uses the port number specified on each endpoint in the network
        endpoint group. For instance group backends, the health check uses the
        port number specified for the backend service's named port defined in
        the instance group's named ports.
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  class WeightReportModeValueValuesEnum(_messages.Enum):
    r"""Weight report mode. used for weighted Load Balancing.

    Values:
      DISABLE: Health Checker will not parse the header field.
      DRY_RUN: Health Checker will parse and report the weight in the header
        field, but load balancing will not be based on the weights and will
        use equal weights.
      ENABLE: Health Checker will try to parse and report the weight in the
        header field, and load balancing will be based on the weights as long
        as all backends have a valid weight or only a subset of backends has
        the UNAVAILABLE_WEIGHT WeightError. The latter case is to continue the
        weighted load balancing while some backends are in TIMEOUT or UNKNOWN
        health status.
    """
    DISABLE = 0
    DRY_RUN = 1
    ENABLE = 2

  host = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portName = _messages.StringField(3)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 4)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 5)
  requestPath = _messages.StringField(6)
  response = _messages.StringField(7)
  weightReportMode = _messages.EnumField('WeightReportModeValueValuesEnum', 8)


class HTTPSHealthCheck(_messages.Message):
  r"""A HTTPSHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how a port is selected for
      health checking. Can be one of the following values: USE_FIXED_PORT:
      Specifies a port number explicitly using the port field in the health
      check. Supported by backend services for passthrough load balancers and
      backend services for proxy load balancers. Not supported by target
      pools. The health check supports all backends supported by the backend
      service provided the backend can be health checked. For example,
      GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint
      groups, and instance group backends. USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: Provides an indirect method of specifying the health
      check port by referring to the backend service. Only supported by
      backend services for proxy load balancers. Not supported by target
      pools. Not supported by backend services for passthrough load balancers.
      Supports all backends that can be health checked; for example,
      GCE_VM_IP_PORT network endpoint groups and instance group backends. For
      GCE_VM_IP_PORT network endpoint group backends, the health check uses
      the port number specified for each endpoint in the network endpoint
      group. For instance group backends, the health check uses the port
      number determined by looking up the backend service's named port in the
      instance group's list of named ports.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.
    WeightReportModeValueValuesEnum: Weight report mode. used for weighted
      Load Balancing.

  Fields:
    host: The value of the host header in the HTTPS health check request. If
      left empty (default value), the host header is set to the destination IP
      address to which health check packets are sent. The destination IP
      address depends on the type of load balancer. For details, see:
      https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-
      packet-dest
    port: The TCP port number to which the health check prober sends packets.
      The default value is 443. Valid values are 1 through 65535.
    portName: Not supported.
    portSpecification: Specifies how a port is selected for health checking.
      Can be one of the following values: USE_FIXED_PORT: Specifies a port
      number explicitly using the port field in the health check. Supported by
      backend services for passthrough load balancers and backend services for
      proxy load balancers. Not supported by target pools. The health check
      supports all backends supported by the backend service provided the
      backend can be health checked. For example, GCE_VM_IP network endpoint
      groups, GCE_VM_IP_PORT network endpoint groups, and instance group
      backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an
      indirect method of specifying the health check port by referring to the
      backend service. Only supported by backend services for proxy load
      balancers. Not supported by target pools. Not supported by backend
      services for passthrough load balancers. Supports all backends that can
      be health checked; for example, GCE_VM_IP_PORT network endpoint groups
      and instance group backends. For GCE_VM_IP_PORT network endpoint group
      backends, the health check uses the port number specified for each
      endpoint in the network endpoint group. For instance group backends, the
      health check uses the port number determined by looking up the backend
      service's named port in the instance group's list of named ports.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    requestPath: The request path of the HTTPS health check request. The
      default value is /. Must comply with RFC3986.
    response: Creates a content-based HTTPS health check. In addition to the
      required HTTP 200 (OK) status code, you can configure the health check
      to pass only when the backend sends this specific ASCII response string
      within the first 1024 bytes of the HTTP response body. For details, see:
      https://cloud.google.com/load-balancing/docs/health-check-
      concepts#criteria-protocol-http
    weightReportMode: Weight report mode. used for weighted Load Balancing.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how a port is selected for health checking. Can be one of
    the following values: USE_FIXED_PORT: Specifies a port number explicitly
    using the port field in the health check. Supported by backend services
    for passthrough load balancers and backend services for proxy load
    balancers. Not supported by target pools. The health check supports all
    backends supported by the backend service provided the backend can be
    health checked. For example, GCE_VM_IP network endpoint groups,
    GCE_VM_IP_PORT network endpoint groups, and instance group backends.
    USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect
    method of specifying the health check port by referring to the backend
    service. Only supported by backend services for proxy load balancers. Not
    supported by target pools. Not supported by backend services for
    passthrough load balancers. Supports all backends that can be health
    checked; for example, GCE_VM_IP_PORT network endpoint groups and instance
    group backends. For GCE_VM_IP_PORT network endpoint group backends, the
    health check uses the port number specified for each endpoint in the
    network endpoint group. For instance group backends, the health check uses
    the port number determined by looking up the backend service's named port
    in the instance group's list of named ports.

    Values:
      USE_FIXED_PORT: The port number in the health check's port is used for
        health checking. Applies to network endpoint group and instance group
        backends.
      USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: For network endpoint group backends, the health check
        uses the port number specified on each endpoint in the network
        endpoint group. For instance group backends, the health check uses the
        port number specified for the backend service's named port defined in
        the instance group's named ports.
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  class WeightReportModeValueValuesEnum(_messages.Enum):
    r"""Weight report mode. used for weighted Load Balancing.

    Values:
      DISABLE: Health Checker will not parse the header field.
      DRY_RUN: Health Checker will parse and report the weight in the header
        field, but load balancing will not be based on the weights and will
        use equal weights.
      ENABLE: Health Checker will try to parse and report the weight in the
        header field, and load balancing will be based on the weights as long
        as all backends have a valid weight or only a subset of backends has
        the UNAVAILABLE_WEIGHT WeightError. The latter case is to continue the
        weighted load balancing while some backends are in TIMEOUT or UNKNOWN
        health status.
    """
    DISABLE = 0
    DRY_RUN = 1
    ENABLE = 2

  host = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portName = _messages.StringField(3)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 4)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 5)
  requestPath = _messages.StringField(6)
  response = _messages.StringField(7)
  weightReportMode = _messages.EnumField('WeightReportModeValueValuesEnum', 8)


class HealthAggregationPolicy(_messages.Message):
  r"""Represents a health aggregation policy. A health aggregation policy
  resource defines a policy to aggregate health. For more information, see
  Health checks overview.

  Enums:
    PolicyTypeValueValuesEnum: Specifies the type of the
      healthAggregationPolicy. The only allowed value for global resources is
      DNS_PUBLIC_IP_POLICY. The only allowed value for regional resources is
      BACKEND_SERVICE_POLICY. Must be specified when the
      healthAggregationPolicy is created, and cannot be mutated.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a HealthAggregationPolicy. An up-to-date
      fingerprint must be provided in order to patch the
      HealthAggregationPolicy; Otherwise, the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve the HealthAggregationPolicy.
    healthyPercentThreshold: Can only be set if the policyType field is
      BACKEND_SERVICE_POLICY. Specifies the threshold (as a percentage) of
      healthy endpoints required in order to consider the aggregated health
      result HEALTHY. Defaults to 60. Must be in range [0, 100]. Not
      applicable if the policyType field is DNB_PUBLIC_IP_POLICY. Can be
      mutated. This field is optional, and will be set to the default if
      unspecified. Note that both this threshold and minHealthyThreshold must
      be satisfied in order for HEALTHY to be the aggregated result.
      "Endpoints" refers to network endpoints within a Network Endpoint Group
      or instances within an Instance Group.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always
      compute#healthAggregationPolicy for health aggregation policies.
    minHealthyThreshold: Can only be set if the policyType field is
      BACKEND_SERVICE_POLICY. Specifies the minimum number of healthy
      endpoints required in order to consider the aggregated health result
      HEALTHY. Defaults to 1. Must be positive. Not applicable if the
      policyType field is DNB_PUBLIC_IP_POLICY. Can be mutated. This field is
      optional, and will be set to the default if unspecified. Note that both
      this threshold and healthyPercentThreshold must be satisfied in order
      for HEALTHY to be the aggregated result. "Endpoints" refers to network
      endpoints within a Network Endpoint Group or instances within an
      Instance Group.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    policyType: Specifies the type of the healthAggregationPolicy. The only
      allowed value for global resources is DNS_PUBLIC_IP_POLICY. The only
      allowed value for regional resources is BACKEND_SERVICE_POLICY. Must be
      specified when the healthAggregationPolicy is created, and cannot be
      mutated.
    region: [Output Only] URL of the region where the health aggregation
      policy resides. This field applies only to the regional resource. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
  """

  class PolicyTypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of the healthAggregationPolicy. The only allowed
    value for global resources is DNS_PUBLIC_IP_POLICY. The only allowed value
    for regional resources is BACKEND_SERVICE_POLICY. Must be specified when
    the healthAggregationPolicy is created, and cannot be mutated.

    Values:
      BACKEND_SERVICE_POLICY: <no description>
      DNS_PUBLIC_IP_POLICY: <no description>
    """
    BACKEND_SERVICE_POLICY = 0
    DNS_PUBLIC_IP_POLICY = 1

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  healthyPercentThreshold = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default='compute#healthAggregationPolicy')
  minHealthyThreshold = _messages.IntegerField(7, variant=_messages.Variant.UINT32)
  name = _messages.StringField(8)
  policyType = _messages.EnumField('PolicyTypeValueValuesEnum', 9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)


class HealthAggregationPolicyList(_messages.Message):
  r"""A HealthAggregationPolicyList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthAggregationPolicy resources.
    kind: [Output Only] Type of the resource. Always
      compute#healthAggregationPolicy for health aggregation policies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('HealthAggregationPolicy', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#healthAggregationPolicyList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class HealthCheck(_messages.Message):
  r"""Represents a health check resource. Google Compute Engine has two health
  check resources: *
  [Regional](/compute/docs/reference/rest/alpha/regionHealthChecks) *
  [Global](/compute/docs/reference/rest/alpha/healthChecks) These health check
  resources can be used for load balancing and for autohealing VMs in a
  managed instance group (MIG). **Load balancing** Health check requirements
  vary depending on the type of load balancer. For details about the type of
  health check supported for each load balancer and corresponding backend
  type, see Health checks overview: Load balancer guide. **Autohealing in
  MIGs** The health checks that you use for autohealing VMs in a MIG can be
  either regional or global. For more information, see Set up an application
  health check and autohealing. For more information, see Health checks
  overview.

  Enums:
    TypeValueValuesEnum: Specifies the type of the healthCheck, either TCP,
      SSL, HTTP, HTTPS, HTTP2 or GRPC. Exactly one of the protocol-specific
      health check fields must be specified, which must match type field.

  Fields:
    checkIntervalSec: How often (in seconds) to send a health check. The
      default value is 5 seconds.
    creationTimestamp: [Output Only] Creation timestamp in 3339 text format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    grpcHealthCheck: A GRPCHealthCheck attribute.
    grpcTlsHealthCheck: A GRPCTLSHealthCheck attribute.
    healthyThreshold: A so-far unhealthy instance will be marked healthy after
      this many consecutive successes. The default value is 2.
    http2HealthCheck: A HTTP2HealthCheck attribute.
    httpHealthCheck: A HTTPHealthCheck attribute.
    httpsHealthCheck: A HTTPSHealthCheck attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: Type of the resource.
    logConfig: Configure logging on this health check.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      For example, a name that is 1-63 characters long, matches the regular
      expression `[a-z]([-a-z0-9]*[a-z0-9])?`, and otherwise complies with
      RFC1035. This regular expression describes a name where the first
      character is a lowercase letter, and all following characters are a
      dash, lowercase letter, or digit, except the last character, which isn't
      a dash.
    region: [Output Only] Region where the health check resides. Not
      applicable to global health checks.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sourceRegions: The list of cloud regions from which health checks are
      performed. If any regions are specified, then exactly 3 regions should
      be specified. The region names must be valid names of Google Cloud
      regions. This can only be set for global health check. If this list is
      non-empty, then there are restrictions on what other health check fields
      are supported and what other resources can use this health check: - SSL,
      HTTP2, and GRPC protocols are not supported. - The TCP request field is
      not supported. - The proxyHeader field for HTTP, HTTPS, and TCP is not
      supported. - The checkIntervalSec field must be at least 30. - The
      health check cannot be used with BackendService nor with managed
      instance group auto-healing.
    sslHealthCheck: A SSLHealthCheck attribute.
    tcpHealthCheck: A TCPHealthCheck attribute.
    timeoutSec: How long (in seconds) to wait before claiming failure. The
      default value is 5 seconds. It is invalid for timeoutSec to have greater
      value than checkIntervalSec.
    type: Specifies the type of the healthCheck, either TCP, SSL, HTTP, HTTPS,
      HTTP2 or GRPC. Exactly one of the protocol-specific health check fields
      must be specified, which must match type field.
    udpHealthCheck: A UDPHealthCheck attribute.
    unhealthyThreshold: A so-far healthy instance will be marked unhealthy
      after this many consecutive failures. The default value is 2.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of the healthCheck, either TCP, SSL, HTTP, HTTPS,
    HTTP2 or GRPC. Exactly one of the protocol-specific health check fields
    must be specified, which must match type field.

    Values:
      GRPC: <no description>
      GRPC_WITH_TLS: <no description>
      HTTP: <no description>
      HTTP2: <no description>
      HTTPS: <no description>
      INVALID: <no description>
      SSL: <no description>
      TCP: <no description>
      UDP: <no description>
    """
    GRPC = 0
    GRPC_WITH_TLS = 1
    HTTP = 2
    HTTP2 = 3
    HTTPS = 4
    INVALID = 5
    SSL = 6
    TCP = 7
    UDP = 8

  checkIntervalSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  grpcHealthCheck = _messages.MessageField('GRPCHealthCheck', 4)
  grpcTlsHealthCheck = _messages.MessageField('GRPCTLSHealthCheck', 5)
  healthyThreshold = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  http2HealthCheck = _messages.MessageField('HTTP2HealthCheck', 7)
  httpHealthCheck = _messages.MessageField('HTTPHealthCheck', 8)
  httpsHealthCheck = _messages.MessageField('HTTPSHealthCheck', 9)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(11, default='compute#healthCheck')
  logConfig = _messages.MessageField('HealthCheckLogConfig', 12)
  name = _messages.StringField(13)
  region = _messages.StringField(14)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  sourceRegions = _messages.StringField(17, repeated=True)
  sslHealthCheck = _messages.MessageField('SSLHealthCheck', 18)
  tcpHealthCheck = _messages.MessageField('TCPHealthCheck', 19)
  timeoutSec = _messages.IntegerField(20, variant=_messages.Variant.INT32)
  type = _messages.EnumField('TypeValueValuesEnum', 21)
  udpHealthCheck = _messages.MessageField('UDPHealthCheck', 22)
  unhealthyThreshold = _messages.IntegerField(23, variant=_messages.Variant.INT32)


class HealthCheckList(_messages.Message):
  r"""Contains a list of HealthCheck resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthCheck resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('HealthCheck', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#healthCheckList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class HealthCheckLogConfig(_messages.Message):
  r"""Configuration of logging on a health check. If logging is enabled, logs
  will be exported to Stackdriver.

  Fields:
    enable: Indicates whether or not to export logs. This is false by default,
      which means no health check logging will be done.
  """

  enable = _messages.BooleanField(1)


class HealthCheckReference(_messages.Message):
  r"""A full or valid partial URL to a health check. For example, the
  following are valid URLs: -
  https://www.googleapis.com/compute/beta/projects/project-
  id/global/httpHealthChecks/health-check - projects/project-
  id/global/httpHealthChecks/health-check - global/httpHealthChecks/health-
  check

  Fields:
    healthCheck: A string attribute.
  """

  healthCheck = _messages.StringField(1)


class HealthCheckService(_messages.Message):
  r"""Represents a Health-Check as a Service resource.

  Enums:
    HealthStatusAggregationPolicyValueValuesEnum: Optional. Policy for how the
      results from multiple health checks for the same endpoint are
      aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION.
      An EndpointHealth message is returned for each pair in the health check
      service. - AND. If any health check of an endpoint reports UNHEALTHY,
      then UNHEALTHY is the HealthState of the endpoint. If all health checks
      report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is
      only allowed with regional HealthCheckService.
    HealthStatusAggregationStrategyValueValuesEnum: This field is deprecated.
      Use health_status_aggregation_policy instead. Policy for how the results
      from multiple health checks for the same endpoint are aggregated. -
      NO_AGGREGATION. An EndpointHealth message is returned for each backend
      in the health check service. - AND. If any backend's health check
      reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire
      health check service. If all backend's are healthy, the HealthState of
      the health check service is HEALTHY. .

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a HealthCheckService. An up-to-date
      fingerprint must be provided in order to patch/update the
      HealthCheckService; Otherwise, the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve the HealthCheckService.
    healthChecks: A list of URLs to the HealthCheck resources. Must have at
      least one HealthCheck, and not more than 10 for regional
      HealthCheckService, and not more than 1 for global HealthCheckService.
      HealthCheck resources must have portSpecification=USE_SERVING_PORT or
      portSpecification=USE_FIXED_PORT. For regional HealthCheckService, the
      HealthCheck must be regional and in the same region. For global
      HealthCheckService, HealthCheck must be global. Mix of regional and
      global HealthChecks is not supported. Multiple regional HealthChecks
      must belong to the same region. Regional HealthChecks must belong to the
      same region as zones of NetworkEndpointGroups. For global
      HealthCheckService using global INTERNET_IP_PORT NetworkEndpointGroups,
      the global HealthChecks must specify sourceRegions, and HealthChecks
      that specify sourceRegions can only be used with global INTERNET_IP_PORT
      NetworkEndpointGroups.
    healthStatusAggregationPolicy: Optional. Policy for how the results from
      multiple health checks for the same endpoint are aggregated. Defaults to
      NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth
      message is returned for each pair in the health check service. - AND. If
      any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the
      HealthState of the endpoint. If all health checks report HEALTHY, the
      HealthState of the endpoint is HEALTHY. . This is only allowed with
      regional HealthCheckService.
    healthStatusAggregationStrategy: This field is deprecated. Use
      health_status_aggregation_policy instead. Policy for how the results
      from multiple health checks for the same endpoint are aggregated. -
      NO_AGGREGATION. An EndpointHealth message is returned for each backend
      in the health check service. - AND. If any backend's health check
      reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire
      health check service. If all backend's are healthy, the HealthState of
      the health check service is HEALTHY. .
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output only] Type of the resource. Always
      compute#healthCheckServicefor health check services.
    name: Name of the resource. The name must be 1-63 characters long, and
      comply with RFC1035. Specifically, the name must be 1-63 characters long
      and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    networkEndpointGroups: A list of URLs to the NetworkEndpointGroup
      resources. Must not have more than 100. For regional HealthCheckService,
      NEGs must be in zones in the region of the HealthCheckService. For
      global HealthCheckServices, the NetworkEndpointGroups must be global
      INTERNET_IP_PORT.
    notificationEndpoints: A list of URLs to the NotificationEndpoint
      resources. Must not have more than 10. A list of endpoints for receiving
      notifications of change in health status. For regional
      HealthCheckService, NotificationEndpoint must be regional and in the
      same region. For global HealthCheckService, NotificationEndpoint must be
      global.
    region: [Output Only] URL of the region where the health check service
      resides. This field is not applicable to global health check services.
      You must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
  """

  class HealthStatusAggregationPolicyValueValuesEnum(_messages.Enum):
    r"""Optional. Policy for how the results from multiple health checks for
    the same endpoint are aggregated. Defaults to NO_AGGREGATION if
    unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for
    each pair in the health check service. - AND. If any health check of an
    endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the
    endpoint. If all health checks report HEALTHY, the HealthState of the
    endpoint is HEALTHY. . This is only allowed with regional
    HealthCheckService.

    Values:
      AND: If any backend's health check reports UNHEALTHY, then UNHEALTHY is
        the HealthState of the entire health check service. If all backend's
        are healthy, the HealthState of the health check service is HEALTHY.
      NO_AGGREGATION: An EndpointHealth message is returned for each backend
        in the health check service.
    """
    AND = 0
    NO_AGGREGATION = 1

  class HealthStatusAggregationStrategyValueValuesEnum(_messages.Enum):
    r"""This field is deprecated. Use health_status_aggregation_policy
    instead. Policy for how the results from multiple health checks for the
    same endpoint are aggregated. - NO_AGGREGATION. An EndpointHealth message
    is returned for each backend in the health check service. - AND. If any
    backend's health check reports UNHEALTHY, then UNHEALTHY is the
    HealthState of the entire health check service. If all backend's are
    healthy, the HealthState of the health check service is HEALTHY. .

    Values:
      AND: This is deprecated. Use health_status_aggregation_policy instead.
        If any backend's health check reports UNHEALTHY, then UNHEALTHY is the
        HealthState of the entire health check service. If all backend's are
        healthy, the HealthState of the health check service is HEALTHY.
      NO_AGGREGATION: This is deprecated. Use health_status_aggregation_policy
        instead. An EndpointHealth message is returned for each backend in the
        health check service.
    """
    AND = 0
    NO_AGGREGATION = 1

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  healthChecks = _messages.StringField(4, repeated=True)
  healthStatusAggregationPolicy = _messages.EnumField('HealthStatusAggregationPolicyValueValuesEnum', 5)
  healthStatusAggregationStrategy = _messages.EnumField('HealthStatusAggregationStrategyValueValuesEnum', 6)
  id = _messages.IntegerField(7, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(8, default='compute#healthCheckService')
  name = _messages.StringField(9)
  networkEndpointGroups = _messages.StringField(10, repeated=True)
  notificationEndpoints = _messages.StringField(11, repeated=True)
  region = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)


class HealthCheckServiceAggregatedList(_messages.Message):
  r"""Contains a list of HealthCheckServicesScopedList.

  Messages:
    ItemsValue: A list of HealthCheckServicesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthCheckServicesScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of HealthCheckServicesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        HealthCheckServices.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A HealthCheckServicesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('HealthCheckServicesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#healthCheckServiceAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class HealthCheckServiceReference(_messages.Message):
  r"""A full or valid partial URL to a health check service. For example, the
  following are valid URLs: -
  https://www.googleapis.com/compute/beta/projects/project-id/regions/us-
  west1/healthCheckServices/health-check-service - projects/project-
  id/regions/us-west1/healthCheckServices/health-check-service - regions/us-
  west1/healthCheckServices/health-check-service

  Fields:
    healthCheckService: A string attribute.
  """

  healthCheckService = _messages.StringField(1)


class HealthCheckServicesList(_messages.Message):
  r"""A HealthCheckServicesList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthCheckService resources.
    kind: [Output Only] Type of the resource. Always
      compute#healthCheckServicesList for lists of HealthCheckServices.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('HealthCheckService', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#healthCheckServicesList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class HealthCheckServicesScopedList(_messages.Message):
  r"""A HealthCheckServicesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    resources: A list of HealthCheckServices contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  resources = _messages.MessageField('HealthCheckService', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class HealthChecksAggregatedList(_messages.Message):
  r"""A HealthChecksAggregatedList object.

  Messages:
    ItemsValue: A list of HealthChecksScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthChecksScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of HealthChecksScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        HealthChecks.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A HealthChecksScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('HealthChecksScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#healthChecksAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class HealthChecksScopedList(_messages.Message):
  r"""A HealthChecksScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    healthChecks: A list of HealthChecks contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  healthChecks = _messages.MessageField('HealthCheck', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class HealthSource(_messages.Message):
  r"""Represents a health source. A health source resource specifies the
  source resources and the health aggregation policy applied to the source
  resources to determine the aggregated health status.

  Enums:
    SourceTypeValueValuesEnum: Specifies the type of the HealthSource. The
      only allowed value is BACKEND_SERVICE. Must be specified when the
      HealthSource is created, and cannot be mutated.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a HealthSource. An up-to-date fingerprint
      must be provided in order to patch the HealthSource; Otherwise, the
      request will fail with error 412 conditionNotMet. To see the latest
      fingerprint, make a get() request to retrieve the HealthSource.
    healthAggregationPolicy: URL to the HealthAggregationPolicy resource. Must
      be set. Must be regional and in the same region as the HealthSource. Can
      be mutated.
    id: [Output Only] A unique identifier for this resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always compute#healthSource for
      health sources.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the health source resides.
      This field applies only to the regional resource. You must specify this
      field as part of the HTTP request URL. It is not settable as a field in
      the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
    sourceType: Specifies the type of the HealthSource. The only allowed value
      is BACKEND_SERVICE. Must be specified when the HealthSource is created,
      and cannot be mutated.
    sources: URLs to the source resources. Must be size 1. Must be a
      BackendService if the sourceType is BACKEND_SERVICE. The BackendService
      must have load balancing scheme INTERNAL or INTERNAL_MANAGED and must be
      regional and in the same region as the HealthSource (cross-region
      deployment for INTERNAL_MANAGED is not supported). The BackendService
      may use only IGs, MIGs, or NEGs of type GCE_VM_IP or GCE_VM_IP_PORT. The
      BackendService may not use haPolicy. Can be mutated.
  """

  class SourceTypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of the HealthSource. The only allowed value is
    BACKEND_SERVICE. Must be specified when the HealthSource is created, and
    cannot be mutated.

    Values:
      BACKEND_SERVICE: <no description>
    """
    BACKEND_SERVICE = 0

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  healthAggregationPolicy = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default='compute#healthSource')
  name = _messages.StringField(7)
  region = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)
  sourceType = _messages.EnumField('SourceTypeValueValuesEnum', 11)
  sources = _messages.StringField(12, repeated=True)


class HealthSourceAggregatedList(_messages.Message):
  r"""Contains a list of HealthSourcesScopedList.

  Messages:
    ItemsValue: A list of HealthSourcesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthSourcesScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of HealthSourcesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        HealthSources.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A HealthSourcesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('HealthSourcesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#healthSourceAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class HealthSourceList(_messages.Message):
  r"""A HealthSourceList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthSource resources.
    kind: [Output Only] Type of the resource. Always compute#healthSource for
      health sources.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('HealthSource', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#healthSourceList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class HealthSourcesScopedList(_messages.Message):
  r"""A HealthSourcesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of health
      sources when the list is empty.

  Fields:
    resources: A list of HealthSources contained in this scope.
    warning: Informational warning which replaces the list of health sources
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of health sources when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  resources = _messages.MessageField('HealthSource', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class HealthStatus(_messages.Message):
  r"""A HealthStatus object.

  Enums:
    HealthStateValueValuesEnum: Health state of the IPv4 address of the
      instance.
    Ipv6HealthStateValueValuesEnum: Health state of the IPv6 address of the
      instance.
    WeightErrorValueValuesEnum:

  Messages:
    AnnotationsValue: Metadata defined as annotations for network endpoint.

  Fields:
    annotations: Metadata defined as annotations for network endpoint.
    forwardingRule: URL of the forwarding rule associated with the health
      status of the instance.
    forwardingRuleIp: A forwarding rule IP address assigned to this instance.
    healthState: Health state of the IPv4 address of the instance.
    instance: URL of the instance resource.
    ipAddress: For target pool based Network Load Balancing, it indicates the
      forwarding rule's IP address assigned to this instance. For other types
      of load balancing, the field indicates VM internal ip.
    ipv6Address: A string attribute.
    ipv6HealthState: Health state of the IPv6 address of the instance.
    port: The named port of the instance group, not necessarily the port that
      is health-checked.
    weight: A string attribute.
    weightError: A WeightErrorValueValuesEnum attribute.
  """

  class HealthStateValueValuesEnum(_messages.Enum):
    r"""Health state of the IPv4 address of the instance.

    Values:
      HEALTHY: <no description>
      UNHEALTHY: <no description>
    """
    HEALTHY = 0
    UNHEALTHY = 1

  class Ipv6HealthStateValueValuesEnum(_messages.Enum):
    r"""Health state of the IPv6 address of the instance.

    Values:
      HEALTHY: <no description>
      UNHEALTHY: <no description>
    """
    HEALTHY = 0
    UNHEALTHY = 1

  class WeightErrorValueValuesEnum(_messages.Enum):
    r"""WeightErrorValueValuesEnum enum type.

    Values:
      INVALID_WEIGHT: The response to a Health Check probe had the HTTP
        response header field X-Load-Balancing-Endpoint-Weight, but its
        content was invalid (i.e., not a non-negative single-precision
        floating-point number in decimal string representation).
      MISSING_WEIGHT: The response to a Health Check probe did not have the
        HTTP response header field X-Load-Balancing-Endpoint-Weight.
      UNAVAILABLE_WEIGHT: This is the value when the accompanied health status
        is either TIMEOUT (i.e.,the Health Check probe was not able to get a
        response in time) or UNKNOWN. For the latter, it should be typically
        because there has not been sufficient time to parse and report the
        weight for a new backend (which is with 0.0.0.0 ip address). However,
        it can be also due to an outage case for which the health status is
        explicitly reset to UNKNOWN.
      WEIGHT_NONE: This is the default value when WeightReportMode is DISABLE,
        and is also the initial value when WeightReportMode has just updated
        to ENABLE or DRY_RUN and there has not been sufficient time to parse
        and report the backend weight.
    """
    INVALID_WEIGHT = 0
    MISSING_WEIGHT = 1
    UNAVAILABLE_WEIGHT = 2
    WEIGHT_NONE = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Metadata defined as annotations for network endpoint.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  forwardingRule = _messages.StringField(2)
  forwardingRuleIp = _messages.StringField(3)
  healthState = _messages.EnumField('HealthStateValueValuesEnum', 4)
  instance = _messages.StringField(5)
  ipAddress = _messages.StringField(6)
  ipv6Address = _messages.StringField(7)
  ipv6HealthState = _messages.EnumField('Ipv6HealthStateValueValuesEnum', 8)
  port = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  weight = _messages.StringField(10)
  weightError = _messages.EnumField('WeightErrorValueValuesEnum', 11)


class HealthStatusForNetworkEndpoint(_messages.Message):
  r"""A HealthStatusForNetworkEndpoint object.

  Enums:
    HealthStateValueValuesEnum: Health state of the network endpoint
      determined based on the health checks configured.
    Ipv6HealthStateValueValuesEnum: Health state of the ipv6 network endpoint
      determined based on the health checks configured.

  Fields:
    backendService: URL of the backend service associated with the health
      state of the network endpoint.
    forwardingRule: URL of the forwarding rule associated with the health
      state of the network endpoint.
    healthCheck: URL of the health check associated with the health state of
      the network endpoint.
    healthCheckService: URL of the health check service associated with the
      health state of the network endpoint.
    healthState: Health state of the network endpoint determined based on the
      health checks configured.
    ipv6HealthState: Health state of the ipv6 network endpoint determined
      based on the health checks configured.
  """

  class HealthStateValueValuesEnum(_messages.Enum):
    r"""Health state of the network endpoint determined based on the health
    checks configured.

    Values:
      DRAINING: Endpoint is being drained.
      HEALTHY: Endpoint is healthy.
      UNHEALTHY: Endpoint is unhealthy.
      UNKNOWN: Health status of the endpoint is unknown.
    """
    DRAINING = 0
    HEALTHY = 1
    UNHEALTHY = 2
    UNKNOWN = 3

  class Ipv6HealthStateValueValuesEnum(_messages.Enum):
    r"""Health state of the ipv6 network endpoint determined based on the
    health checks configured.

    Values:
      DRAINING: Endpoint is being drained.
      HEALTHY: Endpoint is healthy.
      UNHEALTHY: Endpoint is unhealthy.
      UNKNOWN: Health status of the endpoint is unknown.
    """
    DRAINING = 0
    HEALTHY = 1
    UNHEALTHY = 2
    UNKNOWN = 3

  backendService = _messages.MessageField('BackendServiceReference', 1)
  forwardingRule = _messages.MessageField('ForwardingRuleReference', 2)
  healthCheck = _messages.MessageField('HealthCheckReference', 3)
  healthCheckService = _messages.MessageField('HealthCheckServiceReference', 4)
  healthState = _messages.EnumField('HealthStateValueValuesEnum', 5)
  ipv6HealthState = _messages.EnumField('Ipv6HealthStateValueValuesEnum', 6)


class Help(_messages.Message):
  r"""Provides links to documentation or for performing an out of band action.
  For example, if a quota check failed with an error indicating the calling
  project hasn't enabled the accessed service, this can contain a URL pointing
  directly to the right place in the developer console to flip the bit.

  Fields:
    links: URL(s) pointing to additional information on handling the current
      error.
  """

  links = _messages.MessageField('HelpLink', 1, repeated=True)


class HelpLink(_messages.Message):
  r"""Describes a URL link.

  Fields:
    description: Describes what the link offers.
    url: The URL of the link.
  """

  description = _messages.StringField(1)
  url = _messages.StringField(2)


class HostRule(_messages.Message):
  r"""UrlMaps A host-matching rule for a URL. If matched, will use the named
  PathMatcher to select the BackendService.

  Fields:
    description: An optional description of this resource. Provide this
      property when you create the resource.
    hosts: The list of host patterns to match. They must be valid hostnames
      with optional port numbers in the format host:port. * matches any string
      of ([a-z0-9-.]*). In that case, * must be the first character, and if
      followed by anything, the immediate following character must be either -
      or .. * based matching is not supported when the URL map is bound to a
      target gRPC proxy that has the validateForProxyless field set to true.
    pathMatcher: The name of the PathMatcher to use to match the path portion
      of the URL if the hostRule matches the URL's host portion.
  """

  description = _messages.StringField(1)
  hosts = _messages.StringField(2, repeated=True)
  pathMatcher = _messages.StringField(3)


class HttpFaultAbort(_messages.Message):
  r"""Specification for how requests are aborted as part of fault injection.

  Fields:
    httpStatus: The HTTP status code used to abort the request. The value must
      be from 200 to 599 inclusive. For gRPC protocol, the gRPC status code is
      mapped to HTTP status code according to this mapping table. HTTP status
      200 is mapped to gRPC status UNKNOWN. Injecting an OK status is
      currently not supported by Traffic Director.
    percentage: The percentage of traffic for connections, operations, or
      requests that is aborted as part of fault injection. The value must be
      from 0.0 to 100.0 inclusive.
  """

  httpStatus = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  percentage = _messages.FloatField(2)


class HttpFaultDelay(_messages.Message):
  r"""Specifies the delay introduced by the load balancer before forwarding
  the request to the backend service as part of fault injection.

  Fields:
    fixedDelay: Specifies the value of the fixed delay interval.
    percentage: The percentage of traffic for connections, operations, or
      requests for which a delay is introduced as part of fault injection. The
      value must be from 0.0 to 100.0 inclusive.
  """

  fixedDelay = _messages.MessageField('Duration', 1)
  percentage = _messages.FloatField(2)


class HttpFaultInjection(_messages.Message):
  r"""The specification for fault injection introduced into traffic to test
  the resiliency of clients to backend service failure. As part of fault
  injection, when clients send requests to a backend service, delays can be
  introduced by the load balancer on a percentage of requests before sending
  those request to the backend service. Similarly requests from clients can be
  aborted by the load balancer for a percentage of requests.

  Fields:
    abort: The specification for how client requests are aborted as part of
      fault injection.
    delay: The specification for how client requests are delayed as part of
      fault injection, before being sent to a backend service.
  """

  abort = _messages.MessageField('HttpFaultAbort', 1)
  delay = _messages.MessageField('HttpFaultDelay', 2)


class HttpFilterConfig(_messages.Message):
  r"""HttpFilterConfiguration supplies additional contextual settings for
  networkservices.HttpFilter resources enabled by Traffic Director.

  Fields:
    config: The configuration needed to enable the networkservices.HttpFilter
      resource. The configuration must be YAML formatted and only contain
      fields defined in the protobuf identified in configTypeUrl
    configTypeUrl: The fully qualified versioned proto3 type url of the
      protobuf that the filter expects for its contextual settings, for
      example: type.googleapis.com/google.protobuf.Struct
    filterName: Name of the networkservices.HttpFilter resource this
      configuration belongs to. This name must be known to the xDS client.
      Example: envoy.wasm
  """

  config = _messages.StringField(1)
  configTypeUrl = _messages.StringField(2)
  filterName = _messages.StringField(3)


class HttpHeaderAction(_messages.Message):
  r"""The request and response header transformations that take effect before
  the request is passed along to the selected backendService.

  Fields:
    requestHeadersToAdd: Headers to add to a matching request before
      forwarding the request to the backendService.
    requestHeadersToRemove: A list of header names for headers that need to be
      removed from the request before forwarding the request to the
      backendService.
    responseHeadersToAdd: Headers to add the response before sending the
      response back to the client.
    responseHeadersToRemove: A list of header names for headers that need to
      be removed from the response before sending the response back to the
      client.
  """

  requestHeadersToAdd = _messages.MessageField('HttpHeaderOption', 1, repeated=True)
  requestHeadersToRemove = _messages.StringField(2, repeated=True)
  responseHeadersToAdd = _messages.MessageField('HttpHeaderOption', 3, repeated=True)
  responseHeadersToRemove = _messages.StringField(4, repeated=True)


class HttpHeaderMatch(_messages.Message):
  r"""matchRule criteria for request header matches.

  Fields:
    exactMatch: The value should exactly match contents of exactMatch. Only
      one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or
      rangeMatch must be set.
    headerName: The name of the HTTP header to match. For matching against the
      HTTP request's authority, use a headerMatch with the header name
      ":authority". For matching a request's method, use the headerName
      ":method". When the URL map is bound to a target gRPC proxy that has the
      validateForProxyless field set to true, only non-binary user-specified
      custom metadata and the `content-type` header are supported. The
      following transport-level headers cannot be used in header matching
      rules: `:authority`, `:method`, `:path`, `:scheme`, `user-agent`,
      `accept-encoding`, `content-encoding`, `grpc-accept-encoding`, `grpc-
      encoding`, `grpc-previous-rpc-attempts`, `grpc-tags-bin`, `grpc-timeout`
      and `grpc-trace-bin`.
    invertMatch: If set to false, the headerMatch is considered a match if the
      preceding match criteria are met. If set to true, the headerMatch is
      considered a match if the preceding match criteria are NOT met. The
      default setting is false.
    prefixMatch: The value of the header must start with the contents of
      prefixMatch. Only one of exactMatch, prefixMatch, suffixMatch,
      regexMatch, presentMatch or rangeMatch must be set.
    presentMatch: A header with the contents of headerName must exist. The
      match takes place whether or not the request's header has a value. Only
      one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or
      rangeMatch must be set.
    rangeMatch: The header value must be an integer and its value must be in
      the range specified in rangeMatch. If the header does not contain an
      integer, number or is empty, the match fails. For example for a range
      [-5, 0] - -3 will match. - 0 will not match. - 0.25 will not match. -
      -3someString will not match. Only one of exactMatch, prefixMatch,
      suffixMatch, regexMatch, presentMatch or rangeMatch must be set.
      rangeMatch is not supported for load balancers that have
      loadBalancingScheme set to EXTERNAL.
    regexMatch: The value of the header must match the regular expression
      specified in regexMatch. For more information about regular expression
      syntax, see Syntax. For matching against a port specified in the HTTP
      request, use a headerMatch with headerName set to PORT and a regular
      expression that satisfies the RFC2616 Host header's port specifier. Only
      one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or
      rangeMatch must be set. Regular expressions can only be used when the
      loadBalancingScheme is set to INTERNAL_SELF_MANAGED.
    suffixMatch: The value of the header must end with the contents of
      suffixMatch. Only one of exactMatch, prefixMatch, suffixMatch,
      regexMatch, presentMatch or rangeMatch must be set.
  """

  exactMatch = _messages.StringField(1)
  headerName = _messages.StringField(2)
  invertMatch = _messages.BooleanField(3)
  prefixMatch = _messages.StringField(4)
  presentMatch = _messages.BooleanField(5)
  rangeMatch = _messages.MessageField('Int64RangeMatch', 6)
  regexMatch = _messages.StringField(7)
  suffixMatch = _messages.StringField(8)


class HttpHeaderOption(_messages.Message):
  r"""Specification determining how headers are added to requests or
  responses.

  Fields:
    headerName: The name of the header.
    headerValue: The value of the header to add.
    replace: If false, headerValue is appended to any values that already
      exist for the header. If true, headerValue is set for the header,
      discarding any values that were set for that header. The default value
      is false.
  """

  headerName = _messages.StringField(1)
  headerValue = _messages.StringField(2)
  replace = _messages.BooleanField(3)


class HttpHealthCheck(_messages.Message):
  r"""Represents a legacy HTTP Health Check resource. Legacy HTTP health
  checks are now only required by target pool-based network load balancers.
  For all other load balancers, including backend service-based network load
  balancers, and for managed instance group auto-healing, you must use modern
  (non-legacy) health checks. For more information, see Health checks overview
  .

  Fields:
    checkIntervalSec: How often (in seconds) to send a health check. The
      default value is 5 seconds.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    healthyThreshold: A so-far unhealthy instance will be marked healthy after
      this many consecutive successes. The default value is 2.
    host: The value of the host header in the HTTP health check request. If
      left empty (default value), the public IP on behalf of which this health
      check is performed will be used.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#httpHealthCheck
      for HTTP health checks.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    port: The TCP port number for the HTTP health check request. The default
      value is 80.
    requestPath: The request path of the HTTP health check request. The
      default value is /. This field does not support query parameters. Must
      comply with RFC3986.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    timeoutSec: How long (in seconds) to wait before claiming failure. The
      default value is 5 seconds. It is invalid for timeoutSec to have greater
      value than checkIntervalSec.
    unhealthyThreshold: A so-far healthy instance will be marked unhealthy
      after this many consecutive failures. The default value is 2.
  """

  checkIntervalSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  healthyThreshold = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  host = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#httpHealthCheck')
  name = _messages.StringField(8)
  port = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  requestPath = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  timeoutSec = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  unhealthyThreshold = _messages.IntegerField(14, variant=_messages.Variant.INT32)


class HttpHealthCheckList(_messages.Message):
  r"""Contains a list of HttpHealthCheck resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HttpHealthCheck resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('HttpHealthCheck', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#httpHealthCheckList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class HttpQueryParameterMatch(_messages.Message):
  r"""HttpRouteRuleMatch criteria for a request's query parameter.

  Fields:
    exactMatch: The queryParameterMatch matches if the value of the parameter
      exactly matches the contents of exactMatch. Only one of presentMatch,
      exactMatch, or regexMatch must be set.
    name: The name of the query parameter to match. The query parameter must
      exist in the request, in the absence of which the request match fails.
    presentMatch: Specifies that the queryParameterMatch matches if the
      request contains the query parameter, irrespective of whether the
      parameter has a value or not. Only one of presentMatch, exactMatch, or
      regexMatch must be set.
    regexMatch: The queryParameterMatch matches if the value of the parameter
      matches the regular expression specified by regexMatch. For more
      information about regular expression syntax, see Syntax. Only one of
      presentMatch, exactMatch, or regexMatch must be set. Regular expressions
      can only be used when the loadBalancingScheme is set to
      INTERNAL_SELF_MANAGED.
  """

  exactMatch = _messages.StringField(1)
  name = _messages.StringField(2)
  presentMatch = _messages.BooleanField(3)
  regexMatch = _messages.StringField(4)


class HttpRedirectAction(_messages.Message):
  r"""Specifies settings for an HTTP redirect.

  Enums:
    RedirectResponseCodeValueValuesEnum: The HTTP Status code to use for this
      RedirectAction. Supported values are: - MOVED_PERMANENTLY_DEFAULT, which
      is the default value and corresponds to 301. - FOUND, which corresponds
      to 302. - SEE_OTHER which corresponds to 303. - TEMPORARY_REDIRECT,
      which corresponds to 307. In this case, the request method is retained.
      - PERMANENT_REDIRECT, which corresponds to 308. In this case, the
      request method is retained.

  Fields:
    hostRedirect: The host that is used in the redirect response instead of
      the one that was supplied in the request. The value must be from 1 to
      255 characters.
    httpsRedirect: If set to true, the URL scheme in the redirected request is
      set to HTTPS. If set to false, the URL scheme of the redirected request
      remains the same as that of the request. This must only be set for URL
      maps used in TargetHttpProxys. Setting this true for TargetHttpsProxy is
      not permitted. The default is set to false.
    pathRedirect: The path that is used in the redirect response instead of
      the one that was supplied in the request. pathRedirect cannot be
      supplied together with prefixRedirect. Supply one alone or neither. If
      neither is supplied, the path of the original request is used for the
      redirect. The value must be from 1 to 1024 characters.
    prefixRedirect: The prefix that replaces the prefixMatch specified in the
      HttpRouteRuleMatch, retaining the remaining portion of the URL before
      redirecting the request. prefixRedirect cannot be supplied together with
      pathRedirect. Supply one alone or neither. If neither is supplied, the
      path of the original request is used for the redirect. The value must be
      from 1 to 1024 characters.
    redirectResponseCode: The HTTP Status code to use for this RedirectAction.
      Supported values are: - MOVED_PERMANENTLY_DEFAULT, which is the default
      value and corresponds to 301. - FOUND, which corresponds to 302. -
      SEE_OTHER which corresponds to 303. - TEMPORARY_REDIRECT, which
      corresponds to 307. In this case, the request method is retained. -
      PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
      method is retained.
    stripQuery: If set to true, any accompanying query portion of the original
      URL is removed before redirecting the request. If set to false, the
      query portion of the original URL is retained. The default is set to
      false.
  """

  class RedirectResponseCodeValueValuesEnum(_messages.Enum):
    r"""The HTTP Status code to use for this RedirectAction. Supported values
    are: - MOVED_PERMANENTLY_DEFAULT, which is the default value and
    corresponds to 301. - FOUND, which corresponds to 302. - SEE_OTHER which
    corresponds to 303. - TEMPORARY_REDIRECT, which corresponds to 307. In
    this case, the request method is retained. - PERMANENT_REDIRECT, which
    corresponds to 308. In this case, the request method is retained.

    Values:
      FOUND: Http Status Code 302 - Found.
      MOVED_PERMANENTLY_DEFAULT: Http Status Code 301 - Moved Permanently.
      PERMANENT_REDIRECT: Http Status Code 308 - Permanent Redirect
        maintaining HTTP method.
      SEE_OTHER: Http Status Code 303 - See Other.
      TEMPORARY_REDIRECT: Http Status Code 307 - Temporary Redirect
        maintaining HTTP method.
    """
    FOUND = 0
    MOVED_PERMANENTLY_DEFAULT = 1
    PERMANENT_REDIRECT = 2
    SEE_OTHER = 3
    TEMPORARY_REDIRECT = 4

  hostRedirect = _messages.StringField(1)
  httpsRedirect = _messages.BooleanField(2)
  pathRedirect = _messages.StringField(3)
  prefixRedirect = _messages.StringField(4)
  redirectResponseCode = _messages.EnumField('RedirectResponseCodeValueValuesEnum', 5)
  stripQuery = _messages.BooleanField(6)


class HttpRetryPolicy(_messages.Message):
  r"""The retry policy associates with HttpRouteRule

  Fields:
    numRetries: Specifies the allowed number retries. This number must be > 0.
      If not specified, defaults to 1.
    perTryTimeout: Specifies a non-zero timeout per retry attempt. If not
      specified, will use the timeout set in the HttpRouteAction field. If
      timeout in the HttpRouteAction field is not set, this field uses the
      largest timeout among all backend services associated with the route.
      Not supported when the URL map is bound to a target gRPC proxy that has
      the validateForProxyless field set to true.
    retryConditions: Specifies one or more conditions when this retry policy
      applies. Valid values are: - 5xx: retry is attempted if the instance or
      endpoint responds with any 5xx response code, or if the instance or
      endpoint does not respond at all. For example, disconnects, reset, read
      timeout, connection failure, and refused streams. - gateway-error:
      Similar to 5xx, but only applies to response codes 502, 503 or 504. -
      connect-failure: a retry is attempted on failures connecting to the
      instance or endpoint. For example, connection timeouts. - retriable-4xx:
      a retry is attempted if the instance or endpoint responds with a 4xx
      response code. The only error that you can retry is error code 409. -
      refused-stream: a retry is attempted if the instance or endpoint resets
      the stream with a REFUSED_STREAM error code. This reset type indicates
      that it is safe to retry. - cancelled: a retry is attempted if the gRPC
      status code in the response header is set to cancelled. - deadline-
      exceeded: a retry is attempted if the gRPC status code in the response
      header is set to deadline-exceeded. - internal: a retry is attempted if
      the gRPC status code in the response header is set to internal. -
      resource-exhausted: a retry is attempted if the gRPC status code in the
      response header is set to resource-exhausted. - unavailable: a retry is
      attempted if the gRPC status code in the response header is set to
      unavailable. Only the following codes are supported when the URL map is
      bound to target gRPC proxy that has validateForProxyless field set to
      true. - cancelled - deadline-exceeded - internal - resource-exhausted -
      unavailable
  """

  numRetries = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  perTryTimeout = _messages.MessageField('Duration', 2)
  retryConditions = _messages.StringField(3, repeated=True)


class HttpRouteAction(_messages.Message):
  r"""A HttpRouteAction object.

  Fields:
    corsPolicy: The specification for allowing client-side cross-origin
      requests. For more information about the W3C recommendation for cross-
      origin resource sharing (CORS), see Fetch API Living Standard. Not
      supported when the URL map is bound to a target gRPC proxy.
    faultInjectionPolicy: The specification for fault injection introduced
      into traffic to test the resiliency of clients to backend service
      failure. As part of fault injection, when clients send requests to a
      backend service, delays can be introduced by a load balancer on a
      percentage of requests before sending those requests to the backend
      service. Similarly requests from clients can be aborted by the load
      balancer for a percentage of requests. timeout and retry_policy is
      ignored by clients that are configured with a fault_injection_policy if:
      1. The traffic is generated by fault injection AND 2. The fault
      injection is not a delay fault injection. Fault injection is not
      supported with the classic Application Load Balancer . To see which load
      balancers support fault injection, see Load balancing: Routing and
      traffic management features.
    maxStreamDuration: Specifies the maximum duration (timeout) for streams on
      the selected route. Unlike the timeout field where the timeout duration
      starts from the time the request has been fully processed (known as
      *end-of-stream*), the duration in this field is computed from the
      beginning of the stream until the response has been processed, including
      all retries. A stream that does not complete in this duration is closed.
      If not specified, this field uses the maximum maxStreamDuration value
      among all backend services associated with the route. This field is only
      allowed if the Url map is used with backend services with
      loadBalancingScheme set to INTERNAL_SELF_MANAGED.
    requestMirrorPolicy: Specifies the policy on how requests intended for the
      route's backends are shadowed to a separate mirrored backend service.
      The load balancer does not wait for responses from the shadow service.
      Before sending traffic to the shadow service, the host / authority
      header is suffixed with -shadow. Not supported when the URL map is bound
      to a target gRPC proxy that has the validateForProxyless field set to
      true.
    retryPolicy: Specifies the retry policy associated with this route.
    timeout: Specifies the timeout for the selected route. Timeout is computed
      from the time the request has been fully processed (known as *end-of-
      stream*) up until the response has been processed. Timeout includes all
      retries. If not specified, this field uses the largest timeout among all
      backend services associated with the route. Not supported when the URL
      map is bound to a target gRPC proxy that has validateForProxyless field
      set to true.
    urlRewrite: The spec to modify the URL of the request, before forwarding
      the request to the matched service. urlRewrite is the only action
      supported in UrlMaps for classic Application Load Balancers. Not
      supported when the URL map is bound to a target gRPC proxy that has the
      validateForProxyless field set to true.
    weightedBackendServices: A list of weighted backend services to send
      traffic to when a route match occurs. The weights determine the fraction
      of traffic that flows to their corresponding backend service. If all
      traffic needs to go to a single backend service, there must be one
      weightedBackendService with weight set to a non-zero number. After a
      backend service is identified and before forwarding the request to the
      backend service, advanced routing actions such as URL rewrites and
      header transformations are applied depending on additional settings
      specified in this HttpRouteAction.
  """

  corsPolicy = _messages.MessageField('CorsPolicy', 1)
  faultInjectionPolicy = _messages.MessageField('HttpFaultInjection', 2)
  maxStreamDuration = _messages.MessageField('Duration', 3)
  requestMirrorPolicy = _messages.MessageField('RequestMirrorPolicy', 4)
  retryPolicy = _messages.MessageField('HttpRetryPolicy', 5)
  timeout = _messages.MessageField('Duration', 6)
  urlRewrite = _messages.MessageField('UrlRewrite', 7)
  weightedBackendServices = _messages.MessageField('WeightedBackendService', 8, repeated=True)


class HttpRouteRule(_messages.Message):
  r"""The HttpRouteRule setting specifies how to match an HTTP request and the
  corresponding routing action that load balancing proxies perform.

  Fields:
    customErrorResponsePolicy: customErrorResponsePolicy specifies how the
      Load Balancer returns error responses when BackendServiceor
      BackendBucket responds with an error. If a policy for an error code is
      not configured for the RouteRule, a policy for the error code configured
      in pathMatcher.defaultCustomErrorResponsePolicy is applied. If one is
      not specified in pathMatcher.defaultCustomErrorResponsePolicy, the
      policy configured in UrlMap.defaultCustomErrorResponsePolicy takes
      effect. For example, consider a UrlMap with the following configuration:
      - UrlMap.defaultCustomErrorResponsePolicy are configured with policies
      for 5xx and 4xx errors - A RouteRule for /coming_soon/ is configured for
      the error code 404. If the request is for www.myotherdomain.com and a
      404 is encountered, the policy under
      UrlMap.defaultCustomErrorResponsePolicy takes effect. If a 404 response
      is encountered for the request www.example.com/current_events/, the
      pathMatcher's policy takes effect. If however, the request for
      www.example.com/coming_soon/ encounters a 404, the policy in
      RouteRule.customErrorResponsePolicy takes effect. If any of the requests
      in this example encounter a 500 error code, the policy at
      UrlMap.defaultCustomErrorResponsePolicy takes effect. When used in
      conjunction with routeRules.routeAction.retryPolicy, retries take
      precedence. Only once all retries are exhausted, the
      customErrorResponsePolicy is applied. While attempting a retry, if load
      balancer is successful in reaching the service, the
      customErrorResponsePolicy is ignored and the response from the service
      is returned to the client. customErrorResponsePolicy is supported only
      for global external Application Load Balancers.
    description: The short description conveying the intent of this routeRule.
      The description can have a maximum length of 1024 characters.
    headerAction: Specifies changes to request and response headers that need
      to take effect for the selected backendService. The headerAction value
      specified here is applied before the matching
      pathMatchers[].headerAction and after pathMatchers[].routeRules[].routeA
      ction.weightedBackendService.backendServiceWeightAction[].headerAction
      HeaderAction is not supported for load balancers that have their
      loadBalancingScheme set to EXTERNAL. Not supported when the URL map is
      bound to a target gRPC proxy that has validateForProxyless field set to
      true.
    httpFilterConfigs: Outbound route specific configuration for
      networkservices.HttpFilter resources enabled by Traffic Director.
      httpFilterConfigs only applies for load balancers with
      loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for
      more details. Not supported when the URL map is bound to a target gRPC
      proxy that has validateForProxyless field set to true.
    httpFilterMetadata: Outbound route specific metadata supplied to
      networkservices.HttpFilter resources enabled by Traffic Director.
      httpFilterMetadata only applies for load balancers with
      loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for
      more details. The only configTypeUrl supported is
      type.googleapis.com/google.protobuf.Struct Not supported when the URL
      map is bound to a target gRPC proxy that has validateForProxyless field
      set to true.
    matchRules: The list of criteria for matching attributes of a request to
      this routeRule. This list has OR semantics: the request matches this
      routeRule when any of the matchRules are satisfied. However predicates
      within a given matchRule have AND semantics. All predicates within a
      matchRule must match for the request to match the rule.
    priority: For routeRules within a given pathMatcher, priority determines
      the order in which a load balancer interprets routeRules. RouteRules are
      evaluated in order of priority, from the lowest to highest number. The
      priority of a rule decreases as its number increases (1, 2, 3, N+1). The
      first rule that matches the request is applied. You cannot configure two
      or more routeRules with the same priority. Priority for each rule must
      be set to a number from 0 to 2147483647 inclusive. Priority numbers can
      have gaps, which enable you to add or remove rules in the future without
      affecting the rest of the rules. For example, 1, 2, 3, 4, 5, 9, 12, 16
      is a valid series of priority numbers to which you could add rules
      numbered from 6 to 8, 10 to 11, and 13 to 15 in the future without any
      impact on existing rules.
    routeAction: In response to a matching matchRule, the load balancer
      performs advanced routing actions, such as URL rewrites and header
      transformations, before forwarding the request to the selected backend.
      Only one of urlRedirect, service or routeAction.weightedBackendService
      can be set. URL maps for classic Application Load Balancers only support
      the urlRewrite action within a route rule's routeAction.
    service: The full or partial URL of the backend service resource to which
      traffic is directed if this rule is matched. If routeAction is also
      specified, advanced routing actions, such as URL rewrites, take effect
      before sending the request to the backend. Only one of urlRedirect,
      service or routeAction.weightedBackendService can be set.
    urlRedirect: When this rule is matched, the request is redirected to a URL
      specified by urlRedirect. Only one of urlRedirect, service or
      routeAction.weightedBackendService can be set. Not supported when the
      URL map is bound to a target gRPC proxy.
  """

  customErrorResponsePolicy = _messages.MessageField('CustomErrorResponsePolicy', 1)
  description = _messages.StringField(2)
  headerAction = _messages.MessageField('HttpHeaderAction', 3)
  httpFilterConfigs = _messages.MessageField('HttpFilterConfig', 4, repeated=True)
  httpFilterMetadata = _messages.MessageField('HttpFilterConfig', 5, repeated=True)
  matchRules = _messages.MessageField('HttpRouteRuleMatch', 6, repeated=True)
  priority = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  routeAction = _messages.MessageField('HttpRouteAction', 8)
  service = _messages.StringField(9)
  urlRedirect = _messages.MessageField('HttpRedirectAction', 10)


class HttpRouteRuleMatch(_messages.Message):
  r"""HttpRouteRuleMatch specifies a set of criteria for matching requests to
  an HttpRouteRule. All specified criteria must be satisfied for a match to
  occur.

  Fields:
    fullPathMatch: For satisfying the matchRule condition, the path of the
      request must exactly match the value specified in fullPathMatch after
      removing any query parameters and anchor that may be part of the
      original URL. fullPathMatch must be from 1 to 1024 characters. Only one
      of prefixMatch, fullPathMatch or regexMatch must be specified.
    headerMatches: Specifies a list of header match criteria, all of which
      must match corresponding headers in the request.
    ignoreCase: Specifies that prefixMatch and fullPathMatch matches are case
      sensitive. The default value is false. ignoreCase must not be used with
      regexMatch. Not supported when the URL map is bound to a target gRPC
      proxy.
    metadataFilters: Opaque filter criteria used by the load balancer to
      restrict routing configuration to a limited set of xDS compliant
      clients. In their xDS requests to the load balancer, xDS clients present
      node metadata. When there is a match, the relevant routing configuration
      is made available to those proxies. For each metadataFilter in this
      list, if its filterMatchCriteria is set to MATCH_ANY, at least one of
      the filterLabels must match the corresponding label provided in the
      metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of
      its filterLabels must match with corresponding labels provided in the
      metadata. If multiple metadata filters are specified, all of them need
      to be satisfied in order to be considered a match. metadataFilters
      specified here is applied after those specified in ForwardingRule that
      refers to the UrlMap this HttpRouteRuleMatch belongs to. metadataFilters
      only applies to load balancers that have loadBalancingScheme set to
      INTERNAL_SELF_MANAGED. Not supported when the URL map is bound to a
      target gRPC proxy that has validateForProxyless field set to true.
    pathTemplateMatch: If specified, the route is a pattern match expression
      that must match the :path header once the query string is removed. A
      pattern match allows you to match - The value must be between 1 and 1024
      characters - The pattern must start with a leading slash ("/") - There
      may be no more than 5 operators in pattern Precisely one of
      prefix_match, full_path_match, regex_match or path_template_match must
      be set.
    prefixMatch: For satisfying the matchRule condition, the request's path
      must begin with the specified prefixMatch. prefixMatch must begin with a
      /. The value must be from 1 to 1024 characters. Only one of prefixMatch,
      fullPathMatch or regexMatch must be specified.
    queryParameterMatches: Specifies a list of query parameter match criteria,
      all of which must match corresponding query parameters in the request.
      Not supported when the URL map is bound to a target gRPC proxy.
    regexMatch: For satisfying the matchRule condition, the path of the
      request must satisfy the regular expression specified in regexMatch
      after removing any query parameters and anchor supplied with the
      original URL. For more information about regular expression syntax, see
      Syntax. Only one of prefixMatch, fullPathMatch or regexMatch must be
      specified. Regular expressions can only be used when the
      loadBalancingScheme is set to INTERNAL_SELF_MANAGED.
  """

  fullPathMatch = _messages.StringField(1)
  headerMatches = _messages.MessageField('HttpHeaderMatch', 2, repeated=True)
  ignoreCase = _messages.BooleanField(3)
  metadataFilters = _messages.MessageField('MetadataFilter', 4, repeated=True)
  pathTemplateMatch = _messages.StringField(5)
  prefixMatch = _messages.StringField(6)
  queryParameterMatches = _messages.MessageField('HttpQueryParameterMatch', 7, repeated=True)
  regexMatch = _messages.StringField(8)


class HttpsHealthCheck(_messages.Message):
  r"""Represents a legacy HTTPS Health Check resource. Legacy HTTPS health
  checks have been deprecated. If you are using a target pool-based network
  load balancer, you must use a legacy HTTP (not HTTPS) health check. For all
  other load balancers, including backend service-based network load
  balancers, and for managed instance group auto-healing, you must use modern
  (non-legacy) health checks. For more information, see Health checks overview
  .

  Fields:
    checkIntervalSec: How often (in seconds) to send a health check. The
      default value is 5 seconds.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    healthyThreshold: A so-far unhealthy instance will be marked healthy after
      this many consecutive successes. The default value is 2.
    host: The value of the host header in the HTTPS health check request. If
      left empty (default value), the public IP on behalf of which this health
      check is performed will be used.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: Type of the resource.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    port: The TCP port number for the HTTPS health check request. The default
      value is 443.
    requestPath: The request path of the HTTPS health check request. The
      default value is "/". Must comply with RFC3986.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    timeoutSec: How long (in seconds) to wait before claiming failure. The
      default value is 5 seconds. It is invalid for timeoutSec to have a
      greater value than checkIntervalSec.
    unhealthyThreshold: A so-far healthy instance will be marked unhealthy
      after this many consecutive failures. The default value is 2.
  """

  checkIntervalSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  healthyThreshold = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  host = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#httpsHealthCheck')
  name = _messages.StringField(8)
  port = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  requestPath = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  timeoutSec = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  unhealthyThreshold = _messages.IntegerField(14, variant=_messages.Variant.INT32)


class HttpsHealthCheckList(_messages.Message):
  r"""Contains a list of HttpsHealthCheck resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HttpsHealthCheck resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('HttpsHealthCheck', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#httpsHealthCheckList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class Image(_messages.Message):
  r"""Represents an Image resource. You can use images to create boot disks
  for your VM instances. For more information, read Images.

  Enums:
    ArchitectureValueValuesEnum: The architecture of the image. Valid values
      are ARM64 or X86_64.
    SourceTypeValueValuesEnum: The type of the image used to create this disk.
      The default and only valid value is RAW.
    StatusValueValuesEnum: [Output Only] The status of the image. An image can
      be used to create other resources, such as instances, only after the
      image has been successfully created and the status is set to READY.
      Possible values are FAILED, PENDING, or READY.

  Messages:
    LabelsValue: Labels to apply to this image. These can be later modified by
      the setLabels method.
    RawDiskValue: The parameters of the raw disk image.

  Fields:
    architecture: The architecture of the image. Valid values are ARM64 or
      X86_64.
    archiveSizeBytes: Size of the image tar.gz archive stored in Google Cloud
      Storage (in bytes).
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: The deprecation status associated with this image.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    diskSizeGb: Size of the image when restored onto a persistent disk (in
      GB).
    enableConfidentialCompute: Whether this image is created from a
      confidential compute mode disk. [Output Only]: This field is not set by
      user, but from source disk.
    family: The name of the image family to which this image belongs. The
      image family name can be from a publicly managed image family provided
      by Compute Engine, or from a custom image family you create. For
      example, centos-stream-9 is a publicly available image family. For more
      information, see Image family best practices. When creating disks, you
      can specify an image family instead of a specific image name. The image
      family always returns its latest image that is not deprecated. The name
      of the image family must comply with RFC1035.
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. To see a list of available
      options, see the guestOSfeatures[].type parameter.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    imageEncryptionKey: Encrypts the image using a customer-supplied
      encryption key. After you encrypt an image with a customer-supplied key,
      you must provide the same key if you use the image later (e.g. to create
      a disk from the image). Customer-supplied encryption keys do not protect
      access to metadata of the disk. If you do not provide an encryption key
      when creating the image, then the disk will be encrypted using an
      automatically generated key and you do not need to provide a key to use
      the image later.
    kind: [Output Only] Type of the resource. Always compute#image for images.
    labelFingerprint: A fingerprint for the labels being applied to this
      image, which is essentially a hash of the labels used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update labels. You must always
      provide an up-to-date fingerprint hash in order to update or change
      labels, otherwise the request will fail with error 412 conditionNotMet.
      To see the latest fingerprint, make a get() request to retrieve an
      image.
    labels: Labels to apply to this image. These can be later modified by the
      setLabels method.
    licenseCodes: Integer license codes indicating which licenses are attached
      to this image.
    licenses: Any applicable license URI.
    locked: A flag for marketplace VM disk created from the image, which is
      designed for marketplace VM disk to prevent the proprietary data on the
      disk from being accessed unwantedly. The flag will be inherited by the
      disk created from the image. The disk with locked flag set to true will
      be prohibited from performing the operations below: - R/W or R/O disk
      attach - Disk detach, if disk is created via create-on-create - Create
      images - Create snapshots - Create disk clone (create disk from the
      current disk) The image with the locked field set to true will be
      prohibited from performing the operations below: - Create images from
      the current image - Update the locked field for the current image The
      instance with at least one disk with locked flag set to true will be
      prohibited from performing the operations below: - Secondary disk attach
      - Create instant snapshot - Create machine images - Create instance
      template - Delete the instance with --keep-disk parameter set to true
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    rawDisk: The parameters of the raw disk image.
    rolloutOverride: A rollout policy to apply to this image. When specified,
      the rollout policy overrides per-zone references to the image via the
      associated image family. The rollout policy restricts the zones where
      this image is accessible when using a zonal image family reference. When
      the rollout policy does not include the user specified zone, or if the
      zone is rolled out, this image is accessible. The rollout policy for
      this image is read-only, except for allowlisted users. This field might
      not be configured. To view the latest non-deprecated image in a specific
      zone, use the imageFamilyViews.get method.
    satisfiesPzi: Output only. Reserved for future use.
    satisfiesPzs: [Output Only] Reserved for future use.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    shieldedInstanceInitialState: Set the secure boot keys of shielded
      instance.
    sourceDisk: URL of the source disk used to create this image. For example,
      the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /disks/disk - projects/project/zones/zone/disks/disk -
      zones/zone/disks/disk In order to create an image, you must provide the
      full or partial URL of one of the following: - The rawDisk.source URL -
      The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL
    sourceDiskEncryptionKey: The customer-supplied encryption key of the
      source disk. Required if the source disk is protected by a customer-
      supplied encryption key.
    sourceDiskId: [Output Only] The ID value of the disk used to create this
      image. This value may be used to determine whether the image was taken
      from the current or a previous instance of a given disk name.
    sourceImage: URL of the source image used to create this image. The
      following are valid formats for the URL: -
      https://www.googleapis.com/compute/v1/projects/project_id/global/
      images/image_name - projects/project_id/global/images/image_name In
      order to create an image, you must provide the full or partial URL of
      one of the following: - The rawDisk.source URL - The sourceDisk URL -
      The sourceImage URL - The sourceSnapshot URL
    sourceImageEncryptionKey: The customer-supplied encryption key of the
      source image. Required if the source image is protected by a customer-
      supplied encryption key.
    sourceImageId: [Output Only] The ID value of the image used to create this
      image. This value may be used to determine whether the image was taken
      from the current or a previous instance of a given image name.
    sourceSnapshot: URL of the source snapshot used to create this image. The
      following are valid formats for the URL: -
      https://www.googleapis.com/compute/v1/projects/project_id/global/
      snapshots/snapshot_name -
      projects/project_id/global/snapshots/snapshot_name In order to create an
      image, you must provide the full or partial URL of one of the following:
      - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL -
      The sourceSnapshot URL
    sourceSnapshotEncryptionKey: The customer-supplied encryption key of the
      source snapshot. Required if the source snapshot is protected by a
      customer-supplied encryption key.
    sourceSnapshotId: [Output Only] The ID value of the snapshot used to
      create this image. This value may be used to determine whether the
      snapshot was taken from the current or a previous instance of a given
      snapshot name.
    sourceType: The type of the image used to create this disk. The default
      and only valid value is RAW.
    status: [Output Only] The status of the image. An image can be used to
      create other resources, such as instances, only after the image has been
      successfully created and the status is set to READY. Possible values are
      FAILED, PENDING, or READY.
    storageLocations: Cloud Storage bucket storage location of the image
      (regional or multi-regional).
    userLicenses: A list of publicly visible user-licenses. Unlike regular
      licenses, user provided licenses can be modified after the disk is
      created. This includes a list of URLs to the license resource. For
      example, to provide a debian license:
      https://www.googleapis.com/compute/v1/projects/debian-
      cloud/global/licenses/debian-9-stretch
  """

  class ArchitectureValueValuesEnum(_messages.Enum):
    r"""The architecture of the image. Valid values are ARM64 or X86_64.

    Values:
      ARCHITECTURE_UNSPECIFIED: Default value indicating Architecture is not
        set.
      ARM64: Machines with architecture ARM64
      X86_64: Machines with architecture X86_64
    """
    ARCHITECTURE_UNSPECIFIED = 0
    ARM64 = 1
    X86_64 = 2

  class SourceTypeValueValuesEnum(_messages.Enum):
    r"""The type of the image used to create this disk. The default and only
    valid value is RAW.

    Values:
      RAW: <no description>
    """
    RAW = 0

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the image. An image can be used to create
    other resources, such as instances, only after the image has been
    successfully created and the status is set to READY. Possible values are
    FAILED, PENDING, or READY.

    Values:
      DELETING: Image is deleting.
      FAILED: Image creation failed due to an error.
      PENDING: Image hasn't been created as yet.
      READY: Image has been successfully created.
    """
    DELETING = 0
    FAILED = 1
    PENDING = 2
    READY = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this image. These can be later modified by the
    setLabels method.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class RawDiskValue(_messages.Message):
    r"""The parameters of the raw disk image.

    Enums:
      ContainerTypeValueValuesEnum: The format used to encode and transmit the
        block device, which should be TAR. This is just a container and
        transmission format and not a runtime format. Provided by the client
        when the disk image is created.

    Fields:
      containerType: The format used to encode and transmit the block device,
        which should be TAR. This is just a container and transmission format
        and not a runtime format. Provided by the client when the disk image
        is created.
      sha1Checksum: [Deprecated] This field is deprecated. An optional SHA1
        checksum of the disk image before unpackaging provided by the client
        when the disk image is created.
      source: The full Google Cloud Storage URL where the raw disk image
        archive is stored. The following are valid formats for the URL: -
        https://storage.googleapis.com/bucket_name/image_archive_name -
        https://storage.googleapis.com/bucket_name/folder_name/
        image_archive_name In order to create an image, you must provide the
        full or partial URL of one of the following: - The rawDisk.source URL
        - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL
    """

    class ContainerTypeValueValuesEnum(_messages.Enum):
      r"""The format used to encode and transmit the block device, which
      should be TAR. This is just a container and transmission format and not
      a runtime format. Provided by the client when the disk image is created.

      Values:
        TAR: <no description>
      """
      TAR = 0

    containerType = _messages.EnumField('ContainerTypeValueValuesEnum', 1)
    sha1Checksum = _messages.StringField(2)
    source = _messages.StringField(3)

  architecture = _messages.EnumField('ArchitectureValueValuesEnum', 1)
  archiveSizeBytes = _messages.IntegerField(2)
  creationTimestamp = _messages.StringField(3)
  deprecated = _messages.MessageField('DeprecationStatus', 4)
  description = _messages.StringField(5)
  diskSizeGb = _messages.IntegerField(6)
  enableConfidentialCompute = _messages.BooleanField(7)
  family = _messages.StringField(8)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 9, repeated=True)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  imageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 11)
  kind = _messages.StringField(12, default='compute#image')
  labelFingerprint = _messages.BytesField(13)
  labels = _messages.MessageField('LabelsValue', 14)
  licenseCodes = _messages.IntegerField(15, repeated=True)
  licenses = _messages.StringField(16, repeated=True)
  locked = _messages.BooleanField(17)
  name = _messages.StringField(18)
  rawDisk = _messages.MessageField('RawDiskValue', 19)
  rolloutOverride = _messages.MessageField('RolloutPolicy', 20)
  satisfiesPzi = _messages.BooleanField(21)
  satisfiesPzs = _messages.BooleanField(22)
  selfLink = _messages.StringField(23)
  selfLinkWithId = _messages.StringField(24)
  shieldedInstanceInitialState = _messages.MessageField('InitialStateConfig', 25)
  sourceDisk = _messages.StringField(26)
  sourceDiskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 27)
  sourceDiskId = _messages.StringField(28)
  sourceImage = _messages.StringField(29)
  sourceImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 30)
  sourceImageId = _messages.StringField(31)
  sourceSnapshot = _messages.StringField(32)
  sourceSnapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 33)
  sourceSnapshotId = _messages.StringField(34)
  sourceType = _messages.EnumField('SourceTypeValueValuesEnum', 35, default='RAW')
  status = _messages.EnumField('StatusValueValuesEnum', 36)
  storageLocations = _messages.StringField(37, repeated=True)
  userLicenses = _messages.StringField(38, repeated=True)


class ImageFamilyView(_messages.Message):
  r"""A ImageFamilyView object.

  Fields:
    image: The latest image that is part of the specified image family in the
      requested location, and that is not deprecated.
  """

  image = _messages.MessageField('Image', 1)


class ImageList(_messages.Message):
  r"""Contains a list of images.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Image resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Image', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#imageList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InitialStateConfig(_messages.Message):
  r"""Initial State for shielded instance, these are public keys which are
  safe to store in public

  Fields:
    dbs: The Key Database (db).
    dbxs: The forbidden key database (dbx).
    keks: The Key Exchange Key (KEK).
    pk: The Platform Key (PK).
  """

  dbs = _messages.MessageField('FileContentBuffer', 1, repeated=True)
  dbxs = _messages.MessageField('FileContentBuffer', 2, repeated=True)
  keks = _messages.MessageField('FileContentBuffer', 3, repeated=True)
  pk = _messages.MessageField('FileContentBuffer', 4)


class Instance(_messages.Message):
  r"""Represents an Instance resource. An instance is a virtual machine that
  is hosted on Google Cloud Platform. For more information, read Virtual
  Machine Instances.

  Enums:
    KeyRevocationActionTypeValueValuesEnum: KeyRevocationActionType of the
      instance. Supported options are "STOP" and "NONE". The default value is
      "NONE" if it is not specified.
    PostKeyRevocationActionTypeValueValuesEnum: PostKeyRevocationActionType of
      the instance.
    PrivateIpv6GoogleAccessValueValuesEnum: The private IPv6 google access
      type for the VM. If not specified, use INHERIT_FROM_SUBNETWORK as
      default.
    StatusValueValuesEnum: [Output Only] The status of the instance. One of
      the following values: PROVISIONING, STAGING, RUNNING, STOPPING,
      SUSPENDING, SUSPENDED, REPAIRING, and TERMINATED. For more information
      about the status of the instance, see Instance life cycle.

  Messages:
    LabelsValue: Labels to apply to this instance. These can be later modified
      by the setLabels method.
    PartnerMetadataValue: Partner Metadata assigned to the instance. A map
      from a subdomain (namespace) to entries map.
    ServiceIntegrationSpecsValue: Mapping of user-defined keys to
      specifications for service integrations. Currently only a single key-
      value pair is supported.

  Fields:
    advancedMachineFeatures: Controls for advanced machine-related behavior
      features.
    canIpForward: Allows this instance to send and receive packets with non-
      matching destination or source IPs. This is required if you plan to use
      this instance to forward routes. For more information, see Enabling IP
      Forwarding .
    confidentialInstanceConfig: A ConfidentialInstanceConfig attribute.
    cpuPlatform: [Output Only] The CPU platform used by this instance.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deletionProtection: Whether the resource should be protected against
      deletion.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    disks: Array of disks associated with this instance. Persistent disks must
      be created before you can assign them.
    displayDevice: Enables display device for the instance.
    eraseWindowsVssSignature: Specifies whether the disks restored from source
      snapshots or source machine image should erase Windows specific VSS
      signature.
    fingerprint: Specifies a fingerprint for this resource, which is
      essentially a hash of the instance's contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update the instance. You must
      always provide an up-to-date fingerprint hash in order to update the
      instance. To see the latest fingerprint, make get() request to the
      instance.
    guestAccelerators: A list of the type and count of accelerator cards
      attached to the instance.
    hostname: Specifies the hostname of the instance. The specified hostname
      must be RFC1035 compliant. If hostname is not specified, the default
      hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the
      global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when
      using zonal DNS.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    instanceEncryptionKey: Encrypts suspended data for an instance with a
      customer-managed encryption key. If you are creating a new instance,
      this field will encrypt the local SSD and in-memory contents of the
      instance during the suspend operation. If you do not provide an
      encryption key when creating the instance, then the local SSD and in-
      memory contents will be encrypted using an automatically generated key
      during the suspend operation.
    keyRevocationActionType: KeyRevocationActionType of the instance.
      Supported options are "STOP" and "NONE". The default value is "NONE" if
      it is not specified.
    kind: [Output Only] Type of the resource. Always compute#instance for
      instances.
    labelFingerprint: A fingerprint for this request, which is essentially a
      hash of the label's contents and used for optimistic locking. The
      fingerprint is initially generated by Compute Engine and changes after
      every request to modify or update labels. You must always provide an up-
      to-date fingerprint hash in order to update or change labels. To see the
      latest fingerprint, make get() request to the instance.
    labels: Labels to apply to this instance. These can be later modified by
      the setLabels method.
    lastStartTimestamp: [Output Only] Last start timestamp in RFC3339 text
      format.
    lastStopTimestamp: [Output Only] Last stop timestamp in RFC3339 text
      format.
    lastSuspendedTimestamp: [Output Only] Last suspended timestamp in RFC3339
      text format.
    machineType: Full or partial URL of the machine type resource to use for
      this instance, in the format: zones/zone/machineTypes/machine-type. This
      is provided by the client when the instance is created. For example, the
      following is a valid partial url to a predefined machine type: zones/us-
      central1-f/machineTypes/n1-standard-1 To create a custom machine type,
      provide a URL to a machine type in the following format, where CPUS is 1
      or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the
      total memory for this instance. Memory must be a multiple of 256 MB and
      must be supplied in MB (e.g. 5 GB of memory is 5120 MB):
      zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-
      central1-f/machineTypes/custom-4-5120 For a full list of restrictions,
      read the Specifications for custom machine types.
    metadata: The metadata key/value pairs assigned to this instance. This
      includes custom metadata and predefined keys.
    minCpuPlatform: Specifies a minimum CPU platform for the VM instance.
      Applicable values are the friendly names of CPU platforms, such as
      minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge".
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    networkInterfaces: An array of network configurations for this instance.
      These specify how interfaces are configured to interact with other
      network services, such as connecting to the internet. Multiple
      interfaces are supported per instance.
    networkPerformanceConfig: A NetworkPerformanceConfig attribute.
    params: Input only. [Input Only] Additional params passed with the
      request, but not persisted as part of resource payload.
    partnerMetadata: Partner Metadata assigned to the instance. A map from a
      subdomain (namespace) to entries map.
    postKeyRevocationActionType: PostKeyRevocationActionType of the instance.
    preservedStateSizeGb: Total amount of preserved state for SUSPENDED
      instances. Read-only in the api.
    privateIpv6GoogleAccess: The private IPv6 google access type for the VM.
      If not specified, use INHERIT_FROM_SUBNETWORK as default.
    reservationAffinity: Specifies the reservations that this instance can
      consume from.
    resourcePolicies: Resource policies applied to this instance.
    resourceStatus: [Output Only] Specifies values set for instance attributes
      as compared to the values requested by user in the corresponding input
      only field.
    satisfiesPzi: [Output Only] Reserved for future use.
    satisfiesPzs: [Output Only] Reserved for future use.
    scheduling: Sets the scheduling options for this instance.
    secureTags: [Input Only] Secure tags to apply to this instance. These can
      be later modified by the update method. Maximum number of secure tags
      allowed is 50.
    selfLink: [Output Only] Server-defined URL for this resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serviceAccounts: A list of service accounts, with their specified scopes,
      authorized for this instance. Only one service account per VM instance
      is supported. Service accounts generate access tokens that can be
      accessed through the metadata server and used to authenticate
      applications on the instance. See Service Accounts for more information.
    serviceIntegrationSpecs: Mapping of user-defined keys to specifications
      for service integrations. Currently only a single key-value pair is
      supported.
    shieldedInstanceConfig: A ShieldedInstanceConfig attribute.
    shieldedInstanceIntegrityPolicy: A ShieldedInstanceIntegrityPolicy
      attribute.
    shieldedVmConfig: Deprecating, please use shielded_instance_config.
    shieldedVmIntegrityPolicy: Deprecating, please use
      shielded_instance_integrity_policy.
    sourceMachineImage: Source machine image
    sourceMachineImageEncryptionKey: Source machine image encryption key when
      creating an instance from a machine image.
    startRestricted: [Output Only] Whether a VM has been restricted for start
      because Compute Engine has detected suspicious activity.
    status: [Output Only] The status of the instance. One of the following
      values: PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED,
      REPAIRING, and TERMINATED. For more information about the status of the
      instance, see Instance life cycle.
    statusMessage: [Output Only] An optional, human-readable explanation of
      the status.
    tags: Tags to apply to this instance. Tags are used to identify valid
      sources or targets for network firewalls and are specified by the client
      during instance creation. The tags can be later modified by the setTags
      method. Each tag within the list must comply with RFC1035. Multiple tags
      can be specified via the 'tags.items' field.
    upcomingMaintenance: [Output Only] DEPRECATED: Please use
      resource_status.upcoming_maintenance instead. Specifies upcoming
      maintenance for the instance.
    zone: [Output Only] URL of the zone where the instance resides. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
  """

  class KeyRevocationActionTypeValueValuesEnum(_messages.Enum):
    r"""KeyRevocationActionType of the instance. Supported options are "STOP"
    and "NONE". The default value is "NONE" if it is not specified.

    Values:
      KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED: Default value. This value is
        unused.
      NONE: Indicates user chose no operation.
      STOP: Indicates user chose to opt for VM shutdown on key revocation.
    """
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 0
    NONE = 1
    STOP = 2

  class PostKeyRevocationActionTypeValueValuesEnum(_messages.Enum):
    r"""PostKeyRevocationActionType of the instance.

    Values:
      NOOP: Indicates user chose no operation.
      POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED: Default value. This value
        is unused.
      SHUTDOWN: Indicates user chose to opt for VM shutdown on key revocation.
    """
    NOOP = 0
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 1
    SHUTDOWN = 2

  class PrivateIpv6GoogleAccessValueValuesEnum(_messages.Enum):
    r"""The private IPv6 google access type for the VM. If not specified, use
    INHERIT_FROM_SUBNETWORK as default.

    Values:
      ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE: Bidirectional private IPv6 access
        to/from Google services. If specified, the subnetwork who is attached
        to the instance's default network interface will be assigned an
        internal IPv6 prefix if it doesn't have before.
      ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE: Outbound private IPv6 access from
        VMs in this subnet to Google services. If specified, the subnetwork
        who is attached to the instance's default network interface will be
        assigned an internal IPv6 prefix if it doesn't have before.
      INHERIT_FROM_SUBNETWORK: Each network interface inherits
        PrivateIpv6GoogleAccess from its subnetwork.
    """
    ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 0
    ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 1
    INHERIT_FROM_SUBNETWORK = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the instance. One of the following values:
    PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED,
    REPAIRING, and TERMINATED. For more information about the status of the
    instance, see Instance life cycle.

    Values:
      DEPROVISIONING: The instance is halted and we are performing tear down
        tasks like network deprogramming, releasing quota, IP, tearing down
        disks etc.
      PENDING_STOP: The instance is gracefully shutting down.
      PROVISIONING: Resources are being allocated for the instance.
      REPAIRING: The instance is in repair.
      RUNNING: The instance is running.
      STAGING: All required resources have been allocated and the instance is
        being started.
      STOPPED: The instance has stopped successfully.
      STOPPING: The instance is currently stopping (either being deleted or
        killed).
      SUSPENDED: The instance has suspended.
      SUSPENDING: The instance is suspending.
      TERMINATED: The instance has stopped (either by explicit action or
        underlying failure).
    """
    DEPROVISIONING = 0
    PENDING_STOP = 1
    PROVISIONING = 2
    REPAIRING = 3
    RUNNING = 4
    STAGING = 5
    STOPPED = 6
    STOPPING = 7
    SUSPENDED = 8
    SUSPENDING = 9
    TERMINATED = 10

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this instance. These can be later modified by the
    setLabels method.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class PartnerMetadataValue(_messages.Message):
    r"""Partner Metadata assigned to the instance. A map from a subdomain
    (namespace) to entries map.

    Messages:
      AdditionalProperty: An additional property for a PartnerMetadataValue
        object.

    Fields:
      additionalProperties: Additional properties of type PartnerMetadataValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a PartnerMetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A StructuredEntries attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StructuredEntries', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ServiceIntegrationSpecsValue(_messages.Message):
    r"""Mapping of user-defined keys to specifications for service
    integrations. Currently only a single key-value pair is supported.

    Messages:
      AdditionalProperty: An additional property for a
        ServiceIntegrationSpecsValue object.

    Fields:
      additionalProperties: Additional properties of type
        ServiceIntegrationSpecsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ServiceIntegrationSpecsValue object.

      Fields:
        key: Name of the additional property.
        value: A ServiceIntegrationSpec attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ServiceIntegrationSpec', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  advancedMachineFeatures = _messages.MessageField('AdvancedMachineFeatures', 1)
  canIpForward = _messages.BooleanField(2)
  confidentialInstanceConfig = _messages.MessageField('ConfidentialInstanceConfig', 3)
  cpuPlatform = _messages.StringField(4)
  creationTimestamp = _messages.StringField(5)
  deletionProtection = _messages.BooleanField(6)
  description = _messages.StringField(7)
  disks = _messages.MessageField('AttachedDisk', 8, repeated=True)
  displayDevice = _messages.MessageField('DisplayDevice', 9)
  eraseWindowsVssSignature = _messages.BooleanField(10)
  fingerprint = _messages.BytesField(11)
  guestAccelerators = _messages.MessageField('AcceleratorConfig', 12, repeated=True)
  hostname = _messages.StringField(13)
  id = _messages.IntegerField(14, variant=_messages.Variant.UINT64)
  instanceEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 15)
  keyRevocationActionType = _messages.EnumField('KeyRevocationActionTypeValueValuesEnum', 16)
  kind = _messages.StringField(17, default='compute#instance')
  labelFingerprint = _messages.BytesField(18)
  labels = _messages.MessageField('LabelsValue', 19)
  lastStartTimestamp = _messages.StringField(20)
  lastStopTimestamp = _messages.StringField(21)
  lastSuspendedTimestamp = _messages.StringField(22)
  machineType = _messages.StringField(23)
  metadata = _messages.MessageField('Metadata', 24)
  minCpuPlatform = _messages.StringField(25)
  name = _messages.StringField(26)
  networkInterfaces = _messages.MessageField('NetworkInterface', 27, repeated=True)
  networkPerformanceConfig = _messages.MessageField('NetworkPerformanceConfig', 28)
  params = _messages.MessageField('InstanceParams', 29)
  partnerMetadata = _messages.MessageField('PartnerMetadataValue', 30)
  postKeyRevocationActionType = _messages.EnumField('PostKeyRevocationActionTypeValueValuesEnum', 31)
  preservedStateSizeGb = _messages.IntegerField(32)
  privateIpv6GoogleAccess = _messages.EnumField('PrivateIpv6GoogleAccessValueValuesEnum', 33)
  reservationAffinity = _messages.MessageField('ReservationAffinity', 34)
  resourcePolicies = _messages.StringField(35, repeated=True)
  resourceStatus = _messages.MessageField('ResourceStatus', 36)
  satisfiesPzi = _messages.BooleanField(37)
  satisfiesPzs = _messages.BooleanField(38)
  scheduling = _messages.MessageField('Scheduling', 39)
  secureTags = _messages.StringField(40, repeated=True)
  selfLink = _messages.StringField(41)
  selfLinkWithId = _messages.StringField(42)
  serviceAccounts = _messages.MessageField('ServiceAccount', 43, repeated=True)
  serviceIntegrationSpecs = _messages.MessageField('ServiceIntegrationSpecsValue', 44)
  shieldedInstanceConfig = _messages.MessageField('ShieldedInstanceConfig', 45)
  shieldedInstanceIntegrityPolicy = _messages.MessageField('ShieldedInstanceIntegrityPolicy', 46)
  shieldedVmConfig = _messages.MessageField('ShieldedVmConfig', 47)
  shieldedVmIntegrityPolicy = _messages.MessageField('ShieldedVmIntegrityPolicy', 48)
  sourceMachineImage = _messages.StringField(49)
  sourceMachineImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 50)
  startRestricted = _messages.BooleanField(51)
  status = _messages.EnumField('StatusValueValuesEnum', 52)
  statusMessage = _messages.StringField(53)
  tags = _messages.MessageField('Tags', 54)
  upcomingMaintenance = _messages.MessageField('UpcomingMaintenance', 55)
  zone = _messages.StringField(56)


class InstanceAggregatedList(_messages.Message):
  r"""A InstanceAggregatedList object.

  Messages:
    ItemsValue: An object that contains a list of instances scoped by zone.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: An object that contains a list of instances scoped by zone.
    kind: [Output Only] Type of resource. Always
      compute#instanceAggregatedList for aggregated lists of Instance
      resources.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""An object that contains a list of instances scoped by zone.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of instances.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InstancesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstancesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#instanceAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InstanceConsumptionData(_messages.Message):
  r"""A InstanceConsumptionData object.

  Fields:
    consumptionInfo: Resources consumed by the instance.
    instance: Server-defined URL for the instance.
  """

  consumptionInfo = _messages.MessageField('InstanceConsumptionInfo', 1)
  instance = _messages.StringField(2)


class InstanceConsumptionInfo(_messages.Message):
  r"""A InstanceConsumptionInfo object.

  Fields:
    guestCpus: The number of virtual CPUs that are available to the instance.
    localSsdGb: The amount of local SSD storage available to the instance,
      defined in GiB.
    memoryMb: The amount of physical memory available to the instance, defined
      in MiB.
    minNodeCpus: The minimal guaranteed number of virtual CPUs that are
      reserved.
  """

  guestCpus = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  localSsdGb = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  memoryMb = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  minNodeCpus = _messages.IntegerField(4, variant=_messages.Variant.INT32)


class InstanceGroup(_messages.Message):
  r"""Represents an Instance Group resource. Instance Groups can be used to
  configure a target for load balancing. Instance groups can either be managed
  or unmanaged. To create managed instance groups, use the
  instanceGroupManager or regionInstanceGroupManager resource instead. Use
  zonal unmanaged instance groups if you need to apply load balancing to
  groups of heterogeneous instances or if you need to manage the instances
  yourself. You cannot create regional unmanaged instance groups. For more
  information, read Instance groups.

  Fields:
    creationTimestamp: [Output Only] The creation timestamp for this instance
      group in RFC3339 text format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: [Output Only] The fingerprint of the named ports. The system
      uses this fingerprint to detect conflicts when multiple users change the
      named ports concurrently.
    id: [Output Only] A unique identifier for this instance group, generated
      by the server.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroup for instance groups.
    name: The name of the instance group. The name must be 1-63 characters
      long, and comply with RFC1035.
    namedPorts:  Optional. Assigns a name to a port number. For example:
      {name: "http", port: 80} This allows the system to reference ports by
      the assigned name instead of a port number. Named ports can also contain
      multiple ports. For example: [{name: "app1", port: 8080}, {name: "app1",
      port: 8081}, {name: "app2", port: 8082}] Named ports apply to all
      instances in this instance group.
    network: [Output Only] The URL of the network to which all instances in
      the instance group belong. If your instance has multiple network
      interfaces, then the network and subnetwork fields only refer to the
      network and subnet used by your primary interface (nic0).
    region: [Output Only] The URL of the region where the instance group is
      located (for regional resources).
    selfLink: [Output Only] The URL for this instance group. The server
      generates this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    size: [Output Only] The total number of instances in the instance group.
    subnetwork: [Output Only] The URL of the subnetwork to which all instances
      in the instance group belong. If your instance has multiple network
      interfaces, then the network and subnetwork fields only refer to the
      network and subnet used by your primary interface (nic0).
    zone: [Output Only] The URL of the zone where the instance group is
      located (for zonal resources).
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#instanceGroup')
  name = _messages.StringField(6)
  namedPorts = _messages.MessageField('NamedPort', 7, repeated=True)
  network = _messages.StringField(8)
  region = _messages.StringField(9)
  selfLink = _messages.StringField(10)
  selfLinkWithId = _messages.StringField(11)
  size = _messages.IntegerField(12, variant=_messages.Variant.INT32)
  subnetwork = _messages.StringField(13)
  zone = _messages.StringField(14)


class InstanceGroupAggregatedList(_messages.Message):
  r"""A InstanceGroupAggregatedList object.

  Messages:
    ItemsValue: A list of InstanceGroupsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroupsScopedList resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupAggregatedList for aggregated lists of instance
      groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of InstanceGroupsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: The name of the scope that contains this set of
        instance groups.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InstanceGroupsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstanceGroupsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#instanceGroupAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InstanceGroupList(_messages.Message):
  r"""A list of InstanceGroup resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroup resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupList for instance group lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroup', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#instanceGroupList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceGroupManager(_messages.Message):
  r"""Represents a Managed Instance Group resource. An instance group is a
  collection of VM instances that you can manage as a single entity. For more
  information, read Instance groups. For zonal Managed Instance Group, use the
  instanceGroupManagers resource. For regional Managed Instance Group, use the
  regionInstanceGroupManagers resource.

  Enums:
    FailoverActionValueValuesEnum: The action to perform in case of zone
      failure. Only one value is supported, NO_FAILOVER. The default is
      NO_FAILOVER.
    ListManagedInstancesResultsValueValuesEnum: Pagination behavior of the
      listManagedInstances API method for this managed instance group.
    TargetSizeUnitValueValuesEnum: The unit of measure for the target size.

  Fields:
    allInstancesConfig: Specifies configuration that overrides the instance
      template configuration for the group.
    autoHealingPolicies: The autohealing policy for this managed instance
      group. You can specify only one value.
    baseInstanceName: The base instance name is a prefix that you want to
      attach to the names of all VMs in a MIG. The maximum character length is
      58 and the name must comply with RFC1035 format. When a VM is created in
      the group, the MIG appends a hyphen and a random four-character string
      to the base instance name. If you want the MIG to assign sequential
      numbers instead of a random string, then end the base instance name with
      a hyphen followed by one or more hash symbols. The hash symbols indicate
      the number of digits. For example, a base instance name of "vm-###"
      results in "vm-001" as a VM name. @pattern
      [a-z](([-a-z0-9]{0,57})|([-a-z0-9]{0,51}-#{1,10}(\\[[0-9]{1,10}\\])?))
    creationTimestamp: [Output Only] The creation timestamp for this managed
      instance group in RFC3339 text format.
    currentActions: [Output Only] The list of instance actions and the number
      of instances in this managed instance group that are scheduled for each
      of those actions.
    description: An optional description of this resource.
    distributionPolicy: Policy specifying the intended distribution of managed
      instances across zones in a regional managed instance group.
    failoverAction: The action to perform in case of zone failure. Only one
      value is supported, NO_FAILOVER. The default is NO_FAILOVER.
    fingerprint: Fingerprint of this resource. This field may be used in
      optimistic locking. It will be ignored when inserting an
      InstanceGroupManager. An up-to-date fingerprint must be provided in
      order to update the InstanceGroupManager, otherwise the request will
      fail with error 412 conditionNotMet. To see the latest fingerprint, make
      a get() request to retrieve an InstanceGroupManager.
    id: [Output Only] A unique identifier for this resource type. The server
      generates this identifier.
    instanceFlexibilityPolicy: Instance flexibility allowing MIG to create VMs
      from multiple types of machines. Instance flexibility configuration on
      MIG overrides instance template configuration.
    instanceGroup: [Output Only] The URL of the Instance Group resource.
    instanceLifecyclePolicy: The repair policy for this managed instance
      group.
    instanceTemplate: The URL of the instance template that is specified for
      this managed instance group. The group uses this template to create all
      new instances in the managed instance group. The templates for existing
      instances in the group do not change unless you run recreateInstances,
      run applyUpdatesToInstances, or set the group's updatePolicy.type to
      PROACTIVE.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManager for managed instance groups.
    listManagedInstancesResults: Pagination behavior of the
      listManagedInstances API method for this managed instance group.
    multiMig: URL to the multi-MIG that this Managed Instance Group belongs
      to.
    name: The name of the managed instance group. The name must be 1-63
      characters long, and comply with RFC1035.
    namedPorts: [Output Only] Named ports configured on the Instance Groups
      complementary to this Instance Group Manager.
    params: Input only. Additional params passed with the request, but not
      persisted as part of resource payload.
    region: [Output Only] The URL of the region where the managed instance
      group resides (for regional resources).
    resourcePolicies: Resource policies for this managed instance group.
    satisfiesPzi: [Output Only] Reserved for future use.
    satisfiesPzs: [Output Only] Reserved for future use.
    selfLink: [Output Only] The URL for this managed instance group. The
      server defines this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serviceAccount: The service account to be used as credentials for all
      operations performed by the managed instance group on instances. The
      service accounts needs all permissions required to create and delete
      instances. By default, the service account
      {projectNumber}@cloudservices.gserviceaccount.com is used.
    standbyPolicy: Standby policy for stopped and suspended instances.
    statefulPolicy: Stateful configuration for this Instanced Group Manager
    status: [Output Only] The status of this managed instance group.
    targetPools: The URLs for all TargetPool resources to which instances in
      the instanceGroup field are added. The target pools automatically apply
      to all of the instances in the managed instance group.
    targetSize: The target number of running instances for this managed
      instance group. You can reduce this number by using the
      instanceGroupManager deleteInstances or abandonInstances methods.
      Resizing the group also changes this number.
    targetSizePolicy: Configures how target size of MIG is achieved.
    targetSizeUnit: The unit of measure for the target size.
    targetStoppedSize: The target number of stopped instances for this managed
      instance group. This number changes when you: - Stop instance using the
      stopInstances method or start instances using the startInstances method.
      - Manually change the targetStoppedSize using the update method.
    targetSuspendedSize: The target number of suspended instances for this
      managed instance group. This number changes when you: - Suspend instance
      using the suspendInstances method or resume instances using the
      resumeInstances method. - Manually change the targetSuspendedSize using
      the update method.
    updatePolicy: The update policy for this managed instance group.
    versions: Specifies the instance templates used by this managed instance
      group to create instances. Each version is defined by an
      instanceTemplate and a name. Every version can appear at most once per
      instance group. This field overrides the top-level instanceTemplate
      field. Read more about the relationships between these fields. Exactly
      one version must leave the targetSize field unset. That version will be
      applied to all remaining instances. For more information, read about
      canary updates.
    zone: [Output Only] The URL of a zone where the managed instance group is
      located (for zonal resources).
  """

  class FailoverActionValueValuesEnum(_messages.Enum):
    r"""The action to perform in case of zone failure. Only one value is
    supported, NO_FAILOVER. The default is NO_FAILOVER.

    Values:
      NO_FAILOVER: <no description>
      UNKNOWN: <no description>
    """
    NO_FAILOVER = 0
    UNKNOWN = 1

  class ListManagedInstancesResultsValueValuesEnum(_messages.Enum):
    r"""Pagination behavior of the listManagedInstances API method for this
    managed instance group.

    Values:
      PAGELESS: (Default) Pagination is disabled for the group's
        listManagedInstances API method. maxResults and pageToken query
        parameters are ignored and all instances are returned in a single
        response.
      PAGINATED: Pagination is enabled for the group's listManagedInstances
        API method. maxResults and pageToken query parameters are respected.
    """
    PAGELESS = 0
    PAGINATED = 1

  class TargetSizeUnitValueValuesEnum(_messages.Enum):
    r"""The unit of measure for the target size.

    Values:
      INSTANCE: [Default] TargetSize is the target number of instances.
      VCPU: TargetSize is the target count of vCPUs of VMs.
    """
    INSTANCE = 0
    VCPU = 1

  allInstancesConfig = _messages.MessageField('InstanceGroupManagerAllInstancesConfig', 1)
  autoHealingPolicies = _messages.MessageField('InstanceGroupManagerAutoHealingPolicy', 2, repeated=True)
  baseInstanceName = _messages.StringField(3)
  creationTimestamp = _messages.StringField(4)
  currentActions = _messages.MessageField('InstanceGroupManagerActionsSummary', 5)
  description = _messages.StringField(6)
  distributionPolicy = _messages.MessageField('DistributionPolicy', 7)
  failoverAction = _messages.EnumField('FailoverActionValueValuesEnum', 8)
  fingerprint = _messages.BytesField(9)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  instanceFlexibilityPolicy = _messages.MessageField('InstanceGroupManagerInstanceFlexibilityPolicy', 11)
  instanceGroup = _messages.StringField(12)
  instanceLifecyclePolicy = _messages.MessageField('InstanceGroupManagerInstanceLifecyclePolicy', 13)
  instanceTemplate = _messages.StringField(14)
  kind = _messages.StringField(15, default='compute#instanceGroupManager')
  listManagedInstancesResults = _messages.EnumField('ListManagedInstancesResultsValueValuesEnum', 16)
  multiMig = _messages.StringField(17)
  name = _messages.StringField(18)
  namedPorts = _messages.MessageField('NamedPort', 19, repeated=True)
  params = _messages.MessageField('InstanceGroupManagerParams', 20)
  region = _messages.StringField(21)
  resourcePolicies = _messages.MessageField('InstanceGroupManagerResourcePolicies', 22)
  satisfiesPzi = _messages.BooleanField(23)
  satisfiesPzs = _messages.BooleanField(24)
  selfLink = _messages.StringField(25)
  selfLinkWithId = _messages.StringField(26)
  serviceAccount = _messages.StringField(27)
  standbyPolicy = _messages.MessageField('InstanceGroupManagerStandbyPolicy', 28)
  statefulPolicy = _messages.MessageField('StatefulPolicy', 29)
  status = _messages.MessageField('InstanceGroupManagerStatus', 30)
  targetPools = _messages.StringField(31, repeated=True)
  targetSize = _messages.IntegerField(32, variant=_messages.Variant.INT32)
  targetSizePolicy = _messages.MessageField('InstanceGroupManagerTargetSizePolicy', 33)
  targetSizeUnit = _messages.EnumField('TargetSizeUnitValueValuesEnum', 34)
  targetStoppedSize = _messages.IntegerField(35, variant=_messages.Variant.INT32)
  targetSuspendedSize = _messages.IntegerField(36, variant=_messages.Variant.INT32)
  updatePolicy = _messages.MessageField('InstanceGroupManagerUpdatePolicy', 37)
  versions = _messages.MessageField('InstanceGroupManagerVersion', 38, repeated=True)
  zone = _messages.StringField(39)


class InstanceGroupManagerActionsSummary(_messages.Message):
  r"""A InstanceGroupManagerActionsSummary object.

  Fields:
    abandoning: [Output Only] The total number of instances in the managed
      instance group that are scheduled to be abandoned. Abandoning an
      instance removes it from the managed instance group without deleting it.
    creating: [Output Only] The number of instances in the managed instance
      group that are scheduled to be created or are currently being created.
      If the group fails to create any of these instances, it tries again
      until it creates the instance successfully. If you have disabled
      creation retries, this field will not be populated; instead, the
      creatingWithoutRetries field will be populated.
    creatingAtomically: [Output Only] The number of instances that the managed
      instance group will attempt to create atomically, in a batch mode. If
      the desired count of instances can not be created, entire batch will be
      deleted and the group will decrease its targetSize value accordingly.
    creatingWithoutRetries: [Output Only] The number of instances that the
      managed instance group will attempt to create. The group attempts to
      create each instance only once. If the group fails to create any of
      these instances, it decreases the group's targetSize value accordingly.
    deleting: [Output Only] The number of instances in the managed instance
      group that are scheduled to be deleted or are currently being deleted.
    none: [Output Only] The number of instances in the managed instance group
      that are running and have no scheduled actions.
    queuing: [Output Only] The number of instances that the managed instance
      group is currently queuing.
    recreating: [Output Only] The number of instances in the managed instance
      group that are scheduled to be recreated or are currently being being
      recreated. Recreating an instance deletes the existing root persistent
      disk and creates a new disk from the image that is defined in the
      instance template.
    refreshing: [Output Only] The number of instances in the managed instance
      group that are being reconfigured with properties that do not require a
      restart or a recreate action. For example, setting or removing target
      pools for the instance.
    restarting: [Output Only] The number of instances in the managed instance
      group that are scheduled to be restarted or are currently being
      restarted.
    resuming: [Output Only] The number of instances in the managed instance
      group that are scheduled to be resumed or are currently being resumed.
    starting: [Output Only] The number of instances in the managed instance
      group that are scheduled to be started or are currently being started.
    stopping: [Output Only] The number of instances in the managed instance
      group that are scheduled to be stopped or are currently being stopped.
    suspending: [Output Only] The number of instances in the managed instance
      group that are scheduled to be suspended or are currently being
      suspended.
    verifying: [Output Only] The number of instances in the managed instance
      group that are being verified. See the managedInstances[].currentAction
      property in the listManagedInstances method documentation.
  """

  abandoning = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creating = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  creatingAtomically = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  creatingWithoutRetries = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  deleting = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  none = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  queuing = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  recreating = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  refreshing = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  restarting = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  resuming = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  starting = _messages.IntegerField(12, variant=_messages.Variant.INT32)
  stopping = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  suspending = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  verifying = _messages.IntegerField(15, variant=_messages.Variant.INT32)


class InstanceGroupManagerAggregatedList(_messages.Message):
  r"""A InstanceGroupManagerAggregatedList object.

  Messages:
    ItemsValue: A list of InstanceGroupManagersScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroupManagersScopedList resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManagerAggregatedList for an aggregated list of
      managed instance groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of InstanceGroupManagersScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] The name of the scope that contains
        this set of managed instance groups.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InstanceGroupManagersScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstanceGroupManagersScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#instanceGroupManagerAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InstanceGroupManagerAllInstancesConfig(_messages.Message):
  r"""A InstanceGroupManagerAllInstancesConfig object.

  Fields:
    properties: Properties to set on all instances in the group. You can add
      or modify properties using the instanceGroupManagers.patch or
      regionInstanceGroupManagers.patch. After setting allInstancesConfig on
      the group, you must update the group's instances to apply the
      configuration. To apply the configuration, set the group's
      updatePolicy.type field to use proactive updates or use the
      applyUpdatesToInstances method.
  """

  properties = _messages.MessageField('InstancePropertiesPatch', 1)


class InstanceGroupManagerAutoHealingPolicy(_messages.Message):
  r"""A InstanceGroupManagerAutoHealingPolicy object.

  Fields:
    autoHealingTriggers: Restricts what triggers autohealing.
    healthCheck: The URL for the health check that signals autohealing.
    initialDelaySec: The initial delay is the number of seconds that a new VM
      takes to initialize and run its startup script. During a VM's initial
      delay period, the MIG ignores unsuccessful health checks because the VM
      might be in the startup process. This prevents the MIG from prematurely
      recreating a VM. If the health check receives a healthy response during
      the initial delay, it indicates that the startup process is complete and
      the VM is ready. The value of initial delay must be between 0 and 3600
      seconds. The default value is 0.
    maxUnavailable: Maximum number of instances that can be unavailable when
      autohealing. When 'percent' is used, the value is rounded if necessary.
      The instance is considered available if all of the following conditions
      are satisfied: 1. Instance's status is RUNNING. 2. Instance's
      currentAction is NONE (in particular its liveness health check result
      was observed to be HEALTHY at least once as it passed VERIFYING). 3.
      There is no outgoing action on an instance triggered by IGM. By default,
      number of concurrently autohealed instances is smaller than the managed
      instance group target size. However, if a zonal managed instance group
      has only one instance, or a regional managed instance group has only one
      instance per zone, autohealing will recreate these instances when they
      become unhealthy.
  """

  autoHealingTriggers = _messages.MessageField('InstanceGroupManagerAutoHealingPolicyAutoHealingTriggers', 1)
  healthCheck = _messages.StringField(2)
  initialDelaySec = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  maxUnavailable = _messages.MessageField('FixedOrPercent', 4)


class InstanceGroupManagerAutoHealingPolicyAutoHealingTriggers(_messages.Message):
  r"""A InstanceGroupManagerAutoHealingPolicyAutoHealingTriggers object.

  Enums:
    OnHealthCheckValueValuesEnum: If you have configured an application-based
      health check for the group, this field controls whether to trigger VM
      autohealing based on a failed health check. Valid values are: - ON
      (default): The group recreates running VMs that fail the application-
      based health check. - OFF: When set to OFF, you can still observe
      instance health state, but the group does not recreate VMs that fail the
      application-based health check. This is useful for troubleshooting and
      setting up your health check configuration.

  Fields:
    onHealthCheck: If you have configured an application-based health check
      for the group, this field controls whether to trigger VM autohealing
      based on a failed health check. Valid values are: - ON (default): The
      group recreates running VMs that fail the application-based health
      check. - OFF: When set to OFF, you can still observe instance health
      state, but the group does not recreate VMs that fail the application-
      based health check. This is useful for troubleshooting and setting up
      your health check configuration.
  """

  class OnHealthCheckValueValuesEnum(_messages.Enum):
    r"""If you have configured an application-based health check for the
    group, this field controls whether to trigger VM autohealing based on a
    failed health check. Valid values are: - ON (default): The group recreates
    running VMs that fail the application-based health check. - OFF: When set
    to OFF, you can still observe instance health state, but the group does
    not recreate VMs that fail the application-based health check. This is
    useful for troubleshooting and setting up your health check configuration.

    Values:
      OFF: When set to OFF, you can still observe instance health state, but
        the group does not recreate VMs that fail the application-based health
        check. This is useful for troubleshooting and setting up your health
        check configuration.
      ON: (Default) The group recreates running VMs that fail the group's
        application-based health check.
    """
    OFF = 0
    ON = 1

  onHealthCheck = _messages.EnumField('OnHealthCheckValueValuesEnum', 1)


class InstanceGroupManagerInstanceFlexibilityPolicy(_messages.Message):
  r"""A InstanceGroupManagerInstanceFlexibilityPolicy object.

  Messages:
    InstanceSelectionListsValue: Named instance selections configuring
      properties that the group will use when creating new VMs.
    InstanceSelectionsValue: Named instance selections configuring properties
      that the group will use when creating new VMs.

  Fields:
    instanceSelectionLists: Named instance selections configuring properties
      that the group will use when creating new VMs.
    instanceSelections: Named instance selections configuring properties that
      the group will use when creating new VMs.
    provisioningModelMix: Provisioning model configuration used by this
      managed instance group to create instances.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class InstanceSelectionListsValue(_messages.Message):
    r"""Named instance selections configuring properties that the group will
    use when creating new VMs.

    Messages:
      AdditionalProperty: An additional property for a
        InstanceSelectionListsValue object.

    Fields:
      additionalProperties: Additional properties of type
        InstanceSelectionListsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a InstanceSelectionListsValue object.

      Fields:
        key: Name of the additional property.
        value: A
          InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
          attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class InstanceSelectionsValue(_messages.Message):
    r"""Named instance selections configuring properties that the group will
    use when creating new VMs.

    Messages:
      AdditionalProperty: An additional property for a InstanceSelectionsValue
        object.

    Fields:
      additionalProperties: Additional properties of type
        InstanceSelectionsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a InstanceSelectionsValue object.

      Fields:
        key: Name of the additional property.
        value: A
          InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
          attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  instanceSelectionLists = _messages.MessageField('InstanceSelectionListsValue', 1)
  instanceSelections = _messages.MessageField('InstanceSelectionsValue', 2)
  provisioningModelMix = _messages.MessageField('InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix', 3)


class InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection(_messages.Message):
  r"""A InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection object.

  Fields:
    machineTypes: Full machine-type names, e.g. "n1-standard-16".
    rank: Preference of this instance selection. Lower number means higher
      preference. MIG will first try to create a VM based on the machine-type
      with lowest rank and fallback to next rank based on availability.
      Machine types and instance selections with the same rank have the same
      preference.
  """

  machineTypes = _messages.StringField(1, repeated=True)
  rank = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix(_messages.Message):
  r"""A InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix
  object.

  Fields:
    standardCapacityBase: The base capacity that will always use Standard VMs
      to avoid risk of more preemption than the minimum capacity user needs.
      MIG will create only Standard VMs until it reaches
      standard_capacity_base and only then will start using
      standard_capacity_percent_above_base to mix Spot with Standard VMs.
    standardCapacityPercentAboveBase: The percentage of target capacity that
      should use Standard VM. The remaining percentage will use Spot VMs. The
      percentage applies only to the capacity above standard_capacity_base.
  """

  standardCapacityBase = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  standardCapacityPercentAboveBase = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class InstanceGroupManagerInstanceLifecyclePolicy(_messages.Message):
  r"""A InstanceGroupManagerInstanceLifecyclePolicy object.

  Enums:
    DefaultActionOnFailureValueValuesEnum: The action that a MIG performs on a
      failed VM. If the value of the onFailedHealthCheck field is
      `DEFAULT_ACTION`, then the same action also applies to the VMs on which
      your application fails a health check. Valid values are - REPAIR
      (default): MIG automatically repairs a failed VM by recreating it. For
      more information, see about repairing VMs in a MIG. - DO_NOTHING: MIG
      does not repair a failed VM.
    ForceUpdateOnRepairValueValuesEnum: A bit indicating whether to forcefully
      apply the group's latest configuration when repairing a VM. Valid
      options are: - NO (default): If configuration updates are available,
      they are not forcefully applied during repair. Instead, configuration
      updates are applied according to the group's update policy. - YES: If
      configuration updates are available, they are applied during repair.
    OnFailedHealthCheckValueValuesEnum: The action that a MIG performs on an
      unhealthy VM. A VM is marked as unhealthy when the application running
      on that VM fails a health check. Valid values are: - DEFAULT_ACTION
      (default): MIG uses the same action configured for
      instanceLifecyclePolicy.defaultActionOnFailure field. - REPAIR: MIG
      automatically repairs an unhealthy VM by recreating it. - DO_NOTHING:
      MIG doesn't repair an unhealthy VM. For more information, see About
      repairing VMs in a MIG.

  Fields:
    defaultActionOnFailure: The action that a MIG performs on a failed VM. If
      the value of the onFailedHealthCheck field is `DEFAULT_ACTION`, then the
      same action also applies to the VMs on which your application fails a
      health check. Valid values are - REPAIR (default): MIG automatically
      repairs a failed VM by recreating it. For more information, see about
      repairing VMs in a MIG. - DO_NOTHING: MIG does not repair a failed VM.
    forceUpdateOnRepair: A bit indicating whether to forcefully apply the
      group's latest configuration when repairing a VM. Valid options are: -
      NO (default): If configuration updates are available, they are not
      forcefully applied during repair. Instead, configuration updates are
      applied according to the group's update policy. - YES: If configuration
      updates are available, they are applied during repair.
    metadataBasedReadinessSignal: The configuration for metadata based
      readiness signal sent by the instance during initialization when
      stopping / suspending an instance. The Instance Group Manager will wait
      for a signal that indicates successful initialization before stopping /
      suspending an instance. If a successful readiness signal is not sent
      before timeout, the corresponding instance will not be stopped /
      suspended. Instead, an error will be visible in the lastAttempt.errors
      field of the managed instance in the listmanagedinstances method. If
      metadataBasedReadinessSignal.timeoutSec is unset, the Instance Group
      Manager will directly proceed to suspend / stop instances, skipping
      initialization on them.
    onFailedHealthCheck: The action that a MIG performs on an unhealthy VM. A
      VM is marked as unhealthy when the application running on that VM fails
      a health check. Valid values are: - DEFAULT_ACTION (default): MIG uses
      the same action configured for
      instanceLifecyclePolicy.defaultActionOnFailure field. - REPAIR: MIG
      automatically repairs an unhealthy VM by recreating it. - DO_NOTHING:
      MIG doesn't repair an unhealthy VM. For more information, see About
      repairing VMs in a MIG.
  """

  class DefaultActionOnFailureValueValuesEnum(_messages.Enum):
    r"""The action that a MIG performs on a failed VM. If the value of the
    onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also
    applies to the VMs on which your application fails a health check. Valid
    values are - REPAIR (default): MIG automatically repairs a failed VM by
    recreating it. For more information, see about repairing VMs in a MIG. -
    DO_NOTHING: MIG does not repair a failed VM.

    Values:
      DELETE: MIG deletes a failed or an unhealthy VM. Deleting the VM
        decreases the target size of the MIG.
      DO_NOTHING: MIG does not repair a failed VM.
      REPAIR: (default): MIG automatically repairs a failed VM by recreating
        it. For more information, see about repairing VMs in a MIG.
    """
    DELETE = 0
    DO_NOTHING = 1
    REPAIR = 2

  class ForceUpdateOnRepairValueValuesEnum(_messages.Enum):
    r"""A bit indicating whether to forcefully apply the group's latest
    configuration when repairing a VM. Valid options are: - NO (default): If
    configuration updates are available, they are not forcefully applied
    during repair. Instead, configuration updates are applied according to the
    group's update policy. - YES: If configuration updates are available, they
    are applied during repair.

    Values:
      NO: <no description>
      YES: <no description>
    """
    NO = 0
    YES = 1

  class OnFailedHealthCheckValueValuesEnum(_messages.Enum):
    r"""The action that a MIG performs on an unhealthy VM. A VM is marked as
    unhealthy when the application running on that VM fails a health check.
    Valid values are: - DEFAULT_ACTION (default): MIG uses the same action
    configured for instanceLifecyclePolicy.defaultActionOnFailure field. -
    REPAIR: MIG automatically repairs an unhealthy VM by recreating it. -
    DO_NOTHING: MIG doesn't repair an unhealthy VM. For more information, see
    About repairing VMs in a MIG.

    Values:
      DEFAULT_ACTION: (Default) MIG uses the same action configured for
        instanceLifecyclePolicy.defaultActionOnFailure field.
      DO_NOTHING: MIG doesn't repair an unhealthy VM.
      REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
    """
    DEFAULT_ACTION = 0
    DO_NOTHING = 1
    REPAIR = 2

  defaultActionOnFailure = _messages.EnumField('DefaultActionOnFailureValueValuesEnum', 1)
  forceUpdateOnRepair = _messages.EnumField('ForceUpdateOnRepairValueValuesEnum', 2)
  metadataBasedReadinessSignal = _messages.MessageField('InstanceGroupManagerInstanceLifecyclePolicyMetadataBasedReadinessSignal', 3)
  onFailedHealthCheck = _messages.EnumField('OnFailedHealthCheckValueValuesEnum', 4)


class InstanceGroupManagerInstanceLifecyclePolicyMetadataBasedReadinessSignal(_messages.Message):
  r"""A
  InstanceGroupManagerInstanceLifecyclePolicyMetadataBasedReadinessSignal
  object.

  Fields:
    timeoutSec: The number of seconds to wait for a readiness signal during
      initialization before timing out.
  """

  timeoutSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)


class InstanceGroupManagerList(_messages.Message):
  r"""[Output Only] A list of managed instance groups.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroupManager resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManagerList for a list of managed instance groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroupManager', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#instanceGroupManagerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceGroupManagerParams(_messages.Message):
  r"""Input only additional params for instance group manager creation.

  Messages:
    ResourceManagerTagsValue: Resource manager tags to bind to the managed
      instance group. The tags are key-value pairs. Keys must be in the format
      tagKeys/123 and values in the format tagValues/456. For more
      information, see Manage tags for resources.

  Fields:
    resourceManagerTags: Resource manager tags to bind to the managed instance
      group. The tags are key-value pairs. Keys must be in the format
      tagKeys/123 and values in the format tagValues/456. For more
      information, see Manage tags for resources.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ResourceManagerTagsValue(_messages.Message):
    r"""Resource manager tags to bind to the managed instance group. The tags
    are key-value pairs. Keys must be in the format tagKeys/123 and values in
    the format tagValues/456. For more information, see Manage tags for
    resources.

    Messages:
      AdditionalProperty: An additional property for a
        ResourceManagerTagsValue object.

    Fields:
      additionalProperties: Additional properties of type
        ResourceManagerTagsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ResourceManagerTagsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  resourceManagerTags = _messages.MessageField('ResourceManagerTagsValue', 1)


class InstanceGroupManagerResizeRequest(_messages.Message):
  r"""InstanceGroupManagerResizeRequest represents a request to create a
  number of VMs: either immediately or by queuing the request for the
  specified time. This resize request is nested under InstanceGroupManager and
  the VMs created by this request are added to the owning
  InstanceGroupManager.

  Enums:
    StateValueValuesEnum: [Output only] Current state of the request.

  Fields:
    count: This field is deprecated, please use resize_by instead. The count
      of instances to create as part of this resize request.
    creationTimestamp: [Output Only] The creation timestamp for this resize
      request in RFC3339 text format.
    description: An optional description of this resource.
    id: [Output Only] A unique identifier for this resource type. The server
      generates this identifier.
    instances: The names of instances to be created by this resize request.
      The number of names specified determines the number of instances to
      create. The group's target size will be increased by this number. This
      field cannot be used together with 'resize_by'.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManagerResizeRequest for resize requests.
    name: The name of this resize request. The name must be 1-63 characters
      long, and comply with RFC1035.
    queuingPolicy: This field is deprecated, ResizeRequests would not be
      provisioned immediately and would stay in the queue until explicitly
      cancelled. When set, defines queing parameters for the requested
      deferred capacity. When unset, the request starts provisioning
      immediately, or fails if immediate provisioning is not possible.
    region: [Output Only] The URL of a region where the resize request is
      located. Populated only for regional resize requests.
    requestedRunDuration: Requested run duration for instances that will be
      created by this request. At the end of the run duration instance will be
      deleted.
    resizeBy: The number of instances to be created by this resize request.
      The group's target size will be increased by this number. This field
      cannot be used together with 'instances'.
    selfLink: [Output Only] The URL for this resize request. The server
      defines this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    state: [Output only] Current state of the request.
    status: [Output only] Status of the request.
    zone: [Output Only] The URL of a zone where the resize request is located.
      Populated only for zonal resize requests.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output only] Current state of the request.

    Values:
      ACCEPTED: The request was created successfully and was accepted for
        provisioning when the capacity becomes available.
      CANCELLED: The request is cancelled.
      CREATING: Resize request is being created and may still fail creation.
      DELETING: The value is deprecated. ResizeRequests would not change state
        while being deleted. The request is being deleted.
      FAILED: The request failed before or during provisioning. If the request
        fails during provisioning, any VMs that were created during
        provisioning are rolled back and removed from the MIG.
      PROVISIONING: The value is deprecated. ResizeRequests would stay in the
        ACCEPTED state during provisioning attempts. The target resource(s)
        are being provisioned.
      STATE_UNSPECIFIED: Default value. This value should never be returned.
      SUCCEEDED: The request succeeded.
    """
    ACCEPTED = 0
    CANCELLED = 1
    CREATING = 2
    DELETING = 3
    FAILED = 4
    PROVISIONING = 5
    STATE_UNSPECIFIED = 6
    SUCCEEDED = 7

  count = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  instances = _messages.MessageField('PerInstanceConfig', 5, repeated=True)
  kind = _messages.StringField(6, default='compute#instanceGroupManagerResizeRequest')
  name = _messages.StringField(7)
  queuingPolicy = _messages.MessageField('QueuingPolicy', 8)
  region = _messages.StringField(9)
  requestedRunDuration = _messages.MessageField('Duration', 10)
  resizeBy = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)
  state = _messages.EnumField('StateValueValuesEnum', 14)
  status = _messages.MessageField('InstanceGroupManagerResizeRequestStatus', 15)
  zone = _messages.StringField(16)


class InstanceGroupManagerResizeRequestStatus(_messages.Message):
  r"""A InstanceGroupManagerResizeRequestStatus object.

  Messages:
    ErrorValue: [Output only] Fatal errors encountered during the queueing or
      provisioning phases of the ResizeRequest that caused the transition to
      the FAILED state. Contrary to the last_attempt errors, this field is
      final and errors are never removed from here, as the ResizeRequest is
      not going to retry.

  Fields:
    error: [Output only] Fatal errors encountered during the queueing or
      provisioning phases of the ResizeRequest that caused the transition to
      the FAILED state. Contrary to the last_attempt errors, this field is
      final and errors are never removed from here, as the ResizeRequest is
      not going to retry.
    lastAttempt: [Output only] Information about the last attempt to fulfill
      the request. The value is temporary since the ResizeRequest can retry,
      as long as it's still active and the last attempt value can either be
      cleared or replaced with a different error. Since ResizeRequest retries
      infrequently, the value may be stale and no longer show an active
      problem. The value is cleared when ResizeRequest transitions to the
      final state (becomes inactive). If the final state is FAILED the error
      describing it will be storred in the "error" field only.
    queuingPolicy: This field is deprecated, setting queueing policy is no
      longer supported. Constraints for the time when the instances start
      provisioning. Always exposed as absolute time.
  """

  class ErrorValue(_messages.Message):
    r"""[Output only] Fatal errors encountered during the queueing or
    provisioning phases of the ResizeRequest that caused the transition to the
    FAILED state. Contrary to the last_attempt errors, this field is final and
    errors are never removed from here, as the ResizeRequest is not going to
    retry.

    Messages:
      ErrorsValueListEntry: A ErrorsValueListEntry object.

    Fields:
      errors: [Output Only] The array of errors encountered while processing
        this operation.
    """

    class ErrorsValueListEntry(_messages.Message):
      r"""A ErrorsValueListEntry object.

      Messages:
        ErrorDetailsValueListEntry: A ErrorDetailsValueListEntry object.

      Fields:
        code: [Output Only] The error type identifier for this error.
        errorDetails: [Output Only] An optional list of messages that contain
          the error details. There is a set of defined message types to use
          for providing details.The syntax depends on the error code. For
          example, QuotaExceededInfo will have details when the error code is
          QUOTA_EXCEEDED.
        location: [Output Only] Indicates the field in the request that caused
          the error. This property is optional.
        message: [Output Only] An optional, human-readable error message.
      """

      class ErrorDetailsValueListEntry(_messages.Message):
        r"""A ErrorDetailsValueListEntry object.

        Fields:
          errorInfo: A ErrorInfo attribute.
          help: A Help attribute.
          localizedMessage: A LocalizedMessage attribute.
          quotaInfo: A QuotaExceededInfo attribute.
        """

        errorInfo = _messages.MessageField('ErrorInfo', 1)
        help = _messages.MessageField('Help', 2)
        localizedMessage = _messages.MessageField('LocalizedMessage', 3)
        quotaInfo = _messages.MessageField('QuotaExceededInfo', 4)

      code = _messages.StringField(1)
      errorDetails = _messages.MessageField('ErrorDetailsValueListEntry', 2, repeated=True)
      location = _messages.StringField(3)
      message = _messages.StringField(4)

    errors = _messages.MessageField('ErrorsValueListEntry', 1, repeated=True)

  error = _messages.MessageField('ErrorValue', 1)
  lastAttempt = _messages.MessageField('InstanceGroupManagerResizeRequestStatusLastAttempt', 2)
  queuingPolicy = _messages.MessageField('QueuingPolicy', 3)


class InstanceGroupManagerResizeRequestStatusLastAttempt(_messages.Message):
  r"""A InstanceGroupManagerResizeRequestStatusLastAttempt object.

  Messages:
    ErrorValue: Errors that prevented the ResizeRequest to be fulfilled.

  Fields:
    error: Errors that prevented the ResizeRequest to be fulfilled.
  """

  class ErrorValue(_messages.Message):
    r"""Errors that prevented the ResizeRequest to be fulfilled.

    Messages:
      ErrorsValueListEntry: A ErrorsValueListEntry object.

    Fields:
      errors: [Output Only] The array of errors encountered while processing
        this operation.
    """

    class ErrorsValueListEntry(_messages.Message):
      r"""A ErrorsValueListEntry object.

      Messages:
        ErrorDetailsValueListEntry: A ErrorDetailsValueListEntry object.

      Fields:
        code: [Output Only] The error type identifier for this error.
        errorDetails: [Output Only] An optional list of messages that contain
          the error details. There is a set of defined message types to use
          for providing details.The syntax depends on the error code. For
          example, QuotaExceededInfo will have details when the error code is
          QUOTA_EXCEEDED.
        location: [Output Only] Indicates the field in the request that caused
          the error. This property is optional.
        message: [Output Only] An optional, human-readable error message.
      """

      class ErrorDetailsValueListEntry(_messages.Message):
        r"""A ErrorDetailsValueListEntry object.

        Fields:
          errorInfo: A ErrorInfo attribute.
          help: A Help attribute.
          localizedMessage: A LocalizedMessage attribute.
          quotaInfo: A QuotaExceededInfo attribute.
        """

        errorInfo = _messages.MessageField('ErrorInfo', 1)
        help = _messages.MessageField('Help', 2)
        localizedMessage = _messages.MessageField('LocalizedMessage', 3)
        quotaInfo = _messages.MessageField('QuotaExceededInfo', 4)

      code = _messages.StringField(1)
      errorDetails = _messages.MessageField('ErrorDetailsValueListEntry', 2, repeated=True)
      location = _messages.StringField(3)
      message = _messages.StringField(4)

    errors = _messages.MessageField('ErrorsValueListEntry', 1, repeated=True)

  error = _messages.MessageField('ErrorValue', 1)


class InstanceGroupManagerResizeRequestsListResponse(_messages.Message):
  r"""[Output Only] A list of resize requests.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of resize request resources.
    kind: [Output Only] Type of the resource. Always
      compute#instanceGroupManagerResizeRequestList for a list of resize
      requests.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroupManagerResizeRequest', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#instanceGroupManagerResizeRequestList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceGroupManagerResourcePolicies(_messages.Message):
  r"""A InstanceGroupManagerResourcePolicies object.

  Fields:
    workloadPolicy: The URL of the workload policy that is specified for this
      managed instance group. It can be a full or partial URL. For example,
      the following are all valid URLs to a workload policy: -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /resourcePolicies/resourcePolicy -
      projects/project/regions/region/resourcePolicies/resourcePolicy -
      regions/region/resourcePolicies/resourcePolicy
  """

  workloadPolicy = _messages.StringField(1)


class InstanceGroupManagerStandbyPolicy(_messages.Message):
  r"""A InstanceGroupManagerStandbyPolicy object.

  Enums:
    ModeValueValuesEnum: Defines how a MIG resumes or starts VMs from a
      standby pool when the group scales out. The default mode is `MANUAL`.

  Fields:
    initialDelaySec: Specifies the number of seconds that the MIG should wait
      to suspend or stop a VM after that VM was created. The initial delay
      gives the initialization script the time to prepare your VM for a quick
      scale out. The value of initial delay must be between 0 and 3600
      seconds. The default value is 0.
    mode: Defines how a MIG resumes or starts VMs from a standby pool when the
      group scales out. The default mode is `MANUAL`.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Defines how a MIG resumes or starts VMs from a standby pool when the
    group scales out. The default mode is `MANUAL`.

    Values:
      MANUAL: MIG does not automatically resume or start VMs in the standby
        pool when the group scales out.
      SCALE_OUT_POOL: MIG automatically resumes or starts VMs in the standby
        pool when the group scales out, and replenishes the standby pool
        afterwards.
    """
    MANUAL = 0
    SCALE_OUT_POOL = 1

  initialDelaySec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  mode = _messages.EnumField('ModeValueValuesEnum', 2)


class InstanceGroupManagerStatus(_messages.Message):
  r"""A InstanceGroupManagerStatus object.

  Fields:
    allInstancesConfig: [Output only] Status of all-instances configuration on
      the group.
    autoscaler: [Output Only] The URL of the Autoscaler that targets this
      instance group manager.
    bulkInstanceOperation: [Output Only] Status of bulk instance operation.
    isStable: [Output Only] A bit indicating whether the managed instance
      group is in a stable state. A stable state means that: none of the
      instances in the managed instance group is currently undergoing any type
      of change (for example, creation, restart, or deletion); no future
      changes are scheduled for instances in the managed instance group; and
      the managed instance group itself is not being modified.
    stateful: [Output Only] Stateful status of the given Instance Group
      Manager.
    versionTarget: [Output Only] A status of consistency of Instances'
      versions with their target version specified by version field on
      Instance Group Manager.
  """

  allInstancesConfig = _messages.MessageField('InstanceGroupManagerStatusAllInstancesConfig', 1)
  autoscaler = _messages.StringField(2)
  bulkInstanceOperation = _messages.MessageField('InstanceGroupManagerStatusBulkInstanceOperation', 3)
  isStable = _messages.BooleanField(4)
  stateful = _messages.MessageField('InstanceGroupManagerStatusStateful', 5)
  versionTarget = _messages.MessageField('InstanceGroupManagerStatusVersionTarget', 6)


class InstanceGroupManagerStatusAllInstancesConfig(_messages.Message):
  r"""A InstanceGroupManagerStatusAllInstancesConfig object.

  Fields:
    currentRevision: [Output Only] Current all-instances configuration
      revision. This value is in RFC3339 text format.
    effective: [Output Only] A bit indicating whether this configuration has
      been applied to all managed instances in the group.
  """

  currentRevision = _messages.StringField(1)
  effective = _messages.BooleanField(2)


class InstanceGroupManagerStatusBulkInstanceOperation(_messages.Message):
  r"""A InstanceGroupManagerStatusBulkInstanceOperation object.

  Fields:
    inProgress: [Output Only] Informs whether bulk instance operation is in
      progress.
    lastProgressCheck: [Output Only] Information from last progress check of
      bulk instance operation.
  """

  inProgress = _messages.BooleanField(1)
  lastProgressCheck = _messages.MessageField('InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck', 2)


class InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck(_messages.Message):
  r"""A InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck
  object.

  Messages:
    ErrorValue: [Output Only] Contains errors encountered during bulk instance
      operation.

  Fields:
    error: [Output Only] Contains errors encountered during bulk instance
      operation.
    timestamp: [Output Only] Timestamp of the last progress check of bulk
      instance operation. Timestamp is in RFC3339 text format.
  """

  class ErrorValue(_messages.Message):
    r"""[Output Only] Contains errors encountered during bulk instance
    operation.

    Messages:
      ErrorsValueListEntry: A ErrorsValueListEntry object.

    Fields:
      errors: [Output Only] The array of errors encountered while processing
        this operation.
    """

    class ErrorsValueListEntry(_messages.Message):
      r"""A ErrorsValueListEntry object.

      Messages:
        ErrorDetailsValueListEntry: A ErrorDetailsValueListEntry object.

      Fields:
        code: [Output Only] The error type identifier for this error.
        errorDetails: [Output Only] An optional list of messages that contain
          the error details. There is a set of defined message types to use
          for providing details.The syntax depends on the error code. For
          example, QuotaExceededInfo will have details when the error code is
          QUOTA_EXCEEDED.
        location: [Output Only] Indicates the field in the request that caused
          the error. This property is optional.
        message: [Output Only] An optional, human-readable error message.
      """

      class ErrorDetailsValueListEntry(_messages.Message):
        r"""A ErrorDetailsValueListEntry object.

        Fields:
          errorInfo: A ErrorInfo attribute.
          help: A Help attribute.
          localizedMessage: A LocalizedMessage attribute.
          quotaInfo: A QuotaExceededInfo attribute.
        """

        errorInfo = _messages.MessageField('ErrorInfo', 1)
        help = _messages.MessageField('Help', 2)
        localizedMessage = _messages.MessageField('LocalizedMessage', 3)
        quotaInfo = _messages.MessageField('QuotaExceededInfo', 4)

      code = _messages.StringField(1)
      errorDetails = _messages.MessageField('ErrorDetailsValueListEntry', 2, repeated=True)
      location = _messages.StringField(3)
      message = _messages.StringField(4)

    errors = _messages.MessageField('ErrorsValueListEntry', 1, repeated=True)

  error = _messages.MessageField('ErrorValue', 1)
  timestamp = _messages.StringField(2)


class InstanceGroupManagerStatusStateful(_messages.Message):
  r"""A InstanceGroupManagerStatusStateful object.

  Fields:
    hasStatefulConfig: [Output Only] A bit indicating whether the managed
      instance group has stateful configuration, that is, if you have
      configured any items in a stateful policy or in per-instance configs.
      The group might report that it has no stateful configuration even when
      there is still some preserved state on a managed instance, for example,
      if you have deleted all PICs but not yet applied those deletions.
    isStateful: [Output Only] A bit indicating whether the managed instance
      group has stateful configuration, that is, if you have configured any
      items in a stateful policy or in per-instance configs. The group might
      report that it has no stateful configuration even when there is still
      some preserved state on a managed instance, for example, if you have
      deleted all PICs but not yet applied those deletions. This field is
      deprecated in favor of has_stateful_config.
    perInstanceConfigs: [Output Only] Status of per-instance configurations on
      the instances.
  """

  hasStatefulConfig = _messages.BooleanField(1)
  isStateful = _messages.BooleanField(2)
  perInstanceConfigs = _messages.MessageField('InstanceGroupManagerStatusStatefulPerInstanceConfigs', 3)


class InstanceGroupManagerStatusStatefulPerInstanceConfigs(_messages.Message):
  r"""A InstanceGroupManagerStatusStatefulPerInstanceConfigs object.

  Fields:
    allEffective: A bit indicating if all of the group's per-instance
      configurations (listed in the output of a listPerInstanceConfigs API
      call) have status EFFECTIVE or there are no per-instance-configs.
  """

  allEffective = _messages.BooleanField(1)


class InstanceGroupManagerStatusVersionTarget(_messages.Message):
  r"""A InstanceGroupManagerStatusVersionTarget object.

  Fields:
    isReached: [Output Only] A bit indicating whether version target has been
      reached in this managed instance group, i.e. all instances are in their
      target version. Instances' target version are specified by version field
      on Instance Group Manager.
  """

  isReached = _messages.BooleanField(1)


class InstanceGroupManagerTargetSizePolicy(_messages.Message):
  r"""A InstanceGroupManagerTargetSizePolicy object.

  Enums:
    ModeValueValuesEnum: Mode in which operations on size are processed.

  Fields:
    mode: Mode in which operations on size are processed.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Mode in which operations on size are processed.

    Values:
      BULK: Mode in which MIG creates and starts VMs in all-or-nothing manner.
        If any VM from the request cannot be provisioned, the whole request
        waits for conditions that allow for provisioning whole capacity in
        bulk.
      INDIVIDUAL: Default mode in which MIG creates and starts VMs
        individually without cross-dependency between VMs. This means that in
        case of something blocking part of VMs to be provisioned, the other
        part will be created.
      UNSPECIFIED_MODE: If mode is unspecified, MIG will behave as in the
        default `INDIVIDUAL` mode.
    """
    BULK = 0
    INDIVIDUAL = 1
    UNSPECIFIED_MODE = 2

  mode = _messages.EnumField('ModeValueValuesEnum', 1)


class InstanceGroupManagerUpdatePolicy(_messages.Message):
  r"""A InstanceGroupManagerUpdatePolicy object.

  Enums:
    InstanceRedistributionTypeValueValuesEnum: The instance redistribution
      policy for regional managed instance groups. Valid values are: -
      PROACTIVE (default): The group attempts to maintain an even distribution
      of VM instances across zones in the region. - NONE: For non-autoscaled
      groups, proactive redistribution is disabled.
    MinimalActionValueValuesEnum: Minimal action to be taken on an instance.
      Use this option to minimize disruption as much as possible or to apply a
      more disruptive action than is necessary. - To limit disruption as much
      as possible, set the minimal action to REFRESH. If your update requires
      a more disruptive action, Compute Engine performs the necessary action
      to execute the update. - To apply a more disruptive action than is
      strictly necessary, set the minimal action to RESTART or REPLACE. For
      example, Compute Engine does not need to restart a VM to change its
      metadata. But if your application reads instance metadata only when a VM
      is restarted, you can set the minimal action to RESTART in order to pick
      up metadata changes.
    MostDisruptiveAllowedActionValueValuesEnum: Most disruptive action that is
      allowed to be taken on an instance. You can specify either NONE to
      forbid any actions, REFRESH to avoid restarting the VM and to limit
      disruption as much as possible. RESTART to allow actions that can be
      applied without instance replacing or REPLACE to allow all possible
      actions. If the Updater determines that the minimal update action needed
      is more disruptive than most disruptive allowed action you specify it
      will not perform the update at all.
    ReplacementMethodValueValuesEnum: What action should be used to replace
      instances. See minimal_action.REPLACE
    TypeValueValuesEnum: The type of update process. You can specify either
      PROACTIVE so that the MIG automatically updates VMs to the latest
      configurations or OPPORTUNISTIC so that you can select the VMs that you
      want to update.

  Fields:
    instanceRedistributionType: The instance redistribution policy for
      regional managed instance groups. Valid values are: - PROACTIVE
      (default): The group attempts to maintain an even distribution of VM
      instances across zones in the region. - NONE: For non-autoscaled groups,
      proactive redistribution is disabled.
    maxSurge: The maximum number of instances that can be created above the
      specified targetSize during the update process. This value can be either
      a fixed number or, if the group has 10 or more instances, a percentage.
      If you set a percentage, the number of instances is rounded if
      necessary. The default value for maxSurge is a fixed value equal to the
      number of zones in which the managed instance group operates. At least
      one of either maxSurge or maxUnavailable must be greater than 0. Learn
      more about maxSurge.
    maxUnavailable: The maximum number of instances that can be unavailable
      during the update process. An instance is considered available if all of
      the following conditions are satisfied: - The instance's status is
      RUNNING. - If there is a health check on the instance group, the
      instance's health check status must be HEALTHY at least once. If there
      is no health check on the group, then the instance only needs to have a
      status of RUNNING to be considered available. This value can be either a
      fixed number or, if the group has 10 or more instances, a percentage. If
      you set a percentage, the number of instances is rounded if necessary.
      The default value for maxUnavailable is a fixed value equal to the
      number of zones in which the managed instance group operates. At least
      one of either maxSurge or maxUnavailable must be greater than 0. Learn
      more about maxUnavailable.
    minReadySec: Minimum number of seconds to wait for after a newly created
      instance becomes available. This value must be from range [0, 3600].
    minimalAction: Minimal action to be taken on an instance. Use this option
      to minimize disruption as much as possible or to apply a more disruptive
      action than is necessary. - To limit disruption as much as possible, set
      the minimal action to REFRESH. If your update requires a more disruptive
      action, Compute Engine performs the necessary action to execute the
      update. - To apply a more disruptive action than is strictly necessary,
      set the minimal action to RESTART or REPLACE. For example, Compute
      Engine does not need to restart a VM to change its metadata. But if your
      application reads instance metadata only when a VM is restarted, you can
      set the minimal action to RESTART in order to pick up metadata changes.
    mostDisruptiveAllowedAction: Most disruptive action that is allowed to be
      taken on an instance. You can specify either NONE to forbid any actions,
      REFRESH to avoid restarting the VM and to limit disruption as much as
      possible. RESTART to allow actions that can be applied without instance
      replacing or REPLACE to allow all possible actions. If the Updater
      determines that the minimal update action needed is more disruptive than
      most disruptive allowed action you specify it will not perform the
      update at all.
    replacementMethod: What action should be used to replace instances. See
      minimal_action.REPLACE
    type: The type of update process. You can specify either PROACTIVE so that
      the MIG automatically updates VMs to the latest configurations or
      OPPORTUNISTIC so that you can select the VMs that you want to update.
  """

  class InstanceRedistributionTypeValueValuesEnum(_messages.Enum):
    r"""The instance redistribution policy for regional managed instance
    groups. Valid values are: - PROACTIVE (default): The group attempts to
    maintain an even distribution of VM instances across zones in the region.
    - NONE: For non-autoscaled groups, proactive redistribution is disabled.

    Values:
      NONE: No action is being proactively performed in order to bring this
        IGM to its target instance distribution.
      PROACTIVE: This IGM will actively converge to its target instance
        distribution.
    """
    NONE = 0
    PROACTIVE = 1

  class MinimalActionValueValuesEnum(_messages.Enum):
    r"""Minimal action to be taken on an instance. Use this option to minimize
    disruption as much as possible or to apply a more disruptive action than
    is necessary. - To limit disruption as much as possible, set the minimal
    action to REFRESH. If your update requires a more disruptive action,
    Compute Engine performs the necessary action to execute the update. - To
    apply a more disruptive action than is strictly necessary, set the minimal
    action to RESTART or REPLACE. For example, Compute Engine does not need to
    restart a VM to change its metadata. But if your application reads
    instance metadata only when a VM is restarted, you can set the minimal
    action to RESTART in order to pick up metadata changes.

    Values:
      NONE: Do not perform any action.
      REFRESH: Do not stop the instance.
      REPLACE: (Default.) Replace the instance according to the replacement
        method option.
      RESTART: Stop the instance and start it again.
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MostDisruptiveAllowedActionValueValuesEnum(_messages.Enum):
    r"""Most disruptive action that is allowed to be taken on an instance. You
    can specify either NONE to forbid any actions, REFRESH to avoid restarting
    the VM and to limit disruption as much as possible. RESTART to allow
    actions that can be applied without instance replacing or REPLACE to allow
    all possible actions. If the Updater determines that the minimal update
    action needed is more disruptive than most disruptive allowed action you
    specify it will not perform the update at all.

    Values:
      NONE: Do not perform any action.
      REFRESH: Do not stop the instance.
      REPLACE: (Default.) Replace the instance according to the replacement
        method option.
      RESTART: Stop the instance and start it again.
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class ReplacementMethodValueValuesEnum(_messages.Enum):
    r"""What action should be used to replace instances. See
    minimal_action.REPLACE

    Values:
      RECREATE: Instances will be recreated (with the same name)
      SUBSTITUTE: Default option: instances will be deleted and created (with
        a new name)
    """
    RECREATE = 0
    SUBSTITUTE = 1

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of update process. You can specify either PROACTIVE so that
    the MIG automatically updates VMs to the latest configurations or
    OPPORTUNISTIC so that you can select the VMs that you want to update.

    Values:
      OPPORTUNISTIC: MIG will apply new configurations to existing VMs only
        when you selectively target specific or all VMs to be updated.
      PROACTIVE: MIG will automatically apply new configurations to all or a
        subset of existing VMs and also to new VMs that are added to the
        group.
    """
    OPPORTUNISTIC = 0
    PROACTIVE = 1

  instanceRedistributionType = _messages.EnumField('InstanceRedistributionTypeValueValuesEnum', 1)
  maxSurge = _messages.MessageField('FixedOrPercent', 2)
  maxUnavailable = _messages.MessageField('FixedOrPercent', 3)
  minReadySec = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  minimalAction = _messages.EnumField('MinimalActionValueValuesEnum', 5)
  mostDisruptiveAllowedAction = _messages.EnumField('MostDisruptiveAllowedActionValueValuesEnum', 6)
  replacementMethod = _messages.EnumField('ReplacementMethodValueValuesEnum', 7)
  type = _messages.EnumField('TypeValueValuesEnum', 8)


class InstanceGroupManagerVersion(_messages.Message):
  r"""A InstanceGroupManagerVersion object.

  Fields:
    instanceTemplate: The URL of the instance template that is specified for
      this managed instance group. The group uses this template to create new
      instances in the managed instance group until the `targetSize` for this
      version is reached. The templates for existing instances in the group do
      not change unless you run recreateInstances, run
      applyUpdatesToInstances, or set the group's updatePolicy.type to
      PROACTIVE; in those cases, existing instances are updated until the
      `targetSize` for this version is reached.
    name: Name of the version. Unique among all versions in the scope of this
      managed instance group.
    tag: Tag describing the version. Used to trigger rollout of a target
      version even if instance_template remains unchanged. Deprecated in favor
      of 'name'.
    targetSize: Specifies the intended number of instances to be created from
      the instanceTemplate. The final number of instances created from the
      template will be equal to: - If expressed as a fixed number, the minimum
      of either targetSize.fixed or instanceGroupManager.targetSize is used. -
      if expressed as a percent, the targetSize would be
      (targetSize.percent/100 * InstanceGroupManager.targetSize) If there is a
      remainder, the number is rounded. If unset, this version will update any
      remaining instances not updated by another version. Read Starting a
      canary update for more information.
  """

  instanceTemplate = _messages.StringField(1)
  name = _messages.StringField(2)
  tag = _messages.StringField(3)
  targetSize = _messages.MessageField('FixedOrPercent', 4)


class InstanceGroupManagersAbandonInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersAbandonInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to abandon. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class InstanceGroupManagersApplyUpdatesRequest(_messages.Message):
  r"""InstanceGroupManagers.applyUpdatesToInstances

  Enums:
    MaximalActionValueValuesEnum: The maximal action that should be performed
      on the instances. By default REPLACE. This field is deprecated, please
      use most_disruptive_allowed_action.
    MinimalActionValueValuesEnum: The minimal action that you want to perform
      on each instance during the update: - REPLACE: At minimum, delete the
      instance and create it again. - RESTART: Stop the instance and start it
      again. - REFRESH: Do not stop the instance and limit disruption as much
      as possible. - NONE: Do not disrupt the instance at all. By default, the
      minimum action is NONE. If your update requires a more disruptive action
      than you set with this flag, the necessary action is performed to
      execute the update.
    MostDisruptiveAllowedActionValueValuesEnum: The most disruptive action
      that you want to perform on each instance during the update: - REPLACE:
      Delete the instance and create it again. - RESTART: Stop the instance
      and start it again. - REFRESH: Do not stop the instance and limit
      disruption as much as possible. - NONE: Do not disrupt the instance at
      all. By default, the most disruptive allowed action is REPLACE. If your
      update requires a more disruptive action than you set with this flag,
      the update request will fail.

  Fields:
    allInstances: Flag to update all instances instead of specified list of
      "instances". If the flag is set to true then the instances may not be
      specified in the request.
    instances: The list of URLs of one or more instances for which you want to
      apply updates. Each URL can be a full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
    maximalAction: The maximal action that should be performed on the
      instances. By default REPLACE. This field is deprecated, please use
      most_disruptive_allowed_action.
    minimalAction: The minimal action that you want to perform on each
      instance during the update: - REPLACE: At minimum, delete the instance
      and create it again. - RESTART: Stop the instance and start it again. -
      REFRESH: Do not stop the instance and limit disruption as much as
      possible. - NONE: Do not disrupt the instance at all. By default, the
      minimum action is NONE. If your update requires a more disruptive action
      than you set with this flag, the necessary action is performed to
      execute the update.
    mostDisruptiveAllowedAction: The most disruptive action that you want to
      perform on each instance during the update: - REPLACE: Delete the
      instance and create it again. - RESTART: Stop the instance and start it
      again. - REFRESH: Do not stop the instance and limit disruption as much
      as possible. - NONE: Do not disrupt the instance at all. By default, the
      most disruptive allowed action is REPLACE. If your update requires a
      more disruptive action than you set with this flag, the update request
      will fail.
  """

  class MaximalActionValueValuesEnum(_messages.Enum):
    r"""The maximal action that should be performed on the instances. By
    default REPLACE. This field is deprecated, please use
    most_disruptive_allowed_action.

    Values:
      NONE: Do not perform any action.
      REFRESH: Do not stop the instance.
      REPLACE: (Default.) Replace the instance according to the replacement
        method option.
      RESTART: Stop the instance and start it again.
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MinimalActionValueValuesEnum(_messages.Enum):
    r"""The minimal action that you want to perform on each instance during
    the update: - REPLACE: At minimum, delete the instance and create it
    again. - RESTART: Stop the instance and start it again. - REFRESH: Do not
    stop the instance and limit disruption as much as possible. - NONE: Do not
    disrupt the instance at all. By default, the minimum action is NONE. If
    your update requires a more disruptive action than you set with this flag,
    the necessary action is performed to execute the update.

    Values:
      NONE: Do not perform any action.
      REFRESH: Do not stop the instance.
      REPLACE: (Default.) Replace the instance according to the replacement
        method option.
      RESTART: Stop the instance and start it again.
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MostDisruptiveAllowedActionValueValuesEnum(_messages.Enum):
    r"""The most disruptive action that you want to perform on each instance
    during the update: - REPLACE: Delete the instance and create it again. -
    RESTART: Stop the instance and start it again. - REFRESH: Do not stop the
    instance and limit disruption as much as possible. - NONE: Do not disrupt
    the instance at all. By default, the most disruptive allowed action is
    REPLACE. If your update requires a more disruptive action than you set
    with this flag, the update request will fail.

    Values:
      NONE: Do not perform any action.
      REFRESH: Do not stop the instance.
      REPLACE: (Default.) Replace the instance according to the replacement
        method option.
      RESTART: Stop the instance and start it again.
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  allInstances = _messages.BooleanField(1)
  instances = _messages.StringField(2, repeated=True)
  maximalAction = _messages.EnumField('MaximalActionValueValuesEnum', 3)
  minimalAction = _messages.EnumField('MinimalActionValueValuesEnum', 4)
  mostDisruptiveAllowedAction = _messages.EnumField('MostDisruptiveAllowedActionValueValuesEnum', 5)


class InstanceGroupManagersCreateInstancesRequest(_messages.Message):
  r"""InstanceGroupManagers.createInstances

  Fields:
    instances: [Required] List of specifications of per-instance configs.
  """

  instances = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class InstanceGroupManagersDeleteInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersDeleteInstancesRequest object.

  Fields:
    instanceNames: The list of instance names to delete. Queued instances do
      not have URL and can be deleted only by name. You cannot specify both
      URLs and names in a single request.
    instances: The URLs of one or more instances to delete. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
      Queued instances do not have URL and can be deleted only by name. One
      cannot specify both URLs and names in a single request.
    skipInstancesOnValidationError: Specifies whether the request should
      proceed despite the inclusion of instances that are not members of the
      group or that are already in the process of being deleted or abandoned.
      If this field is set to `false` and such an instance is specified in the
      request, the operation fails. The operation always fails if the request
      contains a malformed instance URL or a reference to an instance that
      exists in a zone or region other than the group's zone or region.
  """

  instanceNames = _messages.StringField(1, repeated=True)
  instances = _messages.StringField(2, repeated=True)
  skipInstancesOnValidationError = _messages.BooleanField(3)


class InstanceGroupManagersDeletePerInstanceConfigsReq(_messages.Message):
  r"""InstanceGroupManagers.deletePerInstanceConfigs

  Fields:
    names: The list of instance names for which we want to delete per-instance
      configs on this managed instance group.
  """

  names = _messages.StringField(1, repeated=True)


class InstanceGroupManagersListErrorsResponse(_messages.Message):
  r"""A InstanceGroupManagersListErrorsResponse object.

  Fields:
    items: [Output Only] The list of errors of the managed instance group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
  """

  items = _messages.MessageField('InstanceManagedByIgmError', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class InstanceGroupManagersListManagedInstancesResponse(_messages.Message):
  r"""A InstanceGroupManagersListManagedInstancesResponse object.

  Fields:
    managedInstances: [Output Only] The list of instances in the managed
      instance group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
  """

  managedInstances = _messages.MessageField('ManagedInstance', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class InstanceGroupManagersListPerInstanceConfigsResp(_messages.Message):
  r"""A InstanceGroupManagersListPerInstanceConfigsResp object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    items: [Output Only] The list of PerInstanceConfig.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  items = _messages.MessageField('PerInstanceConfig', 1, repeated=True)
  nextPageToken = _messages.StringField(2)
  warning = _messages.MessageField('WarningValue', 3)


class InstanceGroupManagersPatchPerInstanceConfigsReq(_messages.Message):
  r"""InstanceGroupManagers.patchPerInstanceConfigs

  Fields:
    perInstanceConfigs: The list of per-instance configurations to insert or
      patch on this managed instance group.
  """

  perInstanceConfigs = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class InstanceGroupManagersRecreateInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersRecreateInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to recreate. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class InstanceGroupManagersResizeAdvancedRequest(_messages.Message):
  r"""A InstanceGroupManagersResizeAdvancedRequest object.

  Fields:
    noCreationRetries: If this flag is true, the managed instance group
      attempts to create all instances initiated by this resize request only
      once. If there is an error during creation, the managed instance group
      does not retry create this instance, and we will decrease the targetSize
      of the request instead. If the flag is false, the group attempts to
      recreate each instance continuously until it succeeds. This flag matters
      only in the first attempt of creation of an instance. After an instance
      is successfully created while this flag is enabled, the instance behaves
      the same way as all the other instances created with a regular resize
      request. In particular, if a running instance dies unexpectedly at a
      later time and needs to be recreated, this mode does not affect the
      recreation behavior in that scenario. This flag is applicable only to
      the current resize request. It does not influence other resize requests
      in any way. You can see which instances is being creating in which mode
      by calling the get or listManagedInstances API.
    targetSize: The number of running instances that the managed instance
      group should maintain at any given time. The group automatically adds or
      removes instances to maintain the number of instances specified by this
      parameter.
  """

  noCreationRetries = _messages.BooleanField(1)
  targetSize = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class InstanceGroupManagersResumeInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersResumeInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to resume. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class InstanceGroupManagersScopedList(_messages.Message):
  r"""A InstanceGroupManagersScopedList object.

  Messages:
    WarningValue: [Output Only] The warning that replaces the list of managed
      instance groups when the list is empty.

  Fields:
    instanceGroupManagers: [Output Only] The list of managed instance groups
      that are contained in the specified project and zone.
    warning: [Output Only] The warning that replaces the list of managed
      instance groups when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] The warning that replaces the list of managed instance
    groups when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  instanceGroupManagers = _messages.MessageField('InstanceGroupManager', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InstanceGroupManagersSetAutoHealingRequest(_messages.Message):
  r"""A InstanceGroupManagersSetAutoHealingRequest object.

  Fields:
    autoHealingPolicies: A InstanceGroupManagerAutoHealingPolicy attribute.
  """

  autoHealingPolicies = _messages.MessageField('InstanceGroupManagerAutoHealingPolicy', 1, repeated=True)


class InstanceGroupManagersSetInstanceTemplateRequest(_messages.Message):
  r"""A InstanceGroupManagersSetInstanceTemplateRequest object.

  Fields:
    instanceTemplate: The URL of the instance template that is specified for
      this managed instance group. The group uses this template to create all
      new instances in the managed instance group. The templates for existing
      instances in the group do not change unless you run recreateInstances,
      run applyUpdatesToInstances, or set the group's updatePolicy.type to
      PROACTIVE.
  """

  instanceTemplate = _messages.StringField(1)


class InstanceGroupManagersSetTargetPoolsRequest(_messages.Message):
  r"""A InstanceGroupManagersSetTargetPoolsRequest object.

  Fields:
    fingerprint: The fingerprint of the target pools information. Use this
      optional property to prevent conflicts when multiple users change the
      target pools settings concurrently. Obtain the fingerprint with the
      instanceGroupManagers.get method. Then, include the fingerprint in your
      request to ensure that you do not overwrite changes that were applied
      from another concurrent request.
    targetPools: The list of target pool URLs that instances in this managed
      instance group belong to. The managed instance group applies these
      target pools to all of the instances in the group. Existing instances
      and new instances in the group all receive these target pool settings.
  """

  fingerprint = _messages.BytesField(1)
  targetPools = _messages.StringField(2, repeated=True)


class InstanceGroupManagersStartInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersStartInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to start. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class InstanceGroupManagersStopInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersStopInstancesRequest object.

  Fields:
    forceStop: If this flag is set to true, the Instance Group Manager will
      proceed to stop the instances, skipping initialization on them.
    instances: The URLs of one or more instances to stop. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  forceStop = _messages.BooleanField(1)
  instances = _messages.StringField(2, repeated=True)


class InstanceGroupManagersSuspendInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersSuspendInstancesRequest object.

  Fields:
    forceSuspend: If this flag is set to true, the Instance Group Manager will
      proceed to suspend the instances, skipping initialization on them.
    instances: The URLs of one or more instances to suspend. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  forceSuspend = _messages.BooleanField(1)
  instances = _messages.StringField(2, repeated=True)


class InstanceGroupManagersUpdatePerInstanceConfigsReq(_messages.Message):
  r"""InstanceGroupManagers.updatePerInstanceConfigs

  Fields:
    perInstanceConfigs: The list of per-instance configurations to insert or
      patch on this managed instance group.
  """

  perInstanceConfigs = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class InstanceGroupsAddInstancesRequest(_messages.Message):
  r"""A InstanceGroupsAddInstancesRequest object.

  Fields:
    instances: The list of instances to add to the instance group.
  """

  instances = _messages.MessageField('InstanceReference', 1, repeated=True)


class InstanceGroupsListInstances(_messages.Message):
  r"""A InstanceGroupsListInstances object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceWithNamedPorts resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupsListInstances for the list of instances in the
      specified instance group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceWithNamedPorts', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#instanceGroupsListInstances')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceGroupsListInstancesRequest(_messages.Message):
  r"""A InstanceGroupsListInstancesRequest object.

  Enums:
    InstanceStateValueValuesEnum: A filter for the state of the instances in
      the instance group. Valid options are ALL or RUNNING. If you do not
      specify this parameter the list includes all instances regardless of
      their state.

  Fields:
    instanceState: A filter for the state of the instances in the instance
      group. Valid options are ALL or RUNNING. If you do not specify this
      parameter the list includes all instances regardless of their state.
  """

  class InstanceStateValueValuesEnum(_messages.Enum):
    r"""A filter for the state of the instances in the instance group. Valid
    options are ALL or RUNNING. If you do not specify this parameter the list
    includes all instances regardless of their state.

    Values:
      ALL: Includes all instances in the generated list regardless of their
        state.
      RUNNING: Includes instances in the generated list only if they have a
        RUNNING state.
    """
    ALL = 0
    RUNNING = 1

  instanceState = _messages.EnumField('InstanceStateValueValuesEnum', 1)


class InstanceGroupsRemoveInstancesRequest(_messages.Message):
  r"""A InstanceGroupsRemoveInstancesRequest object.

  Fields:
    instances: The list of instances to remove from the instance group.
  """

  instances = _messages.MessageField('InstanceReference', 1, repeated=True)


class InstanceGroupsScopedList(_messages.Message):
  r"""A InstanceGroupsScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that replaces the
      list of instance groups when the list is empty.

  Fields:
    instanceGroups: [Output Only] The list of instance groups that are
      contained in this scope.
    warning: [Output Only] An informational warning that replaces the list of
      instance groups when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that replaces the list of
    instance groups when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  instanceGroups = _messages.MessageField('InstanceGroup', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InstanceGroupsSetNamedPortsRequest(_messages.Message):
  r"""A InstanceGroupsSetNamedPortsRequest object.

  Fields:
    fingerprint: The fingerprint of the named ports information for this
      instance group. Use this optional property to prevent conflicts when
      multiple users change the named ports settings concurrently. Obtain the
      fingerprint with the instanceGroups.get method. Then, include the
      fingerprint in your request to ensure that you do not overwrite changes
      that were applied from another concurrent request. A request with an
      incorrect fingerprint will fail with error 412 conditionNotMet.
    namedPorts: The list of named ports to set for this instance group.
  """

  fingerprint = _messages.BytesField(1)
  namedPorts = _messages.MessageField('NamedPort', 2, repeated=True)


class InstanceList(_messages.Message):
  r"""Contains a list of instances.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Instance resources.
    kind: [Output Only] Type of resource. Always compute#instanceList for
      lists of Instance resources.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Instance', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#instanceList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceListReferrers(_messages.Message):
  r"""Contains a list of instance referrers.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Reference resources.
    kind: [Output Only] Type of resource. Always compute#instanceListReferrers
      for lists of Instance referrers.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Reference', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#instanceListReferrers')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceManagedByIgmError(_messages.Message):
  r"""A InstanceManagedByIgmError object.

  Fields:
    error: [Output Only] Contents of the error.
    instanceActionDetails: [Output Only] Details of the instance action that
      triggered this error. May be null, if the error was not caused by an
      action on an instance. This field is optional.
    timestamp: [Output Only] The time that this error occurred. This value is
      in RFC3339 text format.
  """

  error = _messages.MessageField('InstanceManagedByIgmErrorManagedInstanceError', 1)
  instanceActionDetails = _messages.MessageField('InstanceManagedByIgmErrorInstanceActionDetails', 2)
  timestamp = _messages.StringField(3)


class InstanceManagedByIgmErrorInstanceActionDetails(_messages.Message):
  r"""A InstanceManagedByIgmErrorInstanceActionDetails object.

  Enums:
    ActionValueValuesEnum: [Output Only] Action that managed instance group
      was executing on the instance when the error occurred. Possible values:

  Fields:
    action: [Output Only] Action that managed instance group was executing on
      the instance when the error occurred. Possible values:
    instance: [Output Only] The URL of the instance. The URL can be set even
      if the instance has not yet been created.
    version: [Output Only] Version this instance was created from, or was
      being created from, but the creation failed. Corresponds to one of the
      versions that were set on the Instance Group Manager resource at the
      time this instance was being created.
  """

  class ActionValueValuesEnum(_messages.Enum):
    r"""[Output Only] Action that managed instance group was executing on the
    instance when the error occurred. Possible values:

    Values:
      ABANDONING: The managed instance group is abandoning this instance. The
        instance will be removed from the instance group and from any target
        pools that are associated with this group.
      CREATING: The managed instance group is creating this instance. If the
        group fails to create this instance, it will try again until it is
        successful.
      CREATING_ATOMICALLY: The managed instance group is creating this
        instance atomically.
      CREATING_WITHOUT_RETRIES: The managed instance group is attempting to
        create this instance only once. If the group fails to create this
        instance, it does not try again and the group's targetSize value is
        decreased.
      DELETING: The managed instance group is permanently deleting this
        instance.
      NONE: The managed instance group has not scheduled any actions for this
        instance.
      QUEUING: The managed instance group is queuing this instance.
      RECREATING: The managed instance group is recreating this instance.
      REFRESHING: The managed instance group is applying configuration changes
        to the instance without stopping it. For example, the group can update
        the target pool list for an instance without stopping that instance.
      RESTARTING: The managed instance group is restarting this instance.
      RESUMING: The managed instance group is resuming this instance.
      STARTING: The managed instance group is starting this instance.
      STOPPING: The managed instance group is stopping this instance.
      SUSPENDING: The managed instance group is suspending this instance.
      VERIFYING: The managed instance group is verifying this already created
        instance. Verification happens every time the instance is (re)created
        or restarted and consists of: 1. Waiting until health check specified
        as part of this managed instance group's autohealing policy reports
        HEALTHY. Note: Applies only if autohealing policy has a health check
        specified 2. Waiting for addition verification steps performed as
        post-instance creation (subject to future extensions).
    """
    ABANDONING = 0
    CREATING = 1
    CREATING_ATOMICALLY = 2
    CREATING_WITHOUT_RETRIES = 3
    DELETING = 4
    NONE = 5
    QUEUING = 6
    RECREATING = 7
    REFRESHING = 8
    RESTARTING = 9
    RESUMING = 10
    STARTING = 11
    STOPPING = 12
    SUSPENDING = 13
    VERIFYING = 14

  action = _messages.EnumField('ActionValueValuesEnum', 1)
  instance = _messages.StringField(2)
  version = _messages.MessageField('ManagedInstanceVersion', 3)


class InstanceManagedByIgmErrorManagedInstanceError(_messages.Message):
  r"""A InstanceManagedByIgmErrorManagedInstanceError object.

  Fields:
    code: [Output Only] Error code.
    message: [Output Only] Error message.
  """

  code = _messages.StringField(1)
  message = _messages.StringField(2)


class InstanceMoveRequest(_messages.Message):
  r"""A InstanceMoveRequest object.

  Fields:
    destinationZone: The URL of the destination zone to move the instance.
      This can be a full or partial URL. For example, the following are all
      valid URLs to a zone: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone -
      projects/project/zones/zone - zones/zone
    targetInstance: The URL of the target instance to move. This can be a full
      or partial URL. For example, the following are all valid URLs to an
      instance: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /instances/instance - projects/project/zones/zone/instances/instance -
      zones/zone/instances/instance
  """

  destinationZone = _messages.StringField(1)
  targetInstance = _messages.StringField(2)


class InstanceParams(_messages.Message):
  r"""Additional instance params.

  Messages:
    ResourceManagerTagsValue: Resource manager tags to be bound to the
      instance. Tag keys and values have the same definition as resource
      manager tags. Keys must be in the format `tagKeys/{tag_key_id}`, and
      values are in the format `tagValues/456`. The field is ignored (both PUT
      & PATCH) when empty.

  Fields:
    resourceManagerTags: Resource manager tags to be bound to the instance.
      Tag keys and values have the same definition as resource manager tags.
      Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the
      format `tagValues/456`. The field is ignored (both PUT & PATCH) when
      empty.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ResourceManagerTagsValue(_messages.Message):
    r"""Resource manager tags to be bound to the instance. Tag keys and values
    have the same definition as resource manager tags. Keys must be in the
    format `tagKeys/{tag_key_id}`, and values are in the format
    `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.

    Messages:
      AdditionalProperty: An additional property for a
        ResourceManagerTagsValue object.

    Fields:
      additionalProperties: Additional properties of type
        ResourceManagerTagsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ResourceManagerTagsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  resourceManagerTags = _messages.MessageField('ResourceManagerTagsValue', 1)


class InstanceProperties(_messages.Message):
  r"""A InstanceProperties object.

  Enums:
    KeyRevocationActionTypeValueValuesEnum: KeyRevocationActionType of the
      instance. Supported options are "STOP" and "NONE". The default value is
      "NONE" if it is not specified.
    PostKeyRevocationActionTypeValueValuesEnum: PostKeyRevocationActionType of
      the instance.
    PrivateIpv6GoogleAccessValueValuesEnum: The private IPv6 google access
      type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default.
      Note that for MachineImage, this is not supported yet.

  Messages:
    LabelsValue: Labels to apply to instances that are created from these
      properties.
    PartnerMetadataValue: Partner Metadata assigned to the instance
      properties. A map from a subdomain (namespace) to entries map.
    ResourceManagerTagsValue: Resource manager tags to be bound to the
      instance. Tag keys and values have the same definition as resource
      manager tags. Keys must be in the format `tagKeys/{tag_key_id}`, and
      values are in the format `tagValues/456`. The field is ignored (both PUT
      & PATCH) when empty.
    ServiceIntegrationSpecsValue: Mapping of user defined keys to
      ServiceIntegrationSpec.

  Fields:
    advancedMachineFeatures: Controls for advanced machine-related behavior
      features. Note that for MachineImage, this is not supported yet.
    canIpForward: Enables instances created based on these properties to send
      packets with source IP addresses other than their own and receive
      packets with destination IP addresses other than their own. If these
      instances will be used as an IP gateway or it will be set as the next-
      hop in a Route resource, specify true. If unsure, leave this set to
      false. See the Enable IP forwarding documentation for more information.
    confidentialInstanceConfig: Specifies the Confidential Instance options.
      Note that for MachineImage, this is not supported yet.
    description: An optional text description for the instances that are
      created from these properties.
    disks: An array of disks that are associated with the instances that are
      created from these properties.
    displayDevice: Display Device properties to enable support for remote
      display products like: Teradici, VNC and TeamViewer Note that for
      MachineImage, this is not supported yet.
    guestAccelerators: A list of guest accelerator cards' type and count to
      use for instances created from these properties.
    keyRevocationActionType: KeyRevocationActionType of the instance.
      Supported options are "STOP" and "NONE". The default value is "NONE" if
      it is not specified.
    labels: Labels to apply to instances that are created from these
      properties.
    machineType: The machine type to use for instances that are created from
      these properties. This field only accepts a machine type name, for
      example `n2-standard-4`. If you use the machine type full or partial
      URL, for example `projects/my-l7ilb-project/zones/us-
      central1-a/machineTypes/n2-standard-4`, the request will result in an
      `INTERNAL_ERROR`.
    metadata: The metadata key/value pairs to assign to instances that are
      created from these properties. These pairs can consist of custom
      metadata or predefined keys. See Project and instance metadata for more
      information.
    minCpuPlatform: Minimum cpu/platform to be used by instances. The instance
      may be scheduled on the specified or newer cpu/platform. Applicable
      values are the friendly names of CPU platforms, such as minCpuPlatform:
      "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". For more
      information, read Specifying a Minimum CPU Platform.
    networkInterfaces: An array of network access configurations for this
      interface.
    networkPerformanceConfig: Note that for MachineImage, this is not
      supported yet.
    partnerMetadata: Partner Metadata assigned to the instance properties. A
      map from a subdomain (namespace) to entries map.
    postKeyRevocationActionType: PostKeyRevocationActionType of the instance.
    privateIpv6GoogleAccess: The private IPv6 google access type for VMs. If
      not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for
      MachineImage, this is not supported yet.
    reservationAffinity: Specifies the reservations that instances can consume
      from. Note that for MachineImage, this is not supported yet.
    resourceManagerTags: Resource manager tags to be bound to the instance.
      Tag keys and values have the same definition as resource manager tags.
      Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the
      format `tagValues/456`. The field is ignored (both PUT & PATCH) when
      empty.
    resourcePolicies: Resource policies (names, not URLs) applied to instances
      created from these properties. Note that for MachineImage, this is not
      supported yet.
    scheduling: Specifies the scheduling options for the instances that are
      created from these properties.
    secureTags: [Input Only] Secure tags to apply to this instance. Maximum
      number of secure tags allowed is 50. Note that for MachineImage, this is
      not supported yet.
    serviceAccounts: A list of service accounts with specified scopes. Access
      tokens for these service accounts are available to the instances that
      are created from these properties. Use metadata queries to obtain the
      access tokens for these instances.
    serviceIntegrationSpecs: Mapping of user defined keys to
      ServiceIntegrationSpec.
    shieldedInstanceConfig: Note that for MachineImage, this is not supported
      yet.
    shieldedVmConfig: Specifies the Shielded VM options for the instances that
      are created from these properties.
    tags: A list of tags to apply to the instances that are created from these
      properties. The tags identify valid sources or targets for network
      firewalls. The setTags method can modify this list of tags. Each tag
      within the list must comply with RFC1035.
  """

  class KeyRevocationActionTypeValueValuesEnum(_messages.Enum):
    r"""KeyRevocationActionType of the instance. Supported options are "STOP"
    and "NONE". The default value is "NONE" if it is not specified.

    Values:
      KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED: Default value. This value is
        unused.
      NONE: Indicates user chose no operation.
      STOP: Indicates user chose to opt for VM shutdown on key revocation.
    """
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 0
    NONE = 1
    STOP = 2

  class PostKeyRevocationActionTypeValueValuesEnum(_messages.Enum):
    r"""PostKeyRevocationActionType of the instance.

    Values:
      NOOP: Indicates user chose no operation.
      POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED: Default value. This value
        is unused.
      SHUTDOWN: Indicates user chose to opt for VM shutdown on key revocation.
    """
    NOOP = 0
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 1
    SHUTDOWN = 2

  class PrivateIpv6GoogleAccessValueValuesEnum(_messages.Enum):
    r"""The private IPv6 google access type for VMs. If not specified, use
    INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is
    not supported yet.

    Values:
      ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE: Bidirectional private IPv6 access
        to/from Google services. If specified, the subnetwork who is attached
        to the instance's default network interface will be assigned an
        internal IPv6 prefix if it doesn't have before.
      ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE: Outbound private IPv6 access from
        VMs in this subnet to Google services. If specified, the subnetwork
        who is attached to the instance's default network interface will be
        assigned an internal IPv6 prefix if it doesn't have before.
      INHERIT_FROM_SUBNETWORK: Each network interface inherits
        PrivateIpv6GoogleAccess from its subnetwork.
    """
    ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 0
    ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 1
    INHERIT_FROM_SUBNETWORK = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to instances that are created from these properties.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class PartnerMetadataValue(_messages.Message):
    r"""Partner Metadata assigned to the instance properties. A map from a
    subdomain (namespace) to entries map.

    Messages:
      AdditionalProperty: An additional property for a PartnerMetadataValue
        object.

    Fields:
      additionalProperties: Additional properties of type PartnerMetadataValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a PartnerMetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A StructuredEntries attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StructuredEntries', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ResourceManagerTagsValue(_messages.Message):
    r"""Resource manager tags to be bound to the instance. Tag keys and values
    have the same definition as resource manager tags. Keys must be in the
    format `tagKeys/{tag_key_id}`, and values are in the format
    `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.

    Messages:
      AdditionalProperty: An additional property for a
        ResourceManagerTagsValue object.

    Fields:
      additionalProperties: Additional properties of type
        ResourceManagerTagsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ResourceManagerTagsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ServiceIntegrationSpecsValue(_messages.Message):
    r"""Mapping of user defined keys to ServiceIntegrationSpec.

    Messages:
      AdditionalProperty: An additional property for a
        ServiceIntegrationSpecsValue object.

    Fields:
      additionalProperties: Additional properties of type
        ServiceIntegrationSpecsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ServiceIntegrationSpecsValue object.

      Fields:
        key: Name of the additional property.
        value: A ServiceIntegrationSpec attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ServiceIntegrationSpec', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  advancedMachineFeatures = _messages.MessageField('AdvancedMachineFeatures', 1)
  canIpForward = _messages.BooleanField(2)
  confidentialInstanceConfig = _messages.MessageField('ConfidentialInstanceConfig', 3)
  description = _messages.StringField(4)
  disks = _messages.MessageField('AttachedDisk', 5, repeated=True)
  displayDevice = _messages.MessageField('DisplayDevice', 6)
  guestAccelerators = _messages.MessageField('AcceleratorConfig', 7, repeated=True)
  keyRevocationActionType = _messages.EnumField('KeyRevocationActionTypeValueValuesEnum', 8)
  labels = _messages.MessageField('LabelsValue', 9)
  machineType = _messages.StringField(10)
  metadata = _messages.MessageField('Metadata', 11)
  minCpuPlatform = _messages.StringField(12)
  networkInterfaces = _messages.MessageField('NetworkInterface', 13, repeated=True)
  networkPerformanceConfig = _messages.MessageField('NetworkPerformanceConfig', 14)
  partnerMetadata = _messages.MessageField('PartnerMetadataValue', 15)
  postKeyRevocationActionType = _messages.EnumField('PostKeyRevocationActionTypeValueValuesEnum', 16)
  privateIpv6GoogleAccess = _messages.EnumField('PrivateIpv6GoogleAccessValueValuesEnum', 17)
  reservationAffinity = _messages.MessageField('ReservationAffinity', 18)
  resourceManagerTags = _messages.MessageField('ResourceManagerTagsValue', 19)
  resourcePolicies = _messages.StringField(20, repeated=True)
  scheduling = _messages.MessageField('Scheduling', 21)
  secureTags = _messages.StringField(22, repeated=True)
  serviceAccounts = _messages.MessageField('ServiceAccount', 23, repeated=True)
  serviceIntegrationSpecs = _messages.MessageField('ServiceIntegrationSpecsValue', 24)
  shieldedInstanceConfig = _messages.MessageField('ShieldedInstanceConfig', 25)
  shieldedVmConfig = _messages.MessageField('ShieldedVmConfig', 26)
  tags = _messages.MessageField('Tags', 27)


class InstancePropertiesPatch(_messages.Message):
  r"""Represents the change that you want to make to the instance properties.

  Messages:
    LabelsValue: The label key-value pairs that you want to patch onto the
      instance.
    MetadataValue: The metadata key-value pairs that you want to patch onto
      the instance. For more information, see Project and instance metadata.

  Fields:
    labels: The label key-value pairs that you want to patch onto the
      instance.
    metadata: The metadata key-value pairs that you want to patch onto the
      instance. For more information, see Project and instance metadata.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""The label key-value pairs that you want to patch onto the instance.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class MetadataValue(_messages.Message):
    r"""The metadata key-value pairs that you want to patch onto the instance.
    For more information, see Project and instance metadata.

    Messages:
      AdditionalProperty: An additional property for a MetadataValue object.

    Fields:
      additionalProperties: Additional properties of type MetadataValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a MetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labels = _messages.MessageField('LabelsValue', 1)
  metadata = _messages.MessageField('MetadataValue', 2)


class InstanceReference(_messages.Message):
  r"""A InstanceReference object.

  Fields:
    instance: The URL for a specific instance. @required
      compute.instancegroups.addInstances/removeInstances
  """

  instance = _messages.StringField(1)


class InstanceSettings(_messages.Message):
  r"""Represents a Instance Settings resource. You can use instance settings
  to configure default settings for Compute Engine VM instances. For example,
  you can use it to configure default machine type of Compute Engine VM
  instances.

  Fields:
    email: Email address of the service account.
    fingerprint: Specifies a fingerprint for instance settings, which is
      essentially a hash of the instance settings resource's contents and used
      for optimistic locking. The fingerprint is initially generated by
      Compute Engine and changes after every request to modify or update the
      instance settings resource. You must always provide an up-to-date
      fingerprint hash in order to update or change the resource, otherwise
      the request will fail with error 412 conditionNotMet. To see the latest
      fingerprint, make a get() request to retrieve the resource.
    kind: [Output Only] Type of the resource. Always compute#instance_settings
      for instance settings.
    metadata: The metadata key/value pairs assigned to all the instances in
      the corresponding scope.
    zone: [Output Only] URL of the zone where the resource resides You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
  """

  email = _messages.StringField(1)
  fingerprint = _messages.BytesField(2)
  kind = _messages.StringField(3, default='compute#instanceSettings')
  metadata = _messages.MessageField('InstanceSettingsMetadata', 4)
  zone = _messages.StringField(5)


class InstanceSettingsMetadata(_messages.Message):
  r"""A InstanceSettingsMetadata object.

  Messages:
    ItemsValue: A metadata key/value items map. The total size of all keys and
      values must be less than 512KB.

  Fields:
    items: A metadata key/value items map. The total size of all keys and
      values must be less than 512KB.
    kind: [Output Only] Type of the resource. Always compute#metadata for
      metadata.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A metadata key/value items map. The total size of all keys and values
    must be less than 512KB.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Additional properties of type ItemsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  items = _messages.MessageField('ItemsValue', 1)
  kind = _messages.StringField(2, default='compute#metadata')


class InstanceTemplate(_messages.Message):
  r"""Represents an Instance Template resource. Google Compute Engine has two
  Instance Template resources: *
  [Global](/compute/docs/reference/rest/alpha/instanceTemplates) *
  [Regional](/compute/docs/reference/rest/alpha/regionInstanceTemplates) You
  can reuse a global instance template in different regions whereas you can
  use a regional instance template in a specified region only. If you want to
  reduce cross-region dependency or achieve data residency, use a regional
  instance template. To create VMs, managed instance groups, and reservations,
  you can use either global or regional instance templates. For more
  information, read Instance Templates.

  Fields:
    creationTimestamp: [Output Only] The creation timestamp for this instance
      template in RFC3339 text format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] A unique identifier for this instance template. The
      server defines this identifier.
    kind: [Output Only] The resource type, which is always
      compute#instanceTemplate for instance templates.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    properties: The instance properties for this instance template.
    region: [Output Only] URL of the region where the instance template
      resides. Only applicable for regional resources.
    selfLink: [Output Only] The URL for this instance template. The server
      defines this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sourceInstance: The source instance used to create the template. You can
      provide this as a partial or full URL to the resource. For example, the
      following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /instances/instance - projects/project/zones/zone/instances/instance
    sourceInstanceParams: The source instance params to use to create this
      instance template.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default='compute#instanceTemplate')
  name = _messages.StringField(5)
  properties = _messages.MessageField('InstanceProperties', 6)
  region = _messages.StringField(7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  sourceInstance = _messages.StringField(10)
  sourceInstanceParams = _messages.MessageField('SourceInstanceParams', 11)


class InstanceTemplateAggregatedList(_messages.Message):
  r"""Contains a list of InstanceTemplatesScopedList.

  Messages:
    ItemsValue: A list of InstanceTemplatesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceTemplatesScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of InstanceTemplatesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: The name of the scope that contains this set of
        instance templates.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InstanceTemplatesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstanceTemplatesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#instanceTemplateAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceTemplateList(_messages.Message):
  r"""A list of instance templates.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceTemplate resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceTemplatesListResponse for instance template lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceTemplate', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#instanceTemplateList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceTemplatesScopedList(_messages.Message):
  r"""A InstanceTemplatesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that replaces the
      list of instance templates when the list is empty.

  Fields:
    instanceTemplates: [Output Only] A list of instance templates that are
      contained within the specified project and zone.
    warning: [Output Only] An informational warning that replaces the list of
      instance templates when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that replaces the list of
    instance templates when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  instanceTemplates = _messages.MessageField('InstanceTemplate', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InstanceWithNamedPorts(_messages.Message):
  r"""A InstanceWithNamedPorts object.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the instance.

  Fields:
    instance: [Output Only] The URL of the instance.
    namedPorts: [Output Only] The named ports that belong to this instance
      group.
    status: [Output Only] The status of the instance.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the instance.

    Values:
      DEPROVISIONING: The instance is halted and we are performing tear down
        tasks like network deprogramming, releasing quota, IP, tearing down
        disks etc.
      PENDING_STOP: The instance is gracefully shutting down.
      PROVISIONING: Resources are being allocated for the instance.
      REPAIRING: The instance is in repair.
      RUNNING: The instance is running.
      STAGING: All required resources have been allocated and the instance is
        being started.
      STOPPED: The instance has stopped successfully.
      STOPPING: The instance is currently stopping (either being deleted or
        killed).
      SUSPENDED: The instance has suspended.
      SUSPENDING: The instance is suspending.
      TERMINATED: The instance has stopped (either by explicit action or
        underlying failure).
    """
    DEPROVISIONING = 0
    PENDING_STOP = 1
    PROVISIONING = 2
    REPAIRING = 3
    RUNNING = 4
    STAGING = 5
    STOPPED = 6
    STOPPING = 7
    SUSPENDED = 8
    SUSPENDING = 9
    TERMINATED = 10

  instance = _messages.StringField(1)
  namedPorts = _messages.MessageField('NamedPort', 2, repeated=True)
  status = _messages.EnumField('StatusValueValuesEnum', 3)


class InstancesAddResourcePoliciesRequest(_messages.Message):
  r"""A InstancesAddResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be added to this instance.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class InstancesBulkInsertOperationMetadata(_messages.Message):
  r"""A InstancesBulkInsertOperationMetadata object.

  Messages:
    PerLocationStatusValue: Status information per location (location name is
      key). Example key: zones/us-central1-a

  Fields:
    perLocationStatus: Status information per location (location name is key).
      Example key: zones/us-central1-a
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class PerLocationStatusValue(_messages.Message):
    r"""Status information per location (location name is key). Example key:
    zones/us-central1-a

    Messages:
      AdditionalProperty: An additional property for a PerLocationStatusValue
        object.

    Fields:
      additionalProperties: Additional properties of type
        PerLocationStatusValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a PerLocationStatusValue object.

      Fields:
        key: Name of the additional property.
        value: A BulkInsertOperationStatus attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('BulkInsertOperationStatus', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  perLocationStatus = _messages.MessageField('PerLocationStatusValue', 1)


class InstancesGetEffectiveFirewallsResponse(_messages.Message):
  r"""A InstancesGetEffectiveFirewallsResponse object.

  Fields:
    firewallPolicys: [Output Only] Effective firewalls from firewall policies.
    firewalls: Effective firewalls on the instance.
    organizationFirewalls: Effective firewalls from organization policies.
  """

  firewallPolicys = _messages.MessageField('InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy', 1, repeated=True)
  firewalls = _messages.MessageField('Firewall', 2, repeated=True)
  organizationFirewalls = _messages.MessageField('InstancesGetEffectiveFirewallsResponseOrganizationFirewallPolicy', 3, repeated=True)


class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy(_messages.Message):
  r"""A InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy object.

  Enums:
    TypeValueValuesEnum: [Output Only] The type of the firewall policy. Can be
      one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL,
      SYSTEM_REGIONAL.

  Fields:
    displayName: [Output Only] Deprecated, please use short name instead. The
      display name of the firewall policy.
    name: [Output Only] The name of the firewall policy.
    packetMirroringRules: [Output Only] The packet mirroring rules that apply
      to the instance.
    priority: [Output only] Priority of firewall policy association. Not
      applicable for type=HIERARCHY.
    rules: [Output Only] The rules that apply to the instance. Only rules that
      target the specific VM instance are returned if target service accounts
      or target secure tags are specified in the rules.
    shortName: [Output Only] The short name of the firewall policy.
    type: [Output Only] The type of the firewall policy. Can be one of
      HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The type of the firewall policy. Can be one of
    HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.

    Values:
      HIERARCHY: <no description>
      NETWORK: <no description>
      NETWORK_REGIONAL: <no description>
      SYSTEM_GLOBAL: <no description>
      SYSTEM_REGIONAL: <no description>
      UNSPECIFIED: <no description>
    """
    HIERARCHY = 0
    NETWORK = 1
    NETWORK_REGIONAL = 2
    SYSTEM_GLOBAL = 3
    SYSTEM_REGIONAL = 4
    UNSPECIFIED = 5

  displayName = _messages.StringField(1)
  name = _messages.StringField(2)
  packetMirroringRules = _messages.MessageField('FirewallPolicyRule', 3, repeated=True)
  priority = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  rules = _messages.MessageField('FirewallPolicyRule', 5, repeated=True)
  shortName = _messages.StringField(6)
  type = _messages.EnumField('TypeValueValuesEnum', 7)


class InstancesGetEffectiveFirewallsResponseOrganizationFirewallPolicy(_messages.Message):
  r"""A pruned SecurityPolicy containing ID and any applicable firewall rules.

  Fields:
    id: The unique identifier for the security policy. This identifier is
      defined by the server.
    rules: The rules that apply to the network.
  """

  id = _messages.IntegerField(1, variant=_messages.Variant.UINT64)
  rules = _messages.MessageField('SecurityPolicyRule', 2, repeated=True)


class InstancesRemoveResourcePoliciesRequest(_messages.Message):
  r"""A InstancesRemoveResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be removed from this instance.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class InstancesReportHostAsFaultyRequest(_messages.Message):
  r"""A InstancesReportHostAsFaultyRequest object.

  Enums:
    ActionHintValueValuesEnum: The action hint to report the host as faulty.
    DisruptionScheduleValueValuesEnum: The disruption schedule for the VM.
      Default to IMMEDIATE.

  Fields:
    actionHint: The action hint to report the host as faulty.
    disruptionSchedule: The disruption schedule for the VM. Default to
      IMMEDIATE.
    faultReasons: A InstancesReportHostAsFaultyRequestFaultReason attribute.
  """

  class ActionHintValueValuesEnum(_messages.Enum):
    r"""The action hint to report the host as faulty.

    Values:
      ACTION_HINT_UNSPECIFIED: Default value. Euivalent to
        DIAGNOSE_AND_REPAIR.
      DIAGNOSE_AND_REPAIR: The action hint to diagnose and repair the host.
      EXECUTE_ALL_RECOMMENDED_SCANS: The action hint to execute recommended
        scans without sending the machine through hwops.
    """
    ACTION_HINT_UNSPECIFIED = 0
    DIAGNOSE_AND_REPAIR = 1
    EXECUTE_ALL_RECOMMENDED_SCANS = 2

  class DisruptionScheduleValueValuesEnum(_messages.Enum):
    r"""The disruption schedule for the VM. Default to IMMEDIATE.

    Values:
      DISRUPTION_SCHEDULE_UNSPECIFIED: Not used. Required as per aip/126.
      FUTURE: Delay disruption for caller control. Will be default soon.
      IMMEDIATE: Default value. Disrupt the VM immediately.
    """
    DISRUPTION_SCHEDULE_UNSPECIFIED = 0
    FUTURE = 1
    IMMEDIATE = 2

  actionHint = _messages.EnumField('ActionHintValueValuesEnum', 1)
  disruptionSchedule = _messages.EnumField('DisruptionScheduleValueValuesEnum', 2)
  faultReasons = _messages.MessageField('InstancesReportHostAsFaultyRequestFaultReason', 3, repeated=True)


class InstancesReportHostAsFaultyRequestFaultReason(_messages.Message):
  r"""A InstancesReportHostAsFaultyRequestFaultReason object.

  Enums:
    BehaviorValueValuesEnum:

  Fields:
    behavior: A BehaviorValueValuesEnum attribute.
    description: A string attribute.
  """

  class BehaviorValueValuesEnum(_messages.Enum):
    r"""BehaviorValueValuesEnum enum type.

    Values:
      BEHAVIOR_UNSPECIFIED: Public reportable behaviors
      PERFORMANCE: <no description>
      SILENT_DATA_CORRUPTION: <no description>
      UNRECOVERABLE_GPU_ERROR: <no description>
    """
    BEHAVIOR_UNSPECIFIED = 0
    PERFORMANCE = 1
    SILENT_DATA_CORRUPTION = 2
    UNRECOVERABLE_GPU_ERROR = 3

  behavior = _messages.EnumField('BehaviorValueValuesEnum', 1)
  description = _messages.StringField(2)


class InstancesResumeRequest(_messages.Message):
  r"""A InstancesResumeRequest object.

  Fields:
    disks: Array of disks associated with this instance that are protected
      with a customer-supplied encryption key. In order to resume the
      instance, the disk url and its corresponding key must be provided. If
      the disk is not protected with a customer-supplied encryption key it
      should not be specified.
    instanceEncryptionKey: Decrypts data associated with an instance that is
      protected with a customer-supplied encryption key. If the instance you
      are starting is protected with a customer-supplied encryption key, the
      correct key must be provided otherwise the instance resume will not
      succeed.
  """

  disks = _messages.MessageField('CustomerEncryptionKeyProtectedDisk', 1, repeated=True)
  instanceEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 2)


class InstancesScopedList(_messages.Message):
  r"""A InstancesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of instances when the list is empty.

  Fields:
    instances: [Output Only] A list of instances contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      instances when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    instances when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  instances = _messages.MessageField('Instance', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InstancesSetLabelsRequest(_messages.Message):
  r"""A InstancesSetLabelsRequest object.

  Messages:
    LabelsValue: A LabelsValue object.

  Fields:
    labelFingerprint: Fingerprint of the previous set of labels for this
      resource, used to prevent conflicts. Provide the latest fingerprint
      value when making a request to add or change labels.
    labels: A LabelsValue attribute.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""A LabelsValue object.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class InstancesSetMachineResourcesRequest(_messages.Message):
  r"""A InstancesSetMachineResourcesRequest object.

  Fields:
    guestAccelerators: A list of the type and count of accelerator cards
      attached to the instance.
  """

  guestAccelerators = _messages.MessageField('AcceleratorConfig', 1, repeated=True)


class InstancesSetMachineTypeRequest(_messages.Message):
  r"""A InstancesSetMachineTypeRequest object.

  Fields:
    machineType: Full or partial URL of the machine type resource. See Machine
      Types for a full list of machine types. For example: zones/us-
      central1-f/machineTypes/n1-standard-1
  """

  machineType = _messages.StringField(1)


class InstancesSetMinCpuPlatformRequest(_messages.Message):
  r"""A InstancesSetMinCpuPlatformRequest object.

  Fields:
    minCpuPlatform: Minimum cpu/platform this instance should be started at.
  """

  minCpuPlatform = _messages.StringField(1)


class InstancesSetNameRequest(_messages.Message):
  r"""A InstancesSetNameRequest object.

  Fields:
    currentName: The current name of this resource, used to prevent conflicts.
      Provide the latest name when making a request to change name.
    name: The name to be applied to the instance. Needs to be RFC 1035
      compliant.
  """

  currentName = _messages.StringField(1)
  name = _messages.StringField(2)


class InstancesSetSecurityPolicyRequest(_messages.Message):
  r"""A InstancesSetSecurityPolicyRequest object.

  Fields:
    networkInterfaces: The network interfaces that the security policy will be
      applied to. Network interfaces use the nicN naming format. You can only
      set a security policy for network interfaces with an access config.
    securityPolicy: A full or partial URL to a security policy to add to this
      instance. If this field is set to an empty string it will remove the
      associated security policy.
  """

  networkInterfaces = _messages.StringField(1, repeated=True)
  securityPolicy = _messages.StringField(2)


class InstancesSetServiceAccountRequest(_messages.Message):
  r"""A InstancesSetServiceAccountRequest object.

  Fields:
    email: Email address of the service account.
    scopes: The list of scopes to be made available for this service account.
  """

  email = _messages.StringField(1)
  scopes = _messages.StringField(2, repeated=True)


class InstancesStartWithEncryptionKeyRequest(_messages.Message):
  r"""A InstancesStartWithEncryptionKeyRequest object.

  Fields:
    disks: Array of disks associated with this instance that are protected
      with a customer-supplied encryption key. In order to start the instance,
      the disk url and its corresponding key must be provided. If the disk is
      not protected with a customer-supplied encryption key it should not be
      specified.
    instanceEncryptionKey: Decrypts data associated with an instance that is
      protected with a customer-supplied encryption key. If the instance you
      are starting is protected with a customer-supplied encryption key, the
      correct key must be provided otherwise the instance start will not
      succeed.
  """

  disks = _messages.MessageField('CustomerEncryptionKeyProtectedDisk', 1, repeated=True)
  instanceEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 2)


class InstantSnapshot(_messages.Message):
  r"""Represents a InstantSnapshot resource. You can use instant snapshots to
  create disk rollback points quickly..

  Enums:
    ArchitectureValueValuesEnum: [Output Only] The architecture of the instant
      snapshot. Valid values are ARM64 or X86_64.
    StatusValueValuesEnum: [Output Only] The status of the instantSnapshot.
      This can be CREATING, DELETING, FAILED, or READY.

  Messages:
    LabelsValue: Labels to apply to this InstantSnapshot. These can be later
      modified by the setLabels method. Label values may be empty.

  Fields:
    architecture: [Output Only] The architecture of the instant snapshot.
      Valid values are ARM64 or X86_64.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    diskSizeGb: [Output Only] Size of the source disk, specified in GB.
    guestFlush: Whether to attempt an application consistent instant snapshot
      by informing the OS to prepare for the snapshot process.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#instantSnapshot
      for InstantSnapshot resources.
    labelFingerprint: A fingerprint for the labels being applied to this
      InstantSnapshot, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a InstantSnapshot.
    labels: Labels to apply to this InstantSnapshot. These can be later
      modified by the setLabels method. Label values may be empty.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the instant snapshot
      resides. You must specify this field as part of the HTTP request URL. It
      is not settable as a field in the request body.
    resourceStatus: [Output Only] Status information for the instant snapshot
      resource.
    satisfiesPzi: Output only. Reserved for future use.
    satisfiesPzs: [Output Only] Reserved for future use.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    sourceDisk: URL of the source disk used to create this instant snapshot.
      Note that the source disk must be in the same zone/region as the instant
      snapshot to be created. This can be a full or valid partial URL. For
      example, the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /disks/disk -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /disks/disk - projects/project/zones/zone/disks/disk -
      projects/project/regions/region/disks/disk - zones/zone/disks/disk -
      regions/region/disks/disk
    sourceDiskId: [Output Only] The ID value of the disk used to create this
      InstantSnapshot. This value may be used to determine whether the
      InstantSnapshot was taken from the current or a previous instance of a
      given disk name.
    sourceInstantSnapshotGroup: [Output Only] URL of the source instant
      snapshot this instant snapshot is part of. Note that the source instant
      snapshot group must be in the same zone/region as the instant snapshot
      to be created. This can be a full or valid partial URL.
    sourceInstantSnapshotGroupId: [Output Only] The ID value of the source
      instant snapshot group this InstantSnapshot is part of. This value may
      be used to determine whether the InstantSnapshot was created as part of
      an InstantSnapshotGroup creation.
    status: [Output Only] The status of the instantSnapshot. This can be
      CREATING, DELETING, FAILED, or READY.
    zone: [Output Only] URL of the zone where the instant snapshot resides.
      You must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
  """

  class ArchitectureValueValuesEnum(_messages.Enum):
    r"""[Output Only] The architecture of the instant snapshot. Valid values
    are ARM64 or X86_64.

    Values:
      ARCHITECTURE_UNSPECIFIED: Default value indicating Architecture is not
        set.
      ARM64: Machines with architecture ARM64
      X86_64: Machines with architecture X86_64
    """
    ARCHITECTURE_UNSPECIFIED = 0
    ARM64 = 1
    X86_64 = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the instantSnapshot. This can be CREATING,
    DELETING, FAILED, or READY.

    Values:
      CREATING: InstantSnapshot creation is in progress.
      DELETING: InstantSnapshot is currently being deleted.
      FAILED: InstantSnapshot creation failed.
      READY: InstantSnapshot has been created successfully.
      UNAVAILABLE: InstantSnapshot is currently unavailable and cannot be used
        for Disk restoration
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3
    UNAVAILABLE = 4

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this InstantSnapshot. These can be later modified
    by the setLabels method. Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  architecture = _messages.EnumField('ArchitectureValueValuesEnum', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  diskSizeGb = _messages.IntegerField(4)
  guestFlush = _messages.BooleanField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#instantSnapshot')
  labelFingerprint = _messages.BytesField(8)
  labels = _messages.MessageField('LabelsValue', 9)
  name = _messages.StringField(10)
  region = _messages.StringField(11)
  resourceStatus = _messages.MessageField('InstantSnapshotResourceStatus', 12)
  satisfiesPzi = _messages.BooleanField(13)
  satisfiesPzs = _messages.BooleanField(14)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  sourceDisk = _messages.StringField(17)
  sourceDiskId = _messages.StringField(18)
  sourceInstantSnapshotGroup = _messages.StringField(19)
  sourceInstantSnapshotGroupId = _messages.StringField(20)
  status = _messages.EnumField('StatusValueValuesEnum', 21)
  zone = _messages.StringField(22)


class InstantSnapshotAggregatedList(_messages.Message):
  r"""A InstantSnapshotAggregatedList object.

  Messages:
    ItemsValue: A list of InstantSnapshotsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstantSnapshotsScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#instantSnapshotAggregatedList for aggregated lists of
      instantSnapshots.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of InstantSnapshotsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of instantSnapshots.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InstantSnapshotsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstantSnapshotsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#instantSnapshotAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InstantSnapshotGroup(_messages.Message):
  r"""Represents an InstantSnapshotGroup resource. An instant snapshot group
  is a set of instant snapshots that represents a point in time state of a
  consistency group.

  Enums:
    StatusValueValuesEnum: [Output Only]

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: Optional. An optional description of this resource. Provide
      this property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always
      compute#instantSnapshotGroup for InstantSnapshotGroup resources.
    name: Identifier. Name of the resource; provided by the client when the
      resource is created. The name must be 1-63 characters long, and comply
      with RFC1035. Specifically, the name must be 1-63 characters long and
      match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means
      the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    region: [Output Only] URL of the region where the instant snapshot group
      resides. You must specify this field as part of the HTTP request URL. It
      is not settable as a field in the request body.
    resourceStatus: A InstantSnapshotGroupResourceStatus attribute.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    sourceConsistencyGroup: A string attribute.
    status: [Output Only]
    zone: [Output Only] URL of the zone where the instant snapshot group
      resides. You must specify this field as part of the HTTP request URL. It
      is not settable as a field in the request body.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only]

    Values:
      CREATING: <no description>
      DELETING: <no description>
      FAILED: <no description>
      INVALID: <no description>
      READY: <no description>
      UNKNOWN: <no description>
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    INVALID = 3
    READY = 4
    UNKNOWN = 5

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default='compute#instantSnapshotGroup')
  name = _messages.StringField(5)
  region = _messages.StringField(6)
  resourceStatus = _messages.MessageField('InstantSnapshotGroupResourceStatus', 7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  sourceConsistencyGroup = _messages.StringField(10)
  status = _messages.EnumField('StatusValueValuesEnum', 11)
  zone = _messages.StringField(12)


class InstantSnapshotGroupParameters(_messages.Message):
  r"""A InstantSnapshotGroupParameters object.

  Fields:
    sourceInstantSnapshotGroup: The source instant snapshot group used to
      create disks. You can provide this as a partial or full URL to the
      resource. For example, the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /instantSnapshotGroups/instantSnapshotGroup -
      projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup -
      zones/zone/instantSnapshotGroups/instantSnapshotGroup
  """

  sourceInstantSnapshotGroup = _messages.StringField(1)


class InstantSnapshotGroupResourceStatus(_messages.Message):
  r"""A InstantSnapshotGroupResourceStatus object.

  Fields:
    consistencyMembershipResolutionTime: [Output Only]
    sourceInfo: [Output Only]
  """

  consistencyMembershipResolutionTime = _messages.StringField(1)
  sourceInfo = _messages.MessageField('InstantSnapshotGroupSourceInfo', 2)


class InstantSnapshotGroupSourceInfo(_messages.Message):
  r"""A InstantSnapshotGroupSourceInfo object.

  Fields:
    consistencyGroup: A string attribute.
    consistencyGroupId: A string attribute.
  """

  consistencyGroup = _messages.StringField(1)
  consistencyGroupId = _messages.StringField(2)


class InstantSnapshotList(_messages.Message):
  r"""Contains a list of InstantSnapshot resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstantSnapshot resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstantSnapshot', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#instantSnapshotList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstantSnapshotResourceStatus(_messages.Message):
  r"""A InstantSnapshotResourceStatus object.

  Fields:
    storageSizeBytes: [Output Only] The storage size of this instant snapshot.
  """

  storageSizeBytes = _messages.IntegerField(1)


class InstantSnapshotsScopedList(_messages.Message):
  r"""A InstantSnapshotsScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of instantSnapshots when the list is empty.

  Fields:
    instantSnapshots: [Output Only] A list of instantSnapshots contained in
      this scope.
    warning: [Output Only] Informational warning which replaces the list of
      instantSnapshots when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    instantSnapshots when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  instantSnapshots = _messages.MessageField('InstantSnapshot', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class Int64RangeMatch(_messages.Message):
  r"""HttpRouteRuleMatch criteria for field values that must stay within the
  specified integer range.

  Fields:
    rangeEnd: The end of the range (exclusive) in signed long integer format.
    rangeStart: The start of the range (inclusive) in signed long integer
      format.
  """

  rangeEnd = _messages.IntegerField(1)
  rangeStart = _messages.IntegerField(2)


class Interconnect(_messages.Message):
  r"""Represents an Interconnect resource. An Interconnect resource is a
  dedicated connection between the Google Cloud network and your on-premises
  network. For more information, read the Dedicated Interconnect Overview.

  Enums:
    AvailableFeaturesValueListEntryValuesEnum:
    InterconnectTypeValueValuesEnum: Type of interconnect, which can take one
      of the following values: - PARTNER: A partner-managed interconnection
      shared between customers though a partner. - DEDICATED: A dedicated
      physical interconnection with the customer. Note that a value IT_PRIVATE
      has been deprecated in favor of DEDICATED.
    LinkTypeValueValuesEnum: Type of link requested, which can take one of the
      following values: - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR
      optics - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. -
      LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that
      this field indicates the speed of each of the links in the bundle, not
      the speed of the entire bundle.
    OperationalStatusValueValuesEnum: [Output Only] The current status of this
      Interconnect's functionality, which can take one of the following
      values: - OS_ACTIVE: A valid Interconnect, which is turned up and is
      ready to use. Attachments may be provisioned on this Interconnect. -
      OS_UNPROVISIONED: An Interconnect that has not completed turnup. No
      attachments may be provisioned on this Interconnect. -
      OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal
      maintenance. No attachments may be provisioned or updated on this
      Interconnect.
    RequestedFeaturesValueListEntryValuesEnum:
    StateValueValuesEnum: [Output Only] The current state of Interconnect
      functionality, which can take one of the following values: - ACTIVE: The
      Interconnect is valid, turned up and ready to use. Attachments may be
      provisioned on this Interconnect. - UNPROVISIONED: The Interconnect has
      not completed turnup. No attachments may be provisioned on this
      Interconnect. - UNDER_MAINTENANCE: The Interconnect is undergoing
      internal maintenance. No attachments may be provisioned or updated on
      this Interconnect.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    aaiEnabled: Enable or disable the application awareness feature on this
      Cloud Interconnect.
    adminEnabled: Administrative status of the interconnect. When this is set
      to true, the Interconnect is functional and can carry traffic. When set
      to false, no packets can be carried over the interconnect and no BGP
      routes are exchanged over it. By default, the status is set to true.
    applicationAwareInterconnect: Configuration information for application
      awareness on this Cloud Interconnect.
    availableFeatures: [Output only] List of features available for this
      Interconnect connection, which can take one of the following values: -
      IF_MACSEC If present then the Interconnect connection is provisioned on
      MACsec capable hardware ports. If not present then the Interconnect
      connection is provisioned on non-MACsec capable ports and MACsec isn't
      supported and enabling MACsec fails.
    circuitInfos: [Output Only] A list of CircuitInfo objects, that describe
      the individual circuits in this LAG.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customerName: Customer name, to put in the Letter of Authorization as the
      party authorized to request a crossconnect.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    expectedOutages: [Output Only] A list of outages expected for this
      Interconnect.
    googleIpAddress: [Output Only] IP address configured on the Google side of
      the Interconnect link. This can be used only for ping tests.
    googleReferenceId: [Output Only] Google reference ID to be used when
      raising support tickets with Google or otherwise to debug backend
      connectivity issues.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interconnectAttachments: [Output Only] A list of the URLs of all
      InterconnectAttachments configured to use this Interconnect.
    interconnectGroups: [Output Only] URLs of InterconnectGroups that include
      this Interconnect. Order is arbitrary and items are unique.
    interconnectType: Type of interconnect, which can take one of the
      following values: - PARTNER: A partner-managed interconnection shared
      between customers though a partner. - DEDICATED: A dedicated physical
      interconnection with the customer. Note that a value IT_PRIVATE has been
      deprecated in favor of DEDICATED.
    kind: [Output Only] Type of the resource. Always compute#interconnect for
      interconnects.
    labelFingerprint: A fingerprint for the labels being applied to this
      Interconnect, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve an Interconnect.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    linkType: Type of link requested, which can take one of the following
      values: - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics -
      LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. -
      LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that
      this field indicates the speed of each of the links in the bundle, not
      the speed of the entire bundle.
    location: URL of the InterconnectLocation object that represents where
      this connection is to be provisioned.
    macsec: Configuration that enables Media Access Control security (MACsec)
      on the Cloud Interconnect connection between Google and your on-premises
      router.
    macsecEnabled: Enable or disable MACsec on this Interconnect connection.
      MACsec enablement fails if the MACsec object is not specified.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    nocContactEmail: Email address to contact the customer NOC for operations
      and maintenance notifications regarding this Interconnect. If specified,
      this will be used for notifications in addition to all other forms
      described, such as Cloud Monitoring logs alerting and Cloud
      Notifications. This field is required for users who sign up for Cloud
      Interconnect using workforce identity federation.
    operationalStatus: [Output Only] The current status of this Interconnect's
      functionality, which can take one of the following values: - OS_ACTIVE:
      A valid Interconnect, which is turned up and is ready to use.
      Attachments may be provisioned on this Interconnect. - OS_UNPROVISIONED:
      An Interconnect that has not completed turnup. No attachments may be
      provisioned on this Interconnect. - OS_UNDER_MAINTENANCE: An
      Interconnect that is undergoing internal maintenance. No attachments may
      be provisioned or updated on this Interconnect.
    peerIpAddress: [Output Only] IP address configured on the customer side of
      the Interconnect link. The customer should configure this IP address
      during turnup when prompted by Google NOC. This can be used only for
      ping tests.
    provisionedLinkCount: [Output Only] Number of links actually provisioned
      in this interconnect.
    remoteLocation: Indicates that this is a Cross-Cloud Interconnect. This
      field specifies the location outside of Google's network that the
      interconnect is connected to.
    requestedFeatures: Optional. List of features requested for this
      Interconnect connection, which can take one of the following values: -
      IF_MACSEC If specified then the connection is created on MACsec capable
      hardware ports. If not specified, the default value is false, which
      allocates non-MACsec capable ports first if available. This parameter
      can be provided only with Interconnect INSERT. It isn't valid for
      Interconnect PATCH.
    requestedLinkCount: Target number of physical links in the link bundle, as
      requested by the customer.
    satisfiesPzs: [Output Only] Reserved for future use.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    state: [Output Only] The current state of Interconnect functionality,
      which can take one of the following values: - ACTIVE: The Interconnect
      is valid, turned up and ready to use. Attachments may be provisioned on
      this Interconnect. - UNPROVISIONED: The Interconnect has not completed
      turnup. No attachments may be provisioned on this Interconnect. -
      UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance.
      No attachments may be provisioned or updated on this Interconnect.
    wireGroups: [Output Only] A list of the URLs of all CrossSiteNetwork
      WireGroups configured to use this Interconnect. The Interconnect cannot
      be deleted if this list is non-empty.
  """

  class AvailableFeaturesValueListEntryValuesEnum(_messages.Enum):
    r"""AvailableFeaturesValueListEntryValuesEnum enum type.

    Values:
      IF_CROSS_SITE_NETWORK: Cross-Site Networking
      IF_MACSEC: Media Access Control security (MACsec)
    """
    IF_CROSS_SITE_NETWORK = 0
    IF_MACSEC = 1

  class InterconnectTypeValueValuesEnum(_messages.Enum):
    r"""Type of interconnect, which can take one of the following values: -
    PARTNER: A partner-managed interconnection shared between customers though
    a partner. - DEDICATED: A dedicated physical interconnection with the
    customer. Note that a value IT_PRIVATE has been deprecated in favor of
    DEDICATED.

    Values:
      DEDICATED: A dedicated physical interconnection with the customer.
      IT_PRIVATE: [Deprecated] A private, physical interconnection with the
        customer.
      PARTNER: A partner-managed interconnection shared between customers via
        partner.
    """
    DEDICATED = 0
    IT_PRIVATE = 1
    PARTNER = 2

  class LinkTypeValueValuesEnum(_messages.Enum):
    r"""Type of link requested, which can take one of the following values: -
    LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics -
    LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. -
    LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that
    this field indicates the speed of each of the links in the bundle, not the
    speed of the entire bundle.

    Values:
      LINK_TYPE_ETHERNET_100G_LR: 100G Ethernet, LR Optics.
      LINK_TYPE_ETHERNET_10G_LR: 10G Ethernet, LR Optics. [(rate_bps) =
        10000000000];
      LINK_TYPE_ETHERNET_400G_LR4: 400G Ethernet, LR4 Optics.
    """
    LINK_TYPE_ETHERNET_100G_LR = 0
    LINK_TYPE_ETHERNET_10G_LR = 1
    LINK_TYPE_ETHERNET_400G_LR4 = 2

  class OperationalStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current status of this Interconnect's functionality,
    which can take one of the following values: - OS_ACTIVE: A valid
    Interconnect, which is turned up and is ready to use. Attachments may be
    provisioned on this Interconnect. - OS_UNPROVISIONED: An Interconnect that
    has not completed turnup. No attachments may be provisioned on this
    Interconnect. - OS_UNDER_MAINTENANCE: An Interconnect that is undergoing
    internal maintenance. No attachments may be provisioned or updated on this
    Interconnect.

    Values:
      OS_ACTIVE: The interconnect is valid, turned up, and ready to use.
        Attachments may be provisioned on this interconnect.
      OS_UNPROVISIONED: The interconnect has not completed turnup. No
        attachments may be provisioned on this interconnect.
    """
    OS_ACTIVE = 0
    OS_UNPROVISIONED = 1

  class RequestedFeaturesValueListEntryValuesEnum(_messages.Enum):
    r"""RequestedFeaturesValueListEntryValuesEnum enum type.

    Values:
      IF_CROSS_SITE_NETWORK: Cross-Site Networking
      IF_MACSEC: Media Access Control security (MACsec)
    """
    IF_CROSS_SITE_NETWORK = 0
    IF_MACSEC = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current state of Interconnect functionality, which
    can take one of the following values: - ACTIVE: The Interconnect is valid,
    turned up and ready to use. Attachments may be provisioned on this
    Interconnect. - UNPROVISIONED: The Interconnect has not completed turnup.
    No attachments may be provisioned on this Interconnect. -
    UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance. No
    attachments may be provisioned or updated on this Interconnect.

    Values:
      ACTIVE: The interconnect is valid, turned up, and ready to use.
        Attachments may be provisioned on this interconnect.
      UNPROVISIONED: The interconnect has not completed turnup. No attachments
        may be provisioned on this interconnect.
    """
    ACTIVE = 0
    UNPROVISIONED = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  aaiEnabled = _messages.BooleanField(1)
  adminEnabled = _messages.BooleanField(2)
  applicationAwareInterconnect = _messages.MessageField('InterconnectApplicationAwareInterconnect', 3)
  availableFeatures = _messages.EnumField('AvailableFeaturesValueListEntryValuesEnum', 4, repeated=True)
  circuitInfos = _messages.MessageField('InterconnectCircuitInfo', 5, repeated=True)
  creationTimestamp = _messages.StringField(6)
  customerName = _messages.StringField(7)
  description = _messages.StringField(8)
  expectedOutages = _messages.MessageField('InterconnectOutageNotification', 9, repeated=True)
  googleIpAddress = _messages.StringField(10)
  googleReferenceId = _messages.StringField(11)
  id = _messages.IntegerField(12, variant=_messages.Variant.UINT64)
  interconnectAttachments = _messages.StringField(13, repeated=True)
  interconnectGroups = _messages.StringField(14, repeated=True)
  interconnectType = _messages.EnumField('InterconnectTypeValueValuesEnum', 15)
  kind = _messages.StringField(16, default='compute#interconnect')
  labelFingerprint = _messages.BytesField(17)
  labels = _messages.MessageField('LabelsValue', 18)
  linkType = _messages.EnumField('LinkTypeValueValuesEnum', 19)
  location = _messages.StringField(20)
  macsec = _messages.MessageField('InterconnectMacsec', 21)
  macsecEnabled = _messages.BooleanField(22)
  name = _messages.StringField(23)
  nocContactEmail = _messages.StringField(24)
  operationalStatus = _messages.EnumField('OperationalStatusValueValuesEnum', 25)
  peerIpAddress = _messages.StringField(26)
  provisionedLinkCount = _messages.IntegerField(27, variant=_messages.Variant.INT32)
  remoteLocation = _messages.StringField(28)
  requestedFeatures = _messages.EnumField('RequestedFeaturesValueListEntryValuesEnum', 29, repeated=True)
  requestedLinkCount = _messages.IntegerField(30, variant=_messages.Variant.INT32)
  satisfiesPzs = _messages.BooleanField(31)
  selfLink = _messages.StringField(32)
  selfLinkWithId = _messages.StringField(33)
  state = _messages.EnumField('StateValueValuesEnum', 34)
  wireGroups = _messages.StringField(35, repeated=True)


class InterconnectApplicationAwareInterconnect(_messages.Message):
  r"""Configuration information for application awareness on this Cloud
  Interconnect.

  Fields:
    bandwidthPercentagePolicy: A
      InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy
      attribute.
    profileDescription: Description for the application awareness profile on
      this Cloud Interconnect.
    shapeAveragePercentages: Optional field to specify a list of shape average
      percentages to be applied in conjunction with StrictPriorityPolicy or
      BandwidthPercentagePolicy.
    strictPriorityPolicy: A
      InterconnectApplicationAwareInterconnectStrictPriorityPolicy attribute.
  """

  bandwidthPercentagePolicy = _messages.MessageField('InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy', 1)
  profileDescription = _messages.StringField(2)
  shapeAveragePercentages = _messages.MessageField('InterconnectApplicationAwareInterconnectBandwidthPercentage', 3, repeated=True)
  strictPriorityPolicy = _messages.MessageField('InterconnectApplicationAwareInterconnectStrictPriorityPolicy', 4)


class InterconnectApplicationAwareInterconnectBandwidthPercentage(_messages.Message):
  r"""Specify bandwidth percentages [1-100] for various traffic classes in
  BandwidthPercentagePolicy. The sum of all percentages must equal 100. All
  traffic classes must have a percentage value specified.

  Enums:
    TrafficClassValueValuesEnum: TrafficClass whose bandwidth percentage is
      being specified.

  Fields:
    percentage: Bandwidth percentage for a specific traffic class.
    trafficClass: TrafficClass whose bandwidth percentage is being specified.
  """

  class TrafficClassValueValuesEnum(_messages.Enum):
    r"""TrafficClass whose bandwidth percentage is being specified.

    Values:
      TC1: Traffic Class 1, corresponding to DSCP ranges (0-7) 000xxx.
      TC2: Traffic Class 2, corresponding to DSCP ranges (8-15) 001xxx.
      TC3: Traffic Class 3, corresponding to DSCP ranges (16-23) 010xxx.
      TC4: Traffic Class 4, corresponding to DSCP ranges (24-31) 011xxx.
      TC5: Traffic Class 5, corresponding to DSCP ranges (32-47) 10xxxx.
      TC6: Traffic Class 6, corresponding to DSCP ranges (48-63) 11xxxx.
    """
    TC1 = 0
    TC2 = 1
    TC3 = 2
    TC4 = 3
    TC5 = 4
    TC6 = 5

  percentage = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  trafficClass = _messages.EnumField('TrafficClassValueValuesEnum', 2)


class InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy(_messages.Message):
  r"""A InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy
  object.

  Fields:
    bandwidthPercentages: Specify bandwidth percentages for various traffic
      classes for queuing type Bandwidth Percent.
  """

  bandwidthPercentages = _messages.MessageField('InterconnectApplicationAwareInterconnectBandwidthPercentage', 1, repeated=True)


class InterconnectApplicationAwareInterconnectStrictPriorityPolicy(_messages.Message):
  r"""Specify configuration for StrictPriorityPolicy."""


class InterconnectAttachment(_messages.Message):
  r"""Represents an Interconnect Attachment (VLAN) resource. You can use
  Interconnect attachments (VLANS) to connect your Virtual Private Cloud
  networks to your on-premises networks through an Interconnect. For more
  information, read Creating VLAN Attachments.

  Enums:
    BandwidthValueValuesEnum: Provisioned bandwidth capacity for the
      interconnect attachment. For attachments of type DEDICATED, the user can
      set the bandwidth. For attachments of type PARTNER, the Google Partner
      that is operating the interconnect must set the bandwidth. Output only
      for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can
      take one of the following values: - BPS_50M: 50 Mbit/s - BPS_100M: 100
      Mbit/s - BPS_200M: 200 Mbit/s - BPS_300M: 300 Mbit/s - BPS_400M: 400
      Mbit/s - BPS_500M: 500 Mbit/s - BPS_1G: 1 Gbit/s - BPS_2G: 2 Gbit/s -
      BPS_5G: 5 Gbit/s - BPS_10G: 10 Gbit/s - BPS_20G: 20 Gbit/s - BPS_50G: 50
      Gbit/s - BPS_100G: 100 Gbit/s
    EdgeAvailabilityDomainValueValuesEnum: Input only. Desired availability
      domain for the attachment. Only available for type PARTNER, at creation
      time, and can take one of the following values: -
      AVAILABILITY_DOMAIN_ANY - AVAILABILITY_DOMAIN_1 - AVAILABILITY_DOMAIN_2
      For improved reliability, customers should configure a pair of
      attachments, one per availability domain. The selected availability
      domain will be provided to the Partner via the pairing key, so that the
      provisioned circuit will lie in the specified domain. If not specified,
      the value will default to AVAILABILITY_DOMAIN_ANY.
    EncryptionValueValuesEnum: Indicates the user-supplied encryption option
      of this VLAN attachment (interconnectAttachment). Can only be specified
      at attachment creation for PARTNER or DEDICATED attachments. Possible
      values are: - NONE - This is the default value, which means that the
      VLAN attachment carries unencrypted traffic. VMs are able to send
      traffic to, or receive traffic from, such a VLAN attachment. - IPSEC -
      The VLAN attachment carries only encrypted traffic that is encrypted by
      an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs
      cannot directly send traffic to, or receive traffic from, such a VLAN
      attachment. To use *HA VPN over Cloud Interconnect*, the VLAN attachment
      must be created with this option.
    OperationalStatusValueValuesEnum: [Output Only] The current status of
      whether or not this interconnect attachment is functional, which can
      take one of the following values: - OS_ACTIVE: The attachment has been
      turned up and is ready to use. - OS_UNPROVISIONED: The attachment is not
      ready to use yet, because turnup is not complete.
    StackTypeValueValuesEnum: The stack type for this interconnect attachment
      to identify whether the IPv6 feature is enabled or not. If not
      specified, IPV4_ONLY will be used. This field can be both set at
      interconnect attachments creation and update interconnect attachment
      operations.
    StateValueValuesEnum: [Output Only] The current state of this attachment's
      functionality. Enum values ACTIVE and UNPROVISIONED are shared by
      DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect
      attachments, while enum values PENDING_PARTNER,
      PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER
      and PARTNER_PROVIDER interconnect attachments. This state can take one
      of the following values: - ACTIVE: The attachment has been turned up and
      is ready to use. - UNPROVISIONED: The attachment is not ready to use
      yet, because turnup is not complete. - PENDING_PARTNER: A newly-created
      PARTNER attachment that has not yet been configured on the Partner side.
      - PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of
      provisioning after a PARTNER_PROVIDER attachment was created that
      references it. - PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER
      attachment that is waiting for a customer to activate it. - DEFUNCT: The
      attachment was deleted externally and is no longer functional. This
      could be because the associated Interconnect was removed, or because the
      other side of a Partner attachment was deleted.
    TypeValueValuesEnum: The type of interconnect attachment this is, which
      can take one of the following values: - DEDICATED: an attachment to a
      Dedicated Interconnect. - PARTNER: an attachment to a Partner
      Interconnect, created by the customer. - PARTNER_PROVIDER: an attachment
      to a Partner Interconnect, created by the partner.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    adminEnabled: Determines whether this Attachment will carry packets. Not
      present for PARTNER_PROVIDER.
    attachmentGroup: [Output Only] URL of the AttachmentGroup that includes
      this Attachment.
    bandwidth: Provisioned bandwidth capacity for the interconnect attachment.
      For attachments of type DEDICATED, the user can set the bandwidth. For
      attachments of type PARTNER, the Google Partner that is operating the
      interconnect must set the bandwidth. Output only for PARTNER type,
      mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the
      following values: - BPS_50M: 50 Mbit/s - BPS_100M: 100 Mbit/s -
      BPS_200M: 200 Mbit/s - BPS_300M: 300 Mbit/s - BPS_400M: 400 Mbit/s -
      BPS_500M: 500 Mbit/s - BPS_1G: 1 Gbit/s - BPS_2G: 2 Gbit/s - BPS_5G: 5
      Gbit/s - BPS_10G: 10 Gbit/s - BPS_20G: 20 Gbit/s - BPS_50G: 50 Gbit/s -
      BPS_100G: 100 Gbit/s
    candidateCloudRouterIpAddress: Single IPv4 address + prefix length to be
      configured on the cloud router interface for this interconnect
      attachment. - Both candidate_cloud_router_ip_address and
      candidate_customer_router_ip_address fields must be set or both must be
      unset. - Prefix length of both candidate_cloud_router_ip_address and
      candidate_customer_router_ip_address must be the same. - Max prefix
      length is 31.
    candidateCloudRouterIpv6Address: Single IPv6 address + prefix length to be
      configured on the cloud router interface for this interconnect
      attachment. - Both candidate_cloud_router_ipv6_address and
      candidate_customer_router_ipv6_address fields must be set or both must
      be unset. - Prefix length of both candidate_cloud_router_ipv6_address
      and candidate_customer_router_ipv6_address must be the same. - Max
      prefix length is 126.
    candidateCustomerRouterIpAddress: Single IPv4 address + prefix length to
      be configured on the customer router interface for this interconnect
      attachment.
    candidateCustomerRouterIpv6Address: Single IPv6 address + prefix length to
      be configured on the customer router interface for this interconnect
      attachment.
    candidateIpv6Subnets: This field is not available.
    candidateSubnets: Input only. Up to 16 candidate prefixes that can be used
      to restrict the allocation of cloudRouterIpAddress and
      customerRouterIpAddress for this attachment. All prefixes must be within
      link-local address space (169.254.0.0/16) and must be /29 or shorter
      (/28, /27, etc). Google will attempt to select an unused /29 from the
      supplied candidate prefix(es). The request will fail if all possible
      /29s are in use on Google's edge. If not supplied, Google will randomly
      select an unused /29 from all of link-local space.
    cloudRouterIpAddress: [Output Only] IPv4 address + prefix length to be
      configured on Cloud Router Interface for this interconnect attachment.
    cloudRouterIpv6Address: [Output Only] IPv6 address + prefix length to be
      configured on Cloud Router Interface for this interconnect attachment.
    cloudRouterIpv6InterfaceId: This field is not available.
    configurationConstraints: [Output Only] Constraints for this attachment,
      if any. The attachment does not work if these constraints are not met.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customerRouterIpAddress: [Output Only] IPv4 address + prefix length to be
      configured on the customer router subinterface for this interconnect
      attachment.
    customerRouterIpv6Address: [Output Only] IPv6 address + prefix length to
      be configured on the customer router subinterface for this interconnect
      attachment.
    customerRouterIpv6InterfaceId: This field is not available.
    dataplaneVersion: [Output Only] Dataplane version for this
      InterconnectAttachment. This field is only present for Dataplane version
      2 and higher. Absence of this field in the API output indicates that the
      Dataplane is version 1.
    description: An optional description of this resource.
    edgeAvailabilityDomain: Input only. Desired availability domain for the
      attachment. Only available for type PARTNER, at creation time, and can
      take one of the following values: - AVAILABILITY_DOMAIN_ANY -
      AVAILABILITY_DOMAIN_1 - AVAILABILITY_DOMAIN_2 For improved reliability,
      customers should configure a pair of attachments, one per availability
      domain. The selected availability domain will be provided to the Partner
      via the pairing key, so that the provisioned circuit will lie in the
      specified domain. If not specified, the value will default to
      AVAILABILITY_DOMAIN_ANY.
    encryption: Indicates the user-supplied encryption option of this VLAN
      attachment (interconnectAttachment). Can only be specified at attachment
      creation for PARTNER or DEDICATED attachments. Possible values are: -
      NONE - This is the default value, which means that the VLAN attachment
      carries unencrypted traffic. VMs are able to send traffic to, or receive
      traffic from, such a VLAN attachment. - IPSEC - The VLAN attachment
      carries only encrypted traffic that is encrypted by an IPsec device,
      such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly
      send traffic to, or receive traffic from, such a VLAN attachment. To use
      *HA VPN over Cloud Interconnect*, the VLAN attachment must be created
      with this option.
    googleReferenceId: [Output Only] Google reference ID, to be used when
      raising support tickets with Google or otherwise to debug backend
      connectivity issues. [Deprecated] This field is not used.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interconnect: URL of the underlying Interconnect object that this
      attachment's traffic will traverse through.
    ipsecInternalAddresses: A list of URLs of addresses that have been
      reserved for the VLAN attachment. Used only for the VLAN attachment that
      has the encryption option as IPSEC. The addresses must be regional
      internal IP address ranges. When creating an HA VPN gateway over the
      VLAN attachment, if the attachment is configured to use a regional
      internal IP address, then the VPN gateway's IP address is allocated from
      the IP address range specified here. For example, if the HA VPN
      gateway's interface 0 is paired to this VLAN attachment, then a regional
      internal IP address for the VPN gateway interface 0 will be allocated
      from the IP address specified for this VLAN attachment. If this field is
      not specified when creating the VLAN attachment, then later on when
      creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's
      IP address is allocated from the regional external IP address pool.
    kind: [Output Only] Type of the resource. Always
      compute#interconnectAttachment for interconnect attachments.
    l2Forwarding: L2 Interconnect Attachment related config. This field is
      required if the type is L2_DEDICATED. The configuration specifies how
      VLAN tags (like dot1q, qinq, or dot1ad) within L2 packets are mapped to
      the destination appliances IP addresses. The packet is then encapsulated
      with the appliance IP address and sent to the edge appliance.
    labelFingerprint: A fingerprint for the labels being applied to this
      InterconnectAttachment, which is essentially a hash of the labels set
      used for optimistic locking. The fingerprint is initially generated by
      Compute Engine and changes after every request to modify or update
      labels. You must always provide an up-to-date fingerprint hash in order
      to update or change labels, otherwise the request will fail with error
      412 conditionNotMet. To see the latest fingerprint, make a get() request
      to retrieve an InterconnectAttachment.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    mtu: Maximum Transmission Unit (MTU), in bytes, of packets passing through
      this interconnect attachment. Only 1440 and 1500 are allowed. If not
      specified, the value will default to 1440.
    multicastEnabled: Whether or not to permit multicast traffic for this
      attachment. Multicast packets will be dropped if this is not enabled.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    operationalStatus: [Output Only] The current status of whether or not this
      interconnect attachment is functional, which can take one of the
      following values: - OS_ACTIVE: The attachment has been turned up and is
      ready to use. - OS_UNPROVISIONED: The attachment is not ready to use
      yet, because turnup is not complete.
    pairingKey: [Output only for type PARTNER. Input only for
      PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of a
      PARTNER attachment used to initiate provisioning with a selected
      partner. Of the form "XXXXX/region/domain"
    partnerAsn: Optional BGP ASN for the router supplied by a Layer 3 Partner
      if they configured BGP on behalf of the customer. Output only for
      PARTNER type, input only for PARTNER_PROVIDER, not available for
      DEDICATED.
    partnerMetadata: Informational metadata about Partner attachments from
      Partners to display to customers. Output only for PARTNER type, mutable
      for PARTNER_PROVIDER, not available for DEDICATED.
    privateInterconnectInfo: [Output Only] Information specific to an
      InterconnectAttachment. This property is populated if the interconnect
      that this is attached to is of type DEDICATED.
    region: [Output Only] URL of the region where the regional interconnect
      attachment resides. You must specify this field as part of the HTTP
      request URL. It is not settable as a field in the request body.
    remoteService: [Output Only] If the attachment is on a Cross-Cloud
      Interconnect connection, this field contains the interconnect's remote
      location service provider. Example values: "Amazon Web Services"
      "Microsoft Azure". The field is set only for attachments on Cross-Cloud
      Interconnect connections. Its value is copied from the
      InterconnectRemoteLocation remoteService field.
    router: URL of the Cloud Router to be used for dynamic routing. This
      router must be in the same region as this InterconnectAttachment. The
      InterconnectAttachment will automatically connect the Interconnect to
      the network & region within which the Cloud Router is configured.
    satisfiesPzs: [Output Only] Reserved for future use.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    stackType: The stack type for this interconnect attachment to identify
      whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY
      will be used. This field can be both set at interconnect attachments
      creation and update interconnect attachment operations.
    state: [Output Only] The current state of this attachment's functionality.
      Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE,
      PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum
      values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER
      are used for only PARTNER and PARTNER_PROVIDER interconnect attachments.
      This state can take one of the following values: - ACTIVE: The
      attachment has been turned up and is ready to use. - UNPROVISIONED: The
      attachment is not ready to use yet, because turnup is not complete. -
      PENDING_PARTNER: A newly-created PARTNER attachment that has not yet
      been configured on the Partner side. - PARTNER_REQUEST_RECEIVED: A
      PARTNER attachment is in the process of provisioning after a
      PARTNER_PROVIDER attachment was created that references it. -
      PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is
      waiting for a customer to activate it. - DEFUNCT: The attachment was
      deleted externally and is no longer functional. This could be because
      the associated Interconnect was removed, or because the other side of a
      Partner attachment was deleted.
    subnetLength: Input only. Length of the IPv4 subnet mask. Allowed values:
      - 29 (default) - 30 The default value is 29, except for Cross-Cloud
      Interconnect connections that use an InterconnectRemoteLocation with a
      constraints.subnetLengthRange.min equal to 30. For example, connections
      that use an Azure remote location fall into this category. In these
      cases, the default value is 30, and requesting 29 returns an error.
      Where both 29 and 30 are allowed, 29 is preferred, because it gives
      Google Cloud Support more debugging visibility.
    type: The type of interconnect attachment this is, which can take one of
      the following values: - DEDICATED: an attachment to a Dedicated
      Interconnect. - PARTNER: an attachment to a Partner Interconnect,
      created by the customer. - PARTNER_PROVIDER: an attachment to a Partner
      Interconnect, created by the partner.
    vlanTag8021q: The IEEE 802.1Q VLAN tag for this attachment, in the range
      2-4093. Only specified at creation time.
  """

  class BandwidthValueValuesEnum(_messages.Enum):
    r"""Provisioned bandwidth capacity for the interconnect attachment. For
    attachments of type DEDICATED, the user can set the bandwidth. For
    attachments of type PARTNER, the Google Partner that is operating the
    interconnect must set the bandwidth. Output only for PARTNER type, mutable
    for PARTNER_PROVIDER and DEDICATED, and can take one of the following
    values: - BPS_50M: 50 Mbit/s - BPS_100M: 100 Mbit/s - BPS_200M: 200 Mbit/s
    - BPS_300M: 300 Mbit/s - BPS_400M: 400 Mbit/s - BPS_500M: 500 Mbit/s -
    BPS_1G: 1 Gbit/s - BPS_2G: 2 Gbit/s - BPS_5G: 5 Gbit/s - BPS_10G: 10
    Gbit/s - BPS_20G: 20 Gbit/s - BPS_50G: 50 Gbit/s - BPS_100G: 100 Gbit/s

    Values:
      BPS_100G: 100 Gbit/s
      BPS_100M: 100 Mbit/s
      BPS_10G: 10 Gbit/s
      BPS_1G: 1 Gbit/s
      BPS_200M: 200 Mbit/s
      BPS_20G: 20 Gbit/s
      BPS_2G: 2 Gbit/s
      BPS_300M: 300 Mbit/s
      BPS_400M: 400 Mbit/s
      BPS_500M: 500 Mbit/s
      BPS_50G: 50 Gbit/s
      BPS_50M: 50 Mbit/s
      BPS_5G: 5 Gbit/s
    """
    BPS_100G = 0
    BPS_100M = 1
    BPS_10G = 2
    BPS_1G = 3
    BPS_200M = 4
    BPS_20G = 5
    BPS_2G = 6
    BPS_300M = 7
    BPS_400M = 8
    BPS_500M = 9
    BPS_50G = 10
    BPS_50M = 11
    BPS_5G = 12

  class EdgeAvailabilityDomainValueValuesEnum(_messages.Enum):
    r"""Input only. Desired availability domain for the attachment. Only
    available for type PARTNER, at creation time, and can take one of the
    following values: - AVAILABILITY_DOMAIN_ANY - AVAILABILITY_DOMAIN_1 -
    AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure
    a pair of attachments, one per availability domain. The selected
    availability domain will be provided to the Partner via the pairing key,
    so that the provisioned circuit will lie in the specified domain. If not
    specified, the value will default to AVAILABILITY_DOMAIN_ANY.

    Values:
      AVAILABILITY_DOMAIN_1: <no description>
      AVAILABILITY_DOMAIN_2: <no description>
      AVAILABILITY_DOMAIN_ANY: <no description>
    """
    AVAILABILITY_DOMAIN_1 = 0
    AVAILABILITY_DOMAIN_2 = 1
    AVAILABILITY_DOMAIN_ANY = 2

  class EncryptionValueValuesEnum(_messages.Enum):
    r"""Indicates the user-supplied encryption option of this VLAN attachment
    (interconnectAttachment). Can only be specified at attachment creation for
    PARTNER or DEDICATED attachments. Possible values are: - NONE - This is
    the default value, which means that the VLAN attachment carries
    unencrypted traffic. VMs are able to send traffic to, or receive traffic
    from, such a VLAN attachment. - IPSEC - The VLAN attachment carries only
    encrypted traffic that is encrypted by an IPsec device, such as an HA VPN
    gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or
    receive traffic from, such a VLAN attachment. To use *HA VPN over Cloud
    Interconnect*, the VLAN attachment must be created with this option.

    Values:
      IPSEC: The interconnect attachment will carry only encrypted traffic
        that is encrypted by an IPsec device such as HA VPN gateway; VMs
        cannot directly send traffic to or receive traffic from such an
        interconnect attachment. To use HA VPN over Cloud Interconnect, the
        interconnect attachment must be created with this option.
      NONE: This is the default value, which means the Interconnect Attachment
        will carry unencrypted traffic. VMs will be able to send traffic to or
        receive traffic from such interconnect attachment.
    """
    IPSEC = 0
    NONE = 1

  class OperationalStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current status of whether or not this interconnect
    attachment is functional, which can take one of the following values: -
    OS_ACTIVE: The attachment has been turned up and is ready to use. -
    OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup
    is not complete.

    Values:
      OS_ACTIVE: Indicates that attachment has been turned up and is ready to
        use.
      OS_UNPROVISIONED: Indicates that attachment is not ready to use yet,
        because turnup is not complete.
    """
    OS_ACTIVE = 0
    OS_UNPROVISIONED = 1

  class StackTypeValueValuesEnum(_messages.Enum):
    r"""The stack type for this interconnect attachment to identify whether
    the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be
    used. This field can be both set at interconnect attachments creation and
    update interconnect attachment operations.

    Values:
      IPV4_IPV6: The interconnect attachment can have both IPv4 and IPv6
        addresses.
      IPV4_ONLY: The interconnect attachment will only be assigned IPv4
        addresses.
    """
    IPV4_IPV6 = 0
    IPV4_ONLY = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current state of this attachment's functionality.
    Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE,
    PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values
    PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used
    for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state
    can take one of the following values: - ACTIVE: The attachment has been
    turned up and is ready to use. - UNPROVISIONED: The attachment is not
    ready to use yet, because turnup is not complete. - PENDING_PARTNER: A
    newly-created PARTNER attachment that has not yet been configured on the
    Partner side. - PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the
    process of provisioning after a PARTNER_PROVIDER attachment was created
    that references it. - PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER
    attachment that is waiting for a customer to activate it. - DEFUNCT: The
    attachment was deleted externally and is no longer functional. This could
    be because the associated Interconnect was removed, or because the other
    side of a Partner attachment was deleted.

    Values:
      ACTIVE: Indicates that attachment has been turned up and is ready to
        use.
      DEFUNCT: The attachment was deleted externally and is no longer
        functional. This could be because the associated Interconnect was
        wiped out, or because the other side of a Partner attachment was
        deleted.
      PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of
        provisioning after a PARTNER_PROVIDER attachment was created that
        references it.
      PENDING_CUSTOMER: PARTNER or PARTNER_PROVIDER attachment that is waiting
        for the customer to activate.
      PENDING_PARTNER: A newly created PARTNER attachment that has not yet
        been configured on the Partner side.
      STATE_UNSPECIFIED: <no description>
      UNPROVISIONED: Indicates that attachment is not ready to use yet,
        because turnup is not complete.
    """
    ACTIVE = 0
    DEFUNCT = 1
    PARTNER_REQUEST_RECEIVED = 2
    PENDING_CUSTOMER = 3
    PENDING_PARTNER = 4
    STATE_UNSPECIFIED = 5
    UNPROVISIONED = 6

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of interconnect attachment this is, which can take one of the
    following values: - DEDICATED: an attachment to a Dedicated Interconnect.
    - PARTNER: an attachment to a Partner Interconnect, created by the
    customer. - PARTNER_PROVIDER: an attachment to a Partner Interconnect,
    created by the partner.

    Values:
      DEDICATED: Attachment to a dedicated interconnect.
      L2_DEDICATED: Attachment to a L2 interconnect, created by the customer.
      PARTNER: Attachment to a partner interconnect, created by the customer.
      PARTNER_PROVIDER: Attachment to a partner interconnect, created by the
        partner.
    """
    DEDICATED = 0
    L2_DEDICATED = 1
    PARTNER = 2
    PARTNER_PROVIDER = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  adminEnabled = _messages.BooleanField(1)
  attachmentGroup = _messages.StringField(2)
  bandwidth = _messages.EnumField('BandwidthValueValuesEnum', 3)
  candidateCloudRouterIpAddress = _messages.StringField(4)
  candidateCloudRouterIpv6Address = _messages.StringField(5)
  candidateCustomerRouterIpAddress = _messages.StringField(6)
  candidateCustomerRouterIpv6Address = _messages.StringField(7)
  candidateIpv6Subnets = _messages.StringField(8, repeated=True)
  candidateSubnets = _messages.StringField(9, repeated=True)
  cloudRouterIpAddress = _messages.StringField(10)
  cloudRouterIpv6Address = _messages.StringField(11)
  cloudRouterIpv6InterfaceId = _messages.StringField(12)
  configurationConstraints = _messages.MessageField('InterconnectAttachmentConfigurationConstraints', 13)
  creationTimestamp = _messages.StringField(14)
  customerRouterIpAddress = _messages.StringField(15)
  customerRouterIpv6Address = _messages.StringField(16)
  customerRouterIpv6InterfaceId = _messages.StringField(17)
  dataplaneVersion = _messages.IntegerField(18, variant=_messages.Variant.INT32)
  description = _messages.StringField(19)
  edgeAvailabilityDomain = _messages.EnumField('EdgeAvailabilityDomainValueValuesEnum', 20)
  encryption = _messages.EnumField('EncryptionValueValuesEnum', 21)
  googleReferenceId = _messages.StringField(22)
  id = _messages.IntegerField(23, variant=_messages.Variant.UINT64)
  interconnect = _messages.StringField(24)
  ipsecInternalAddresses = _messages.StringField(25, repeated=True)
  kind = _messages.StringField(26, default='compute#interconnectAttachment')
  l2Forwarding = _messages.MessageField('InterconnectAttachmentL2Forwarding', 27)
  labelFingerprint = _messages.BytesField(28)
  labels = _messages.MessageField('LabelsValue', 29)
  mtu = _messages.IntegerField(30, variant=_messages.Variant.INT32)
  multicastEnabled = _messages.BooleanField(31)
  name = _messages.StringField(32)
  operationalStatus = _messages.EnumField('OperationalStatusValueValuesEnum', 33)
  pairingKey = _messages.StringField(34)
  partnerAsn = _messages.IntegerField(35)
  partnerMetadata = _messages.MessageField('InterconnectAttachmentPartnerMetadata', 36)
  privateInterconnectInfo = _messages.MessageField('InterconnectAttachmentPrivateInfo', 37)
  region = _messages.StringField(38)
  remoteService = _messages.StringField(39)
  router = _messages.StringField(40)
  satisfiesPzs = _messages.BooleanField(41)
  selfLink = _messages.StringField(42)
  selfLinkWithId = _messages.StringField(43)
  stackType = _messages.EnumField('StackTypeValueValuesEnum', 44)
  state = _messages.EnumField('StateValueValuesEnum', 45)
  subnetLength = _messages.IntegerField(46, variant=_messages.Variant.INT32)
  type = _messages.EnumField('TypeValueValuesEnum', 47)
  vlanTag8021q = _messages.IntegerField(48, variant=_messages.Variant.INT32)


class InterconnectAttachmentAggregatedList(_messages.Message):
  r"""A InterconnectAttachmentAggregatedList object.

  Messages:
    ItemsValue: A list of InterconnectAttachmentsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectAttachmentsScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#interconnectAttachmentAggregatedList for aggregated lists of
      interconnect attachments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of InterconnectAttachmentsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        interconnect attachments.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InterconnectAttachmentsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InterconnectAttachmentsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#interconnectAttachmentAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InterconnectAttachmentConfigurationConstraints(_messages.Message):
  r"""A InterconnectAttachmentConfigurationConstraints object.

  Enums:
    BgpMd5ValueValuesEnum: [Output Only] Whether the attachment's BGP session
      requires/allows/disallows BGP MD5 authentication. This can take one of
      the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED. For
      example, a Cross-Cloud Interconnect connection to a remote cloud
      provider that requires BGP MD5 authentication has the
      interconnectRemoteLocation attachment_configuration_constraints.bgp_md5
      field set to MD5_REQUIRED, and that property is propagated to the
      attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is
      returned if MD5 is requested.

  Fields:
    bgpMd5: [Output Only] Whether the attachment's BGP session
      requires/allows/disallows BGP MD5 authentication. This can take one of
      the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED. For
      example, a Cross-Cloud Interconnect connection to a remote cloud
      provider that requires BGP MD5 authentication has the
      interconnectRemoteLocation attachment_configuration_constraints.bgp_md5
      field set to MD5_REQUIRED, and that property is propagated to the
      attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is
      returned if MD5 is requested.
    bgpPeerAsnRanges: [Output Only] List of ASN ranges that the remote
      location is known to support. Formatted as an array of inclusive ranges
      {min: min-value, max: max-value}. For example, [{min: 123, max: 123},
      {min: 64512, max: 65534}] allows the peer ASN to be 123 or anything in
      the range 64512-65534. This field is only advisory. Although the API
      accepts other ranges, these are the ranges that we recommend.
  """

  class BgpMd5ValueValuesEnum(_messages.Enum):
    r"""[Output Only] Whether the attachment's BGP session
    requires/allows/disallows BGP MD5 authentication. This can take one of the
    following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED. For
    example, a Cross-Cloud Interconnect connection to a remote cloud provider
    that requires BGP MD5 authentication has the interconnectRemoteLocation
    attachment_configuration_constraints.bgp_md5 field set to MD5_REQUIRED,
    and that property is propagated to the attachment. Similarly, if BGP MD5
    is MD5_UNSUPPORTED, an error is returned if MD5 is requested.

    Values:
      MD5_OPTIONAL: MD5_OPTIONAL: BGP MD5 authentication is supported and can
        optionally be configured.
      MD5_REQUIRED: MD5_REQUIRED: BGP MD5 authentication must be configured.
      MD5_UNSUPPORTED: MD5_UNSUPPORTED: BGP MD5 authentication must not be
        configured
    """
    MD5_OPTIONAL = 0
    MD5_REQUIRED = 1
    MD5_UNSUPPORTED = 2

  bgpMd5 = _messages.EnumField('BgpMd5ValueValuesEnum', 1)
  bgpPeerAsnRanges = _messages.MessageField('InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange', 2, repeated=True)


class InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange(_messages.Message):
  r"""A InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange object.

  Fields:
    max: A integer attribute.
    min: A integer attribute.
  """

  max = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  min = _messages.IntegerField(2, variant=_messages.Variant.UINT32)


class InterconnectAttachmentGroup(_messages.Message):
  r"""An interconnect attachment group resource allows customers to create,
  analyze, and expand highly available deployments.

  Messages:
    AttachmentsValue: Attachments in the AttachmentGroup. Keys are arbitrary
      user-specified strings. Users are encouraged, but not required, to use
      their preferred format for resource links as keys. Note that there are
      add-members and remove-members methods in gcloud. The size of this map
      is limited by an "Attachments per group" quota.

  Fields:
    attachments: Attachments in the AttachmentGroup. Keys are arbitrary user-
      specified strings. Users are encouraged, but not required, to use their
      preferred format for resource links as keys. Note that there are add-
      members and remove-members methods in gcloud. The size of this map is
      limited by an "Attachments per group" quota.
    configured: A InterconnectAttachmentGroupConfigured attribute.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    etag: Opaque system-generated token that uniquely identifies the
      configuration. If provided when patching a configuration in update mode,
      the provided token must match the current token or the update is
      rejected. This provides a reliable means of doing read-modify-write
      (optimistic locking) as described by AIP 154.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    intent: A InterconnectAttachmentGroupIntent attribute.
    interconnectGroup: The URL of an InterconnectGroup that groups these
      Attachments' Interconnects. Customers do not need to set this unless
      directed by Google Support.
    kind: [Output Only] Type of the resource. Always
      compute#interconnectAttachmentGroup.
    logicalStructure: A InterconnectAttachmentGroupLogicalStructure attribute.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AttachmentsValue(_messages.Message):
    r"""Attachments in the AttachmentGroup. Keys are arbitrary user-specified
    strings. Users are encouraged, but not required, to use their preferred
    format for resource links as keys. Note that there are add-members and
    remove-members methods in gcloud. The size of this map is limited by an
    "Attachments per group" quota.

    Messages:
      AdditionalProperty: An additional property for a AttachmentsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AttachmentsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AttachmentsValue object.

      Fields:
        key: Name of the additional property.
        value: A InterconnectAttachmentGroupAttachment attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InterconnectAttachmentGroupAttachment', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  attachments = _messages.MessageField('AttachmentsValue', 1)
  configured = _messages.MessageField('InterconnectAttachmentGroupConfigured', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  etag = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  intent = _messages.MessageField('InterconnectAttachmentGroupIntent', 7)
  interconnectGroup = _messages.StringField(8)
  kind = _messages.StringField(9, default='compute#interconnectAttachmentGroup')
  logicalStructure = _messages.MessageField('InterconnectAttachmentGroupLogicalStructure', 10)
  name = _messages.StringField(11)
  selfLink = _messages.StringField(12)


class InterconnectAttachmentGroupAttachment(_messages.Message):
  r"""An Attachment in this AttachmentGroup.

  Fields:
    attachment: A string attribute.
  """

  attachment = _messages.StringField(1)


class InterconnectAttachmentGroupConfigured(_messages.Message):
  r"""[Output Only] The redundancy this group is configured to support. The
  way a user queries what SLA their Attachment gets is by looking at this
  field of the Attachment's AttachmentGroup.

  Fields:
    availabilitySla: A InterconnectAttachmentGroupConfiguredAvailabilitySLA
      attribute.
  """

  availabilitySla = _messages.MessageField('InterconnectAttachmentGroupConfiguredAvailabilitySLA', 1)


class InterconnectAttachmentGroupConfiguredAvailabilitySLA(_messages.Message):
  r"""[Output Only] Which SLA this group is configured to support, and why
  this group does or does not meet that SLA's requirements.

  Enums:
    EffectiveSlaValueValuesEnum:

  Fields:
    effectiveSla: A EffectiveSlaValueValuesEnum attribute.
    intendedSlaBlockers: A
      InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
      attribute.
  """

  class EffectiveSlaValueValuesEnum(_messages.Enum):
    r"""EffectiveSlaValueValuesEnum enum type.

    Values:
      EFFECTIVE_SLA_UNSPECIFIED: <no description>
      NO_SLA: <no description>
      PRODUCTION_CRITICAL: <no description>
      PRODUCTION_NON_CRITICAL: <no description>
    """
    EFFECTIVE_SLA_UNSPECIFIED = 0
    NO_SLA = 1
    PRODUCTION_CRITICAL = 2
    PRODUCTION_NON_CRITICAL = 3

  effectiveSla = _messages.EnumField('EffectiveSlaValueValuesEnum', 1)
  intendedSlaBlockers = _messages.MessageField('InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers', 2, repeated=True)


class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers(_messages.Message):
  r"""[Output Only] Reasons why configuration.availabilitySLA.sla differs from
  intent.availabilitySLA. This list is empty if and only if those are the
  same.

  Enums:
    BlockerTypeValueValuesEnum:

  Fields:
    attachments: [Output Only] URLs of any particular Attachments to explain
      this blocker in more detail.
    blockerType: A BlockerTypeValueValuesEnum attribute.
    documentationLink: [Output Only] The url of Google Cloud public
      documentation explaining this requirement. This is set for every type of
      requirement.
    explanation: [Output Only] A human-readable explanation of this
      requirement and why it's not met. This is set for every type of
      requirement.
    metros: [Output Only] Metros used to explain this blocker in more detail.
      These are three-letter lowercase strings like "iad". This will be set
      for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not
      apply to others.
    regions: [Output Only] Regions used to explain this blocker in more
      detail. These are region names formatted like "us-central1". This will
      be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply
      to others.
    zones: [Output Only] Zones used to explain this blocker in more detail.
      Format is "zone1" and/or "zone2". This will be set for some blockers
      (like MISSING_ZONE) but does not apply to others.
  """

  class BlockerTypeValueValuesEnum(_messages.Enum):
    r"""BlockerTypeValueValuesEnum enum type.

    Values:
      BLOCKER_TYPE_UNSPECIFIED: <no description>
      INCOMPATIBLE_METROS: <no description>
      INCOMPATIBLE_REGIONS: <no description>
      MISSING_GLOBAL_ROUTING: <no description>
      NO_ATTACHMENTS: <no description>
      NO_ATTACHMENTS_IN_METRO_AND_ZONE: <no description>
      OTHER: <no description>
    """
    BLOCKER_TYPE_UNSPECIFIED = 0
    INCOMPATIBLE_METROS = 1
    INCOMPATIBLE_REGIONS = 2
    MISSING_GLOBAL_ROUTING = 3
    NO_ATTACHMENTS = 4
    NO_ATTACHMENTS_IN_METRO_AND_ZONE = 5
    OTHER = 6

  attachments = _messages.StringField(1, repeated=True)
  blockerType = _messages.EnumField('BlockerTypeValueValuesEnum', 2)
  documentationLink = _messages.StringField(3)
  explanation = _messages.StringField(4)
  metros = _messages.StringField(5, repeated=True)
  regions = _messages.StringField(6, repeated=True)
  zones = _messages.StringField(7, repeated=True)


class InterconnectAttachmentGroupIntent(_messages.Message):
  r"""The user's intent for this AttachmentGroup. This is the only required
  field besides the name that must be specified on group creation.

  Enums:
    AvailabilitySlaValueValuesEnum:

  Fields:
    availabilitySla: A AvailabilitySlaValueValuesEnum attribute.
  """

  class AvailabilitySlaValueValuesEnum(_messages.Enum):
    r"""AvailabilitySlaValueValuesEnum enum type.

    Values:
      AVAILABILITY_SLA_UNSPECIFIED: <no description>
      NO_SLA: <no description>
      PRODUCTION_CRITICAL: <no description>
      PRODUCTION_NON_CRITICAL: <no description>
    """
    AVAILABILITY_SLA_UNSPECIFIED = 0
    NO_SLA = 1
    PRODUCTION_CRITICAL = 2
    PRODUCTION_NON_CRITICAL = 3

  availabilitySla = _messages.EnumField('AvailabilitySlaValueValuesEnum', 1)


class InterconnectAttachmentGroupLogicalStructure(_messages.Message):
  r"""[Output Only] An analysis of the logical layout of Attachments in this
  group. Every Attachment in the group is shown once in this structure.

  Fields:
    regions: A InterconnectAttachmentGroupLogicalStructureRegion attribute.
  """

  regions = _messages.MessageField('InterconnectAttachmentGroupLogicalStructureRegion', 1, repeated=True)


class InterconnectAttachmentGroupLogicalStructureRegion(_messages.Message):
  r"""[Output Only] The regions Attachments in this group are in.

  Fields:
    metros: A InterconnectAttachmentGroupLogicalStructureRegionMetro
      attribute.
    region: [Output Only] The name of a region, like "us-central1".
  """

  metros = _messages.MessageField('InterconnectAttachmentGroupLogicalStructureRegionMetro', 1, repeated=True)
  region = _messages.StringField(2)


class InterconnectAttachmentGroupLogicalStructureRegionMetro(_messages.Message):
  r"""[Output Only] The metros of Attachments in this group in this region.

  Fields:
    facilities: A
      InterconnectAttachmentGroupLogicalStructureRegionMetroFacility
      attribute.
    metro: [Output Only] The name of the metro, as a three-letter lowercase
      string like "iad". This is the first component of the location of an
      Interconnect.
  """

  facilities = _messages.MessageField('InterconnectAttachmentGroupLogicalStructureRegionMetroFacility', 1, repeated=True)
  metro = _messages.StringField(2)


class InterconnectAttachmentGroupLogicalStructureRegionMetroFacility(_messages.Message):
  r"""[Output Only] The facilities used for this group's Attachments'
  Interconnects.

  Fields:
    facility: [Output Only] The name of a facility, like "iad-1234".
    zones: A
      InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
      attribute.
  """

  facility = _messages.StringField(1)
  zones = _messages.MessageField('InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone', 2, repeated=True)


class InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone(_messages.Message):
  r"""[Output Only] The zones that Attachments in this group are present in,
  in the given facilities. This is inherited from their Interconnects.

  Fields:
    attachments: [Output Only] URLs of Attachments in the given zone, to the
      given region, on Interconnects in the given facility and metro. Every
      Attachment in the AG has such an entry.
    zone: [Output Only] The name of a zone, either "zone1" or "zone2".
  """

  attachments = _messages.StringField(1, repeated=True)
  zone = _messages.StringField(2)


class InterconnectAttachmentGroupsCreateMembers(_messages.Message):
  r"""A InterconnectAttachmentGroupsCreateMembers object.

  Enums:
    IntentMismatchBehaviorValueValuesEnum: How to behave when
      configured.availabilitySLA.effectiveSLA would not equal
      intent.availabilitySLA after this call.

  Fields:
    attachments: Parameters for the specific Attachments to create.
    intentMismatchBehavior: How to behave when
      configured.availabilitySLA.effectiveSLA would not equal
      intent.availabilitySLA after this call.
    templateAttachment: Default parameters for the Attachments to create in
      this call.
  """

  class IntentMismatchBehaviorValueValuesEnum(_messages.Enum):
    r"""How to behave when configured.availabilitySLA.effectiveSLA would not
    equal intent.availabilitySLA after this call.

    Values:
      CREATE: <no description>
      REJECT: <no description>
      UNSPECIFIED: <no description>
    """
    CREATE = 0
    REJECT = 1
    UNSPECIFIED = 2

  attachments = _messages.MessageField('InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput', 1, repeated=True)
  intentMismatchBehavior = _messages.EnumField('IntentMismatchBehaviorValueValuesEnum', 2)
  templateAttachment = _messages.MessageField('InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput', 3)


class InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput(_messages.Message):
  r"""LINT.IfChange Parameters used to create an InterconnectAttachment. This
  is similar to InterconnectAttachment, but the region field used here is not
  output only and all other output only fields are excluded.

  Enums:
    BandwidthValueValuesEnum: Provisioned bandwidth capacity for the
      interconnect attachment. For attachments of type DEDICATED, the user can
      set the bandwidth. For attachments of type PARTNER, the Google Partner
      that is operating the interconnect must set the bandwidth. Output only
      for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can
      take one of the following values: - BPS_50M: 50 Mbit/s - BPS_100M: 100
      Mbit/s - BPS_200M: 200 Mbit/s - BPS_300M: 300 Mbit/s - BPS_400M: 400
      Mbit/s - BPS_500M: 500 Mbit/s - BPS_1G: 1 Gbit/s - BPS_2G: 2 Gbit/s -
      BPS_5G: 5 Gbit/s - BPS_10G: 10 Gbit/s - BPS_20G: 20 Gbit/s - BPS_50G: 50
      Gbit/s - BPS_100G: 100 Gbit/s
    EdgeAvailabilityDomainValueValuesEnum: Input only. Desired availability
      domain for the attachment. Only available for type PARTNER, at creation
      time, and can take one of the following values: -
      AVAILABILITY_DOMAIN_ANY - AVAILABILITY_DOMAIN_1 - AVAILABILITY_DOMAIN_2
      For improved reliability, customers should configure a pair of
      attachments, one per availability domain. The selected availability
      domain will be provided to the Partner via the pairing key, so that the
      provisioned circuit will lie in the specified domain. If not specified,
      the value will default to AVAILABILITY_DOMAIN_ANY.
    EncryptionValueValuesEnum: Indicates the user-supplied encryption option
      of this VLAN attachment (interconnectAttachment). Can only be specified
      at attachment creation for PARTNER or DEDICATED attachments. Possible
      values are: - alpha - This is the default value, which means that the
      VLAN attachment carries unencrypted traffic. VMs are able to send
      traffic to, or receive traffic from, such a VLAN attachment. - IPSEC -
      The VLAN attachment carries only encrypted traffic that is encrypted by
      an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs
      cannot directly send traffic to, or receive traffic from, such a VLAN
      attachment. To use *HA VPN over Cloud Interconnect*, the VLAN attachment
      must be created with this option.
    StackTypeValueValuesEnum: The stack type for this interconnect attachment
      to identify whether the IPv6 feature is enabled or not. If not
      specified, IPV4_ONLY will be used. This field can be both set at
      interconnect attachments creation and update interconnect attachment
      operations.
    TypeValueValuesEnum: The type of interconnect attachment this is, which
      can take one of the following values: - DEDICATED: an attachment to a
      Dedicated Interconnect. - PARTNER: an attachment to a Partner
      Interconnect, created by the customer. - PARTNER_PROVIDER: an attachment
      to a Partner Interconnect, created by the partner.

  Fields:
    adminEnabled: Determines whether this Attachment will carry packets. Not
      present for PARTNER_PROVIDER.
    bandwidth: Provisioned bandwidth capacity for the interconnect attachment.
      For attachments of type DEDICATED, the user can set the bandwidth. For
      attachments of type PARTNER, the Google Partner that is operating the
      interconnect must set the bandwidth. Output only for PARTNER type,
      mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the
      following values: - BPS_50M: 50 Mbit/s - BPS_100M: 100 Mbit/s -
      BPS_200M: 200 Mbit/s - BPS_300M: 300 Mbit/s - BPS_400M: 400 Mbit/s -
      BPS_500M: 500 Mbit/s - BPS_1G: 1 Gbit/s - BPS_2G: 2 Gbit/s - BPS_5G: 5
      Gbit/s - BPS_10G: 10 Gbit/s - BPS_20G: 20 Gbit/s - BPS_50G: 50 Gbit/s -
      BPS_100G: 100 Gbit/s
    candidateCloudRouterIpAddress: Single IPv4 address + prefix length to be
      configured on the cloud router interface for this interconnect
      attachment. - Both candidate_cloud_router_ip_address and
      candidate_customer_router_ip_address fields must be set or both must be
      unset. - Prefix length of both candidate_cloud_router_ip_address and
      candidate_customer_router_ip_address must be the same. - Max prefix
      length is 31.
    candidateCloudRouterIpv6Address: Single IPv6 address + prefix length to be
      configured on the cloud router interface for this interconnect
      attachment. - Both candidate_cloud_router_ipv6_address and
      candidate_customer_router_ipv6_address fields must be set or both must
      be unset. - Prefix length of both candidate_cloud_router_ipv6_address
      and candidate_customer_router_ipv6_address must be the same. - Max
      prefix length is 126.
    candidateCustomerRouterIpAddress: Single IPv4 address + prefix length to
      be configured on the customer router interface for this interconnect
      attachment.
    candidateCustomerRouterIpv6Address: Single IPv6 address + prefix length to
      be configured on the customer router interface for this interconnect
      attachment.
    candidateIpv6Subnets: This field is not available.
    candidateSubnets: Input only. Up to 16 candidate prefixes that can be used
      to restrict the allocation of cloudRouterIpAddress and
      customerRouterIpAddress for this attachment. All prefixes must be within
      link-local address space (169.254.0.0/16) and must be /29 or shorter
      (/28, /27, etc). Google will attempt to select an unused /29 from the
      supplied candidate prefix(es). The request will fail if all possible
      /29s are in use on Google's edge. If not supplied, Google will randomly
      select an unused /29 from all of link-local space.
    cloudRouterIpv6InterfaceId: This field is not available.
    customerRouterIpv6InterfaceId: This field is not available.
    description: An optional description of this resource.
    edgeAvailabilityDomain: Input only. Desired availability domain for the
      attachment. Only available for type PARTNER, at creation time, and can
      take one of the following values: - AVAILABILITY_DOMAIN_ANY -
      AVAILABILITY_DOMAIN_1 - AVAILABILITY_DOMAIN_2 For improved reliability,
      customers should configure a pair of attachments, one per availability
      domain. The selected availability domain will be provided to the Partner
      via the pairing key, so that the provisioned circuit will lie in the
      specified domain. If not specified, the value will default to
      AVAILABILITY_DOMAIN_ANY.
    encryption: Indicates the user-supplied encryption option of this VLAN
      attachment (interconnectAttachment). Can only be specified at attachment
      creation for PARTNER or DEDICATED attachments. Possible values are: -
      alpha - This is the default value, which means that the VLAN attachment
      carries unencrypted traffic. VMs are able to send traffic to, or receive
      traffic from, such a VLAN attachment. - IPSEC - The VLAN attachment
      carries only encrypted traffic that is encrypted by an IPsec device,
      such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly
      send traffic to, or receive traffic from, such a VLAN attachment. To use
      *HA VPN over Cloud Interconnect*, the VLAN attachment must be created
      with this option.
    interconnect: URL of the underlying Interconnect object that this
      attachment's traffic will traverse through.
    ipsecInternalAddresses: A list of URLs of addresses that have been
      reserved for the VLAN attachment. Used only for the VLAN attachment that
      has the encryption option as IPSEC. The addresses must be regional
      internal IP address ranges. When creating an HA VPN gateway over the
      VLAN attachment, if the attachment is configured to use a regional
      internal IP address, then the VPN gateway's IP address is allocated from
      the IP address range specified here. For example, if the HA VPN
      gateway's interface 0 is paired to this VLAN attachment, then a regional
      internal IP address for the VPN gateway interface 0 will be allocated
      from the IP address specified for this VLAN attachment. If this field is
      not specified when creating the VLAN attachment, then later on when
      creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's
      IP address is allocated from the regional external IP address pool.
    l2Forwarding: L2 Interconnect Attachment related config. This field is
      required if the type is L2_DEDICATED. The configuration specifies how
      VLAN tags (like dot1q, qinq, or dot1ad) within L2 packets are mapped to
      the destination appliances IP addresses. The packet is then encapsulated
      with the appliance IP address and sent to the edge appliance.
    mtu: Maximum Transmission Unit (MTU), in bytes, of packets passing through
      this interconnect attachment. Only 1440 and 1500 are allowed. If not
      specified, the value will default to 1440.
    multicastEnabled: Whether or not to permit multicast traffic for this
      attachment. Multicast packets will be dropped if this is not enabled.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    pairingKey: [Output only for type PARTNER. Input only for
      PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of a
      PARTNER attachment used to initiate provisioning with a selected
      partner. Of the form "XXXXX/region/domain"
    partnerAsn: Optional BGP ASN for the router supplied by a Layer 3 Partner
      if they configured BGP on behalf of the customer. Output only for
      PARTNER type, input only for PARTNER_PROVIDER, not available for
      DEDICATED.
    partnerMetadata: Informational metadata about Partner attachments from
      Partners to display to customers. Output only for PARTNER type, mutable
      for PARTNER_PROVIDER, not available for DEDICATED.
    region: The region that the Attachment is in.
    router: URL of the Cloud Router to be used for dynamic routing. This
      router must be in the same region as this InterconnectAttachment. The
      InterconnectAttachment will automatically connect the Interconnect to
      the network & region within which the Cloud Router is configured.
    stackType: The stack type for this interconnect attachment to identify
      whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY
      will be used. This field can be both set at interconnect attachments
      creation and update interconnect attachment operations.
    subnetLength: Input only. Length of the IPv4 subnet mask. Allowed values:
      - 29 (default) - 30 The default value is 29, except for Cross-Cloud
      Interconnect connections that use an InterconnectRemoteLocation with a
      constraints.subnetLengthRange.min equal to 30. For example, connections
      that use an Azure remote location fall into this category. In these
      cases, the default value is 30, and requesting 29 returns an error.
      Where both 29 and 30 are allowed, 29 is preferred, because it gives
      Google Cloud Support more debugging visibility.
    type: The type of interconnect attachment this is, which can take one of
      the following values: - DEDICATED: an attachment to a Dedicated
      Interconnect. - PARTNER: an attachment to a Partner Interconnect,
      created by the customer. - PARTNER_PROVIDER: an attachment to a Partner
      Interconnect, created by the partner.
    vlanTag8021q: The IEEE 802.1Q VLAN tag for this attachment, in the range
      2-4093. Only specified at creation time.
  """

  class BandwidthValueValuesEnum(_messages.Enum):
    r"""Provisioned bandwidth capacity for the interconnect attachment. For
    attachments of type DEDICATED, the user can set the bandwidth. For
    attachments of type PARTNER, the Google Partner that is operating the
    interconnect must set the bandwidth. Output only for PARTNER type, mutable
    for PARTNER_PROVIDER and DEDICATED, and can take one of the following
    values: - BPS_50M: 50 Mbit/s - BPS_100M: 100 Mbit/s - BPS_200M: 200 Mbit/s
    - BPS_300M: 300 Mbit/s - BPS_400M: 400 Mbit/s - BPS_500M: 500 Mbit/s -
    BPS_1G: 1 Gbit/s - BPS_2G: 2 Gbit/s - BPS_5G: 5 Gbit/s - BPS_10G: 10
    Gbit/s - BPS_20G: 20 Gbit/s - BPS_50G: 50 Gbit/s - BPS_100G: 100 Gbit/s

    Values:
      BPS_100G: 100 Gbit/s
      BPS_100M: 100 Mbit/s
      BPS_10G: 10 Gbit/s
      BPS_1G: 1 Gbit/s
      BPS_200M: 200 Mbit/s
      BPS_20G: 20 Gbit/s
      BPS_2G: 2 Gbit/s
      BPS_300M: 300 Mbit/s
      BPS_400M: 400 Mbit/s
      BPS_500M: 500 Mbit/s
      BPS_50G: 50 Gbit/s
      BPS_50M: 50 Mbit/s
      BPS_5G: 5 Gbit/s
    """
    BPS_100G = 0
    BPS_100M = 1
    BPS_10G = 2
    BPS_1G = 3
    BPS_200M = 4
    BPS_20G = 5
    BPS_2G = 6
    BPS_300M = 7
    BPS_400M = 8
    BPS_500M = 9
    BPS_50G = 10
    BPS_50M = 11
    BPS_5G = 12

  class EdgeAvailabilityDomainValueValuesEnum(_messages.Enum):
    r"""Input only. Desired availability domain for the attachment. Only
    available for type PARTNER, at creation time, and can take one of the
    following values: - AVAILABILITY_DOMAIN_ANY - AVAILABILITY_DOMAIN_1 -
    AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure
    a pair of attachments, one per availability domain. The selected
    availability domain will be provided to the Partner via the pairing key,
    so that the provisioned circuit will lie in the specified domain. If not
    specified, the value will default to AVAILABILITY_DOMAIN_ANY.

    Values:
      AVAILABILITY_DOMAIN_1: <no description>
      AVAILABILITY_DOMAIN_2: <no description>
      AVAILABILITY_DOMAIN_ANY: <no description>
    """
    AVAILABILITY_DOMAIN_1 = 0
    AVAILABILITY_DOMAIN_2 = 1
    AVAILABILITY_DOMAIN_ANY = 2

  class EncryptionValueValuesEnum(_messages.Enum):
    r"""Indicates the user-supplied encryption option of this VLAN attachment
    (interconnectAttachment). Can only be specified at attachment creation for
    PARTNER or DEDICATED attachments. Possible values are: - alpha - This is
    the default value, which means that the VLAN attachment carries
    unencrypted traffic. VMs are able to send traffic to, or receive traffic
    from, such a VLAN attachment. - IPSEC - The VLAN attachment carries only
    encrypted traffic that is encrypted by an IPsec device, such as an HA VPN
    gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or
    receive traffic from, such a VLAN attachment. To use *HA VPN over Cloud
    Interconnect*, the VLAN attachment must be created with this option.

    Values:
      IPSEC: The interconnect attachment will carry only encrypted traffic
        that is encrypted by an IPsec device such as HA VPN gateway; VMs
        cannot directly send traffic to or receive traffic from such an
        interconnect attachment. To use HA VPN over Cloud Interconnect, the
        interconnect attachment must be created with this option.
      NONE: This is the default value, which means the Interconnect Attachment
        will carry unencrypted traffic. VMs will be able to send traffic to or
        receive traffic from such interconnect attachment.
    """
    IPSEC = 0
    NONE = 1

  class StackTypeValueValuesEnum(_messages.Enum):
    r"""The stack type for this interconnect attachment to identify whether
    the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be
    used. This field can be both set at interconnect attachments creation and
    update interconnect attachment operations.

    Values:
      IPV4_IPV6: The interconnect attachment can have both IPv4 and IPv6
        addresses.
      IPV4_ONLY: The interconnect attachment will only be assigned IPv4
        addresses.
    """
    IPV4_IPV6 = 0
    IPV4_ONLY = 1

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of interconnect attachment this is, which can take one of the
    following values: - DEDICATED: an attachment to a Dedicated Interconnect.
    - PARTNER: an attachment to a Partner Interconnect, created by the
    customer. - PARTNER_PROVIDER: an attachment to a Partner Interconnect,
    created by the partner.

    Values:
      DEDICATED: Attachment to a dedicated interconnect.
      L2_DEDICATED: Attachment to a L2 interconnect, created by the customer.
      PARTNER: Attachment to a partner interconnect, created by the customer.
      PARTNER_PROVIDER: Attachment to a partner interconnect, created by the
        partner.
    """
    DEDICATED = 0
    L2_DEDICATED = 1
    PARTNER = 2
    PARTNER_PROVIDER = 3

  adminEnabled = _messages.BooleanField(1)
  bandwidth = _messages.EnumField('BandwidthValueValuesEnum', 2)
  candidateCloudRouterIpAddress = _messages.StringField(3)
  candidateCloudRouterIpv6Address = _messages.StringField(4)
  candidateCustomerRouterIpAddress = _messages.StringField(5)
  candidateCustomerRouterIpv6Address = _messages.StringField(6)
  candidateIpv6Subnets = _messages.StringField(7, repeated=True)
  candidateSubnets = _messages.StringField(8, repeated=True)
  cloudRouterIpv6InterfaceId = _messages.StringField(9)
  customerRouterIpv6InterfaceId = _messages.StringField(10)
  description = _messages.StringField(11)
  edgeAvailabilityDomain = _messages.EnumField('EdgeAvailabilityDomainValueValuesEnum', 12)
  encryption = _messages.EnumField('EncryptionValueValuesEnum', 13)
  interconnect = _messages.StringField(14)
  ipsecInternalAddresses = _messages.StringField(15, repeated=True)
  l2Forwarding = _messages.MessageField('InterconnectAttachmentL2Forwarding', 16)
  mtu = _messages.IntegerField(17, variant=_messages.Variant.INT32)
  multicastEnabled = _messages.BooleanField(18)
  name = _messages.StringField(19)
  pairingKey = _messages.StringField(20)
  partnerAsn = _messages.IntegerField(21)
  partnerMetadata = _messages.MessageField('InterconnectAttachmentPartnerMetadata', 22)
  region = _messages.StringField(23)
  router = _messages.StringField(24)
  stackType = _messages.EnumField('StackTypeValueValuesEnum', 25)
  subnetLength = _messages.IntegerField(26, variant=_messages.Variant.INT32)
  type = _messages.EnumField('TypeValueValuesEnum', 27)
  vlanTag8021q = _messages.IntegerField(28, variant=_messages.Variant.INT32)


class InterconnectAttachmentGroupsCreateMembersRequest(_messages.Message):
  r"""A InterconnectAttachmentGroupsCreateMembersRequest object.

  Fields:
    request: A InterconnectAttachmentGroupsCreateMembers attribute.
  """

  request = _messages.MessageField('InterconnectAttachmentGroupsCreateMembers', 1)


class InterconnectAttachmentGroupsGetOperationalStatusResponse(_messages.Message):
  r"""Response for the
  InterconnectAttachmentGroupsGetOperationalStatusResponse.

  Fields:
    etag: A string attribute.
    result: A InterconnectAttachmentGroupsOperationalStatus attribute.
  """

  etag = _messages.StringField(1)
  result = _messages.MessageField('InterconnectAttachmentGroupsOperationalStatus', 2)


class InterconnectAttachmentGroupsListResponse(_messages.Message):
  r"""A InterconnectAttachmentGroupsListResponse object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectAttachmentGroup resources.
    kind: A string attribute.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('InterconnectAttachmentGroup', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#interconnectAttachmentGroup')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class InterconnectAttachmentGroupsOperationalStatus(_messages.Message):
  r"""A InterconnectAttachmentGroupsOperationalStatus object.

  Enums:
    GroupStatusValueValuesEnum: Summarizes the status of the group.

  Fields:
    attachmentStatuses: A
      InterconnectAttachmentGroupsOperationalStatusAttachmentStatus attribute.
    configured: A InterconnectAttachmentGroupConfigured attribute.
    groupStatus: Summarizes the status of the group.
    intent: A InterconnectAttachmentGroupIntent attribute.
    operational: The operational state of the group, including only active
      Attachments.
  """

  class GroupStatusValueValuesEnum(_messages.Enum):
    r"""Summarizes the status of the group.

    Values:
      DEGRADED: <no description>
      FULLY_DOWN: <no description>
      FULLY_UP: <no description>
      UNSPECIFIED: <no description>
    """
    DEGRADED = 0
    FULLY_DOWN = 1
    FULLY_UP = 2
    UNSPECIFIED = 3

  attachmentStatuses = _messages.MessageField('InterconnectAttachmentGroupsOperationalStatusAttachmentStatus', 1, repeated=True)
  configured = _messages.MessageField('InterconnectAttachmentGroupConfigured', 2)
  groupStatus = _messages.EnumField('GroupStatusValueValuesEnum', 3)
  intent = _messages.MessageField('InterconnectAttachmentGroupIntent', 4)
  operational = _messages.MessageField('InterconnectAttachmentGroupConfigured', 5)


class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus(_messages.Message):
  r"""The status of one Attachment in the group. List order is arbitrary.

  Enums:
    IsActiveValueValuesEnum: Whether this Attachment is participating in the
      redundant configuration. This will be ACTIVE if and only if the status
      below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the
      analysis that generates operational.availabilitySLA.
    StatusValueValuesEnum: Whether this Attachment is active, and if so,
      whether BGP is up. This is based on the statuses available in the
      Pantheon UI here: http://google3/java/com/google/cloud/boq/clientapi/gce
      /hybrid/api/interconnect_models.proto

  Fields:
    adminEnabled: Whether this Attachment is enabled. This becomes false when
      the customer drains their Attachment.
    attachment: The URL of the Attachment being described.
    isActive: Whether this Attachment is participating in the redundant
      configuration. This will be ACTIVE if and only if the status below is
      CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis
      that generates operational.availabilitySLA.
    status: Whether this Attachment is active, and if so, whether BGP is up.
      This is based on the statuses available in the Pantheon UI here: http://
      google3/java/com/google/cloud/boq/clientapi/gce/hybrid/api/interconnect_
      models.proto
  """

  class IsActiveValueValuesEnum(_messages.Enum):
    r"""Whether this Attachment is participating in the redundant
    configuration. This will be ACTIVE if and only if the status below is
    CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis
    that generates operational.availabilitySLA.

    Values:
      ACTIVE: <no description>
      INACTIVE: <no description>
      UNSPECIFIED: <no description>
    """
    ACTIVE = 0
    INACTIVE = 1
    UNSPECIFIED = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""Whether this Attachment is active, and if so, whether BGP is up. This
    is based on the statuses available in the Pantheon UI here: http://google3
    /java/com/google/cloud/boq/clientapi/gce/hybrid/api/interconnect_models.pr
    oto

    Values:
      ATTACHMENT_STATUS_UNKNOWN: <no description>
      CONNECTION_DISABLED: <no description>
      CONNECTION_DOWN: <no description>
      CONNECTION_UP: <no description>
      DEFUNCT: <no description>
      IPSEC_CONFIGURATION_NEEDED_STATUS: <no description>
      IPSEC_READY_TO_RESUME_FLOW_STATUS: <no description>
      IPV4_DOWN_IPV6_UP: <no description>
      IPV4_UP_IPV6_DOWN: <no description>
      PARTNER_REQUEST_RECEIVED: <no description>
      PENDING_CUSTOMER: <no description>
      PENDING_PARTNER: <no description>
      PROVISIONED: <no description>
      ROUTER_CONFIGURATION_BROKEN: <no description>
      UNPROVISIONED: <no description>
    """
    ATTACHMENT_STATUS_UNKNOWN = 0
    CONNECTION_DISABLED = 1
    CONNECTION_DOWN = 2
    CONNECTION_UP = 3
    DEFUNCT = 4
    IPSEC_CONFIGURATION_NEEDED_STATUS = 5
    IPSEC_READY_TO_RESUME_FLOW_STATUS = 6
    IPV4_DOWN_IPV6_UP = 7
    IPV4_UP_IPV6_DOWN = 8
    PARTNER_REQUEST_RECEIVED = 9
    PENDING_CUSTOMER = 10
    PENDING_PARTNER = 11
    PROVISIONED = 12
    ROUTER_CONFIGURATION_BROKEN = 13
    UNPROVISIONED = 14

  adminEnabled = _messages.BooleanField(1)
  attachment = _messages.StringField(2)
  isActive = _messages.EnumField('IsActiveValueValuesEnum', 3)
  status = _messages.EnumField('StatusValueValuesEnum', 4)


class InterconnectAttachmentL2Forwarding(_messages.Message):
  r"""L2 Interconnect Attachment related configuration.

  Messages:
    ApplianceMappingsValue: Optional. A map of VLAN tags to appliances and
      optional inner mapping rules. If VLANs are not explicitly mapped to any
      appliance, the defaultApplianceIpAddress is used. Each VLAN tag can be a
      single number or a range of numbers in the range of 1 to 4094, e.g., "1"
      or "4001-4094". Non-empty and non-overlapping VLAN tag ranges are
      enforced, and violating operations will be rejected. The VLAN tags in
      the Ethernet header must use an ethertype value of 0x88A8 or 0x8100.

  Fields:
    applianceMappings: Optional. A map of VLAN tags to appliances and optional
      inner mapping rules. If VLANs are not explicitly mapped to any
      appliance, the defaultApplianceIpAddress is used. Each VLAN tag can be a
      single number or a range of numbers in the range of 1 to 4094, e.g., "1"
      or "4001-4094". Non-empty and non-overlapping VLAN tag ranges are
      enforced, and violating operations will be rejected. The VLAN tags in
      the Ethernet header must use an ethertype value of 0x88A8 or 0x8100.
    defaultApplianceIpAddress: Optional. A single IPv4 or IPv6 address used as
      the default destination IP when there is no VLAN mapping result found.
      Unset field (null-value) indicates the unmatched packet should be
      dropped.
    geneveHeader: Optional. It represents the structure of a Geneve (Generic
      Network Virtualization Encapsulation) header, as defined in RFC8926. It
      encapsulates packets from various protocols (e.g., Ethernet, IPv4, IPv6)
      for use in network virtualization environments.
    network: Required. Resource URL of the network to which this attachment
      belongs.
    tunnelEndpointIpAddress: Required. A single IPv4 or IPv6 address. This
      address will be used as the source IP address for packets sent to the
      appliances, and must be used as the destination IP address for packets
      that should be sent out through this attachment.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ApplianceMappingsValue(_messages.Message):
    r"""Optional. A map of VLAN tags to appliances and optional inner mapping
    rules. If VLANs are not explicitly mapped to any appliance, the
    defaultApplianceIpAddress is used. Each VLAN tag can be a single number or
    a range of numbers in the range of 1 to 4094, e.g., "1" or "4001-4094".
    Non-empty and non-overlapping VLAN tag ranges are enforced, and violating
    operations will be rejected. The VLAN tags in the Ethernet header must use
    an ethertype value of 0x88A8 or 0x8100.

    Messages:
      AdditionalProperty: An additional property for a ApplianceMappingsValue
        object.

    Fields:
      additionalProperties: Additional properties of type
        ApplianceMappingsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ApplianceMappingsValue object.

      Fields:
        key: Name of the additional property.
        value: A InterconnectAttachmentL2ForwardingApplianceMapping attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InterconnectAttachmentL2ForwardingApplianceMapping', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  applianceMappings = _messages.MessageField('ApplianceMappingsValue', 1)
  defaultApplianceIpAddress = _messages.StringField(2)
  geneveHeader = _messages.MessageField('InterconnectAttachmentL2ForwardingGeneveHeader', 3)
  network = _messages.StringField(4)
  tunnelEndpointIpAddress = _messages.StringField(5)


class InterconnectAttachmentL2ForwardingApplianceMapping(_messages.Message):
  r"""Two-level VLAN-to-Appliance mapping rule.

  Fields:
    applianceIpAddress: Optional. A single IPv4 or IPv6 address used as the
      destination IP address for ingress packets that match on a VLAN tag, but
      do not match a more specific inner VLAN tag. Unset field (null-value)
      indicates both VLAN tags are required to be mapped. Otherwise,
      defaultApplianceIpAddress is used.
    innerVlanToApplianceMappings: Optional. Used to match against the inner
      VLAN when the packet contains two VLAN tags. A list of mapping rules
      from inner VLAN tags to IP addresses. If the inner VLAN is not
      explicitly mapped to an IP address range, the applianceIpAddress is
      used.
    name: Optional. The name of this appliance mapping rule.
  """

  applianceIpAddress = _messages.StringField(1)
  innerVlanToApplianceMappings = _messages.MessageField('InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping', 2, repeated=True)
  name = _messages.StringField(3)


class InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping(_messages.Message):
  r"""The inner VLAN-to-Appliance mapping.

  Fields:
    innerApplianceIpAddress: Required in this object. A single IPv4 or IPv6
      address used as the destination IP address for ingress packets that
      match on both VLAN tags.
    innerVlanTags: Required in this object. Used to match the inner VLAN tag
      on the packet. Each entry can be a single number or a range of numbers
      in the range of 1 to 4094, e.g., ["1", "4001-4094"] is valid. Non-empty
      and Non-overlapping VLAN tag ranges are enforced, and violating
      operations will be rejected. The inner VLAN tags must have an ethertype
      value of 0x8100.
  """

  innerApplianceIpAddress = _messages.StringField(1)
  innerVlanTags = _messages.StringField(2, repeated=True)


class InterconnectAttachmentL2ForwardingGeneveHeader(_messages.Message):
  r"""GeneveHeader related configurations.

  Fields:
    vni: Optional. VNI is a 24-bit unique virtual network identifier, from 0
      to 16,777,215.
  """

  vni = _messages.IntegerField(1, variant=_messages.Variant.UINT32)


class InterconnectAttachmentList(_messages.Message):
  r"""Response to the list request, and contains a list of interconnect
  attachments.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectAttachment resources.
    kind: [Output Only] Type of resource. Always
      compute#interconnectAttachmentList for lists of interconnect
      attachments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InterconnectAttachment', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#interconnectAttachmentList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InterconnectAttachmentPartnerMetadata(_messages.Message):
  r"""Informational metadata about Partner attachments from Partners to
  display to customers. These fields are propagated from PARTNER_PROVIDER
  attachments to their corresponding PARTNER attachments.

  Fields:
    interconnectName: Plain text name of the Interconnect this attachment is
      connected to, as displayed in the Partner's portal. For instance
      "Chicago 1". This value may be validated to match approved Partner
      values.
    partnerName: Plain text name of the Partner providing this attachment.
      This value may be validated to match approved Partner values.
    portalUrl: URL of the Partner's portal for this Attachment. Partners may
      customise this to be a deep link to the specific resource on the Partner
      portal. This value may be validated to match approved Partner values.
  """

  interconnectName = _messages.StringField(1)
  partnerName = _messages.StringField(2)
  portalUrl = _messages.StringField(3)


class InterconnectAttachmentPrivateInfo(_messages.Message):
  r"""Information for an interconnect attachment when this belongs to an
  interconnect of type DEDICATED.

  Fields:
    tag8021q: [Output Only] 802.1q encapsulation tag to be used for traffic
      between Google and the customer, going to and from this network and
      region.
  """

  tag8021q = _messages.IntegerField(1, variant=_messages.Variant.UINT32)


class InterconnectAttachmentsScopedList(_messages.Message):
  r"""A InterconnectAttachmentsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of addresses
      when the list is empty.

  Fields:
    interconnectAttachments: A list of interconnect attachments contained in
      this scope.
    warning: Informational warning which replaces the list of addresses when
      the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of addresses when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  interconnectAttachments = _messages.MessageField('InterconnectAttachment', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InterconnectCircuitInfo(_messages.Message):
  r"""Describes a single physical circuit between the Customer and Google.
  CircuitInfo objects are created by Google, so all fields are output only.

  Fields:
    customerDemarcId: Customer-side demarc ID for this circuit.
    googleCircuitId: Google-assigned unique ID for this circuit. Assigned at
      circuit turn-up.
    googleDemarcId: Google-side demarc ID for this circuit. Assigned at
      circuit turn-up and provided by Google to the customer in the LOA.
  """

  customerDemarcId = _messages.StringField(1)
  googleCircuitId = _messages.StringField(2)
  googleDemarcId = _messages.StringField(3)


class InterconnectDiagnostics(_messages.Message):
  r"""Diagnostics information about the Interconnect connection, which
  contains detailed and current technical information about Google's side of
  the connection.

  Enums:
    BundleAggregationTypeValueValuesEnum: The aggregation type of the bundle
      interface.
    BundleOperationalStatusValueValuesEnum: The operational status of the
      bundle interface.

  Fields:
    arpCaches: A list of InterconnectDiagnostics.ARPEntry objects, describing
      individual neighbors currently seen by the Google router in the ARP
      cache for the Interconnect. This will be empty when the Interconnect is
      not bundled.
    bundleAggregationType: The aggregation type of the bundle interface.
    bundleOperationalStatus: The operational status of the bundle interface.
    links: A list of InterconnectDiagnostics.LinkStatus objects, describing
      the status for each link on the Interconnect.
    macAddress: The MAC address of the Interconnect's bundle interface.
  """

  class BundleAggregationTypeValueValuesEnum(_messages.Enum):
    r"""The aggregation type of the bundle interface.

    Values:
      BUNDLE_AGGREGATION_TYPE_LACP: LACP is enabled.
      BUNDLE_AGGREGATION_TYPE_STATIC: LACP is disabled.
    """
    BUNDLE_AGGREGATION_TYPE_LACP = 0
    BUNDLE_AGGREGATION_TYPE_STATIC = 1

  class BundleOperationalStatusValueValuesEnum(_messages.Enum):
    r"""The operational status of the bundle interface.

    Values:
      BUNDLE_OPERATIONAL_STATUS_DOWN: If bundleAggregationType is LACP: LACP
        is not established and/or all links in the bundle have DOWN
        operational status. If bundleAggregationType is STATIC: one or more
        links in the bundle has DOWN operational status.
      BUNDLE_OPERATIONAL_STATUS_UP: If bundleAggregationType is LACP: LACP is
        established and at least one link in the bundle has UP operational
        status. If bundleAggregationType is STATIC: all links in the bundle
        (typically just one) have UP operational status.
    """
    BUNDLE_OPERATIONAL_STATUS_DOWN = 0
    BUNDLE_OPERATIONAL_STATUS_UP = 1

  arpCaches = _messages.MessageField('InterconnectDiagnosticsARPEntry', 1, repeated=True)
  bundleAggregationType = _messages.EnumField('BundleAggregationTypeValueValuesEnum', 2)
  bundleOperationalStatus = _messages.EnumField('BundleOperationalStatusValueValuesEnum', 3)
  links = _messages.MessageField('InterconnectDiagnosticsLinkStatus', 4, repeated=True)
  macAddress = _messages.StringField(5)


class InterconnectDiagnosticsARPEntry(_messages.Message):
  r"""Describing the ARP neighbor entries seen on this link

  Fields:
    ipAddress: The IP address of this ARP neighbor.
    macAddress: The MAC address of this ARP neighbor.
  """

  ipAddress = _messages.StringField(1)
  macAddress = _messages.StringField(2)


class InterconnectDiagnosticsLinkLACPStatus(_messages.Message):
  r"""A InterconnectDiagnosticsLinkLACPStatus object.

  Enums:
    StateValueValuesEnum: The state of a LACP link, which can take one of the
      following values: - ACTIVE: The link is configured and active within the
      bundle. - DETACHED: The link is not configured within the bundle. This
      means that the rest of the object should be empty.

  Fields:
    googleSystemId: System ID of the port on Google's side of the LACP
      exchange.
    neighborSystemId: System ID of the port on the neighbor's side of the LACP
      exchange.
    state: The state of a LACP link, which can take one of the following
      values: - ACTIVE: The link is configured and active within the bundle. -
      DETACHED: The link is not configured within the bundle. This means that
      the rest of the object should be empty.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""The state of a LACP link, which can take one of the following values:
    - ACTIVE: The link is configured and active within the bundle. - DETACHED:
    The link is not configured within the bundle. This means that the rest of
    the object should be empty.

    Values:
      ACTIVE: The link is configured and active within the bundle.
      DETACHED: The link is not configured within the bundle, this means the
        rest of the object should be empty.
    """
    ACTIVE = 0
    DETACHED = 1

  googleSystemId = _messages.StringField(1)
  neighborSystemId = _messages.StringField(2)
  state = _messages.EnumField('StateValueValuesEnum', 3)


class InterconnectDiagnosticsLinkOpticalPower(_messages.Message):
  r"""A InterconnectDiagnosticsLinkOpticalPower object.

  Enums:
    StateValueValuesEnum: The status of the current value when compared to the
      warning and alarm levels for the receiving or transmitting transceiver.
      Possible states include: - OK: The value has not crossed a warning
      threshold. - LOW_WARNING: The value has crossed below the low warning
      threshold. - HIGH_WARNING: The value has crossed above the high warning
      threshold. - LOW_ALARM: The value has crossed below the low alarm
      threshold. - HIGH_ALARM: The value has crossed above the high alarm
      threshold.

  Fields:
    state: The status of the current value when compared to the warning and
      alarm levels for the receiving or transmitting transceiver. Possible
      states include: - OK: The value has not crossed a warning threshold. -
      LOW_WARNING: The value has crossed below the low warning threshold. -
      HIGH_WARNING: The value has crossed above the high warning threshold. -
      LOW_ALARM: The value has crossed below the low alarm threshold. -
      HIGH_ALARM: The value has crossed above the high alarm threshold.
    value: Value of the current receiving or transmitting optical power, read
      in dBm. Take a known good optical value, give it a 10% margin and
      trigger warnings relative to that value. In general, a -7dBm warning and
      a -11dBm alarm are good optical value estimates for most links.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""The status of the current value when compared to the warning and alarm
    levels for the receiving or transmitting transceiver. Possible states
    include: - OK: The value has not crossed a warning threshold. -
    LOW_WARNING: The value has crossed below the low warning threshold. -
    HIGH_WARNING: The value has crossed above the high warning threshold. -
    LOW_ALARM: The value has crossed below the low alarm threshold. -
    HIGH_ALARM: The value has crossed above the high alarm threshold.

    Values:
      HIGH_ALARM: The value has crossed above the high alarm threshold.
      HIGH_WARNING: The value of the current optical power has crossed above
        the high warning threshold.
      LOW_ALARM: The value of the current optical power has crossed below the
        low alarm threshold.
      LOW_WARNING: The value of the current optical power has crossed below
        the low warning threshold.
      OK: The value of the current optical power has not crossed a warning
        threshold.
    """
    HIGH_ALARM = 0
    HIGH_WARNING = 1
    LOW_ALARM = 2
    LOW_WARNING = 3
    OK = 4

  state = _messages.EnumField('StateValueValuesEnum', 1)
  value = _messages.FloatField(2, variant=_messages.Variant.FLOAT)


class InterconnectDiagnosticsLinkStatus(_messages.Message):
  r"""A InterconnectDiagnosticsLinkStatus object.

  Enums:
    OperationalStatusValueValuesEnum: The operational status of the link.

  Fields:
    arpCaches: A list of InterconnectDiagnostics.ARPEntry objects, describing
      the ARP neighbor entries seen on this link. This will be empty if the
      link is bundled
    circuitId: The unique ID for this link assigned during turn up by Google.
    googleDemarc: The Demarc address assigned by Google and provided in the
      LoA.
    lacpStatus: A InterconnectDiagnosticsLinkLACPStatus attribute.
    macsec: Describes the status of MACsec encryption on this link.
    operationalStatus: The operational status of the link.
    receivingOpticalPower: An InterconnectDiagnostics.LinkOpticalPower object,
      describing the current value and status of the received light level.
    transmittingOpticalPower: An InterconnectDiagnostics.LinkOpticalPower
      object, describing the current value and status of the transmitted light
      level.
  """

  class OperationalStatusValueValuesEnum(_messages.Enum):
    r"""The operational status of the link.

    Values:
      LINK_OPERATIONAL_STATUS_DOWN: The interface is unable to communicate
        with the remote end.
      LINK_OPERATIONAL_STATUS_UP: The interface has low level communication
        with the remote end.
    """
    LINK_OPERATIONAL_STATUS_DOWN = 0
    LINK_OPERATIONAL_STATUS_UP = 1

  arpCaches = _messages.MessageField('InterconnectDiagnosticsARPEntry', 1, repeated=True)
  circuitId = _messages.StringField(2)
  googleDemarc = _messages.StringField(3)
  lacpStatus = _messages.MessageField('InterconnectDiagnosticsLinkLACPStatus', 4)
  macsec = _messages.MessageField('InterconnectDiagnosticsMacsecStatus', 5)
  operationalStatus = _messages.EnumField('OperationalStatusValueValuesEnum', 6)
  receivingOpticalPower = _messages.MessageField('InterconnectDiagnosticsLinkOpticalPower', 7)
  transmittingOpticalPower = _messages.MessageField('InterconnectDiagnosticsLinkOpticalPower', 8)


class InterconnectDiagnosticsMacsecStatus(_messages.Message):
  r"""Describes the status of MACsec encryption on the link.

  Fields:
    ckn: Indicates the Connectivity Association Key Name (CKN) currently being
      used if MACsec is operational.
    operational: Indicates whether or not MACsec is operational on this link.
  """

  ckn = _messages.StringField(1)
  operational = _messages.BooleanField(2)


class InterconnectGroup(_messages.Message):
  r"""An interconnect group resource allows customers to create, analyze, and
  expand their redundant connections.

  Messages:
    InterconnectsValue: Interconnects in the InterconnectGroup. Keys are
      arbitrary user-specified strings. Users are encouraged, but not
      required, to use their preferred format for resource links as keys. Note
      that there are add-members and remove-members methods in gcloud. The
      size of this map is limited by an "Interconnects per group" quota.

  Fields:
    configured: A InterconnectGroupConfigured attribute.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    etag: Opaque system-generated token that uniquely identifies the
      configuration. If provided when patching a configuration in update mode,
      the provided token must match the current token or the update is
      rejected. This provides a reliable means of doing read-modify-write
      (optimistic locking) as described by API 154.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    intent: A InterconnectGroupIntent attribute.
    interconnects: Interconnects in the InterconnectGroup. Keys are arbitrary
      user-specified strings. Users are encouraged, but not required, to use
      their preferred format for resource links as keys. Note that there are
      add-members and remove-members methods in gcloud. The size of this map
      is limited by an "Interconnects per group" quota.
    kind: [Output Only] Type of the resource. Always compute#InterconnectGroup
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    physicalStructure: A InterconnectGroupPhysicalStructure attribute.
    selfLink: [Output Only] Server-defined URL for the resource.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class InterconnectsValue(_messages.Message):
    r"""Interconnects in the InterconnectGroup. Keys are arbitrary user-
    specified strings. Users are encouraged, but not required, to use their
    preferred format for resource links as keys. Note that there are add-
    members and remove-members methods in gcloud. The size of this map is
    limited by an "Interconnects per group" quota.

    Messages:
      AdditionalProperty: An additional property for a InterconnectsValue
        object.

    Fields:
      additionalProperties: Additional properties of type InterconnectsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a InterconnectsValue object.

      Fields:
        key: Name of the additional property.
        value: A InterconnectGroupInterconnect attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InterconnectGroupInterconnect', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  configured = _messages.MessageField('InterconnectGroupConfigured', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  etag = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  intent = _messages.MessageField('InterconnectGroupIntent', 6)
  interconnects = _messages.MessageField('InterconnectsValue', 7)
  kind = _messages.StringField(8, default='compute#InterconnectGroup')
  name = _messages.StringField(9)
  physicalStructure = _messages.MessageField('InterconnectGroupPhysicalStructure', 10)
  selfLink = _messages.StringField(11)


class InterconnectGroupConfigured(_messages.Message):
  r"""[Output Only] The status of the group as configured. This has the same
  structure as the operational field reported by the OperationalStatus method,
  but does not take into account the operational status of each resource.

  Fields:
    topologyCapability: A InterconnectGroupConfiguredTopologyCapability
      attribute.
  """

  topologyCapability = _messages.MessageField('InterconnectGroupConfiguredTopologyCapability', 1)


class InterconnectGroupConfiguredTopologyCapability(_messages.Message):
  r"""[Output Only] How reliable this topology is configured to be, and why
  this group does or does not meet the requirements for the intended
  capability.

  Enums:
    SupportedSlaValueValuesEnum:

  Fields:
    intendedCapabilityBlockers: A
      InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
      attribute.
    supportedSla: A SupportedSlaValueValuesEnum attribute.
  """

  class SupportedSlaValueValuesEnum(_messages.Enum):
    r"""SupportedSlaValueValuesEnum enum type.

    Values:
      NO_SLA: <no description>
      PRODUCTION_CRITICAL: <no description>
      PRODUCTION_NON_CRITICAL: <no description>
      UNSPECIFIED: <no description>
    """
    NO_SLA = 0
    PRODUCTION_CRITICAL = 1
    PRODUCTION_NON_CRITICAL = 2
    UNSPECIFIED = 3

  intendedCapabilityBlockers = _messages.MessageField('InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers', 1, repeated=True)
  supportedSla = _messages.EnumField('SupportedSlaValueValuesEnum', 2)


class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers(_messages.Message):
  r"""[Output Only] Reasons why configuration.topologyCapability.sla differs
  from intent.topologyCapability. This list is empty if and only if those are
  the same.

  Enums:
    BlockerTypeValueValuesEnum:

  Fields:
    blockerType: A BlockerTypeValueValuesEnum attribute.
    documentationLink: [Output Only] The url of Google Cloud public
      documentation explaining this requirement. This is set for every type of
      requirement.
    explanation: [Output Only] A human-readable explanation of this
      requirement and why it's not met. This is set for every type of
      requirement.
    facilities: [Output Only] Facilities used to explain this blocker in more
      detail. Like physicalStructure.metros.facilities.facility, this is a
      numeric string like "5467".
    interconnects: [Output Only] Interconnects used to explain this blocker in
      more detail.
    metros: [Output Only] Metros used to explain this blocker in more detail.
      These are three-letter lowercase strings like "iad". A blocker like
      INCOMPATIBLE_METROS will specify the problematic metros in this field.
    zones: [Output Only] Zones used to explain this blocker in more detail.
      Zone names are "zone1" and/or "zone2".
  """

  class BlockerTypeValueValuesEnum(_messages.Enum):
    r"""BlockerTypeValueValuesEnum enum type.

    Values:
      INCOMPATIBLE_METROS: <no description>
      NOT_AVAILABLE: <no description>
      NO_INTERCONNECTS: <no description>
      NO_INTERCONNECTS_IN_METRO_AND_ZONE: <no description>
      OTHER: <no description>
      UNSPECIFIED: <no description>
    """
    INCOMPATIBLE_METROS = 0
    NOT_AVAILABLE = 1
    NO_INTERCONNECTS = 2
    NO_INTERCONNECTS_IN_METRO_AND_ZONE = 3
    OTHER = 4
    UNSPECIFIED = 5

  blockerType = _messages.EnumField('BlockerTypeValueValuesEnum', 1)
  documentationLink = _messages.StringField(2)
  explanation = _messages.StringField(3)
  facilities = _messages.StringField(4, repeated=True)
  interconnects = _messages.StringField(5, repeated=True)
  metros = _messages.StringField(6, repeated=True)
  zones = _messages.StringField(7, repeated=True)


class InterconnectGroupIntent(_messages.Message):
  r"""The user's intent for this group. This is the only required field
  besides the name that must be specified on group creation.

  Enums:
    TopologyCapabilityValueValuesEnum:

  Fields:
    topologyCapability: A TopologyCapabilityValueValuesEnum attribute.
  """

  class TopologyCapabilityValueValuesEnum(_messages.Enum):
    r"""TopologyCapabilityValueValuesEnum enum type.

    Values:
      NO_SLA: <no description>
      PRODUCTION_CRITICAL: <no description>
      PRODUCTION_NON_CRITICAL: <no description>
      UNSPECIFIED: <no description>
    """
    NO_SLA = 0
    PRODUCTION_CRITICAL = 1
    PRODUCTION_NON_CRITICAL = 2
    UNSPECIFIED = 3

  topologyCapability = _messages.EnumField('TopologyCapabilityValueValuesEnum', 1)


class InterconnectGroupInterconnect(_messages.Message):
  r"""An Interconnect in this InterconnectGroup.

  Fields:
    interconnect: The URL of an Interconnect in this group. All Interconnects
      in the group are unique.
  """

  interconnect = _messages.StringField(1)


class InterconnectGroupPhysicalStructure(_messages.Message):
  r"""[Output Only] An analysis of the physical layout of Interconnects in
  this group. Every Interconnect in the group is shown once in this structure.

  Fields:
    metros: A InterconnectGroupPhysicalStructureMetros attribute.
  """

  metros = _messages.MessageField('InterconnectGroupPhysicalStructureMetros', 1, repeated=True)


class InterconnectGroupPhysicalStructureMetros(_messages.Message):
  r"""[Output Only] The metros Interconnects in this group are in.

  Fields:
    facilities: A InterconnectGroupPhysicalStructureMetrosFacilities
      attribute.
    metro: [Output Only] The name of the metro, as a three-letter lowercase
      string like "iad". This is the first component of the location of
      Interconnects underneath this.
  """

  facilities = _messages.MessageField('InterconnectGroupPhysicalStructureMetrosFacilities', 1, repeated=True)
  metro = _messages.StringField(2)


class InterconnectGroupPhysicalStructureMetrosFacilities(_messages.Message):
  r"""[Output Only] The facilities Interconnects in this metro are present in.

  Fields:
    facility: [Output Only] The ID of this facility, as a numeric string like
      "5467". This is the third component of the location of Interconnects in
      this facility.
    zones: A InterconnectGroupPhysicalStructureMetrosFacilitiesZones
      attribute.
  """

  facility = _messages.StringField(1)
  zones = _messages.MessageField('InterconnectGroupPhysicalStructureMetrosFacilitiesZones', 2, repeated=True)


class InterconnectGroupPhysicalStructureMetrosFacilitiesZones(_messages.Message):
  r"""[Output Only] The zones that Interconnects in this facility are present
  in.

  Fields:
    interconnects: [Output Only] URLs of Interconnects in this redundancy
      group in the given metro, facility, and zone.
    zone: [Output Only] The name of the zone, either "zone1" or "zone2". This
      is the second component of the location of Interconnects in this
      facility.
  """

  interconnects = _messages.StringField(1, repeated=True)
  zone = _messages.StringField(2)


class InterconnectGroupsCreateMembers(_messages.Message):
  r"""A InterconnectGroupsCreateMembers object.

  Enums:
    IntentMismatchBehaviorValueValuesEnum: How to behave when
      configured.topologyCapability.supportedSLA would not equal
      intent.topologyCapability after this call.

  Fields:
    intentMismatchBehavior: How to behave when
      configured.topologyCapability.supportedSLA would not equal
      intent.topologyCapability after this call.
    interconnects: A InterconnectGroupsCreateMembersInterconnectInput
      attribute.
    templateInterconnect: Parameters for the Interconnects to create.
  """

  class IntentMismatchBehaviorValueValuesEnum(_messages.Enum):
    r"""How to behave when configured.topologyCapability.supportedSLA would
    not equal intent.topologyCapability after this call.

    Values:
      CREATE: <no description>
      REJECT: <no description>
      UNSPECIFIED: <no description>
    """
    CREATE = 0
    REJECT = 1
    UNSPECIFIED = 2

  intentMismatchBehavior = _messages.EnumField('IntentMismatchBehaviorValueValuesEnum', 1)
  interconnects = _messages.MessageField('InterconnectGroupsCreateMembersInterconnectInput', 2, repeated=True)
  templateInterconnect = _messages.MessageField('InterconnectGroupsCreateMembersInterconnectInput', 3)


class InterconnectGroupsCreateMembersInterconnectInput(_messages.Message):
  r"""LINT.IfChange

  Enums:
    InterconnectTypeValueValuesEnum: Type of interconnect, which can take one
      of the following values: - PARTNER: A partner-managed interconnection
      shared between customers though a partner. - DEDICATED: A dedicated
      physical interconnection with the customer. Note that a value IT_PRIVATE
      has been deprecated in favor of DEDICATED.
    LinkTypeValueValuesEnum: Type of link requested, which can take one of the
      following values: - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR
      optics - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. -
      LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that
      this field indicates the speed of each of the links in the bundle, not
      the speed of the entire bundle.
    RequestedFeaturesValueListEntryValuesEnum:

  Fields:
    adminEnabled: Administrative status of the interconnect. When this is set
      to true, the Interconnect is functional and can carry traffic. When set
      to false, no packets can be carried over the interconnect and no BGP
      routes are exchanged over it. By default, the status is set to true.
    customerName: Customer name, to put in the Letter of Authorization as the
      party authorized to request a crossconnect.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    facility: A zone-free location to use for all Interconnects created in
      this call, like "iad-1234".
    interconnectType: Type of interconnect, which can take one of the
      following values: - PARTNER: A partner-managed interconnection shared
      between customers though a partner. - DEDICATED: A dedicated physical
      interconnection with the customer. Note that a value IT_PRIVATE has been
      deprecated in favor of DEDICATED.
    linkType: Type of link requested, which can take one of the following
      values: - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics -
      LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. -
      LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that
      this field indicates the speed of each of the links in the bundle, not
      the speed of the entire bundle.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    nocContactEmail: Email address to contact the customer NOC for operations
      and maintenance notifications regarding this Interconnect. If specified,
      this will be used for notifications in addition to all other forms
      described, such as Cloud Monitoring logs alerting and Cloud
      Notifications. This field is required for users who sign up for Cloud
      Interconnect using workforce identity federation.
    remoteLocation: Indicates that this is a Cross-Cloud Interconnect. This
      field specifies the location outside of Google's network that the
      interconnect is connected to.
    requestedFeatures: Optional. List of features requested for this
      Interconnect connection, which can take one of the following values: -
      IF_MACSEC If specified then the connection is created on MACsec capable
      hardware ports. If not specified, the default value is false, which
      allocates non-MACsec capable ports first if available. This parameter
      can be provided only with Interconnect INSERT. It isn't valid for
      Interconnect PATCH.
    requestedLinkCount: Target number of physical links in the link bundle, as
      requested by the customer.
  """

  class InterconnectTypeValueValuesEnum(_messages.Enum):
    r"""Type of interconnect, which can take one of the following values: -
    PARTNER: A partner-managed interconnection shared between customers though
    a partner. - DEDICATED: A dedicated physical interconnection with the
    customer. Note that a value IT_PRIVATE has been deprecated in favor of
    DEDICATED.

    Values:
      DEDICATED: A dedicated physical interconnection with the customer.
      IT_PRIVATE: [Deprecated] A private, physical interconnection with the
        customer.
      PARTNER: A partner-managed interconnection shared between customers via
        partner.
    """
    DEDICATED = 0
    IT_PRIVATE = 1
    PARTNER = 2

  class LinkTypeValueValuesEnum(_messages.Enum):
    r"""Type of link requested, which can take one of the following values: -
    LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics -
    LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. -
    LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that
    this field indicates the speed of each of the links in the bundle, not the
    speed of the entire bundle.

    Values:
      LINK_TYPE_ETHERNET_100G_LR: 100G Ethernet, LR Optics.
      LINK_TYPE_ETHERNET_10G_LR: 10G Ethernet, LR Optics. [(rate_bps) =
        10000000000];
      LINK_TYPE_ETHERNET_400G_LR4: 400G Ethernet, LR4 Optics.
    """
    LINK_TYPE_ETHERNET_100G_LR = 0
    LINK_TYPE_ETHERNET_10G_LR = 1
    LINK_TYPE_ETHERNET_400G_LR4 = 2

  class RequestedFeaturesValueListEntryValuesEnum(_messages.Enum):
    r"""RequestedFeaturesValueListEntryValuesEnum enum type.

    Values:
      IF_CROSS_SITE_NETWORK: Cross-Site Networking
      IF_MACSEC: Media Access Control security (MACsec)
    """
    IF_CROSS_SITE_NETWORK = 0
    IF_MACSEC = 1

  adminEnabled = _messages.BooleanField(1)
  customerName = _messages.StringField(2)
  description = _messages.StringField(3)
  facility = _messages.StringField(4)
  interconnectType = _messages.EnumField('InterconnectTypeValueValuesEnum', 5)
  linkType = _messages.EnumField('LinkTypeValueValuesEnum', 6)
  name = _messages.StringField(7)
  nocContactEmail = _messages.StringField(8)
  remoteLocation = _messages.StringField(9)
  requestedFeatures = _messages.EnumField('RequestedFeaturesValueListEntryValuesEnum', 10, repeated=True)
  requestedLinkCount = _messages.IntegerField(11, variant=_messages.Variant.INT32)


class InterconnectGroupsCreateMembersRequest(_messages.Message):
  r"""A InterconnectGroupsCreateMembersRequest object.

  Fields:
    request: A InterconnectGroupsCreateMembers attribute.
  """

  request = _messages.MessageField('InterconnectGroupsCreateMembers', 1)


class InterconnectGroupsGetOperationalStatusResponse(_messages.Message):
  r"""Response for the InterconnectGroupsGetOperationalStatusResponse.

  Fields:
    etag: A string attribute.
    result: A InterconnectGroupsOperationalStatus attribute.
  """

  etag = _messages.StringField(1)
  result = _messages.MessageField('InterconnectGroupsOperationalStatus', 2)


class InterconnectGroupsListResponse(_messages.Message):
  r"""A InterconnectGroupsListResponse object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectGroup resources.
    kind: A string attribute.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('InterconnectGroup', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#InterconnectGroup')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class InterconnectGroupsOperationalStatus(_messages.Message):
  r"""Request to get the status of the interconnect group with extra detail.

  Enums:
    GroupStatusValueValuesEnum: Summarizes the status of the group.

  Fields:
    configured: The configuration analysis, as returned by Get.
    groupStatus: Summarizes the status of the group.
    intent: The intent of the resource, as returned by Get.
    interconnectStatuses: A
      InterconnectGroupsOperationalStatusInterconnectStatus attribute.
    operational: The operational state of the group, including only active
      Interconnects.
  """

  class GroupStatusValueValuesEnum(_messages.Enum):
    r"""Summarizes the status of the group.

    Values:
      DEGRADED: <no description>
      FULLY_DOWN: <no description>
      FULLY_UP: <no description>
      GROUPS_STATUS_UNSPECIFIED: <no description>
    """
    DEGRADED = 0
    FULLY_DOWN = 1
    FULLY_UP = 2
    GROUPS_STATUS_UNSPECIFIED = 3

  configured = _messages.MessageField('InterconnectGroupConfigured', 1)
  groupStatus = _messages.EnumField('GroupStatusValueValuesEnum', 2)
  intent = _messages.MessageField('InterconnectGroupIntent', 3)
  interconnectStatuses = _messages.MessageField('InterconnectGroupsOperationalStatusInterconnectStatus', 4, repeated=True)
  operational = _messages.MessageField('InterconnectGroupConfigured', 5)


class InterconnectGroupsOperationalStatusInterconnectStatus(_messages.Message):
  r"""The status of one Interconnect in the group. The order is arbitrary.

  Enums:
    IsActiveValueValuesEnum: Whether this interconnect is participating in the
      redundant configuration.

  Fields:
    adminEnabled: Whether the Interconnect is enabled.
    diagnostics: The diagnostics of the Interconnect, as returned by the
      existing get-diagnostics method.
    interconnect: The URL of the Interconnect being described.
    isActive: Whether this interconnect is participating in the redundant
      configuration.
  """

  class IsActiveValueValuesEnum(_messages.Enum):
    r"""Whether this interconnect is participating in the redundant
    configuration.

    Values:
      ACTIVE: <no description>
      INACTIVE: <no description>
      IS_ACTIVE_UNSPECIFIED: <no description>
    """
    ACTIVE = 0
    INACTIVE = 1
    IS_ACTIVE_UNSPECIFIED = 2

  adminEnabled = _messages.BooleanField(1)
  diagnostics = _messages.MessageField('InterconnectDiagnostics', 2)
  interconnect = _messages.StringField(3)
  isActive = _messages.EnumField('IsActiveValueValuesEnum', 4)


class InterconnectList(_messages.Message):
  r"""Response to the list request, and contains a list of interconnects.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Interconnect resources.
    kind: [Output Only] Type of resource. Always compute#interconnectList for
      lists of interconnects.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Interconnect', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#interconnectList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InterconnectLocation(_messages.Message):
  r"""Represents an Interconnect Attachment (VLAN) Location resource. You can
  use this resource to find location details about an Interconnect attachment
  (VLAN). For more information about interconnect attachments, read Creating
  VLAN Attachments.

  Enums:
    AvailableFeaturesValueListEntryValuesEnum:
    AvailableLinkTypesValueListEntryValuesEnum:
    ContinentValueValuesEnum: [Output Only] Continent for this location, which
      can take one of the following values: - AFRICA - ASIA_PAC - EUROPE -
      NORTH_AMERICA - SOUTH_AMERICA
    StatusValueValuesEnum: [Output Only] The status of this
      InterconnectLocation, which can take one of the following values: -
      CLOSED: The InterconnectLocation is closed and is unavailable for
      provisioning new Interconnects. - AVAILABLE: The InterconnectLocation is
      available for provisioning new Interconnects.

  Fields:
    address: [Output Only] The postal address of the Point of Presence, each
      line in the address is separated by a newline character.
    availabilityZone: [Output Only] Availability zone for this
      InterconnectLocation. Within a metropolitan area (metro), maintenance
      will not be simultaneously scheduled in more than one availability zone.
      Example: "zone1" or "zone2".
    availableFeatures: [Output only] List of features available at this
      InterconnectLocation, which can take one of the following values: -
      IF_MACSEC
    availableLinkTypes: [Output only] List of link types available at this
      InterconnectLocation, which can take one of the following values: -
      LINK_TYPE_ETHERNET_10G_LR - LINK_TYPE_ETHERNET_100G_LR
    city: [Output Only] Metropolitan area designator that indicates which city
      an interconnect is located. For example: "Chicago, IL", "Amsterdam,
      Netherlands".
    continent: [Output Only] Continent for this location, which can take one
      of the following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA -
      SOUTH_AMERICA
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    crossSiteInterconnectInfos: [Output Only] A list of
      InterconnectLocation.CrossSiteInterconnectInfo objects, that describe
      where Cross-Site Interconnect wires may connect to from this location
      and associated connection parameters. Cross-Site Interconnect isn't
      allowed to locations which are not listed.
    description: [Output Only] An optional description of the resource.
    facilityProvider: [Output Only] The name of the provider for this facility
      (e.g., EQUINIX).
    facilityProviderFacilityId: [Output Only] A provider-assigned Identifier
      for this facility (e.g., Ashburn-DC1).
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always
      compute#interconnectLocation for interconnect locations.
    name: [Output Only] Name of the resource.
    peeringdbFacilityId: [Output Only] The peeringdb identifier for this
      facility (corresponding with a netfac type in peeringdb).
    regionInfos: [Output Only] A list of InterconnectLocation.RegionInfo
      objects, that describe parameters pertaining to the relation between
      this InterconnectLocation and various Google Cloud regions.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] The status of this InterconnectLocation, which can
      take one of the following values: - CLOSED: The InterconnectLocation is
      closed and is unavailable for provisioning new Interconnects. -
      AVAILABLE: The InterconnectLocation is available for provisioning new
      Interconnects.
    supportsPzs: [Output Only] Reserved for future use.
  """

  class AvailableFeaturesValueListEntryValuesEnum(_messages.Enum):
    r"""AvailableFeaturesValueListEntryValuesEnum enum type.

    Values:
      IF_CROSS_SITE_NETWORK: Cross-Site Networking
      IF_MACSEC: Media Access Control security (MACsec)
    """
    IF_CROSS_SITE_NETWORK = 0
    IF_MACSEC = 1

  class AvailableLinkTypesValueListEntryValuesEnum(_messages.Enum):
    r"""AvailableLinkTypesValueListEntryValuesEnum enum type.

    Values:
      LINK_TYPE_ETHERNET_100G_LR: 100G Ethernet, LR Optics.
      LINK_TYPE_ETHERNET_10G_LR: 10G Ethernet, LR Optics. [(rate_bps) =
        10000000000];
      LINK_TYPE_ETHERNET_400G_LR4: 400G Ethernet, LR4 Optics.
    """
    LINK_TYPE_ETHERNET_100G_LR = 0
    LINK_TYPE_ETHERNET_10G_LR = 1
    LINK_TYPE_ETHERNET_400G_LR4 = 2

  class ContinentValueValuesEnum(_messages.Enum):
    r"""[Output Only] Continent for this location, which can take one of the
    following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA -
    SOUTH_AMERICA

    Values:
      AFRICA: <no description>
      ASIA_PAC: <no description>
      C_AFRICA: <no description>
      C_ASIA_PAC: <no description>
      C_EUROPE: <no description>
      C_NORTH_AMERICA: <no description>
      C_SOUTH_AMERICA: <no description>
      EUROPE: <no description>
      NORTH_AMERICA: <no description>
      SOUTH_AMERICA: <no description>
    """
    AFRICA = 0
    ASIA_PAC = 1
    C_AFRICA = 2
    C_ASIA_PAC = 3
    C_EUROPE = 4
    C_NORTH_AMERICA = 5
    C_SOUTH_AMERICA = 6
    EUROPE = 7
    NORTH_AMERICA = 8
    SOUTH_AMERICA = 9

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of this InterconnectLocation, which can take
    one of the following values: - CLOSED: The InterconnectLocation is closed
    and is unavailable for provisioning new Interconnects. - AVAILABLE: The
    InterconnectLocation is available for provisioning new Interconnects.

    Values:
      AVAILABLE: The InterconnectLocation is available for provisioning new
        Interconnects.
      CLOSED: The InterconnectLocation is closed for provisioning new
        Interconnects.
    """
    AVAILABLE = 0
    CLOSED = 1

  address = _messages.StringField(1)
  availabilityZone = _messages.StringField(2)
  availableFeatures = _messages.EnumField('AvailableFeaturesValueListEntryValuesEnum', 3, repeated=True)
  availableLinkTypes = _messages.EnumField('AvailableLinkTypesValueListEntryValuesEnum', 4, repeated=True)
  city = _messages.StringField(5)
  continent = _messages.EnumField('ContinentValueValuesEnum', 6)
  creationTimestamp = _messages.StringField(7)
  crossSiteInterconnectInfos = _messages.MessageField('InterconnectLocationCrossSiteInterconnectInfo', 8, repeated=True)
  description = _messages.StringField(9)
  facilityProvider = _messages.StringField(10)
  facilityProviderFacilityId = _messages.StringField(11)
  id = _messages.IntegerField(12, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(13, default='compute#interconnectLocation')
  name = _messages.StringField(14)
  peeringdbFacilityId = _messages.StringField(15)
  regionInfos = _messages.MessageField('InterconnectLocationRegionInfo', 16, repeated=True)
  selfLink = _messages.StringField(17)
  selfLinkWithId = _messages.StringField(18)
  status = _messages.EnumField('StatusValueValuesEnum', 19)
  supportsPzs = _messages.BooleanField(20)


class InterconnectLocationCrossSiteInterconnectInfo(_messages.Message):
  r"""Information about Cross-Site Interconnect wires which may be created
  between the containing location and another remote location.

  Fields:
    city: The remote location for Cross-Site Interconnect wires. This
      specifies an InterconnectLocation city (metropolitan area designator),
      which itself may match multiple InterconnectLocations.
    maxSingleFlowGbps: The maximum gbps for a single flow to this metro. This
      limits the total bandwidth which may be configured per wire.
  """

  city = _messages.StringField(1)
  maxSingleFlowGbps = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class InterconnectLocationList(_messages.Message):
  r"""Response to the list request, and contains a list of interconnect
  locations.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectLocation resources.
    kind: [Output Only] Type of resource. Always
      compute#interconnectLocationList for lists of interconnect locations.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InterconnectLocation', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#interconnectLocationList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InterconnectLocationRegionInfo(_messages.Message):
  r"""Information about any potential InterconnectAttachments between an
  Interconnect at a specific InterconnectLocation, and a specific Cloud
  Region.

  Enums:
    LocationPresenceValueValuesEnum: Identifies the network presence of this
      location.

  Fields:
    expectedRttMs: Expected round-trip time in milliseconds, from this
      InterconnectLocation to a VM in this region.
    locationPresence: Identifies the network presence of this location.
    region: URL for the region of this location.
  """

  class LocationPresenceValueValuesEnum(_messages.Enum):
    r"""Identifies the network presence of this location.

    Values:
      GLOBAL: This region is not in any common network presence with this
        InterconnectLocation.
      LOCAL_REGION: This region shares the same regional network presence as
        this InterconnectLocation.
      LP_GLOBAL: [Deprecated] This region is not in any common network
        presence with this InterconnectLocation.
      LP_LOCAL_REGION: [Deprecated] This region shares the same regional
        network presence as this InterconnectLocation.
    """
    GLOBAL = 0
    LOCAL_REGION = 1
    LP_GLOBAL = 2
    LP_LOCAL_REGION = 3

  expectedRttMs = _messages.IntegerField(1)
  locationPresence = _messages.EnumField('LocationPresenceValueValuesEnum', 2)
  region = _messages.StringField(3)


class InterconnectMacsec(_messages.Message):
  r"""Configuration information for enabling Media Access Control security
  (MACsec) on this Cloud Interconnect connection between Google and your on-
  premises router.

  Fields:
    failOpen: If set to true, the Interconnect connection is configured with a
      should-secure MACsec security policy, that allows the Google router to
      fallback to cleartext traffic if the MKA session cannot be established.
      By default, the Interconnect connection is configured with a must-secure
      security policy that drops all traffic if the MKA session cannot be
      established with your router.
    preSharedKeys: Required. A keychain placeholder describing a set of named
      key objects along with their start times. A MACsec CKN/CAK is generated
      for each key in the key chain. Google router automatically picks the key
      with the most recent startTime when establishing or re-establishing a
      MACsec secure link.
  """

  failOpen = _messages.BooleanField(1)
  preSharedKeys = _messages.MessageField('InterconnectMacsecPreSharedKey', 2, repeated=True)


class InterconnectMacsecConfig(_messages.Message):
  r"""MACsec configuration information for the Interconnect connection.
  Contains the generated Connectivity Association Key Name (CKN) and the key
  (CAK) for this Interconnect connection.

  Fields:
    preSharedKeys: A keychain placeholder describing a set of named key
      objects along with their start times. A MACsec CKN/CAK is generated for
      each key in the key chain. Google router automatically picks the key
      with the most recent startTime when establishing or re-establishing a
      MACsec secure link.
  """

  preSharedKeys = _messages.MessageField('InterconnectMacsecConfigPreSharedKey', 1, repeated=True)


class InterconnectMacsecConfigPreSharedKey(_messages.Message):
  r"""Describes a pre-shared key used to setup MACsec in static connectivity
  association key (CAK) mode.

  Fields:
    cak: An auto-generated Connectivity Association Key (CAK) for this key.
    ckn: An auto-generated Connectivity Association Key Name (CKN) for this
      key.
    name: User provided name for this pre-shared key.
    startTime: User provided timestamp on or after which this key is valid.
  """

  cak = _messages.StringField(1)
  ckn = _messages.StringField(2)
  name = _messages.StringField(3)
  startTime = _messages.StringField(4)


class InterconnectMacsecPreSharedKey(_messages.Message):
  r"""Describes a pre-shared key used to setup MACsec in static connectivity
  association key (CAK) mode.

  Fields:
    name: Required. A name for this pre-shared key. The name must be 1-63
      characters long, and comply with RFC1035. Specifically, the name must be
      1-63 characters long and match the regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a
      lowercase letter, and all following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash.
    startTime: A RFC3339 timestamp on or after which the key is valid.
      startTime can be in the future. If the keychain has a single key,
      startTime can be omitted. If the keychain has multiple keys, startTime
      is mandatory for each key. The start times of keys must be in increasing
      order. The start times of two consecutive keys must be at least 6 hours
      apart.
  """

  name = _messages.StringField(1)
  startTime = _messages.StringField(2)


class InterconnectOutageNotification(_messages.Message):
  r"""Description of a planned outage on this Interconnect.

  Enums:
    IssueTypeValueValuesEnum: Form this outage is expected to take, which can
      take one of the following values: - OUTAGE: The Interconnect may be
      completely out of service for some or all of the specified window. -
      PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
      should remain up, but with reduced bandwidth. Note that the versions of
      this enum prefixed with "IT_" have been deprecated in favor of the
      unprefixed values.
    SourceValueValuesEnum: The party that generated this notification, which
      can take the following value: - GOOGLE: this notification as generated
      by Google. Note that the value of NSRC_GOOGLE has been deprecated in
      favor of GOOGLE.
    StateValueValuesEnum: State of this notification, which can take one of
      the following values: - ACTIVE: This outage notification is active. The
      event could be in the past, present, or future. See start_time and
      end_time for scheduling. - CANCELLED: The outage associated with this
      notification was cancelled before the outage was due to start. -
      COMPLETED: The outage associated with this notification is complete.
      Note that the versions of this enum prefixed with "NS_" have been
      deprecated in favor of the unprefixed values.

  Fields:
    affectedCircuits: If issue_type is IT_PARTIAL_OUTAGE, a list of the
      Google-side circuit IDs that will be affected.
    description: A description about the purpose of the outage.
    endTime: Scheduled end time for the outage (milliseconds since Unix
      epoch).
    issueType: Form this outage is expected to take, which can take one of the
      following values: - OUTAGE: The Interconnect may be completely out of
      service for some or all of the specified window. - PARTIAL_OUTAGE: Some
      circuits comprising the Interconnect as a whole should remain up, but
      with reduced bandwidth. Note that the versions of this enum prefixed
      with "IT_" have been deprecated in favor of the unprefixed values.
    name: Unique identifier for this outage notification.
    source: The party that generated this notification, which can take the
      following value: - GOOGLE: this notification as generated by Google.
      Note that the value of NSRC_GOOGLE has been deprecated in favor of
      GOOGLE.
    startTime: Scheduled start time for the outage (milliseconds since Unix
      epoch).
    state: State of this notification, which can take one of the following
      values: - ACTIVE: This outage notification is active. The event could be
      in the past, present, or future. See start_time and end_time for
      scheduling. - CANCELLED: The outage associated with this notification
      was cancelled before the outage was due to start. - COMPLETED: The
      outage associated with this notification is complete. Note that the
      versions of this enum prefixed with "NS_" have been deprecated in favor
      of the unprefixed values.
  """

  class IssueTypeValueValuesEnum(_messages.Enum):
    r"""Form this outage is expected to take, which can take one of the
    following values: - OUTAGE: The Interconnect may be completely out of
    service for some or all of the specified window. - PARTIAL_OUTAGE: Some
    circuits comprising the Interconnect as a whole should remain up, but with
    reduced bandwidth. Note that the versions of this enum prefixed with "IT_"
    have been deprecated in favor of the unprefixed values.

    Values:
      IT_OUTAGE: [Deprecated] The Interconnect may be completely out of
        service for some or all of the specified window.
      IT_PARTIAL_OUTAGE: [Deprecated] Some circuits comprising the
        Interconnect will be out of service during the expected window. The
        interconnect as a whole should remain up, albeit with reduced
        bandwidth.
      OUTAGE: The Interconnect may be completely out of service for some or
        all of the specified window.
      PARTIAL_OUTAGE: Some circuits comprising the Interconnect will be out of
        service during the expected window. The interconnect as a whole should
        remain up, albeit with reduced bandwidth.
    """
    IT_OUTAGE = 0
    IT_PARTIAL_OUTAGE = 1
    OUTAGE = 2
    PARTIAL_OUTAGE = 3

  class SourceValueValuesEnum(_messages.Enum):
    r"""The party that generated this notification, which can take the
    following value: - GOOGLE: this notification as generated by Google. Note
    that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.

    Values:
      GOOGLE: This notification was generated by Google.
      NSRC_GOOGLE: [Deprecated] This notification was generated by Google.
    """
    GOOGLE = 0
    NSRC_GOOGLE = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""State of this notification, which can take one of the following
    values: - ACTIVE: This outage notification is active. The event could be
    in the past, present, or future. See start_time and end_time for
    scheduling. - CANCELLED: The outage associated with this notification was
    cancelled before the outage was due to start. - COMPLETED: The outage
    associated with this notification is complete. Note that the versions of
    this enum prefixed with "NS_" have been deprecated in favor of the
    unprefixed values.

    Values:
      ACTIVE: This outage notification is active. The event could be in the
        future, present, or past. See start_time and end_time for scheduling.
      CANCELLED: The outage associated with this notification was cancelled
        before the outage was due to start.
      COMPLETED: The outage associated with this notification is complete.
      NS_ACTIVE: [Deprecated] This outage notification is active. The event
        could be in the future, present, or past. See start_time and end_time
        for scheduling.
      NS_CANCELED: [Deprecated] The outage associated with this notification
        was canceled before the outage was due to start.
    """
    ACTIVE = 0
    CANCELLED = 1
    COMPLETED = 2
    NS_ACTIVE = 3
    NS_CANCELED = 4

  affectedCircuits = _messages.StringField(1, repeated=True)
  description = _messages.StringField(2)
  endTime = _messages.IntegerField(3)
  issueType = _messages.EnumField('IssueTypeValueValuesEnum', 4)
  name = _messages.StringField(5)
  source = _messages.EnumField('SourceValueValuesEnum', 6)
  startTime = _messages.IntegerField(7)
  state = _messages.EnumField('StateValueValuesEnum', 8)


class InterconnectRemoteLocation(_messages.Message):
  r"""Represents a Cross-Cloud Interconnect Remote Location resource. You can
  use this resource to find remote location details about an Interconnect
  attachment (VLAN).

  Enums:
    ContinentValueValuesEnum: [Output Only] Continent for this location, which
      can take one of the following values: - AFRICA - ASIA_PAC - EUROPE -
      NORTH_AMERICA - SOUTH_AMERICA
    LacpValueValuesEnum: [Output Only] Link Aggregation Control Protocol
      (LACP) constraints, which can take one of the following values:
      LACP_SUPPORTED, LACP_UNSUPPORTED
    StatusValueValuesEnum: [Output Only] The status of this
      InterconnectRemoteLocation, which can take one of the following values:
      - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
      for provisioning new Cross-Cloud Interconnects. - AVAILABLE: The
      InterconnectRemoteLocation is available for provisioning new Cross-Cloud
      Interconnects.

  Fields:
    address: [Output Only] The postal address of the Point of Presence, each
      line in the address is separated by a newline character.
    attachmentConfigurationConstraints: [Output Only] Subset of fields from
      InterconnectAttachment's |configurationConstraints| field that apply to
      all attachments for this remote location.
    city: [Output Only] Metropolitan area designator that indicates which city
      an interconnect is located. For example: "Chicago, IL", "Amsterdam,
      Netherlands".
    constraints: [Output Only] Constraints on the parameters for creating
      Cross-Cloud Interconnect and associated InterconnectAttachments.
    continent: [Output Only] Continent for this location, which can take one
      of the following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA -
      SOUTH_AMERICA
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: [Output Only] An optional description of the resource.
    facilityProvider: [Output Only] The name of the provider for this facility
      (e.g., EQUINIX).
    facilityProviderFacilityId: [Output Only] A provider-assigned Identifier
      for this facility (e.g., Ashburn-DC1).
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always
      compute#interconnectRemoteLocation for interconnect remote locations.
    lacp: [Output Only] Link Aggregation Control Protocol (LACP) constraints,
      which can take one of the following values: LACP_SUPPORTED,
      LACP_UNSUPPORTED
    maxLagSize100Gbps: [Output Only] The maximum number of 100 Gbps ports
      supported in a link aggregation group (LAG). When linkType is 100 Gbps,
      requestedLinkCount cannot exceed max_lag_size_100_gbps.
    maxLagSize10Gbps: [Output Only] The maximum number of 10 Gbps ports
      supported in a link aggregation group (LAG). When linkType is 10 Gbps,
      requestedLinkCount cannot exceed max_lag_size_10_gbps.
    name: [Output Only] Name of the resource.
    peeringdbFacilityId: [Output Only] The peeringdb identifier for this
      facility (corresponding with a netfac type in peeringdb).
    permittedConnections: [Output Only] Permitted connections.
    remoteService: [Output Only] Indicates the service provider present at the
      remote location. Example values: "Amazon Web Services", "Microsoft
      Azure".
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] The status of this InterconnectRemoteLocation, which
      can take one of the following values: - CLOSED: The
      InterconnectRemoteLocation is closed and is unavailable for provisioning
      new Cross-Cloud Interconnects. - AVAILABLE: The
      InterconnectRemoteLocation is available for provisioning new Cross-Cloud
      Interconnects.
  """

  class ContinentValueValuesEnum(_messages.Enum):
    r"""[Output Only] Continent for this location, which can take one of the
    following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA -
    SOUTH_AMERICA

    Values:
      AFRICA: <no description>
      ASIA_PAC: <no description>
      EUROPE: <no description>
      NORTH_AMERICA: <no description>
      SOUTH_AMERICA: <no description>
    """
    AFRICA = 0
    ASIA_PAC = 1
    EUROPE = 2
    NORTH_AMERICA = 3
    SOUTH_AMERICA = 4

  class LacpValueValuesEnum(_messages.Enum):
    r"""[Output Only] Link Aggregation Control Protocol (LACP) constraints,
    which can take one of the following values: LACP_SUPPORTED,
    LACP_UNSUPPORTED

    Values:
      LACP_SUPPORTED: LACP_SUPPORTED: LACP is supported, and enabled by
        default on the Cross-Cloud Interconnect.
      LACP_UNSUPPORTED: LACP_UNSUPPORTED: LACP is not supported and is not be
        enabled on this port. GetDiagnostics shows bundleAggregationType as
        "static". GCP does not support LAGs without LACP, so
        requestedLinkCount must be 1.
    """
    LACP_SUPPORTED = 0
    LACP_UNSUPPORTED = 1

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of this InterconnectRemoteLocation, which can
    take one of the following values: - CLOSED: The InterconnectRemoteLocation
    is closed and is unavailable for provisioning new Cross-Cloud
    Interconnects. - AVAILABLE: The InterconnectRemoteLocation is available
    for provisioning new Cross-Cloud Interconnects.

    Values:
      AVAILABLE: The InterconnectRemoteLocation is available for provisioning
        new Cross-Cloud Interconnects.
      CLOSED: The InterconnectRemoteLocation is closed for provisioning new
        Cross-Cloud Interconnects.
    """
    AVAILABLE = 0
    CLOSED = 1

  address = _messages.StringField(1)
  attachmentConfigurationConstraints = _messages.MessageField('InterconnectAttachmentConfigurationConstraints', 2)
  city = _messages.StringField(3)
  constraints = _messages.MessageField('InterconnectRemoteLocationConstraints', 4)
  continent = _messages.EnumField('ContinentValueValuesEnum', 5)
  creationTimestamp = _messages.StringField(6)
  description = _messages.StringField(7)
  facilityProvider = _messages.StringField(8)
  facilityProviderFacilityId = _messages.StringField(9)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(11, default='compute#interconnectRemoteLocation')
  lacp = _messages.EnumField('LacpValueValuesEnum', 12)
  maxLagSize100Gbps = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  maxLagSize10Gbps = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  name = _messages.StringField(15)
  peeringdbFacilityId = _messages.StringField(16)
  permittedConnections = _messages.MessageField('InterconnectRemoteLocationPermittedConnections', 17, repeated=True)
  remoteService = _messages.StringField(18)
  selfLink = _messages.StringField(19)
  selfLinkWithId = _messages.StringField(20)
  status = _messages.EnumField('StatusValueValuesEnum', 21)


class InterconnectRemoteLocationConstraints(_messages.Message):
  r"""A InterconnectRemoteLocationConstraints object.

  Enums:
    PortPairRemoteLocationValueValuesEnum: [Output Only] Port pair remote
      location constraints, which can take one of the following values:
      PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
      PORT_PAIR_MATCHING_REMOTE_LOCATION. Google Cloud API refers only to
      individual ports, but the UI uses this field when ordering a pair of
      ports, to prevent users from accidentally ordering something that is
      incompatible with their cloud provider. Specifically, when ordering a
      redundant pair of Cross-Cloud Interconnect ports, and one of them uses a
      remote location with portPairMatchingRemoteLocation set to matching, the
      UI requires that both ports use the same remote location.
    PortPairVlanValueValuesEnum: [Output Only] Port pair VLAN constraints,
      which can take one of the following values:
      PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN

  Fields:
    portPairRemoteLocation: [Output Only] Port pair remote location
      constraints, which can take one of the following values:
      PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
      PORT_PAIR_MATCHING_REMOTE_LOCATION. Google Cloud API refers only to
      individual ports, but the UI uses this field when ordering a pair of
      ports, to prevent users from accidentally ordering something that is
      incompatible with their cloud provider. Specifically, when ordering a
      redundant pair of Cross-Cloud Interconnect ports, and one of them uses a
      remote location with portPairMatchingRemoteLocation set to matching, the
      UI requires that both ports use the same remote location.
    portPairVlan: [Output Only] Port pair VLAN constraints, which can take one
      of the following values: PORT_PAIR_UNCONSTRAINED_VLAN,
      PORT_PAIR_MATCHING_VLAN
    subnetLengthRange: [Output Only] [min-length, max-length] The minimum and
      maximum value (inclusive) for the IPv4 subnet length. For example, an
      interconnectRemoteLocation for Azure has {min: 30, max: 30} because
      Azure requires /30 subnets. This range specifies the values supported by
      both cloud providers. Interconnect currently supports /29 and /30 IPv4
      subnet lengths. If a remote cloud has no constraint on IPv4 subnet
      length, the range would thus be {min: 29, max: 30}.
  """

  class PortPairRemoteLocationValueValuesEnum(_messages.Enum):
    r"""[Output Only] Port pair remote location constraints, which can take
    one of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
    PORT_PAIR_MATCHING_REMOTE_LOCATION. Google Cloud API refers only to
    individual ports, but the UI uses this field when ordering a pair of
    ports, to prevent users from accidentally ordering something that is
    incompatible with their cloud provider. Specifically, when ordering a
    redundant pair of Cross-Cloud Interconnect ports, and one of them uses a
    remote location with portPairMatchingRemoteLocation set to matching, the
    UI requires that both ports use the same remote location.

    Values:
      PORT_PAIR_MATCHING_REMOTE_LOCATION: If
        PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider
        allocates ports in pairs, and the user should choose the same remote
        location for both ports.
      PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION: If
        PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision a
        redundant pair of Cross-Cloud Interconnects using two different remote
        locations in the same city.
    """
    PORT_PAIR_MATCHING_REMOTE_LOCATION = 0
    PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 1

  class PortPairVlanValueValuesEnum(_messages.Enum):
    r"""[Output Only] Port pair VLAN constraints, which can take one of the
    following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN

    Values:
      PORT_PAIR_MATCHING_VLAN: If PORT_PAIR_MATCHING_VLAN, the Interconnect
        for this attachment is part of a pair of ports that should have
        matching VLAN allocations. This occurs with Cross-Cloud Interconnect
        to Azure remote locations. While GCP's API does not explicitly group
        pairs of ports, the UI uses this field to ensure matching VLAN ids
        when configuring a redundant VLAN pair.
      PORT_PAIR_UNCONSTRAINED_VLAN: PORT_PAIR_UNCONSTRAINED_VLAN means there
        is no constraint.
    """
    PORT_PAIR_MATCHING_VLAN = 0
    PORT_PAIR_UNCONSTRAINED_VLAN = 1

  portPairRemoteLocation = _messages.EnumField('PortPairRemoteLocationValueValuesEnum', 1)
  portPairVlan = _messages.EnumField('PortPairVlanValueValuesEnum', 2)
  subnetLengthRange = _messages.MessageField('InterconnectRemoteLocationConstraintsSubnetLengthRange', 3)


class InterconnectRemoteLocationConstraintsSubnetLengthRange(_messages.Message):
  r"""A InterconnectRemoteLocationConstraintsSubnetLengthRange object.

  Fields:
    max: A integer attribute.
    min: A integer attribute.
  """

  max = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  min = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class InterconnectRemoteLocationList(_messages.Message):
  r"""Response to the list request, and contains a list of interconnect remote
  locations.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectRemoteLocation resources.
    kind: [Output Only] Type of resource. Always
      compute#interconnectRemoteLocationList for lists of interconnect remote
      locations.
    nextPageToken: [Output Only] This token lets you get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InterconnectRemoteLocation', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#interconnectRemoteLocationList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InterconnectRemoteLocationPermittedConnections(_messages.Message):
  r"""A InterconnectRemoteLocationPermittedConnections object.

  Fields:
    interconnectLocation: [Output Only] URL of an Interconnect location that
      is permitted to connect to this Interconnect remote location.
  """

  interconnectLocation = _messages.StringField(1)


class InterconnectsGetDiagnosticsResponse(_messages.Message):
  r"""Response for the InterconnectsGetDiagnosticsRequest.

  Fields:
    result: A InterconnectDiagnostics attribute.
  """

  result = _messages.MessageField('InterconnectDiagnostics', 1)


class InterconnectsGetMacsecConfigResponse(_messages.Message):
  r"""Response for the InterconnectsGetMacsecConfigRequest.

  Fields:
    etag: end_interface: MixerGetResponseWithEtagBuilder
    result: A InterconnectMacsecConfig attribute.
  """

  etag = _messages.StringField(1)
  result = _messages.MessageField('InterconnectMacsecConfig', 2)


class InternalIpAddress(_messages.Message):
  r"""A InternalIpAddress object.

  Enums:
    TypeValueValuesEnum: The type of the internal IP address.

  Fields:
    cidr: IP CIDR address or range.
    owner: The owner of the internal IP address.
    purpose: The purpose of the internal IP address if applicable.
    region: The region of the internal IP address if applicable.
    type: The type of the internal IP address.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of the internal IP address.

    Values:
      PEER_RESERVED: Reserved IP ranges on peer networks.
      PEER_USED: Used IP ranges on peer networks, including peer subnetwork IP
        ranges.
      REMOTE_RESERVED: Reserved IP ranges on peer networks of peer networks.
      REMOTE_USED: Used IP ranges on peer networks of peer networks.
      RESERVED: Reserved IP ranges on local network.
      SUBNETWORK: Subnetwork IP ranges on local network.
      TYPE_UNSPECIFIED: <no description>
    """
    PEER_RESERVED = 0
    PEER_USED = 1
    REMOTE_RESERVED = 2
    REMOTE_USED = 3
    RESERVED = 4
    SUBNETWORK = 5
    TYPE_UNSPECIFIED = 6

  cidr = _messages.StringField(1)
  owner = _messages.StringField(2)
  purpose = _messages.StringField(3)
  region = _messages.StringField(4)
  type = _messages.EnumField('TypeValueValuesEnum', 5)


class InternalIpOwner(_messages.Message):
  r"""A InternalIpOwner object.

  Fields:
    ipCidrRange: IP CIDR range being owned.
    owners: URLs of the IP owners of the IP CIDR range.
    systemOwned: Whether this IP CIDR range is reserved for system use.
  """

  ipCidrRange = _messages.StringField(1)
  owners = _messages.StringField(2, repeated=True)
  systemOwned = _messages.BooleanField(3)


class IpAddressesList(_messages.Message):
  r"""A IpAddressesList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InternalIpAddress resources.
    kind: [Output Only] Type of resource. Always compute#ipAddressesList for
      IP addresses lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InternalIpAddress', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#ipAddressesList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class IpOwnerList(_messages.Message):
  r"""Contains a list of IP owners.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InternalIpOwner resources.
    kind: [Output Only] Type of resource. Always compute#ipOwnerList for lists
      of IP owners.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InternalIpOwner', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#ipOwnerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class Jwt(_messages.Message):
  r"""[Deprecated] JWT configuration for origin authentication. JWT
  configuration for origin authentication.

  Fields:
    audiences: A JWT containing any of these audiences will be accepted. The
      service name will be accepted if audiences is empty. Examples:
      bookstore_android.apps.googleusercontent.com,
      bookstore_web.apps.googleusercontent.com
    issuer: Identifies the issuer that issued the JWT, which is usually a URL
      or an email address. Examples: https://securetoken.google.com,
      1234567-compute@developer.gserviceaccount.com
    jwksPublicKeys: The provider's public key set to validate the signature of
      the JWT.
    jwtHeaders: jwt_headers and jwt_params define where to extract the JWT
      from an HTTP request. If no explicit location is specified, the
      following default locations are tried in order: 1. The Authorization
      header using the Bearer schema. See `here `_. Example: Authorization:
      Bearer . 2. `access_token` query parameter. See `this `_ Multiple JWTs
      can be verified for a request. Each JWT has to be extracted from the
      locations its issuer specified or from the default locations. This field
      is set if JWT is sent in a request header. This field specifies the
      header name. For example, if `header=x-goog-iap-jwt-assertion`, the
      header format will be x-goog-iap-jwt-assertion: .
    jwtParams: This field is set if JWT is sent in a query parameter. This
      field specifies the query parameter name. For example, if jwt_params[0]
      is jwt_token, the JWT format in the query parameter is /path?jwt_token=.
  """

  audiences = _messages.StringField(1, repeated=True)
  issuer = _messages.StringField(2)
  jwksPublicKeys = _messages.StringField(3)
  jwtHeaders = _messages.MessageField('JwtHeader', 4, repeated=True)
  jwtParams = _messages.StringField(5, repeated=True)


class JwtHeader(_messages.Message):
  r"""[Deprecated] This message specifies a header location to extract JWT
  token. This message specifies a header location to extract JWT token.

  Fields:
    name: The HTTP header name.
    valuePrefix: The value prefix. The value format is "value_prefix" For
      example, for "Authorization: Bearer ", value_prefix="Bearer " with a
      space at the end.
  """

  name = _messages.StringField(1)
  valuePrefix = _messages.StringField(2)


class License(_messages.Message):
  r"""Represents a License resource. A License represents billing and
  aggregate usage data for public and marketplace images. *Caution* This
  resource is intended for use only by third-party partners who are creating
  Cloud Marketplace images.

  Fields:
    allowedReplacementLicenses: Specifies licenseCodes of licenses that can
      replace this license. Note: such replacements are allowed even if
      removable_from_disk is false.
    appendableToDisk: If true, this license can be appended to an existing
      disk's set of licenses.
    chargesUseFee: [Output Only] Deprecated. This field no longer reflects
      whether a license charges a usage fee.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional textual description of the resource; provided by
      the client when the resource is created.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    incompatibleLicenses: Specifies licenseCodes of licenses that are
      incompatible with this license. If a license is incompatible with this
      license, it cannot be attached to the same disk or image.
    kind: [Output Only] Type of resource. Always compute#license for licenses.
    licenseCode: [Output Only] The unique code used to attach this license to
      images, snapshots, and disks.
    minimumRetention: If set, this license will be unable to be removed or
      replaced once attached to a disk until the minimum_retention period has
      passed.
    multiTenantOnly: If true, this license can only be used on VMs on multi
      tenant nodes.
    name: Name of the resource. The name must be 1-63 characters long and
      comply with RFC1035.
    osLicense: If true, indicates this is an OS license. Only one OS license
      can be attached to a disk or image at a time.
    removableFromDisk: If true, this license can be removed from a disk's set
      of licenses, with no replacement license needed.
    requiredCoattachedLicenses: Specifies the set of permissible coattached
      licenseCodes of licenses that satisfy the coattachment requirement of
      this license. At least one license from the set must be attached to the
      same disk or image as this license.
    resourceRequirements: [Input Only] Deprecated.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    soleTenantOnly: If true, this license can only be used on VMs on sole
      tenant nodes.
    transferable: If false, licenses will not be copied from the source
      resource when creating an image from a disk, disk from snapshot, or
      snapshot from disk.
    updateTimestamp: [Output Only] Last update timestamp in RFC3339 text
      format.
  """

  allowedReplacementLicenses = _messages.StringField(1, repeated=True)
  appendableToDisk = _messages.BooleanField(2)
  chargesUseFee = _messages.BooleanField(3)
  creationTimestamp = _messages.StringField(4)
  description = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  incompatibleLicenses = _messages.StringField(7, repeated=True)
  kind = _messages.StringField(8, default='compute#license')
  licenseCode = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  minimumRetention = _messages.MessageField('Duration', 10)
  multiTenantOnly = _messages.BooleanField(11)
  name = _messages.StringField(12)
  osLicense = _messages.BooleanField(13)
  removableFromDisk = _messages.BooleanField(14)
  requiredCoattachedLicenses = _messages.StringField(15, repeated=True)
  resourceRequirements = _messages.MessageField('LicenseResourceRequirements', 16)
  selfLink = _messages.StringField(17)
  selfLinkWithId = _messages.StringField(18)
  soleTenantOnly = _messages.BooleanField(19)
  transferable = _messages.BooleanField(20)
  updateTimestamp = _messages.StringField(21)


class LicenseCode(_messages.Message):
  r"""Represents a License Code resource. A License Code is a unique
  identifier used to represent a license resource. *Caution* This resource is
  intended for use only by third-party partners who are creating Cloud
  Marketplace images.

  Enums:
    StateValueValuesEnum: [Output Only] Current state of this License Code.

  Fields:
    allowedReplacementLicenses: Specifies licenseCodes of licenses that can
      replace this license. Note: such replacements are allowed even if
      removable_from_disk is false.
    appendableToDisk: If true, this license can be appended to an existing
      disk's set of licenses.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: [Output Only] Description of this License Code.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    incompatibleLicenses: Specifies licenseCodes of licenses that are
      incompatible with this license. If a license is incompatible with this
      license, it cannot be attached to the same disk or image.
    kind: [Output Only] Type of resource. Always compute#licenseCode for
      licenses.
    licenseAlias: [Output Only] URL and description aliases of Licenses with
      the same License Code.
    minimumRetention: If set, this license will be unable to be removed or
      replaced once attached to a disk until the minimum_retention period has
      passed.
    multiTenantOnly: If true, this license can only be used on VMs on multi
      tenant nodes.
    name: [Output Only] Name of the resource. The name is 1-20 characters long
      and must be a valid 64 bit integer.
    osLicense: If true, indicates this is an OS license. Only one OS license
      can be attached to a disk or image at a time.
    removableFromDisk: If true, this license can be removed from a disk's set
      of licenses, with no replacement license needed.
    requiredCoattachedLicenses: Specifies the set of permissible coattached
      licenseCodes of licenses that satisfy the coattachment requirement of
      this license. At least one license from the set must be attached to the
      same disk or image as this license.
    selfLink: [Output Only] Server-defined URL for the resource.
    soleTenantOnly: If true, this license can only be used on VMs on sole
      tenant nodes.
    state: [Output Only] Current state of this License Code.
    transferable: [Output Only] If true, the license will remain attached when
      creating images or snapshots from disks. Otherwise, the license is not
      transferred.
    updateTimestamp: [Output Only] Last update timestamp in RFC3339 text
      format.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] Current state of this License Code.

    Values:
      DISABLED: Machines are not allowed to attach boot disks with this
        License Code. Requests to create new resources with this license will
        be rejected.
      ENABLED: Use is allowed for anyone with USE_READ_ONLY access to this
        License Code.
      RESTRICTED: Use of this license is limited to a project whitelist.
      STATE_UNSPECIFIED: <no description>
      TERMINATED: Reserved state.
    """
    DISABLED = 0
    ENABLED = 1
    RESTRICTED = 2
    STATE_UNSPECIFIED = 3
    TERMINATED = 4

  allowedReplacementLicenses = _messages.StringField(1, repeated=True)
  appendableToDisk = _messages.BooleanField(2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  incompatibleLicenses = _messages.StringField(6, repeated=True)
  kind = _messages.StringField(7, default='compute#licenseCode')
  licenseAlias = _messages.MessageField('LicenseCodeLicenseAlias', 8, repeated=True)
  minimumRetention = _messages.MessageField('Duration', 9)
  multiTenantOnly = _messages.BooleanField(10)
  name = _messages.StringField(11)
  osLicense = _messages.BooleanField(12)
  removableFromDisk = _messages.BooleanField(13)
  requiredCoattachedLicenses = _messages.StringField(14, repeated=True)
  selfLink = _messages.StringField(15)
  soleTenantOnly = _messages.BooleanField(16)
  state = _messages.EnumField('StateValueValuesEnum', 17)
  transferable = _messages.BooleanField(18)
  updateTimestamp = _messages.StringField(19)


class LicenseCodeLicenseAlias(_messages.Message):
  r"""A LicenseCodeLicenseAlias object.

  Fields:
    description: [Output Only] Description of this License Code.
    selfLink: [Output Only] URL of license corresponding to this License Code.
  """

  description = _messages.StringField(1)
  selfLink = _messages.StringField(2)


class LicenseResourceCommitment(_messages.Message):
  r"""Commitment for a particular license resource.

  Fields:
    amount: The number of licenses you plan to purchase.
    coresPerLicense: The number of cores per license.
    license: The applicable license URI.
  """

  amount = _messages.IntegerField(1)
  coresPerLicense = _messages.StringField(2)
  license = _messages.StringField(3)


class LicenseResourceRequirements(_messages.Message):
  r"""A LicenseResourceRequirements object.

  Fields:
    minGuestCpuCount: [Input Only] Deprecated. This field no longer reflects
      the minimum number of guest cpus required to use the Instance.
    minMemoryMb: [Input Only] Deprecated. This field no longer reflects the
      minimum memory required to use the Instance.
  """

  minGuestCpuCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  minMemoryMb = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class LicensesListResponse(_messages.Message):
  r"""A LicensesListResponse object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of License resources.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('License', 2, repeated=True)
  nextPageToken = _messages.StringField(3)
  selfLink = _messages.StringField(4)
  warning = _messages.MessageField('WarningValue', 5)


class ListInstantSnapshotGroups(_messages.Message):
  r"""Contains a list of InstantSnapshotGroup resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstantSnapshotGroup resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('InstantSnapshotGroup', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#instantSnapshotGroupsList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class ListSnapshotGroups(_messages.Message):
  r"""Contains a list of SnapshotGroup resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SnapshotGroup resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('SnapshotGroup', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#snapshotGroupsList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class LocalDisk(_messages.Message):
  r"""A LocalDisk object.

  Fields:
    diskCount: Specifies the number of such disks.
    diskSizeGb: Specifies the size of the disk in base-2 GB.
    diskType: Specifies the desired disk type on the node. This disk type must
      be a local storage type (e.g.: local-ssd). Note that for nodeTemplates,
      this should be the name of the disk type and not its URL.
  """

  diskCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  diskSizeGb = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  diskType = _messages.StringField(3)


class LocalizedMessage(_messages.Message):
  r"""Provides a localized error message that is safe to return to the user
  which can be attached to an RPC error.

  Fields:
    locale: The locale used following the specification defined at
      https://www.rfc-editor.org/rfc/bcp/bcp47.txt. Examples are: "en-US",
      "fr-CH", "es-MX"
    message: The localized error message in the above locale.
  """

  locale = _messages.StringField(1)
  message = _messages.StringField(2)


class LocationPolicy(_messages.Message):
  r"""Configuration for location policy among multiple possible locations
  (e.g. preferences for zone selection among zones in a single region).

  Enums:
    TargetShapeValueValuesEnum: Strategy for distributing VMs across zones in
      a region.

  Messages:
    LocationsValue: Location configurations mapped by location name. Currently
      only zone names are supported and must be represented as valid internal
      URLs, such as zones/us-central1-a.

  Fields:
    locations: Location configurations mapped by location name. Currently only
      zone names are supported and must be represented as valid internal URLs,
      such as zones/us-central1-a.
    targetShape: Strategy for distributing VMs across zones in a region.
  """

  class TargetShapeValueValuesEnum(_messages.Enum):
    r"""Strategy for distributing VMs across zones in a region.

    Values:
      ANY: GCE picks zones for creating VM instances to fulfill the requested
        number of VMs within present resource constraints and to maximize
        utilization of unused zonal reservations. Recommended for batch
        workloads that do not require high availability.
      ANY_SINGLE_ZONE: GCE always selects a single zone for all the VMs,
        optimizing for resource quotas, available reservations and general
        capacity. Recommended for batch workloads that cannot tollerate
        distribution over multiple zones. This the default shape in Bulk
        Insert and Capacity Advisor APIs.
      BALANCED: GCE prioritizes acquisition of resources, scheduling VMs in
        zones where resources are available while distributing VMs as evenly
        as possible across allowed zones to minimize the impact of zonal
        failure. Recommended for highly available serving workloads.
    """
    ANY = 0
    ANY_SINGLE_ZONE = 1
    BALANCED = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LocationsValue(_messages.Message):
    r"""Location configurations mapped by location name. Currently only zone
    names are supported and must be represented as valid internal URLs, such
    as zones/us-central1-a.

    Messages:
      AdditionalProperty: An additional property for a LocationsValue object.

    Fields:
      additionalProperties: Additional properties of type LocationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LocationsValue object.

      Fields:
        key: Name of the additional property.
        value: A LocationPolicyLocation attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('LocationPolicyLocation', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  locations = _messages.MessageField('LocationsValue', 1)
  targetShape = _messages.EnumField('TargetShapeValueValuesEnum', 2)


class LocationPolicyLocation(_messages.Message):
  r"""A LocationPolicyLocation object.

  Enums:
    PreferenceValueValuesEnum: Preference for a given location. Set to either
      ALLOW or DENY.

  Fields:
    constraints: Constraints that the caller requires on the result
      distribution in this zone.
    names: Names of resources to be put in the location. Must contain unique,
      correct resource names. If used, targetShape must be left unset.
    preference: Preference for a given location. Set to either ALLOW or DENY.
  """

  class PreferenceValueValuesEnum(_messages.Enum):
    r"""Preference for a given location. Set to either ALLOW or DENY.

    Values:
      ALLOW: Location is allowed for use.
      DENY: Location is prohibited.
      PREFERENCE_UNSPECIFIED: Default value, unused.
    """
    ALLOW = 0
    DENY = 1
    PREFERENCE_UNSPECIFIED = 2

  constraints = _messages.MessageField('LocationPolicyLocationConstraints', 1)
  names = _messages.StringField(2, repeated=True)
  preference = _messages.EnumField('PreferenceValueValuesEnum', 3)


class LocationPolicyLocationConstraints(_messages.Message):
  r"""Per-zone constraints on location policy for this zone.

  Fields:
    maxCount: Maximum number of items that are allowed to be placed in this
      zone. The value must be non-negative.
  """

  maxCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)


class MachineImage(_messages.Message):
  r"""Represents a machine image resource. A machine image is a Compute Engine
  resource that stores all the configuration, metadata, permissions, and data
  from one or more disks required to create a Virtual machine (VM) instance.
  For more information, see Machine images.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the machine image. One
      of the following values: INVALID, CREATING, READY, DELETING, and
      UPLOADING.

  Messages:
    LabelsValue: Labels to apply to this machine image. These can be later
      modified by the setLabels method.

  Fields:
    creationTimestamp: [Output Only] The creation timestamp for this machine
      image in RFC3339 text format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    guestFlush: [Input Only] Whether to attempt an application consistent
      machine image by informing the OS to prepare for the snapshot process.
    id: [Output Only] A unique identifier for this machine image. The server
      defines this identifier.
    instanceProperties: [Output Only] Properties of source instance
    kind: [Output Only] The resource type, which is always
      compute#machineImage for machine image.
    labelFingerprint: A fingerprint for the labels being applied to this
      machine image, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels. To see the latest fingerprint, make get() request to the
      machine image.
    labels: Labels to apply to this machine image. These can be later modified
      by the setLabels method.
    machineImageEncryptionKey: Encrypts the machine image using a customer-
      supplied encryption key. After you encrypt a machine image using a
      customer-supplied key, you must provide the same key if you use the
      machine image later. For example, you must provide the encryption key
      when you create an instance from the encrypted machine image in a future
      request. Customer-supplied encryption keys do not protect access to
      metadata of the machine image. If you do not provide an encryption key
      when creating the machine image, then the machine image will be
      encrypted using an automatically generated key and you do not need to
      provide a key to use the machine image later.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    params: Input only. [Input Only] Additional parameters that are passed in
      the request, but are not persisted in the resource.
    satisfiesPzi: Output only. Reserved for future use.
    satisfiesPzs: [Output Only] Reserved for future use.
    savedDisks: An array of Machine Image specific properties for disks
      attached to the source instance
    selfLink: [Output Only] The URL for this machine image. The server defines
      this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sourceDiskEncryptionKeys: [Input Only] The customer-supplied encryption
      key of the disks attached to the source instance. Required if the source
      disk is protected by a customer-supplied encryption key.
    sourceInstance: The source instance used to create the machine image. You
      can provide this as a partial or full URL to the resource. For example,
      the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /instances/instance - projects/project/zones/zone/instances/instance
    sourceInstanceProperties: [Output Only] DEPRECATED: Please use
      instance_properties instead for source instance related properties. New
      properties will not be added to this field.
    status: [Output Only] The status of the machine image. One of the
      following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
    storageLocations: The regional or multi-regional Cloud Storage bucket
      location where the machine image is stored.
    totalStorageBytes: [Output Only] Total size of the storage used by the
      machine image.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the machine image. One of the following
    values: INVALID, CREATING, READY, DELETING, and UPLOADING.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
      UPLOADING: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3
    UPLOADING = 4

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this machine image. These can be later modified by
    the setLabels method.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  guestFlush = _messages.BooleanField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  instanceProperties = _messages.MessageField('InstanceProperties', 5)
  kind = _messages.StringField(6, default='compute#machineImage')
  labelFingerprint = _messages.BytesField(7)
  labels = _messages.MessageField('LabelsValue', 8)
  machineImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 9)
  name = _messages.StringField(10)
  params = _messages.MessageField('MachineImageParams', 11)
  satisfiesPzi = _messages.BooleanField(12)
  satisfiesPzs = _messages.BooleanField(13)
  savedDisks = _messages.MessageField('SavedDisk', 14, repeated=True)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  sourceDiskEncryptionKeys = _messages.MessageField('SourceDiskEncryptionKey', 17, repeated=True)
  sourceInstance = _messages.StringField(18)
  sourceInstanceProperties = _messages.MessageField('SourceInstanceProperties', 19)
  status = _messages.EnumField('StatusValueValuesEnum', 20)
  storageLocations = _messages.StringField(21, repeated=True)
  totalStorageBytes = _messages.IntegerField(22)


class MachineImageList(_messages.Message):
  r"""A list of machine images.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of MachineImage resources.
    kind: [Output Only] The resource type, which is always
      compute#machineImagesListResponse for machine image lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('MachineImage', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#machineImageList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class MachineImageParams(_messages.Message):
  r"""Machine Image parameters

  Fields:
    excludedDisks: Input only. [Input Only] Specifies the list of disk device
      names that must be excluded from the new machine image.
    includedDisks: Input only. [Input Only] Specifies the list of disk device
      names that must be included with the new machine image.
  """

  excludedDisks = _messages.StringField(1, repeated=True)
  includedDisks = _messages.StringField(2, repeated=True)


class MachineType(_messages.Message):
  r"""Represents a Machine Type resource. You can use specific machine types
  for your VM instances based on performance and pricing requirements. For
  more information, read Machine Types.

  Enums:
    ArchitectureValueValuesEnum: [Output Only] The architecture of the machine
      type.

  Messages:
    AcceleratorsValueListEntry: A AcceleratorsValueListEntry object.

  Fields:
    accelerators: [Output Only] A list of accelerator configurations assigned
      to this machine type.
    architecture: [Output Only] The architecture of the machine type.
    bundledLocalSsds: [Output Only] The configuration of bundled local SSD for
      the machine type.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      machine type. Only applicable if the machine type is unavailable.
    description: [Output Only] An optional textual description of the
      resource.
    guestCpus: [Output Only] The number of virtual CPUs that are available to
      the instance.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    isSharedCpu: [Output Only] Whether this machine type has a shared CPU. See
      Shared-core machine types for more information.
    kind: [Output Only] The type of the resource. Always compute#machineType
      for machine types.
    maximumPersistentDisks: [Output Only] Maximum persistent disks allowed.
    maximumPersistentDisksSizeGb: [Output Only] Maximum total persistent disks
      size (GB) allowed.
    memoryMb: [Output Only] The amount of physical memory available to the
      instance, defined in MB.
    name: [Output Only] Name of the resource.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    zone: [Output Only] The name of the zone where the machine type resides,
      such as us-central1-a.
  """

  class ArchitectureValueValuesEnum(_messages.Enum):
    r"""[Output Only] The architecture of the machine type.

    Values:
      ARCHITECTURE_UNSPECIFIED: Default value indicating Architecture is not
        set.
      ARM64: Machines with architecture ARM64
      X86_64: Machines with architecture X86_64
    """
    ARCHITECTURE_UNSPECIFIED = 0
    ARM64 = 1
    X86_64 = 2

  class AcceleratorsValueListEntry(_messages.Message):
    r"""A AcceleratorsValueListEntry object.

    Fields:
      guestAcceleratorCount: Number of accelerator cards exposed to the guest.
      guestAcceleratorType: The accelerator type resource name, not a full
        URL, e.g. nvidia-tesla-t4.
    """

    guestAcceleratorCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
    guestAcceleratorType = _messages.StringField(2)

  accelerators = _messages.MessageField('AcceleratorsValueListEntry', 1, repeated=True)
  architecture = _messages.EnumField('ArchitectureValueValuesEnum', 2)
  bundledLocalSsds = _messages.MessageField('BundledLocalSsds', 3)
  creationTimestamp = _messages.StringField(4)
  deprecated = _messages.MessageField('DeprecationStatus', 5)
  description = _messages.StringField(6)
  guestCpus = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  isSharedCpu = _messages.BooleanField(9)
  kind = _messages.StringField(10, default='compute#machineType')
  maximumPersistentDisks = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  maximumPersistentDisksSizeGb = _messages.IntegerField(12)
  memoryMb = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  name = _messages.StringField(14)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  zone = _messages.StringField(17)


class MachineTypeAggregatedList(_messages.Message):
  r"""A MachineTypeAggregatedList object.

  Messages:
    ItemsValue: A list of MachineTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of MachineTypesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#machineTypeAggregatedList for aggregated lists of machine types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of MachineTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of machine types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A MachineTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('MachineTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#machineTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class MachineTypeList(_messages.Message):
  r"""Contains a list of machine types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of MachineType resources.
    kind: [Output Only] Type of resource. Always compute#machineTypeList for
      lists of machine types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('MachineType', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#machineTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class MachineTypesScopedList(_messages.Message):
  r"""A MachineTypesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      machine types list is empty.

  Fields:
    machineTypes: [Output Only] A list of machine types contained in this
      scope.
    warning: [Output Only] An informational warning that appears when the
      machine types list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the machine
    types list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  machineTypes = _messages.MessageField('MachineType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ManagedInstance(_messages.Message):
  r"""A Managed Instance resource.

  Enums:
    CurrentActionValueValuesEnum: [Output Only] The current action that the
      managed instance group has scheduled for the instance. Possible values:
      - NONE The instance is running, and the managed instance group does not
      have any scheduled actions for this instance. - CREATING The managed
      instance group is creating this instance. If the group fails to create
      this instance, it will try again until it is successful. -
      CREATING_WITHOUT_RETRIES The managed instance group is attempting to
      create this instance only once. If the group fails to create this
      instance, it does not try again and the group's targetSize value is
      decreased instead. - RECREATING The managed instance group is recreating
      this instance. - DELETING The managed instance group is permanently
      deleting this instance. - ABANDONING The managed instance group is
      abandoning this instance. The instance will be removed from the instance
      group and from any target pools that are associated with this group. -
      RESTARTING The managed instance group is restarting the instance. -
      REFRESHING The managed instance group is applying configuration changes
      to the instance without stopping it. For example, the group can update
      the target pool list for an instance without stopping that instance. -
      VERIFYING The managed instance group has created the instance and it is
      in the process of being verified.
    InstanceStatusValueValuesEnum: [Output Only] The status of the instance.
      This field is empty when the instance does not exist.
    TargetStatusValueValuesEnum: [Output Only] The eventual status of the
      instance. The instance group manager will not be identified as stable
      till each managed instance reaches its targetStatus.

  Fields:
    allInstancesConfig: [Output Only] Current all-instances configuration
      revision applied to this instance.
    currentAction: [Output Only] The current action that the managed instance
      group has scheduled for the instance. Possible values: - NONE The
      instance is running, and the managed instance group does not have any
      scheduled actions for this instance. - CREATING The managed instance
      group is creating this instance. If the group fails to create this
      instance, it will try again until it is successful. -
      CREATING_WITHOUT_RETRIES The managed instance group is attempting to
      create this instance only once. If the group fails to create this
      instance, it does not try again and the group's targetSize value is
      decreased instead. - RECREATING The managed instance group is recreating
      this instance. - DELETING The managed instance group is permanently
      deleting this instance. - ABANDONING The managed instance group is
      abandoning this instance. The instance will be removed from the instance
      group and from any target pools that are associated with this group. -
      RESTARTING The managed instance group is restarting the instance. -
      REFRESHING The managed instance group is applying configuration changes
      to the instance without stopping it. For example, the group can update
      the target pool list for an instance without stopping that instance. -
      VERIFYING The managed instance group has created the instance and it is
      in the process of being verified.
    currentActionDetails: A ManagedInstanceCurrentActionDetails attribute.
    id: [Output only] The unique identifier for this resource. This field is
      empty when instance does not exist.
    instance: [Output Only] The URL of the instance. The URL can exist even if
      the instance has not yet been created.
    instanceFlexibilityOverride: [Output Only] The overrides to instance
      properties resulting from InstanceFlexibilityPolicy.
    instanceHealth: [Output Only] Health state of the instance per health-
      check.
    instanceStatus: [Output Only] The status of the instance. This field is
      empty when the instance does not exist.
    instanceTemplate: [Output Only] The intended template of the instance.
      This field is empty when current_action is one of { DELETING, ABANDONING
      }.
    lastAttempt: [Output Only] Information about the last attempt to create or
      delete the instance.
    name: [Output Only] The name of the instance. The name always exists even
      if the instance has not yet been created.
    preservedStateFromConfig: [Output Only] Preserved state applied from per-
      instance config for this instance.
    preservedStateFromPolicy: [Output Only] Preserved state generated based on
      stateful policy for this instance.
    propertiesFromFlexibilityPolicy: [Output Only] Instance properties
      selected for this instance resulting from InstanceFlexibilityPolicy.
    sizeInUnit: [Output only] The size of the VM represented by this Managed
      Instance. This is how much this Managed Instance contributes to the size
      of the group.
    tag: [Output Only] Tag describing the version.
    targetStatus: [Output Only] The eventual status of the instance. The
      instance group manager will not be identified as stable till each
      managed instance reaches its targetStatus.
    version: [Output Only] Intended version of this instance.
  """

  class CurrentActionValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current action that the managed instance group has
    scheduled for the instance. Possible values: - NONE The instance is
    running, and the managed instance group does not have any scheduled
    actions for this instance. - CREATING The managed instance group is
    creating this instance. If the group fails to create this instance, it
    will try again until it is successful. - CREATING_WITHOUT_RETRIES The
    managed instance group is attempting to create this instance only once. If
    the group fails to create this instance, it does not try again and the
    group's targetSize value is decreased instead. - RECREATING The managed
    instance group is recreating this instance. - DELETING The managed
    instance group is permanently deleting this instance. - ABANDONING The
    managed instance group is abandoning this instance. The instance will be
    removed from the instance group and from any target pools that are
    associated with this group. - RESTARTING The managed instance group is
    restarting the instance. - REFRESHING The managed instance group is
    applying configuration changes to the instance without stopping it. For
    example, the group can update the target pool list for an instance without
    stopping that instance. - VERIFYING The managed instance group has created
    the instance and it is in the process of being verified.

    Values:
      ABANDONING: The managed instance group is abandoning this instance. The
        instance will be removed from the instance group and from any target
        pools that are associated with this group.
      CREATING: The managed instance group is creating this instance. If the
        group fails to create this instance, it will try again until it is
        successful.
      CREATING_ATOMICALLY: The managed instance group is creating this
        instance atomically.
      CREATING_WITHOUT_RETRIES: The managed instance group is attempting to
        create this instance only once. If the group fails to create this
        instance, it does not try again and the group's targetSize value is
        decreased.
      DELETING: The managed instance group is permanently deleting this
        instance.
      NONE: The managed instance group has not scheduled any actions for this
        instance.
      QUEUING: The managed instance group is queuing this instance.
      RECREATING: The managed instance group is recreating this instance.
      REFRESHING: The managed instance group is applying configuration changes
        to the instance without stopping it. For example, the group can update
        the target pool list for an instance without stopping that instance.
      RESTARTING: The managed instance group is restarting this instance.
      RESUMING: The managed instance group is resuming this instance.
      STARTING: The managed instance group is starting this instance.
      STOPPING: The managed instance group is stopping this instance.
      SUSPENDING: The managed instance group is suspending this instance.
      VERIFYING: The managed instance group is verifying this already created
        instance. Verification happens every time the instance is (re)created
        or restarted and consists of: 1. Waiting until health check specified
        as part of this managed instance group's autohealing policy reports
        HEALTHY. Note: Applies only if autohealing policy has a health check
        specified 2. Waiting for addition verification steps performed as
        post-instance creation (subject to future extensions).
    """
    ABANDONING = 0
    CREATING = 1
    CREATING_ATOMICALLY = 2
    CREATING_WITHOUT_RETRIES = 3
    DELETING = 4
    NONE = 5
    QUEUING = 6
    RECREATING = 7
    REFRESHING = 8
    RESTARTING = 9
    RESUMING = 10
    STARTING = 11
    STOPPING = 12
    SUSPENDING = 13
    VERIFYING = 14

  class InstanceStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the instance. This field is empty when the
    instance does not exist.

    Values:
      DEPROVISIONING: The instance is halted and we are performing tear down
        tasks like network deprogramming, releasing quota, IP, tearing down
        disks etc.
      PENDING_STOP: The instance is gracefully shutting down.
      PROVISIONING: Resources are being allocated for the instance.
      REPAIRING: The instance is in repair.
      RUNNING: The instance is running.
      STAGING: All required resources have been allocated and the instance is
        being started.
      STOPPED: The instance has stopped successfully.
      STOPPING: The instance is currently stopping (either being deleted or
        killed).
      SUSPENDED: The instance has suspended.
      SUSPENDING: The instance is suspending.
      TERMINATED: The instance has stopped (either by explicit action or
        underlying failure).
    """
    DEPROVISIONING = 0
    PENDING_STOP = 1
    PROVISIONING = 2
    REPAIRING = 3
    RUNNING = 4
    STAGING = 5
    STOPPED = 6
    STOPPING = 7
    SUSPENDED = 8
    SUSPENDING = 9
    TERMINATED = 10

  class TargetStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The eventual status of the instance. The instance group
    manager will not be identified as stable till each managed instance
    reaches its targetStatus.

    Values:
      ABANDONED: The managed instance will eventually be ABANDONED, i.e.
        dissociated from the managed instance group.
      DELETED: The managed instance will eventually be DELETED.
      RUNNING: The managed instance will eventually reach status RUNNING.
      STOPPED: The managed instance will eventually reach status TERMINATED.
      SUSPENDED: The managed instance will eventually reach status SUSPENDED.
    """
    ABANDONED = 0
    DELETED = 1
    RUNNING = 2
    STOPPED = 3
    SUSPENDED = 4

  allInstancesConfig = _messages.MessageField('ManagedInstanceAllInstancesConfig', 1)
  currentAction = _messages.EnumField('CurrentActionValueValuesEnum', 2)
  currentActionDetails = _messages.MessageField('ManagedInstanceCurrentActionDetails', 3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  instance = _messages.StringField(5)
  instanceFlexibilityOverride = _messages.MessageField('ManagedInstanceInstanceFlexibilityOverride', 6)
  instanceHealth = _messages.MessageField('ManagedInstanceInstanceHealth', 7, repeated=True)
  instanceStatus = _messages.EnumField('InstanceStatusValueValuesEnum', 8)
  instanceTemplate = _messages.StringField(9)
  lastAttempt = _messages.MessageField('ManagedInstanceLastAttempt', 10)
  name = _messages.StringField(11)
  preservedStateFromConfig = _messages.MessageField('PreservedState', 12)
  preservedStateFromPolicy = _messages.MessageField('PreservedState', 13)
  propertiesFromFlexibilityPolicy = _messages.MessageField('ManagedInstancePropertiesFromFlexibilityPolicy', 14)
  sizeInUnit = _messages.FloatField(15, variant=_messages.Variant.FLOAT)
  tag = _messages.StringField(16)
  targetStatus = _messages.EnumField('TargetStatusValueValuesEnum', 17)
  version = _messages.MessageField('ManagedInstanceVersion', 18)


class ManagedInstanceAllInstancesConfig(_messages.Message):
  r"""A ManagedInstanceAllInstancesConfig object.

  Fields:
    revision: [Output Only] Current all-instances configuration revision. This
      value is in RFC3339 text format.
  """

  revision = _messages.StringField(1)


class ManagedInstanceCurrentActionDetails(_messages.Message):
  r"""A ManagedInstanceCurrentActionDetails object.

  Enums:
    TriggerValueValuesEnum: [Output Only] Details of the current action that
      the managed instance group has scheduled for the instance. Contains
      trigger for the current action, and methodName in case it was triggered
      by API call. Possible values for trigger: - API Any API call. -
      PROACTIVE_UPDATE Proactive updater scheduled an update on this managed
      instance. - AUTOSCALING Instance being deleted/created after a decision
      from the Autoscaler. - REDISTRIBUTION The regional managed instance
      group is moving instances between zones to restore balance. -
      STANDBY_REFILL The managed instance group is refilling the Standby Pool
      (stopped/suspended virtual machines) after scale up. - MAINTENANCE
      Manual maintenance. - FAILED_CREATION The managed instance group is
      handling failed instance creation. - INSTANCE_FAILURE The managed
      instance group is handling instance failure, according to the Instance
      Lifecycle Policy. - FAILED_HEALTH_CHECK The managed instance group is
      handling failed health check, according to the Instance Lifecycle
      Policy. - TERMINATION_TIMESTAMP Instance reached termination time, thus
      managed instance group stops/deletes it.

  Fields:
    methodName: A string attribute.
    trigger: [Output Only] Details of the current action that the managed
      instance group has scheduled for the instance. Contains trigger for the
      current action, and methodName in case it was triggered by API call.
      Possible values for trigger: - API Any API call. - PROACTIVE_UPDATE
      Proactive updater scheduled an update on this managed instance. -
      AUTOSCALING Instance being deleted/created after a decision from the
      Autoscaler. - REDISTRIBUTION The regional managed instance group is
      moving instances between zones to restore balance. - STANDBY_REFILL The
      managed instance group is refilling the Standby Pool (stopped/suspended
      virtual machines) after scale up. - MAINTENANCE Manual maintenance. -
      FAILED_CREATION The managed instance group is handling failed instance
      creation. - INSTANCE_FAILURE The managed instance group is handling
      instance failure, according to the Instance Lifecycle Policy. -
      FAILED_HEALTH_CHECK The managed instance group is handling failed health
      check, according to the Instance Lifecycle Policy. -
      TERMINATION_TIMESTAMP Instance reached termination time, thus managed
      instance group stops/deletes it.
  """

  class TriggerValueValuesEnum(_messages.Enum):
    r"""[Output Only] Details of the current action that the managed instance
    group has scheduled for the instance. Contains trigger for the current
    action, and methodName in case it was triggered by API call. Possible
    values for trigger: - API Any API call. - PROACTIVE_UPDATE Proactive
    updater scheduled an update on this managed instance. - AUTOSCALING
    Instance being deleted/created after a decision from the Autoscaler. -
    REDISTRIBUTION The regional managed instance group is moving instances
    between zones to restore balance. - STANDBY_REFILL The managed instance
    group is refilling the Standby Pool (stopped/suspended virtual machines)
    after scale up. - MAINTENANCE Manual maintenance. - FAILED_CREATION The
    managed instance group is handling failed instance creation. -
    INSTANCE_FAILURE The managed instance group is handling instance failure,
    according to the Instance Lifecycle Policy. - FAILED_HEALTH_CHECK The
    managed instance group is handling failed health check, according to the
    Instance Lifecycle Policy. - TERMINATION_TIMESTAMP Instance reached
    termination time, thus managed instance group stops/deletes it.

    Values:
      API: Any API call.
      AUTOSCALING: Instance being deleted/created after a decision from the
        Autoscaler.
      FAILED_CREATION: The managed instance group is handling failed instance
        creation.
      FAILED_HEALTH_CHECK: The managed instance group is handling failed
        health check, according to the Instance Lifecycle Policy.
      INSTANCE_FAILURE: The managed instance group is handling instance
        failure, according to the Instance Lifecycle Policy.
      MAINTENANCE: Manual maintenance.
      NONE: Default value, not visible externally.
      PROACTIVE_UPDATE: Proactive updater scheduled an update on this managed
        instance.
      REDISTRIBUTION: The regional managed instance group is moving instances
        between zones to restore balance.
      STANDBY_REFILL: The managed instance group is refilling the Standby Pool
        (stopped/suspended virtual machines) after scale up.
      TERMINATION_TIMESTAMP: Instance reached termination time, thus managed
        instance group stops/deletes it.
    """
    API = 0
    AUTOSCALING = 1
    FAILED_CREATION = 2
    FAILED_HEALTH_CHECK = 3
    INSTANCE_FAILURE = 4
    MAINTENANCE = 5
    NONE = 6
    PROACTIVE_UPDATE = 7
    REDISTRIBUTION = 8
    STANDBY_REFILL = 9
    TERMINATION_TIMESTAMP = 10

  methodName = _messages.StringField(1)
  trigger = _messages.EnumField('TriggerValueValuesEnum', 2)


class ManagedInstanceInstanceFlexibilityOverride(_messages.Message):
  r"""A ManagedInstanceInstanceFlexibilityOverride object.

  Enums:
    ProvisioningModelValueValuesEnum: The provisioning model to be used for
      this instance.

  Fields:
    machineType: The machine type to be used for this instance.
    provisioningModel: The provisioning model to be used for this instance.
  """

  class ProvisioningModelValueValuesEnum(_messages.Enum):
    r"""The provisioning model to be used for this instance.

    Values:
      FLEX_START: Instance is provisioned using the Flex Start provisioning
        model and has a limited runtime.
      RESERVATION_BOUND: Bound to the lifecycle of the reservation in which it
        is provisioned.
      SPOT: Heavily discounted, no guaranteed runtime.
      STANDARD: Standard provisioning with user controlled runtime, no
        discounts.
    """
    FLEX_START = 0
    RESERVATION_BOUND = 1
    SPOT = 2
    STANDARD = 3

  machineType = _messages.StringField(1)
  provisioningModel = _messages.EnumField('ProvisioningModelValueValuesEnum', 2)


class ManagedInstanceInstanceHealth(_messages.Message):
  r"""A ManagedInstanceInstanceHealth object.

  Enums:
    DetailedHealthStateValueValuesEnum: [Output Only] The current detailed
      instance health state.
    HealthStateValueValuesEnum: [Output Only] The current instance health
      state. This field will not get promoted to beta/GA and might be removed
      from alpha APIs after 01/12/2019. Please use detailed_health_state field
      instead.

  Fields:
    detailedHealthState: [Output Only] The current detailed instance health
      state.
    healthCheck: [Output Only] The URL for the health check that verifies
      whether the instance is healthy.
    healthState: [Output Only] The current instance health state. This field
      will not get promoted to beta/GA and might be removed from alpha APIs
      after 01/12/2019. Please use detailed_health_state field instead.
  """

  class DetailedHealthStateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current detailed instance health state.

    Values:
      DRAINING: The instance is being drained. The existing connections to the
        instance have time to complete, but the new ones are being refused.
      HEALTHY: The instance is reachable i.e. a connection to the application
        health checking endpoint can be established, and conforms to the
        requirements defined by the health check.
      TIMEOUT: The instance is unreachable i.e. a connection to the
        application health checking endpoint cannot be established, or the
        server does not respond within the specified timeout.
      UNHEALTHY: The instance is reachable, but does not conform to the
        requirements defined by the health check.
      UNKNOWN: The health checking system is aware of the instance but its
        health is not known at the moment.
    """
    DRAINING = 0
    HEALTHY = 1
    TIMEOUT = 2
    UNHEALTHY = 3
    UNKNOWN = 4

  class HealthStateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current instance health state. This field will not
    get promoted to beta/GA and might be removed from alpha APIs after
    01/12/2019. Please use detailed_health_state field instead.

    Values:
      HEALTHY: The instance is reachable i.e. a connection to the application
        health checking endpoint can be established, and conforms to the
        requirements defined by the health check.
      UNHEALTHY: The instance is reachable, but does not conform to the
        requirements defined by the health check.
    """
    HEALTHY = 0
    UNHEALTHY = 1

  detailedHealthState = _messages.EnumField('DetailedHealthStateValueValuesEnum', 1)
  healthCheck = _messages.StringField(2)
  healthState = _messages.EnumField('HealthStateValueValuesEnum', 3)


class ManagedInstanceLastAttempt(_messages.Message):
  r"""A ManagedInstanceLastAttempt object.

  Messages:
    ErrorsValue: [Output Only] Encountered errors during the last attempt to
      create or delete the instance.

  Fields:
    errors: [Output Only] Encountered errors during the last attempt to create
      or delete the instance.
  """

  class ErrorsValue(_messages.Message):
    r"""[Output Only] Encountered errors during the last attempt to create or
    delete the instance.

    Messages:
      ErrorsValueListEntry: A ErrorsValueListEntry object.

    Fields:
      errors: [Output Only] The array of errors encountered while processing
        this operation.
    """

    class ErrorsValueListEntry(_messages.Message):
      r"""A ErrorsValueListEntry object.

      Messages:
        ErrorDetailsValueListEntry: A ErrorDetailsValueListEntry object.

      Fields:
        code: [Output Only] The error type identifier for this error.
        errorDetails: [Output Only] An optional list of messages that contain
          the error details. There is a set of defined message types to use
          for providing details.The syntax depends on the error code. For
          example, QuotaExceededInfo will have details when the error code is
          QUOTA_EXCEEDED.
        location: [Output Only] Indicates the field in the request that caused
          the error. This property is optional.
        message: [Output Only] An optional, human-readable error message.
      """

      class ErrorDetailsValueListEntry(_messages.Message):
        r"""A ErrorDetailsValueListEntry object.

        Fields:
          errorInfo: A ErrorInfo attribute.
          help: A Help attribute.
          localizedMessage: A LocalizedMessage attribute.
          quotaInfo: A QuotaExceededInfo attribute.
        """

        errorInfo = _messages.MessageField('ErrorInfo', 1)
        help = _messages.MessageField('Help', 2)
        localizedMessage = _messages.MessageField('LocalizedMessage', 3)
        quotaInfo = _messages.MessageField('QuotaExceededInfo', 4)

      code = _messages.StringField(1)
      errorDetails = _messages.MessageField('ErrorDetailsValueListEntry', 2, repeated=True)
      location = _messages.StringField(3)
      message = _messages.StringField(4)

    errors = _messages.MessageField('ErrorsValueListEntry', 1, repeated=True)

  errors = _messages.MessageField('ErrorsValue', 1)


class ManagedInstancePropertiesFromFlexibilityPolicy(_messages.Message):
  r"""A ManagedInstancePropertiesFromFlexibilityPolicy object.

  Enums:
    ProvisioningModelValueValuesEnum: The provisioning model to be used for
      this instance.

  Fields:
    machineType: The machine type to be used for this instance.
    provisioningModel: The provisioning model to be used for this instance.
  """

  class ProvisioningModelValueValuesEnum(_messages.Enum):
    r"""The provisioning model to be used for this instance.

    Values:
      FLEX_START: Instance is provisioned using the Flex Start provisioning
        model and has a limited runtime.
      RESERVATION_BOUND: Bound to the lifecycle of the reservation in which it
        is provisioned.
      SPOT: Heavily discounted, no guaranteed runtime.
      STANDARD: Standard provisioning with user controlled runtime, no
        discounts.
    """
    FLEX_START = 0
    RESERVATION_BOUND = 1
    SPOT = 2
    STANDARD = 3

  machineType = _messages.StringField(1)
  provisioningModel = _messages.EnumField('ProvisioningModelValueValuesEnum', 2)


class ManagedInstanceVersion(_messages.Message):
  r"""A ManagedInstanceVersion object.

  Fields:
    instanceTemplate: [Output Only] The intended template of the instance.
      This field is empty when current_action is one of { DELETING, ABANDONING
      }.
    name: [Output Only] Name of the version.
  """

  instanceTemplate = _messages.StringField(1)
  name = _messages.StringField(2)


class Metadata(_messages.Message):
  r"""A metadata key/value entry.

  Messages:
    ItemsValueListEntry: Metadata

  Fields:
    fingerprint: Specifies a fingerprint for this request, which is
      essentially a hash of the metadata's contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update metadata. You must
      always provide an up-to-date fingerprint hash in order to update or
      change metadata, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve the resource.
    items: Array of key/value pairs. The total size of all keys and values
      must be less than 512 KB.
    kind: [Output Only] Type of the resource. Always compute#metadata for
      metadata.
  """

  class ItemsValueListEntry(_messages.Message):
    r"""Metadata

    Fields:
      key: Key for the metadata entry. Keys must conform to the following
        regexp: [a-zA-Z0-9-_]+, and be less than 128 bytes in length. This is
        reflected as part of a URL in the metadata server. Additionally, to
        avoid ambiguity, keys must not conflict with any other metadata keys
        for the project.
      value: Value for the metadata entry. These are free-form strings, and
        only have meaning as interpreted by the image running in the instance.
        The only restriction placed on values is that their size must be less
        than or equal to 262144 bytes (256 KiB).
    """

    key = _messages.StringField(1)
    value = _messages.StringField(2)

  fingerprint = _messages.BytesField(1)
  items = _messages.MessageField('ItemsValueListEntry', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#metadata')


class MetadataCredentialsFromPlugin(_messages.Message):
  r"""[Deprecated] Custom authenticator credentials. Custom authenticator
  credentials.

  Fields:
    name: Plugin name.
    structConfig: A text proto that conforms to a Struct type definition
      interpreted by the plugin.
  """

  name = _messages.StringField(1)
  structConfig = _messages.StringField(2)


class MetadataFilter(_messages.Message):
  r"""Opaque filter criteria used by load balancers to restrict routing
  configuration to a limited set of load balancing proxies. Proxies and
  sidecars involved in load balancing would typically present metadata to the
  load balancers that need to match criteria specified here. If a match takes
  place, the relevant configuration is made available to those proxies. For
  each metadataFilter in this list, if its filterMatchCriteria is set to
  MATCH_ANY, at least one of the filterLabels must match the corresponding
  label provided in the metadata. If its filterMatchCriteria is set to
  MATCH_ALL, then all of its filterLabels must match with corresponding labels
  provided in the metadata. An example for using metadataFilters would be: if
  load balancing involves Envoys, they receive routing configuration when
  values in metadataFilters match values supplied in of their XDS requests to
  loadbalancers.

  Enums:
    FilterMatchCriteriaValueValuesEnum: Specifies how individual filter label
      matches within the list of filterLabels and contributes toward the
      overall metadataFilter match. Supported values are: - MATCH_ANY: at
      least one of the filterLabels must have a matching label in the provided
      metadata. - MATCH_ALL: all filterLabels must have matching labels in the
      provided metadata.

  Fields:
    filterLabels: The list of label value pairs that must match labels in the
      provided metadata based on filterMatchCriteria This list must not be
      empty and can have at the most 64 entries.
    filterMatchCriteria: Specifies how individual filter label matches within
      the list of filterLabels and contributes toward the overall
      metadataFilter match. Supported values are: - MATCH_ANY: at least one of
      the filterLabels must have a matching label in the provided metadata. -
      MATCH_ALL: all filterLabels must have matching labels in the provided
      metadata.
  """

  class FilterMatchCriteriaValueValuesEnum(_messages.Enum):
    r"""Specifies how individual filter label matches within the list of
    filterLabels and contributes toward the overall metadataFilter match.
    Supported values are: - MATCH_ANY: at least one of the filterLabels must
    have a matching label in the provided metadata. - MATCH_ALL: all
    filterLabels must have matching labels in the provided metadata.

    Values:
      MATCH_ALL: Specifies that all filterLabels must match for the
        metadataFilter to be considered a match.
      MATCH_ANY: Specifies that any filterLabel must match for the
        metadataFilter to be considered a match.
      NOT_SET: Indicates that the match criteria was not set. A metadataFilter
        must never be created with this value.
    """
    MATCH_ALL = 0
    MATCH_ANY = 1
    NOT_SET = 2

  filterLabels = _messages.MessageField('MetadataFilterLabelMatch', 1, repeated=True)
  filterMatchCriteria = _messages.EnumField('FilterMatchCriteriaValueValuesEnum', 2)


class MetadataFilterLabelMatch(_messages.Message):
  r"""MetadataFilter label name value pairs that are expected to match
  corresponding labels presented as metadata to the load balancer.

  Fields:
    name: Name of metadata label. The name can have a maximum length of 1024
      characters and must be at least 1 character long.
    value: The value of the label must match the specified value. value can
      have a maximum length of 1024 characters.
  """

  name = _messages.StringField(1)
  value = _messages.StringField(2)


class Money(_messages.Message):
  r"""Represents an amount of money with its currency type.

  Fields:
    currencyCode: The three-letter currency code defined in ISO 4217.
    nanos: Number of nano (10^-9) units of the amount. The value must be
      between -999,999,999 and +999,999,999 inclusive. If `units` is positive,
      `nanos` must be positive or zero. If `units` is zero, `nanos` can be
      positive, zero, or negative. If `units` is negative, `nanos` must be
      negative or zero. For example $-1.75 is represented as `units`=-1 and
      `nanos`=-750,000,000.
    units: The whole units of the amount. For example if `currencyCode` is
      `"USD"`, then 1 unit is one US dollar.
  """

  currencyCode = _messages.StringField(1)
  nanos = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  units = _messages.IntegerField(3)


class MultiMig(_messages.Message):
  r"""Multi-MIG represents a group of managed instance groups.

  Fields:
    creationTimestamp: [Output only] The creation timestamp of this multi-MIG
      in RFC3339 text format.
    description: An optional description of this resource.
    id: [Output only] The unique identifier for this resource type. The server
      generates this identifier.
    kind: [Output only] Type of the resource. Always compute#multiMig for
      multi-MIGs.
    name: The name of the multi-MIG. The name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    region: [Output only] The URL of the region where the resource resides.
      You must specify this field as part of the HTTP request URL. You cannot
      set the region as a field in the request body.
    resourcePolicies: Resource policies for this multi-MIG.
    selfLink: [Output only] Server-defined URL for the resource.
    selfLinkWithId: [Output only] Server-defined URL for this resource with
      the resource id.
    status: A MultiMigStatus attribute.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default='compute#multiMig')
  name = _messages.StringField(5)
  region = _messages.StringField(6)
  resourcePolicies = _messages.MessageField('MultiMigResourcePolicies', 7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  status = _messages.MessageField('MultiMigStatus', 10)


class MultiMigMember(_messages.Message):
  r"""Represents a Multi-MIG member resource.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp of this multi-MIG
      member in RFC3339 text format.
    description: An optional description of this resource.
    id: [Output only] The unique identifier for this resource type. The server
      generates this identifier.
    kind: Type of the resource. Always compute#multiMigMember for a list of
      multi-MIG members.
    name: [Output Only] The name of this multi-MIG member generated by Google
      Compute Engine.
    region: [Output Only] The URL of the region where the multi-MIG resides.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] The status of this multi-MIG member
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default='compute#multiMigMember')
  name = _messages.StringField(5)
  region = _messages.StringField(6)
  selfLink = _messages.StringField(7)
  selfLinkWithId = _messages.StringField(8)
  status = _messages.MessageField('MultiMigMemberStatus', 9)


class MultiMigMemberList(_messages.Message):
  r"""A MultiMigMemberList object.

  Messages:
    WarningValue: Informational warning message.

  Fields:
    id: Unique identifier for the resource; defined by the server.
    items: A list of multi-MIG member resources.
    kind: Type of the resource. Always compute#multiMigMember for a list of
      multi-MIG members.
    nextPageToken: This token allows you to get the next page of results for
      list requests. If the number of results is larger than maxResults, use
      the nextPageToken as a value for the query parameter pageToken in the
      next list request. Subsequent list requests will have their own
      nextPageToken to continue paging through the results.
    selfLink: [Output only] Server-defined URL for this resource.
    warning: Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('MultiMigMember', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#multiMigMemberList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class MultiMigMemberStatus(_messages.Message):
  r"""A MultiMigMemberStatus object.

  Fields:
    instanceGroupManager: [Output Only] URL of member instance group manager
  """

  instanceGroupManager = _messages.StringField(1)


class MultiMigResourcePolicies(_messages.Message):
  r"""Resource policies message for a multi-MIG. Specifies the workload policy
  configuration of the multi-MIG.

  Fields:
    workloadPolicy: The URL of the workload policy for this multi-MIG. It can
      be a full or partial URL. For example, the following are all valid URLs
      to a workload policy: -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /resourcePolicies/resourcePolicy -
      projects/project/regions/region/resourcePolicies/resourcePolicy -
      regions/region/resourcePolicies/resourcePolicy
  """

  workloadPolicy = _messages.StringField(1)


class MultiMigStatus(_messages.Message):
  r"""A MultiMigStatus object.

  Fields:
    memberInstanceGroupManagers: A string attribute.
    membersCount: [Output Only] The number of instance group manager members
      in this multi-MIG.
  """

  memberInstanceGroupManagers = _messages.StringField(1, repeated=True)
  membersCount = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class MultiMigsList(_messages.Message):
  r"""A MultiMigsList object.

  Messages:
    WarningValue: Informational warning message.

  Fields:
    etag: A string attribute.
    id: Unique identifier for the resource; defined by the server.
    items: A list of multi-MIGs in the specified project and region.
    kind: Type of resource.
    nextPageToken: This token allows you to get the next page of results for
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output only] Server-defined URL for this resource.
    unreachables: [Output only] Unreachable resources.
    warning: Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('MultiMig', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#multiMigList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class MutualTls(_messages.Message):
  r"""[Deprecated] Configuration for the mutual Tls mode for peer
  authentication. Configuration for the mutual Tls mode for peer
  authentication.

  Enums:
    ModeValueValuesEnum: Specifies if the server TLS is configured to be
      strict or permissive. This field can be set to one of the following:
      STRICT: Client certificate must be presented, connection is in TLS.
      PERMISSIVE: Client certificate can be omitted, connection can be either
      plaintext or TLS.

  Fields:
    mode: Specifies if the server TLS is configured to be strict or
      permissive. This field can be set to one of the following: STRICT:
      Client certificate must be presented, connection is in TLS. PERMISSIVE:
      Client certificate can be omitted, connection can be either plaintext or
      TLS.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Specifies if the server TLS is configured to be strict or permissive.
    This field can be set to one of the following: STRICT: Client certificate
    must be presented, connection is in TLS. PERMISSIVE: Client certificate
    can be omitted, connection can be either plaintext or TLS.

    Values:
      INVALID: <no description>
      PERMISSIVE: Client certificate can be omitted, connection can be either
        plaintext or TLS.
      STRICT: Client certificate must be presented, connection is in TLS.
    """
    INVALID = 0
    PERMISSIVE = 1
    STRICT = 2

  mode = _messages.EnumField('ModeValueValuesEnum', 1)


class NamedPort(_messages.Message):
  r"""The named port. For example: <"http", 80>.

  Fields:
    name: The name for this named port. The name must be 1-63 characters long,
      and comply with RFC1035.
    port: The port number, which can be a value between 1 and 65535.
  """

  name = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class NamedSet(_messages.Message):
  r"""A NamedSet object.

  Enums:
    TypeValueValuesEnum: This named set's type

  Fields:
    elements: CEL expressions that are comparable to constructs of this set's
      type (see Policy Language).
    fingerprint: A fingerprint for the Named Set being applied to this Router,
      which is essentially a hash of the Named Set used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update the Named Set. You must
      always provide an up-to-date fingerprint hash in order to update or
      change labels. To see the latest fingerprint, make a getNamedSet()
      request to retrieve a Named Set.
    name: This set's name, which must be a resource ID segment and unique
      within all named sets owned by the Router. Name should conform to
      RFC1035.
    type: This named set's type
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""This named set's type

    Values:
      NAMED_SET_TYPE_COMMUNITY: The Named Set is a Community Named Set.
      NAMED_SET_TYPE_PREFIX: The Named Set is a Prefix Named Set.
    """
    NAMED_SET_TYPE_COMMUNITY = 0
    NAMED_SET_TYPE_PREFIX = 1

  elements = _messages.MessageField('Expr', 1, repeated=True)
  fingerprint = _messages.BytesField(2)
  name = _messages.StringField(3)
  type = _messages.EnumField('TypeValueValuesEnum', 4)


class NatIpInfo(_messages.Message):
  r"""Contains NAT IP information of a NAT config (i.e. usage status, mode).

  Fields:
    natIpInfoMappings: A list of all NAT IPs assigned to this NAT config.
    natName: Name of the NAT config which the NAT IP belongs to.
  """

  natIpInfoMappings = _messages.MessageField('NatIpInfoNatIpInfoMapping', 1, repeated=True)
  natName = _messages.StringField(2)


class NatIpInfoNatIpInfoMapping(_messages.Message):
  r"""Contains information of a NAT IP.

  Enums:
    ModeValueValuesEnum: Specifies whether NAT IP is auto or manual.
    UsageValueValuesEnum: Specifies whether NAT IP is currently serving at
      least one endpoint or not.

  Fields:
    mode: Specifies whether NAT IP is auto or manual.
    natIp: NAT IP address. For example: 203.0.113.11.
    usage: Specifies whether NAT IP is currently serving at least one endpoint
      or not.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Specifies whether NAT IP is auto or manual.

    Values:
      AUTO: <no description>
      MANUAL: <no description>
    """
    AUTO = 0
    MANUAL = 1

  class UsageValueValuesEnum(_messages.Enum):
    r"""Specifies whether NAT IP is currently serving at least one endpoint or
    not.

    Values:
      IN_USE: <no description>
      UNUSED: <no description>
    """
    IN_USE = 0
    UNUSED = 1

  mode = _messages.EnumField('ModeValueValuesEnum', 1)
  natIp = _messages.StringField(2)
  usage = _messages.EnumField('UsageValueValuesEnum', 3)


class NatIpInfoResponse(_messages.Message):
  r"""A NatIpInfoResponse object.

  Fields:
    result: [Output Only] A list of NAT IP information.
  """

  result = _messages.MessageField('NatIpInfo', 1, repeated=True)


class Network(_messages.Message):
  r"""Represents a VPC Network resource. Networks connect resources to each
  other and to the internet. For more information, read Virtual Private Cloud
  (VPC) Network.

  Enums:
    NetworkFirewallPolicyEnforcementOrderValueValuesEnum: The network firewall
      policy enforcement order. Can be either AFTER_CLASSIC_FIREWALL or
      BEFORE_CLASSIC_FIREWALL. Defaults to AFTER_CLASSIC_FIREWALL if the field
      is not specified.

  Fields:
    IPv4Range: Deprecated in favor of subnet mode networks. The range of
      internal addresses that are legal on this network. This range is a CIDR
      specification, for example: 192.168.0.0/16. Provided by the client when
      the network is created.
    autoCreateSubnetworks: Must be set to create a VPC network. If not set, a
      legacy network is created. When set to true, the VPC network is created
      in auto mode. When set to false, the VPC network is created in custom
      mode. An auto mode VPC network starts with one subnet per region. Each
      subnet has a predetermined range as described in Auto mode VPC network
      IP ranges. For custom mode VPC networks, you can add subnets using the
      subnetworks insert method.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this field
      when you create the resource.
    enableUlaInternalIpv6: Enable ULA internal ipv6 on this network. Enabling
      this feature will assign a /48 from google defined ULA prefix fd20::/20.
      .
    firewallPolicy: [Output Only] URL of the firewall policy the network is
      associated with.
    gatewayIPv4: [Output Only] The gateway address for default routing out of
      the network, selected by Google Cloud.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    internalIpv6Range: When enabling ula internal ipv6, caller optionally can
      specify the /48 range they want from the google defined ULA prefix
      fd20::/20. The input must be a valid /48 ULA IPv6 address and must be
      within the fd20::/20. Operation will fail if the speficied /48 is
      already in used by another resource. If the field is not speficied, then
      a /48 range will be randomly allocated from fd20::/20 and returned via
      this field. .
    kind: [Output Only] Type of the resource. Always compute#network for
      networks.
    mtu: Maximum Transmission Unit in bytes. The minimum value for this field
      is 1300 and the maximum value is 8896. The suggested value is 1500,
      which is the default MTU used on the Internet, or 8896 if you want to
      use Jumbo frames. If unspecified, the value defaults to 1460.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character
      must be a lowercase letter, and all following characters (except for the
      last character) must be a dash, lowercase letter, or digit. The last
      character must be a lowercase letter or digit.
    networkFirewallPolicyEnforcementOrder: The network firewall policy
      enforcement order. Can be either AFTER_CLASSIC_FIREWALL or
      BEFORE_CLASSIC_FIREWALL. Defaults to AFTER_CLASSIC_FIREWALL if the field
      is not specified.
    networkProfile: A full or partial URL of the network profile to apply to
      this network. This field can be set only at resource creation time. For
      example, the following are valid URLs: - https://www.googleapis.com/comp
      ute/{api_version}/projects/{project_id}/global/networkProfiles/{network_
      profile_name} -
      projects/{project_id}/global/networkProfiles/{network_profile_name}
    peerings: [Output Only] A list of network peerings for the resource.
    region: [Output Only] URL of the region where the regional network
      resides. This field is not applicable to global network. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    routingConfig: The network-level routing configuration for this network.
      Used by Cloud Router to determine what type of network-wide routing
      behavior to enforce.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    subnetworks: [Output Only] Server-defined fully-qualified URLs for all
      subnetworks in this VPC network.
  """

  class NetworkFirewallPolicyEnforcementOrderValueValuesEnum(_messages.Enum):
    r"""The network firewall policy enforcement order. Can be either
    AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to
    AFTER_CLASSIC_FIREWALL if the field is not specified.

    Values:
      AFTER_CLASSIC_FIREWALL: <no description>
      BEFORE_CLASSIC_FIREWALL: <no description>
    """
    AFTER_CLASSIC_FIREWALL = 0
    BEFORE_CLASSIC_FIREWALL = 1

  IPv4Range = _messages.StringField(1)
  autoCreateSubnetworks = _messages.BooleanField(2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  enableUlaInternalIpv6 = _messages.BooleanField(5)
  firewallPolicy = _messages.StringField(6)
  gatewayIPv4 = _messages.StringField(7)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  internalIpv6Range = _messages.StringField(9)
  kind = _messages.StringField(10, default='compute#network')
  mtu = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  name = _messages.StringField(12)
  networkFirewallPolicyEnforcementOrder = _messages.EnumField('NetworkFirewallPolicyEnforcementOrderValueValuesEnum', 13)
  networkProfile = _messages.StringField(14)
  peerings = _messages.MessageField('NetworkPeering', 15, repeated=True)
  region = _messages.StringField(16)
  routingConfig = _messages.MessageField('NetworkRoutingConfig', 17)
  selfLink = _messages.StringField(18)
  selfLinkWithId = _messages.StringField(19)
  subnetworks = _messages.StringField(20, repeated=True)


class NetworkAttachment(_messages.Message):
  r"""NetworkAttachments A network attachment resource ...

  Enums:
    ConnectionPreferenceValueValuesEnum:

  Fields:
    connectionEndpoints: [Output Only] An array of connections for all the
      producers connected to this network attachment.
    connectionPreference: A ConnectionPreferenceValueValuesEnum attribute.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. An up-to-date
      fingerprint must be provided in order to patch.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: [Output Only] The URL of the network which the Network Attachment
      belongs to. Practically it is inferred by fetching the network of the
      first subnetwork associated. Because it is required that all the
      subnetworks must be from the same network, it is assured that the
      Network Attachment belongs to the same network as all the subnetworks.
    producerAcceptLists: Projects that are allowed to connect to this network
      attachment. The project can be specified using its id or number.
    producerRejectLists: Projects that are not allowed to connect to this
      network attachment. The project can be specified using its id or number.
    region: [Output Only] URL of the region where the network attachment
      resides. This field applies only to the region resource. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    subnetworks: An array of URLs where each entry is the URL of a subnet
      provided by the service consumer to use for endpoints in the producers
      that connect to this network attachment.
  """

  class ConnectionPreferenceValueValuesEnum(_messages.Enum):
    r"""ConnectionPreferenceValueValuesEnum enum type.

    Values:
      ACCEPT_AUTOMATIC: <no description>
      ACCEPT_MANUAL: <no description>
      INVALID: <no description>
    """
    ACCEPT_AUTOMATIC = 0
    ACCEPT_MANUAL = 1
    INVALID = 2

  connectionEndpoints = _messages.MessageField('NetworkAttachmentConnectedEndpoint', 1, repeated=True)
  connectionPreference = _messages.EnumField('ConnectionPreferenceValueValuesEnum', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  fingerprint = _messages.BytesField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#networkAttachment')
  name = _messages.StringField(8)
  network = _messages.StringField(9)
  producerAcceptLists = _messages.StringField(10, repeated=True)
  producerRejectLists = _messages.StringField(11, repeated=True)
  region = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)
  subnetworks = _messages.StringField(15, repeated=True)


class NetworkAttachmentAggregatedList(_messages.Message):
  r"""Contains a list of NetworkAttachmentsScopedList.

  Messages:
    ItemsValue: A list of NetworkAttachmentsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkAttachmentsScopedList resources.
    kind: A string attribute.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NetworkAttachmentsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        NetworkAttachments.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NetworkAttachmentsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NetworkAttachmentsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#networkAttachmentAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NetworkAttachmentConnectedEndpoint(_messages.Message):
  r"""[Output Only] A connection connected to this network attachment.

  Enums:
    StatusValueValuesEnum: The status of a connected endpoint to this network
      attachment.

  Fields:
    ipAddress: The IPv4 address assigned to the producer instance network
      interface. This value will be a range in case of Serverless.
    ipv6Address: The IPv6 address assigned to the producer instance network
      interface. This is only assigned when the stack types of both the
      instance network interface and the consumer subnet are IPv4_IPv6.
    projectIdOrNum: The project id or number of the interface to which the IP
      was assigned.
    secondaryIpCidrRanges: Alias IP ranges from the same subnetwork.
    status: The status of a connected endpoint to this network attachment.
    subnetwork: The subnetwork used to assign the IP to the producer instance
      network interface.
    subnetworkCidrRange: [Output Only] The CIDR range of the subnet from which
      the IPv4 internal IP was allocated from.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""The status of a connected endpoint to this network attachment.

    Values:
      ACCEPTED: The consumer allows traffic from the producer to reach its
        VPC.
      CLOSED: The consumer network attachment no longer exists.
      NEEDS_ATTENTION: The consumer needs to take further action before
        traffic can be served.
      PENDING: The consumer neither allows nor prohibits traffic from the
        producer to reach its VPC.
      REJECTED: The consumer prohibits traffic from the producer to reach its
        VPC.
      STATUS_UNSPECIFIED: <no description>
    """
    ACCEPTED = 0
    CLOSED = 1
    NEEDS_ATTENTION = 2
    PENDING = 3
    REJECTED = 4
    STATUS_UNSPECIFIED = 5

  ipAddress = _messages.StringField(1)
  ipv6Address = _messages.StringField(2)
  projectIdOrNum = _messages.StringField(3)
  secondaryIpCidrRanges = _messages.StringField(4, repeated=True)
  status = _messages.EnumField('StatusValueValuesEnum', 5)
  subnetwork = _messages.StringField(6)
  subnetworkCidrRange = _messages.StringField(7)


class NetworkAttachmentList(_messages.Message):
  r"""A NetworkAttachmentList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkAttachment resources.
    kind: A string attribute.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NetworkAttachment', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#networkAttachmentList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NetworkAttachmentsScopedList(_messages.Message):
  r"""A NetworkAttachmentsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of network
      attachments when the list is empty.

  Fields:
    networkAttachments: A list of NetworkAttachments contained in this scope.
    warning: Informational warning which replaces the list of network
      attachments when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of network attachments
    when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  networkAttachments = _messages.MessageField('NetworkAttachment', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NetworkEdgeSecurityService(_messages.Message):
  r"""Represents a Google Cloud Armor network edge security service resource.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a NetworkEdgeSecurityService. An up-to-
      date fingerprint must be provided in order to update the
      NetworkEdgeSecurityService, otherwise the request will fail with error
      412 conditionNotMet. To see the latest fingerprint, make a get() request
      to retrieve a NetworkEdgeSecurityService.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output only] Type of the resource. Always
      compute#networkEdgeSecurityService for NetworkEdgeSecurityServices
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the resource resides. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    securityPolicy: The resource URL for the network edge security service
      associated with this network edge security service.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#networkEdgeSecurityService')
  name = _messages.StringField(6)
  region = _messages.StringField(7)
  securityPolicy = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)


class NetworkEdgeSecurityServiceAggregatedList(_messages.Message):
  r"""A NetworkEdgeSecurityServiceAggregatedList object.

  Messages:
    ItemsValue: A list of NetworkEdgeSecurityServicesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkEdgeSecurityServicesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#networkEdgeSecurityServiceAggregatedList for lists of Network
      Edge Security Services.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NetworkEdgeSecurityServicesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of security
        policies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NetworkEdgeSecurityServicesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NetworkEdgeSecurityServicesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#networkEdgeSecurityServiceAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class NetworkEdgeSecurityServicesScopedList(_messages.Message):
  r"""A NetworkEdgeSecurityServicesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of security
      policies when the list is empty.

  Fields:
    networkEdgeSecurityServices: A list of NetworkEdgeSecurityServices
      contained in this scope.
    warning: Informational warning which replaces the list of security
      policies when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of security policies
    when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  networkEdgeSecurityServices = _messages.MessageField('NetworkEdgeSecurityService', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NetworkEndpoint(_messages.Message):
  r"""The network endpoint.

  Messages:
    AnnotationsValue: Optional metadata defined as annotations on the network
      endpoint.

  Fields:
    annotations: Optional metadata defined as annotations on the network
      endpoint.
    clientDestinationPort: Represents the port number to which PSC consumer
      sends packets. Optional. Only valid for network endpoint groups created
      with GCE_VM_IP_PORTMAP endpoint type.
    fqdn: Optional fully qualified domain name of network endpoint. This can
      only be specified when NetworkEndpointGroup.network_endpoint_type is
      NON_GCP_FQDN_PORT.
    instance: The name or a URL of VM instance of this network endpoint.
      Optional, the field presence depends on the network endpoint type. The
      field is required for network endpoints of type GCE_VM_IP and
      GCE_VM_IP_PORT. The instance must be in the same zone of network
      endpoint group (for zonal NEGs) or in the zone within the region of the
      NEG (for regional NEGs). If the ipAddress is specified, it must belongs
      to the VM instance. The name must be 1-63 characters long, and comply
      with RFC1035 or be a valid URL pointing to an existing instance.
    ipAddress: Optional IPv4 address of network endpoint. The IP address must
      belong to a VM in Compute Engine (either the primary IP or as part of an
      aliased IP range). If the IP address is not specified, then the primary
      IP address for the VM instance in the network that the network endpoint
      group belongs to will be used. This field is redundant and need not be
      set for network endpoints of type GCE_VM_IP. If set, it must be set to
      the primary internal IP address of the attached VM instance that matches
      the subnetwork of the NEG. The primary internal IP address from any NIC
      of a multi-NIC VM instance can be added to a NEG as long as it matches
      the NEG subnetwork.
    ipv6Address: Optional IPv6 address of network endpoint.
    port: Optional port number of network endpoint. If not specified, the
      defaultPort for the network endpoint group will be used. This field can
      not be set for network endpoints of type GCE_VM_IP.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Optional metadata defined as annotations on the network endpoint.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  clientDestinationPort = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  fqdn = _messages.StringField(3)
  instance = _messages.StringField(4)
  ipAddress = _messages.StringField(5)
  ipv6Address = _messages.StringField(6)
  port = _messages.IntegerField(7, variant=_messages.Variant.INT32)


class NetworkEndpointGroup(_messages.Message):
  r"""Represents a collection of network endpoints. A network endpoint group
  (NEG) defines how a set of endpoints should be reached, whether they are
  reachable, and where they are located. For more information about using NEGs
  for different use cases, see Network endpoint groups overview.

  Enums:
    NetworkEndpointTypeValueValuesEnum: Type of network endpoints in this
      network endpoint group. Can be one of GCE_VM_IP, GCE_VM_IP_PORT,
      NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT, INTERNET_IP_PORT,
      SERVERLESS, PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP.
    TypeValueValuesEnum: Specify the type of this network endpoint group. Only
      LOAD_BALANCING is valid for now.

  Messages:
    AnnotationsValue: Optional. Metadata defined as annotations on the network
      endpoint group.

  Fields:
    annotations: Optional. Metadata defined as annotations on the network
      endpoint group.
    appEngine: Optional. Only valid when networkEndpointType is SERVERLESS.
      Only one of cloudRun, appEngine or cloudFunction may be set.
    cloudFunction: Optional. Only valid when networkEndpointType is
      SERVERLESS. Only one of cloudRun, appEngine or cloudFunction may be set.
    cloudRun: Optional. Only valid when networkEndpointType is SERVERLESS.
      Only one of cloudRun, appEngine or cloudFunction may be set.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    defaultPort: The default port used if the port number is not specified in
      the network endpoint. Optional. If the network endpoint type is either
      GCE_VM_IP, SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be
      specified.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always
      compute#networkEndpointGroup for network endpoint group.
    loadBalancer: This field is only valid when the network endpoint group is
      used for load balancing. [Deprecated] This field is deprecated.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: The URL of the network to which all network endpoints in the NEG
      belong. Uses default project network if unspecified.
    networkEndpointType: Type of network endpoints in this network endpoint
      group. Can be one of GCE_VM_IP, GCE_VM_IP_PORT, NON_GCP_PRIVATE_IP_PORT,
      INTERNET_FQDN_PORT, INTERNET_IP_PORT, SERVERLESS,
      PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP.
    pscData: Optional. Only valid when networkEndpointType is
      PRIVATE_SERVICE_CONNECT.
    pscTargetService: The target service url used to set up private service
      connection to a Google API or a PSC Producer Service Attachment. An
      example value is: asia-northeast3-cloudkms.googleapis.com. Optional.
      Only valid when networkEndpointType is PRIVATE_SERVICE_CONNECT.
    region: [Output Only] The URL of the region where the network endpoint
      group is located.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serverlessDeployment: Only valid when networkEndpointType is SERVERLESS.
      Only one of cloudRun, appEngine, cloudFunction or serverlessDeployment
      may be set.
    size: [Output only] Number of network endpoints in the network endpoint
      group.
    subnetwork: Optional URL of the subnetwork to which all network endpoints
      in the NEG belong.
    type: Specify the type of this network endpoint group. Only LOAD_BALANCING
      is valid for now.
    zone: [Output Only] The URL of the zone where the network endpoint group
      is located.
  """

  class NetworkEndpointTypeValueValuesEnum(_messages.Enum):
    r"""Type of network endpoints in this network endpoint group. Can be one
    of GCE_VM_IP, GCE_VM_IP_PORT, NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,
    INTERNET_IP_PORT, SERVERLESS, PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP.

    Values:
      GCE_VM_IP: The network endpoint is represented by an IP address.
      GCE_VM_IP_PORT: The network endpoint is represented by IP address and
        port pair.
      GCE_VM_IP_PORTMAP: The network endpoint is represented by an IP, Port
        and Client Destination Port.
      INTERNET_FQDN_PORT: The network endpoint is represented by fully
        qualified domain name and port.
      INTERNET_IP_PORT: The network endpoint is represented by an internet IP
        address and port.
      NON_GCP_PRIVATE_IP_PORT: The network endpoint is represented by an IP
        address and port. The endpoint belongs to a VM or pod running in a
        customer's on-premises.
      PRIVATE_SERVICE_CONNECT: The network endpoint is either public Google
        APIs or services exposed by other GCP Project with a Service
        Attachment. The connection is set up by private service connect
      SERVERLESS: The network endpoint is handled by specified serverless
        infrastructure.
    """
    GCE_VM_IP = 0
    GCE_VM_IP_PORT = 1
    GCE_VM_IP_PORTMAP = 2
    INTERNET_FQDN_PORT = 3
    INTERNET_IP_PORT = 4
    NON_GCP_PRIVATE_IP_PORT = 5
    PRIVATE_SERVICE_CONNECT = 6
    SERVERLESS = 7

  class TypeValueValuesEnum(_messages.Enum):
    r"""Specify the type of this network endpoint group. Only LOAD_BALANCING
    is valid for now.

    Values:
      LOAD_BALANCING: The network endpoint group is a backend of a load
        balancer.
    """
    LOAD_BALANCING = 0

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Optional. Metadata defined as annotations on the network endpoint
    group.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  appEngine = _messages.MessageField('NetworkEndpointGroupAppEngine', 2)
  cloudFunction = _messages.MessageField('NetworkEndpointGroupCloudFunction', 3)
  cloudRun = _messages.MessageField('NetworkEndpointGroupCloudRun', 4)
  creationTimestamp = _messages.StringField(5)
  defaultPort = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  description = _messages.StringField(7)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(9, default='compute#networkEndpointGroup')
  loadBalancer = _messages.MessageField('NetworkEndpointGroupLbNetworkEndpointGroup', 10)
  name = _messages.StringField(11)
  network = _messages.StringField(12)
  networkEndpointType = _messages.EnumField('NetworkEndpointTypeValueValuesEnum', 13)
  pscData = _messages.MessageField('NetworkEndpointGroupPscData', 14)
  pscTargetService = _messages.StringField(15)
  region = _messages.StringField(16)
  selfLink = _messages.StringField(17)
  selfLinkWithId = _messages.StringField(18)
  serverlessDeployment = _messages.MessageField('NetworkEndpointGroupServerlessDeployment', 19)
  size = _messages.IntegerField(20, variant=_messages.Variant.INT32)
  subnetwork = _messages.StringField(21)
  type = _messages.EnumField('TypeValueValuesEnum', 22)
  zone = _messages.StringField(23)


class NetworkEndpointGroupAggregatedList(_messages.Message):
  r"""A NetworkEndpointGroupAggregatedList object.

  Messages:
    ItemsValue: A list of NetworkEndpointGroupsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkEndpointGroupsScopedList resources.
    kind: [Output Only] The resource type, which is always
      compute#networkEndpointGroupAggregatedList for aggregated lists of
      network endpoint groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NetworkEndpointGroupsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: The name of the scope that contains this set of
        network endpoint groups.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NetworkEndpointGroupsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NetworkEndpointGroupsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#networkEndpointGroupAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NetworkEndpointGroupAppEngine(_messages.Message):
  r"""Configuration for an App Engine network endpoint group (NEG). The
  service is optional, may be provided explicitly or in the URL mask. The
  version is optional and can only be provided explicitly or in the URL mask
  when service is present. Note: App Engine service must be in the same
  project and located in the same region as the Serverless NEG.

  Fields:
    service: Optional serving service. The service name is case-sensitive and
      must be 1-63 characters long. Example value: default, my-service.
    urlMask: An URL mask is one of the main components of the Cloud Function.
      A template to parse service and version fields from a request URL. URL
      mask allows for routing to multiple App Engine services without having
      to create multiple Network Endpoint Groups and backend services. For
      example, the request URLs foo1-dot-appname.appspot.com/v1 and foo1-dot-
      appname.appspot.com/v2 can be backed by the same Serverless NEG with URL
      mask <service>-dot-appname.appspot.com/<version>. The URL mask will
      parse them to { service = "foo1", version = "v1" } and { service =
      "foo1", version = "v2" } respectively.
    version: Optional serving version. The version name is case-sensitive and
      must be 1-100 characters long. Example value: v1, v2.
  """

  service = _messages.StringField(1)
  urlMask = _messages.StringField(2)
  version = _messages.StringField(3)


class NetworkEndpointGroupCloudFunction(_messages.Message):
  r"""Configuration for a Cloud Function network endpoint group (NEG). The
  function must be provided explicitly or in the URL mask. Note: Cloud
  Function must be in the same project and located in the same region as the
  Serverless NEG.

  Fields:
    function: A user-defined name of the Cloud Function. The function name is
      case-sensitive and must be 1-63 characters long. Example value: func1.
    urlMask: An URL mask is one of the main components of the Cloud Function.
      A template to parse function field from a request URL. URL mask allows
      for routing to multiple Cloud Functions without having to create
      multiple Network Endpoint Groups and backend services. For example,
      request URLs mydomain.com/function1 and mydomain.com/function2 can be
      backed by the same Serverless NEG with URL mask /<function>. The URL
      mask will parse them to { function = "function1" } and { function =
      "function2" } respectively.
  """

  function = _messages.StringField(1)
  urlMask = _messages.StringField(2)


class NetworkEndpointGroupCloudRun(_messages.Message):
  r"""Configuration for a Cloud Run network endpoint group (NEG). The service
  must be provided explicitly or in the URL mask. The tag is optional, may be
  provided explicitly or in the URL mask. Note: Cloud Run service must be in
  the same project and located in the same region as the Serverless NEG.

  Fields:
    service: Cloud Run service is the main resource of Cloud Run. The service
      must be 1-63 characters long, and comply with RFC1035. Example value:
      "run-service".
    tag: Optional Cloud Run tag represents the "named-revision" to provide
      additional fine-grained traffic routing information. The tag must be
      1-63 characters long, and comply with RFC1035. Example value:
      "revision-0010".
    urlMask: An URL mask is one of the main components of the Cloud Function.
      A template to parse <service> and <tag> fields from a request URL. URL
      mask allows for routing to multiple Run services without having to
      create multiple network endpoint groups and backend services. For
      example, request URLs foo1.domain.com/bar1 and foo1.domain.com/bar2 can
      be backed by the same Serverless Network Endpoint Group (NEG) with URL
      mask <tag>.domain.com/<service>. The URL mask will parse them to {
      service="bar1", tag="foo1" } and { service="bar2", tag="foo2" }
      respectively.
  """

  service = _messages.StringField(1)
  tag = _messages.StringField(2)
  urlMask = _messages.StringField(3)


class NetworkEndpointGroupLbNetworkEndpointGroup(_messages.Message):
  r"""Load balancing specific fields for network endpoint group.

  Fields:
    defaultPort: The default port used if the port number is not specified in
      the network endpoint. If the network endpoint type is either GCE_VM_IP,
      SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be specified.
      [Deprecated] This field is deprecated.
    network: The URL of the network to which all network endpoints in the NEG
      belong. Uses default project network if unspecified. [Deprecated] This
      field is deprecated.
    subnetwork: Optional URL of the subnetwork to which all network endpoints
      in the NEG belong. [Deprecated] This field is deprecated.
    zone: [Output Only] The URL of the zone where the network endpoint group
      is located. [Deprecated] This field is deprecated.
  """

  defaultPort = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  network = _messages.StringField(2)
  subnetwork = _messages.StringField(3)
  zone = _messages.StringField(4)


class NetworkEndpointGroupList(_messages.Message):
  r"""A NetworkEndpointGroupList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkEndpointGroup resources.
    kind: [Output Only] The resource type, which is always
      compute#networkEndpointGroupList for network endpoint group lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NetworkEndpointGroup', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#networkEndpointGroupList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NetworkEndpointGroupPscData(_messages.Message):
  r"""All data that is specifically relevant to only network endpoint groups
  of type PRIVATE_SERVICE_CONNECT.

  Enums:
    PscConnectionStatusValueValuesEnum: [Output Only] The connection status of
      the PSC Forwarding Rule.

  Fields:
    consumerPscAddress: [Output Only] Address allocated from given subnetwork
      for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act
      as an endpoint in L7 PSC-XLB.
    producerPort: The psc producer port is used to connect PSC NEG with
      specific port on the PSC Producer side; should only be used for the
      PRIVATE_SERVICE_CONNECT NEG type
    pscConnectionId: [Output Only] The PSC connection id of the PSC Network
      Endpoint Group Consumer.
    pscConnectionStatus: [Output Only] The connection status of the PSC
      Forwarding Rule.
  """

  class PscConnectionStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The connection status of the PSC Forwarding Rule.

    Values:
      ACCEPTED: The connection has been accepted by the producer.
      CLOSED: The connection has been closed by the producer and will not
        serve traffic going forward.
      NEEDS_ATTENTION: The connection has been accepted by the producer, but
        the producer needs to take further action before the forwarding rule
        can serve traffic.
      PENDING: The connection is pending acceptance by the producer.
      REJECTED: The connection has been rejected by the producer.
      STATUS_UNSPECIFIED: <no description>
    """
    ACCEPTED = 0
    CLOSED = 1
    NEEDS_ATTENTION = 2
    PENDING = 3
    REJECTED = 4
    STATUS_UNSPECIFIED = 5

  consumerPscAddress = _messages.StringField(1)
  producerPort = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  pscConnectionId = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  pscConnectionStatus = _messages.EnumField('PscConnectionStatusValueValuesEnum', 4)


class NetworkEndpointGroupServerlessDeployment(_messages.Message):
  r"""Configuration for a serverless network endpoint group (NEG). The
  platform must be provided. Note: The target backend service must be in the
  same project and located in the same region as the Serverless NEG.

  Fields:
    platform: The platform of the backend target(s) of this NEG. The only
      supported value is API Gateway: apigateway.googleapis.com.
    resource: The user-defined name of the workload/instance. This value must
      be provided explicitly or in the urlMask. The resource identified by
      this value is platform-specific and is as follows: 1. API Gateway: The
      gateway ID 2. App Engine: The service name 3. Cloud Functions: The
      function name 4. Cloud Run: The service name
    urlMask: An URL mask is one of the main components of the Cloud Function.
      A template to parse platform-specific fields from a request URL. URL
      mask allows for routing to multiple resources on the same serverless
      platform without having to create multiple Network Endpoint Groups and
      backend resources. The fields parsed by this template are platform-
      specific and are as follows: 1. API Gateway: The gateway ID 2. App
      Engine: The service and version 3. Cloud Functions: The function name 4.
      Cloud Run: The service and tag
    version: The optional resource version. The version identified by this
      value is platform-specific and is follows: 1. API Gateway: Unused 2. App
      Engine: The service version 3. Cloud Functions: Unused 4. Cloud Run: The
      service tag
  """

  platform = _messages.StringField(1)
  resource = _messages.StringField(2)
  urlMask = _messages.StringField(3)
  version = _messages.StringField(4)


class NetworkEndpointGroupsAttachEndpointsRequest(_messages.Message):
  r"""A NetworkEndpointGroupsAttachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be attached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class NetworkEndpointGroupsDetachEndpointsRequest(_messages.Message):
  r"""A NetworkEndpointGroupsDetachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be detached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class NetworkEndpointGroupsListEndpointsRequest(_messages.Message):
  r"""A NetworkEndpointGroupsListEndpointsRequest object.

  Enums:
    HealthStatusValueValuesEnum: Optional query parameter for showing the
      health status of each network endpoint. Valid options are SKIP or SHOW.
      If you don't specify this parameter, the health status of network
      endpoints will not be provided.

  Fields:
    endpointFilters: Optional list of endpoints to query. This is a more
      efficient but also limited version of filter parameter. Endpoints in the
      filter must have ip_address and port fields populated, other fields are
      not supported.
    healthStatus: Optional query parameter for showing the health status of
      each network endpoint. Valid options are SKIP or SHOW. If you don't
      specify this parameter, the health status of network endpoints will not
      be provided.
  """

  class HealthStatusValueValuesEnum(_messages.Enum):
    r"""Optional query parameter for showing the health status of each network
    endpoint. Valid options are SKIP or SHOW. If you don't specify this
    parameter, the health status of network endpoints will not be provided.

    Values:
      SHOW: Show the health status for each network endpoint. Impacts latency
        of the call.
      SKIP: Health status for network endpoints will not be provided.
    """
    SHOW = 0
    SKIP = 1

  endpointFilters = _messages.MessageField('NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter', 1, repeated=True)
  healthStatus = _messages.EnumField('HealthStatusValueValuesEnum', 2)


class NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter(_messages.Message):
  r"""A NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter object.

  Fields:
    networkEndpoint: A NetworkEndpoint attribute.
  """

  networkEndpoint = _messages.MessageField('NetworkEndpoint', 1)


class NetworkEndpointGroupsListNetworkEndpoints(_messages.Message):
  r"""A NetworkEndpointGroupsListNetworkEndpoints object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkEndpointWithHealthStatus resources.
    kind: [Output Only] The resource type, which is always
      compute#networkEndpointGroupsListNetworkEndpoints for the list of
      network endpoints in the specified network endpoint group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NetworkEndpointWithHealthStatus', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#networkEndpointGroupsListNetworkEndpoints')
  nextPageToken = _messages.StringField(4)
  warning = _messages.MessageField('WarningValue', 5)


class NetworkEndpointGroupsScopedList(_messages.Message):
  r"""A NetworkEndpointGroupsScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that replaces the
      list of network endpoint groups when the list is empty.

  Fields:
    networkEndpointGroups: [Output Only] The list of network endpoint groups
      that are contained in this scope.
    warning: [Output Only] An informational warning that replaces the list of
      network endpoint groups when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that replaces the list of
    network endpoint groups when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  networkEndpointGroups = _messages.MessageField('NetworkEndpointGroup', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NetworkEndpointWithHealthStatus(_messages.Message):
  r"""A NetworkEndpointWithHealthStatus object.

  Fields:
    healths: [Output only] The health status of network endpoint. Optional.
      Displayed only if the network endpoint has centralized health checking
      configured.
    networkEndpoint: [Output only] The network endpoint.
  """

  healths = _messages.MessageField('HealthStatusForNetworkEndpoint', 1, repeated=True)
  networkEndpoint = _messages.MessageField('NetworkEndpoint', 2)


class NetworkFirewallPolicyAggregatedList(_messages.Message):
  r"""A NetworkFirewallPolicyAggregatedList object.

  Messages:
    ItemsValue: A list of FirewallPoliciesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of FirewallPoliciesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#networkFirewallPoliciesAggregatedList for lists of network
      firewall policies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of FirewallPoliciesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        addresses.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A FirewallPoliciesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('FirewallPoliciesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#networkFirewallPolicyAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NetworkInterface(_messages.Message):
  r"""A network interface resource attached to an instance.

  Enums:
    IgmpQueryValueValuesEnum: Indicate whether igmp query is enabled on the
      network interface or not. If enabled, also indicates the version of IGMP
      supported.
    Ipv6AccessTypeValueValuesEnum: [Output Only] One of EXTERNAL, INTERNAL to
      indicate whether the IP can be accessed from the Internet. This field is
      always inherited from its subnetwork. Valid only if stackType is
      IPV4_IPV6.
    NicTypeValueValuesEnum: The type of vNIC to be used on this interface.
      This may be gVNIC or VirtioNet.
    StackTypeValueValuesEnum: The stack type for this network interface. To
      assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6
      addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This
      field can be both set at instance creation and update network interface
      operations.

  Fields:
    accessConfigs: An array of configurations for this interface. Currently,
      only one access config, ONE_TO_ONE_NAT, is supported. If there are no
      accessConfigs specified, then this instance will have no external
      internet access.
    aliasIpRanges: An array of alias IP ranges for this network interface. You
      can only specify this field for network interfaces in VPC networks.
    fingerprint: Fingerprint hash of contents stored in this network
      interface. This field will be ignored when inserting an Instance or
      adding a NetworkInterface. An up-to-date fingerprint must be provided in
      order to update the NetworkInterface. The request will fail with error
      400 Bad Request if the fingerprint is not provided, or 412 Precondition
      Failed if the fingerprint is out of date.
    igmpQuery: Indicate whether igmp query is enabled on the network interface
      or not. If enabled, also indicates the version of IGMP supported.
    internalIpv6PrefixLength: The prefix length of the primary internal IPv6
      range.
    ipv6AccessConfigs: An array of IPv6 access configurations for this
      interface. Currently, only one IPv6 access config, DIRECT_IPV6, is
      supported. If there is no ipv6AccessConfig specified, then this instance
      will have no external IPv6 Internet access.
    ipv6AccessType: [Output Only] One of EXTERNAL, INTERNAL to indicate
      whether the IP can be accessed from the Internet. This field is always
      inherited from its subnetwork. Valid only if stackType is IPV4_IPV6.
    ipv6Address: An IPv6 internal network address for this network interface.
      To use a static internal IP address, it must be unused and in the same
      region as the instance's zone. If not specified, Google Cloud will
      automatically assign an internal IPv6 address from the instance's
      subnetwork.
    kind: [Output Only] Type of the resource. Always compute#networkInterface
      for network interfaces.
    name: [Output Only] The name of the network interface, which is generated
      by the server. For a VM, the network interface uses the nicN naming
      format. Where N is a value between 0 and 7. The default interface value
      is nic0.
    network: URL of the VPC network resource for this instance. When creating
      an instance, if neither the network nor the subnetwork is specified, the
      default network global/networks/default is used. If the selected project
      doesn't have the default network, you must specify a network or subnet.
      If the network is not specified but the subnetwork is specified, the
      network is inferred. If you specify this property, you can specify the
      network as a full or partial URL. For example, the following are all
      valid URLs: -
      https://www.googleapis.com/compute/v1/projects/project/global/networks/
      network - projects/project/global/networks/network -
      global/networks/default
    networkAttachment: The URL of the network attachment that this interface
      should connect to in the following format: projects/{project_number}/reg
      ions/{region_name}/networkAttachments/{network_attachment_name}.
    networkIP: An IPv4 internal IP address to assign to the instance for this
      network interface. If not specified by the user, an unused internal IP
      is assigned by the system.
    nicType: The type of vNIC to be used on this interface. This may be gVNIC
      or VirtioNet.
    parentNicName: Name of the parent network interface of a dynamic network
      interface.
    queueCount: The networking queue count that's specified by users for the
      network interface. Both Rx and Tx queues will be set to this number.
      It'll be empty if not specified by the users.
    stackType: The stack type for this network interface. To assign only IPv4
      addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use
      IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both
      set at instance creation and update network interface operations.
    subinterfaces: SubInterfaces help enable L2 communication for the instance
      over subnetworks that support L2. Every network interface will get a
      default untagged (vlan not specified) subinterface. Users can specify
      additional tagged subinterfaces which are sub-fields to the Network
      Interface.
    subnetwork: The URL of the Subnetwork resource for this instance. If the
      network resource is in legacy mode, do not specify this field. If the
      network is in auto subnet mode, specifying the subnetwork is optional.
      If the network is in custom subnet mode, specifying the subnetwork is
      required. If you specify this field, you can specify the subnetwork as a
      full or partial URL. For example, the following are all valid URLs: -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /subnetworks/subnetwork - regions/region/subnetworks/subnetwork
    vlan: VLAN tag of a dynamic network interface, must be an integer in the
      range from 2 to 255 inclusively.
  """

  class IgmpQueryValueValuesEnum(_messages.Enum):
    r"""Indicate whether igmp query is enabled on the network interface or
    not. If enabled, also indicates the version of IGMP supported.

    Values:
      IGMP_QUERY_DISABLED: The network interface has disabled IGMP query.
      IGMP_QUERY_V2: The network interface has enabled IGMP query - v2.
    """
    IGMP_QUERY_DISABLED = 0
    IGMP_QUERY_V2 = 1

  class Ipv6AccessTypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can
    be accessed from the Internet. This field is always inherited from its
    subnetwork. Valid only if stackType is IPV4_IPV6.

    Values:
      EXTERNAL: This network interface can have external IPv6.
      INTERNAL: This network interface can have internal IPv6.
    """
    EXTERNAL = 0
    INTERNAL = 1

  class NicTypeValueValuesEnum(_messages.Enum):
    r"""The type of vNIC to be used on this interface. This may be gVNIC or
    VirtioNet.

    Values:
      GVNIC: GVNIC
      IDPF: IDPF
      IRDMA: IRDMA
      MRDMA: MRDMA
      UNSPECIFIED_NIC_TYPE: No type specified.
      VIRTIO_NET: VIRTIO
    """
    GVNIC = 0
    IDPF = 1
    IRDMA = 2
    MRDMA = 3
    UNSPECIFIED_NIC_TYPE = 4
    VIRTIO_NET = 5

  class StackTypeValueValuesEnum(_messages.Enum):
    r"""The stack type for this network interface. To assign only IPv4
    addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use
    IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set
    at instance creation and update network interface operations.

    Values:
      IPV4_IPV6: The network interface can have both IPv4 and IPv6 addresses.
      IPV4_ONLY: The network interface will only be assigned IPv4 addresses.
      IPV6_ONLY: The network interface will only be assigned IPv6 addresses.
    """
    IPV4_IPV6 = 0
    IPV4_ONLY = 1
    IPV6_ONLY = 2

  accessConfigs = _messages.MessageField('AccessConfig', 1, repeated=True)
  aliasIpRanges = _messages.MessageField('AliasIpRange', 2, repeated=True)
  fingerprint = _messages.BytesField(3)
  igmpQuery = _messages.EnumField('IgmpQueryValueValuesEnum', 4)
  internalIpv6PrefixLength = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  ipv6AccessConfigs = _messages.MessageField('AccessConfig', 6, repeated=True)
  ipv6AccessType = _messages.EnumField('Ipv6AccessTypeValueValuesEnum', 7)
  ipv6Address = _messages.StringField(8)
  kind = _messages.StringField(9, default='compute#networkInterface')
  name = _messages.StringField(10)
  network = _messages.StringField(11)
  networkAttachment = _messages.StringField(12)
  networkIP = _messages.StringField(13)
  nicType = _messages.EnumField('NicTypeValueValuesEnum', 14)
  parentNicName = _messages.StringField(15)
  queueCount = _messages.IntegerField(16, variant=_messages.Variant.INT32)
  stackType = _messages.EnumField('StackTypeValueValuesEnum', 17)
  subinterfaces = _messages.MessageField('NetworkInterfaceSubInterface', 18, repeated=True)
  subnetwork = _messages.StringField(19)
  vlan = _messages.IntegerField(20, variant=_messages.Variant.INT32)


class NetworkInterfaceSubInterface(_messages.Message):
  r"""A NetworkInterfaceSubInterface object.

  Enums:
    IpAllocationModeValueValuesEnum:

  Fields:
    ipAddress: An IPv4 internal IP address to assign to the instance for this
      subinterface. If specified, ip_allocation_mode should be set to
      ALLOCATE_IP.
    ipAllocationMode: A IpAllocationModeValueValuesEnum attribute.
    subnetwork: If specified, this subnetwork must belong to the same network
      as that of the network interface. If not specified the subnet of network
      interface will be used. If you specify this property, you can specify
      the subnetwork as a full or partial URL. For example, the following are
      all valid URLs: -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /subnetworks/subnetwork - regions/region/subnetworks/subnetwork
    vlan: VLAN tag. Should match the VLAN(s) supported by the subnetwork to
      which this subinterface is connecting.
  """

  class IpAllocationModeValueValuesEnum(_messages.Enum):
    r"""IpAllocationModeValueValuesEnum enum type.

    Values:
      ALLOCATE_IP: Allocates an internal IPv4 IP address from subnets
        secondary IP Range.
      DO_NOT_ALLOCATE_IP: No IP allocation is done for the subinterface.
      UNSPECIFIED: <no description>
    """
    ALLOCATE_IP = 0
    DO_NOT_ALLOCATE_IP = 1
    UNSPECIFIED = 2

  ipAddress = _messages.StringField(1)
  ipAllocationMode = _messages.EnumField('IpAllocationModeValueValuesEnum', 2)
  subnetwork = _messages.StringField(3)
  vlan = _messages.IntegerField(4, variant=_messages.Variant.INT32)


class NetworkList(_messages.Message):
  r"""Contains a list of networks.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Network resources.
    kind: [Output Only] Type of resource. Always compute#networkList for lists
      of networks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Network', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#networkList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NetworkPeering(_messages.Message):
  r"""A network peering attached to a network resource. The message includes
  the peering name, peer network, peering state, and a flag indicating whether
  Google Compute Engine should automatically create routes for the peering.

  Enums:
    StackTypeValueValuesEnum: Which IP version(s) of traffic and routes are
      allowed to be imported or exported between peer networks. The default
      value is IPV4_ONLY.
    StateValueValuesEnum: [Output Only] State for the peering, either `ACTIVE`
      or `INACTIVE`. The peering is `ACTIVE` when there's a matching
      configuration in the peer network.
    UpdateStrategyValueValuesEnum: The update strategy determines the
      semantics for updates and deletes to the peering connection
      configuration.

  Fields:
    advertisePeerSubnetsViaRouters: Whether Cloud Routers in this network can
      automatically advertise subnets from the peer network.
    autoCreateRoutes: This field will be deprecated soon. Use the
      exchange_subnet_routes field instead. Indicates whether full mesh
      connectivity is created and managed automatically between peered
      networks. Currently this field should always be true since Google
      Compute Engine will automatically create and manage subnetwork routes
      between two networks when peering state is ACTIVE.
    connectionStatus: [Output Only] The effective state of the peering
      connection as a whole.
    exchangeSubnetRoutes: Indicates whether full mesh connectivity is created
      and managed automatically between peered networks. Currently this field
      should always be true since Google Compute Engine will automatically
      create and manage subnetwork routes between two networks when peering
      state is ACTIVE.
    exportCustomRoutes: Whether to export the custom routes to peer network.
      The default value is false.
    exportSubnetRoutesWithPublicIp: Whether subnet routes with public IP range
      are exported. The default value is true, all subnet routes are exported.
      IPv4 special-use ranges are always exported to peers and are not
      controlled by this field.
    importCustomRoutes: Whether to import the custom routes from peer network.
      The default value is false.
    importSubnetRoutesWithPublicIp: Whether subnet routes with public IP range
      are imported. The default value is false. IPv4 special-use ranges are
      always imported from peers and are not controlled by this field.
    name: Name of this peering. Provided by the client when the peering is
      created. The name must comply with RFC1035. Specifically, the name must
      be 1-63 characters long and match regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase
      letter, and all the following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash.
    network: The URL of the peer network. It can be either full URL or partial
      URL. The peer network may belong to a different project. If the partial
      URL does not contain project, it is assumed that the peer network is in
      the same project as the current network.
    peerMtu: Maximum Transmission Unit in bytes.
    stackType: Which IP version(s) of traffic and routes are allowed to be
      imported or exported between peer networks. The default value is
      IPV4_ONLY.
    state: [Output Only] State for the peering, either `ACTIVE` or `INACTIVE`.
      The peering is `ACTIVE` when there's a matching configuration in the
      peer network.
    stateDetails: [Output Only] Details about the current state of the
      peering.
    updateStrategy: The update strategy determines the semantics for updates
      and deletes to the peering connection configuration.
  """

  class StackTypeValueValuesEnum(_messages.Enum):
    r"""Which IP version(s) of traffic and routes are allowed to be imported
    or exported between peer networks. The default value is IPV4_ONLY.

    Values:
      IPV4_IPV6: This Peering will allow IPv4 traffic and routes to be
        exchanged. Additionally if the matching peering is IPV4_IPV6, IPv6
        traffic and routes will be exchanged as well.
      IPV4_ONLY: This Peering will only allow IPv4 traffic and routes to be
        exchanged, even if the matching peering is IPV4_IPV6.
    """
    IPV4_IPV6 = 0
    IPV4_ONLY = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] State for the peering, either `ACTIVE` or `INACTIVE`.
    The peering is `ACTIVE` when there's a matching configuration in the peer
    network.

    Values:
      ACTIVE: Matching configuration exists on the peer.
      INACTIVE: There is no matching configuration on the peer, including the
        case when peer does not exist.
    """
    ACTIVE = 0
    INACTIVE = 1

  class UpdateStrategyValueValuesEnum(_messages.Enum):
    r"""The update strategy determines the semantics for updates and deletes
    to the peering connection configuration.

    Values:
      CONSENSUS: Updates are reflected in the local peering but aren't applied
        to the peering connection until a complementary change is made to the
        matching peering. To delete a peering with the consensus update
        strategy, both the peerings must request the deletion of the peering
        before the peering can be deleted.
      INDEPENDENT: In this mode changes to the peering configuration can be
        unilaterally altered by changing a single network peering. This is the
        default value if the field is unspecified.
      UNSPECIFIED: Peerings with update strategy UNSPECIFIED are created with
        update strategy INDEPENDENT.
    """
    CONSENSUS = 0
    INDEPENDENT = 1
    UNSPECIFIED = 2

  advertisePeerSubnetsViaRouters = _messages.BooleanField(1)
  autoCreateRoutes = _messages.BooleanField(2)
  connectionStatus = _messages.MessageField('NetworkPeeringConnectionStatus', 3)
  exchangeSubnetRoutes = _messages.BooleanField(4)
  exportCustomRoutes = _messages.BooleanField(5)
  exportSubnetRoutesWithPublicIp = _messages.BooleanField(6)
  importCustomRoutes = _messages.BooleanField(7)
  importSubnetRoutesWithPublicIp = _messages.BooleanField(8)
  name = _messages.StringField(9)
  network = _messages.StringField(10)
  peerMtu = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  stackType = _messages.EnumField('StackTypeValueValuesEnum', 12)
  state = _messages.EnumField('StateValueValuesEnum', 13)
  stateDetails = _messages.StringField(14)
  updateStrategy = _messages.EnumField('UpdateStrategyValueValuesEnum', 15)


class NetworkPeeringConnectionStatus(_messages.Message):
  r"""[Output Only] Describes the state of a peering connection, not just the
  local peering. This field provides information about the effective settings
  for the connection as a whole, including pending delete/update requests for
  CONSENSUS peerings.

  Enums:
    UpdateStrategyValueValuesEnum: The update strategy determines the
      update/delete semantics for this peering connection.

  Fields:
    consensusState: The consensus state contains the information about the
      status of update and delete for a consensus peering connection.
    trafficConfiguration: The active connectivity settings for the peering
      connection based on the settings of the network peerings.
    updateStrategy: The update strategy determines the update/delete semantics
      for this peering connection.
  """

  class UpdateStrategyValueValuesEnum(_messages.Enum):
    r"""The update strategy determines the update/delete semantics for this
    peering connection.

    Values:
      CONSENSUS: Updates are reflected in the local peering but aren't applied
        to the peering connection until a complementary change is made to the
        matching peering. To delete a peering with the consensus update
        strategy, both the peerings must request the deletion of the peering
        before the peering can be deleted.
      INDEPENDENT: In this mode changes to the peering configuration can be
        unilaterally altered by changing a single network peering. This is the
        default value if the field is unspecified.
      UNSPECIFIED: Peerings with update strategy UNSPECIFIED are created with
        update strategy INDEPENDENT.
    """
    CONSENSUS = 0
    INDEPENDENT = 1
    UNSPECIFIED = 2

  consensusState = _messages.MessageField('NetworkPeeringConnectionStatusConsensusState', 1)
  trafficConfiguration = _messages.MessageField('NetworkPeeringConnectionStatusTrafficConfiguration', 2)
  updateStrategy = _messages.EnumField('UpdateStrategyValueValuesEnum', 3)


class NetworkPeeringConnectionStatusConsensusState(_messages.Message):
  r"""Surfaces relevant state for a consensus peering connection update/delete
  semantics. Only set when connection_status.update_strategy is CONSENSUS or
  one network peering is proposing upgrading to CONSENSUS.

  Enums:
    DeleteStatusValueValuesEnum: The status of the delete request.
    UpdateStatusValueValuesEnum: The status of the update request.

  Fields:
    deleteStatus: The status of the delete request.
    updateStatus: The status of the update request.
  """

  class DeleteStatusValueValuesEnum(_messages.Enum):
    r"""The status of the delete request.

    Values:
      DELETE_ACKNOWLEDGED: Both network admins have agreed this consensus
        peering connection can be deleted.
      DELETE_STATUS_UNSPECIFIED: <no description>
      LOCAL_DELETE_REQUESTED: Network admin has requested deletion of this
        peering connection.
      PEER_DELETE_REQUESTED: The peer network admin has requested deletion of
        this peering connection.
    """
    DELETE_ACKNOWLEDGED = 0
    DELETE_STATUS_UNSPECIFIED = 1
    LOCAL_DELETE_REQUESTED = 2
    PEER_DELETE_REQUESTED = 3

  class UpdateStatusValueValuesEnum(_messages.Enum):
    r"""The status of the update request.

    Values:
      IN_SYNC: No pending configuration update proposals to the peering
        connection.
      PENDING_LOCAL_ACKNOWLEDMENT: The peer network admin has made an
        updatePeering call. The change are awaiting acknowledgment from this
        peering's network admin.
      PENDING_PEER_ACKNOWLEDGEMENT: The local network admin has made an
        updatePeering call. The change are awaiting acknowledgment from the
        peer network admin.
      UPDATE_STATUS_UNSPECIFIED: <no description>
    """
    IN_SYNC = 0
    PENDING_LOCAL_ACKNOWLEDMENT = 1
    PENDING_PEER_ACKNOWLEDGEMENT = 2
    UPDATE_STATUS_UNSPECIFIED = 3

  deleteStatus = _messages.EnumField('DeleteStatusValueValuesEnum', 1)
  updateStatus = _messages.EnumField('UpdateStatusValueValuesEnum', 2)


class NetworkPeeringConnectionStatusTrafficConfiguration(_messages.Message):
  r"""A NetworkPeeringConnectionStatusTrafficConfiguration object.

  Enums:
    StackTypeValueValuesEnum: Which IP version(s) of traffic and routes are
      being imported or exported between peer networks.

  Fields:
    exportCustomRoutesToPeer: Whether custom routes are being exported to the
      peer network.
    exportSubnetRoutesWithPublicIpToPeer: Whether subnet routes with public IP
      range are being exported to the peer network.
    importCustomRoutesFromPeer: Whether custom routes is being imported from
      the peer network.
    importSubnetRoutesWithPublicIpFromPeer: Whether subnet routes with public
      IP range are being imported from the peer network.
    stackType: Which IP version(s) of traffic and routes are being imported or
      exported between peer networks.
  """

  class StackTypeValueValuesEnum(_messages.Enum):
    r"""Which IP version(s) of traffic and routes are being imported or
    exported between peer networks.

    Values:
      IPV4_IPV6: This Peering will allow IPv4 traffic and routes to be
        exchanged. Additionally if the matching peering is IPV4_IPV6, IPv6
        traffic and routes will be exchanged as well.
      IPV4_ONLY: This Peering will only allow IPv4 traffic and routes to be
        exchanged, even if the matching peering is IPV4_IPV6.
    """
    IPV4_IPV6 = 0
    IPV4_ONLY = 1

  exportCustomRoutesToPeer = _messages.BooleanField(1)
  exportSubnetRoutesWithPublicIpToPeer = _messages.BooleanField(2)
  importCustomRoutesFromPeer = _messages.BooleanField(3)
  importSubnetRoutesWithPublicIpFromPeer = _messages.BooleanField(4)
  stackType = _messages.EnumField('StackTypeValueValuesEnum', 5)


class NetworkPerformanceConfig(_messages.Message):
  r"""A NetworkPerformanceConfig object.

  Enums:
    ExternalIpEgressBandwidthTierValueValuesEnum:
    TotalEgressBandwidthTierValueValuesEnum:

  Fields:
    externalIpEgressBandwidthTier: A
      ExternalIpEgressBandwidthTierValueValuesEnum attribute.
    totalEgressBandwidthTier: A TotalEgressBandwidthTierValueValuesEnum
      attribute.
  """

  class ExternalIpEgressBandwidthTierValueValuesEnum(_messages.Enum):
    r"""ExternalIpEgressBandwidthTierValueValuesEnum enum type.

    Values:
      DEFAULT: <no description>
      TIER_1: <no description>
    """
    DEFAULT = 0
    TIER_1 = 1

  class TotalEgressBandwidthTierValueValuesEnum(_messages.Enum):
    r"""TotalEgressBandwidthTierValueValuesEnum enum type.

    Values:
      DEFAULT: <no description>
      TIER_1: <no description>
    """
    DEFAULT = 0
    TIER_1 = 1

  externalIpEgressBandwidthTier = _messages.EnumField('ExternalIpEgressBandwidthTierValueValuesEnum', 1)
  totalEgressBandwidthTier = _messages.EnumField('TotalEgressBandwidthTierValueValuesEnum', 2)


class NetworkProfile(_messages.Message):
  r"""NetworkProfile represents a Google managed network profile resource.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: [Output Only] An optional description of this resource.
    features: [Output Only] Features supported by the network.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#networkProfile
      for network profiles.
    location: [Output Only] Location to which the network is restricted.
    name: [Output Only] Name of the resource.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  features = _messages.MessageField('NetworkProfileNetworkFeatures', 3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#networkProfile')
  location = _messages.MessageField('NetworkProfileLocation', 6)
  name = _messages.StringField(7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)


class NetworkProfileLocation(_messages.Message):
  r"""A NetworkProfileLocation object.

  Enums:
    ScopeValueValuesEnum:

  Fields:
    name: A string attribute.
    scope: A ScopeValueValuesEnum attribute.
  """

  class ScopeValueValuesEnum(_messages.Enum):
    r"""ScopeValueValuesEnum enum type.

    Values:
      REGION: <no description>
      ZONE: <no description>
    """
    REGION = 0
    ZONE = 1

  name = _messages.StringField(1)
  scope = _messages.EnumField('ScopeValueValuesEnum', 2)


class NetworkProfileNetworkFeatures(_messages.Message):
  r"""A NetworkProfileNetworkFeatures object.

  Enums:
    AddressPurposesValueListEntryValuesEnum:
    AllowAliasIpRangesValueValuesEnum: Specifies whether alias IP ranges (and
      secondary address ranges) are allowed.
    AllowAutoModeSubnetValueValuesEnum: Specifies whether auto mode subnet
      creation is allowed.
    AllowClassDFirewallsValueValuesEnum: Specifies whether firewalls for Class
      D address ranges are supported.
    AllowCloudNatValueValuesEnum: Specifies whether cloud NAT creation is
      allowed.
    AllowCloudRouterValueValuesEnum: Specifies whether cloud router creation
      is allowed.
    AllowExternalIpAccessValueValuesEnum: Specifies whether VMs are allowed to
      have external IP access on network interfaces connected to this VPC.
    AllowInterconnectValueValuesEnum: Specifies whether Cloud Interconnect
      creation is allowed.
    AllowLoadBalancingValueValuesEnum: Specifies whether cloud load balancing
      is allowed.
    AllowMultiNicInSameNetworkValueValuesEnum: Specifies whether multi-nic in
      the same network is allowed.
    AllowPacketMirroringValueValuesEnum: Specifies whether Packet Mirroring
      1.0 is supported.
    AllowPrivateGoogleAccessValueValuesEnum: Specifies whether private Google
      access is allowed.
    AllowPscValueValuesEnum: Specifies whether PSC creation is allowed.
    AllowSameNetworkUnicastValueValuesEnum: Specifies whether unicast within
      the same network is allowed.
    AllowStaticRoutesValueValuesEnum: Specifies whether static route creation
      is allowed.
    AllowSubInterfacesValueValuesEnum: Specifies whether sub interfaces are
      allowed.
    AllowVpcPeeringValueValuesEnum: Specifies whether VPC peering is allowed.
    AllowVpnValueValuesEnum: Specifies whether VPN creation is allowed.
    InterfaceTypesValueListEntryValuesEnum:
    SubnetPurposesValueListEntryValuesEnum:
    SubnetStackTypesValueListEntryValuesEnum:
    UnicastValueValuesEnum: Specifies which type of unicast is supported.

  Fields:
    addressPurposes: Specifies what address purposes are supported. If empty,
      all address purposes are supported.
    allowAliasIpRanges: Specifies whether alias IP ranges (and secondary
      address ranges) are allowed.
    allowAutoModeSubnet: Specifies whether auto mode subnet creation is
      allowed.
    allowClassDFirewalls: Specifies whether firewalls for Class D address
      ranges are supported.
    allowCloudNat: Specifies whether cloud NAT creation is allowed.
    allowCloudRouter: Specifies whether cloud router creation is allowed.
    allowExternalIpAccess: Specifies whether VMs are allowed to have external
      IP access on network interfaces connected to this VPC.
    allowInterconnect: Specifies whether Cloud Interconnect creation is
      allowed.
    allowLoadBalancing: Specifies whether cloud load balancing is allowed.
    allowMultiNicInSameNetwork: Specifies whether multi-nic in the same
      network is allowed.
    allowPacketMirroring: Specifies whether Packet Mirroring 1.0 is supported.
    allowPrivateGoogleAccess: Specifies whether private Google access is
      allowed.
    allowPsc: Specifies whether PSC creation is allowed.
    allowSameNetworkUnicast: Specifies whether unicast within the same network
      is allowed.
    allowStaticRoutes: Specifies whether static route creation is allowed.
    allowSubInterfaces: Specifies whether sub interfaces are allowed.
    allowVpcPeering: Specifies whether VPC peering is allowed.
    allowVpn: Specifies whether VPN creation is allowed.
    interfaceTypes: If set, limits the interface types that the network
      supports. If empty, all interface types are supported.
    subnetPurposes: Specifies which subnetwork purposes are supported.
    subnetStackTypes: Specifies which subnetwork stack types are supported.
    unicast: Specifies which type of unicast is supported.
  """

  class AddressPurposesValueListEntryValuesEnum(_messages.Enum):
    r"""AddressPurposesValueListEntryValuesEnum enum type.

    Values:
      DNS_RESOLVER: DNS resolver address in the subnetwork.
      GCE_ENDPOINT: VM internal/alias IP, Internal LB service IP, etc.
      IPSEC_INTERCONNECT: A regional internal IP address range reserved for
        the VLAN attachment that is used in HA VPN over Cloud Interconnect.
        This regional internal IP address range must not overlap with any IP
        address range of subnet/route in the VPC network and its peering
        networks. After the VLAN attachment is created with the reserved IP
        address range, when creating a new VPN gateway, its interface IP
        address is allocated from the associated VLAN attachment's IP address
        range.
      NAT_AUTO: External IP automatically reserved for Cloud NAT.
      PRIVATE_SERVICE_CONNECT: A private network IP address that can be used
        to configure Private Service Connect. This purpose can be specified
        only for GLOBAL addresses of Type INTERNAL
      SERVERLESS: A regional internal IP address range reserved for
        Serverless.
      SHARED_LOADBALANCER_VIP: A private network IP address that can be shared
        by multiple Internal Load Balancer forwarding rules.
      SYSTEM_MANAGED: A regional internal IP address that is reserved and
        managed by Google Cloud. It can not be assigned to Google Cloud
        compute resources such as VM and internal load balancer.
      VPC_PEERING: IP range for peer networks.
    """
    DNS_RESOLVER = 0
    GCE_ENDPOINT = 1
    IPSEC_INTERCONNECT = 2
    NAT_AUTO = 3
    PRIVATE_SERVICE_CONNECT = 4
    SERVERLESS = 5
    SHARED_LOADBALANCER_VIP = 6
    SYSTEM_MANAGED = 7
    VPC_PEERING = 8

  class AllowAliasIpRangesValueValuesEnum(_messages.Enum):
    r"""Specifies whether alias IP ranges (and secondary address ranges) are
    allowed.

    Values:
      ALIAS_IP_RANGES_ALLOWED: <no description>
      ALIAS_IP_RANGES_BLOCKED: <no description>
    """
    ALIAS_IP_RANGES_ALLOWED = 0
    ALIAS_IP_RANGES_BLOCKED = 1

  class AllowAutoModeSubnetValueValuesEnum(_messages.Enum):
    r"""Specifies whether auto mode subnet creation is allowed.

    Values:
      AUTO_MODE_SUBNET_ALLOWED: <no description>
      AUTO_MODE_SUBNET_BLOCKED: <no description>
    """
    AUTO_MODE_SUBNET_ALLOWED = 0
    AUTO_MODE_SUBNET_BLOCKED = 1

  class AllowClassDFirewallsValueValuesEnum(_messages.Enum):
    r"""Specifies whether firewalls for Class D address ranges are supported.

    Values:
      CLASS_D_FIREWALLS_ALLOWED: <no description>
      CLASS_D_FIREWALLS_BLOCKED: <no description>
    """
    CLASS_D_FIREWALLS_ALLOWED = 0
    CLASS_D_FIREWALLS_BLOCKED = 1

  class AllowCloudNatValueValuesEnum(_messages.Enum):
    r"""Specifies whether cloud NAT creation is allowed.

    Values:
      CLOUD_NAT_ALLOWED: <no description>
      CLOUD_NAT_BLOCKED: <no description>
    """
    CLOUD_NAT_ALLOWED = 0
    CLOUD_NAT_BLOCKED = 1

  class AllowCloudRouterValueValuesEnum(_messages.Enum):
    r"""Specifies whether cloud router creation is allowed.

    Values:
      CLOUD_ROUTER_ALLOWED: <no description>
      CLOUD_ROUTER_BLOCKED: <no description>
    """
    CLOUD_ROUTER_ALLOWED = 0
    CLOUD_ROUTER_BLOCKED = 1

  class AllowExternalIpAccessValueValuesEnum(_messages.Enum):
    r"""Specifies whether VMs are allowed to have external IP access on
    network interfaces connected to this VPC.

    Values:
      EXTERNAL_IP_ACCESS_ALLOWED: <no description>
      EXTERNAL_IP_ACCESS_BLOCKED: <no description>
    """
    EXTERNAL_IP_ACCESS_ALLOWED = 0
    EXTERNAL_IP_ACCESS_BLOCKED = 1

  class AllowInterconnectValueValuesEnum(_messages.Enum):
    r"""Specifies whether Cloud Interconnect creation is allowed.

    Values:
      INTERCONNECT_ALLOWED: <no description>
      INTERCONNECT_BLOCKED: <no description>
    """
    INTERCONNECT_ALLOWED = 0
    INTERCONNECT_BLOCKED = 1

  class AllowLoadBalancingValueValuesEnum(_messages.Enum):
    r"""Specifies whether cloud load balancing is allowed.

    Values:
      LOAD_BALANCING_ALLOWED: <no description>
      LOAD_BALANCING_BLOCKED: <no description>
    """
    LOAD_BALANCING_ALLOWED = 0
    LOAD_BALANCING_BLOCKED = 1

  class AllowMultiNicInSameNetworkValueValuesEnum(_messages.Enum):
    r"""Specifies whether multi-nic in the same network is allowed.

    Values:
      MULTI_NIC_IN_SAME_NETWORK_ALLOWED: <no description>
      MULTI_NIC_IN_SAME_NETWORK_BLOCKED: <no description>
    """
    MULTI_NIC_IN_SAME_NETWORK_ALLOWED = 0
    MULTI_NIC_IN_SAME_NETWORK_BLOCKED = 1

  class AllowPacketMirroringValueValuesEnum(_messages.Enum):
    r"""Specifies whether Packet Mirroring 1.0 is supported.

    Values:
      PACKET_MIRRORING_ALLOWED: <no description>
      PACKET_MIRRORING_BLOCKED: <no description>
    """
    PACKET_MIRRORING_ALLOWED = 0
    PACKET_MIRRORING_BLOCKED = 1

  class AllowPrivateGoogleAccessValueValuesEnum(_messages.Enum):
    r"""Specifies whether private Google access is allowed.

    Values:
      PRIVATE_GOOGLE_ACCESS_ALLOWED: <no description>
      PRIVATE_GOOGLE_ACCESS_BLOCKED: <no description>
    """
    PRIVATE_GOOGLE_ACCESS_ALLOWED = 0
    PRIVATE_GOOGLE_ACCESS_BLOCKED = 1

  class AllowPscValueValuesEnum(_messages.Enum):
    r"""Specifies whether PSC creation is allowed.

    Values:
      PSC_ALLOWED: <no description>
      PSC_BLOCKED: <no description>
    """
    PSC_ALLOWED = 0
    PSC_BLOCKED = 1

  class AllowSameNetworkUnicastValueValuesEnum(_messages.Enum):
    r"""Specifies whether unicast within the same network is allowed.

    Values:
      SAME_NETWORK_UNICAST_ALLOWED: <no description>
      SAME_NETWORK_UNICAST_BLOCKED: <no description>
    """
    SAME_NETWORK_UNICAST_ALLOWED = 0
    SAME_NETWORK_UNICAST_BLOCKED = 1

  class AllowStaticRoutesValueValuesEnum(_messages.Enum):
    r"""Specifies whether static route creation is allowed.

    Values:
      STATIC_ROUTES_ALLOWED: <no description>
      STATIC_ROUTES_BLOCKED: <no description>
    """
    STATIC_ROUTES_ALLOWED = 0
    STATIC_ROUTES_BLOCKED = 1

  class AllowSubInterfacesValueValuesEnum(_messages.Enum):
    r"""Specifies whether sub interfaces are allowed.

    Values:
      SUBINTERFACES_ALLOWED: <no description>
      SUBINTERFACES_BLOCKED: <no description>
    """
    SUBINTERFACES_ALLOWED = 0
    SUBINTERFACES_BLOCKED = 1

  class AllowVpcPeeringValueValuesEnum(_messages.Enum):
    r"""Specifies whether VPC peering is allowed.

    Values:
      VPC_PEERING_ALLOWED: <no description>
      VPC_PEERING_BLOCKED: <no description>
    """
    VPC_PEERING_ALLOWED = 0
    VPC_PEERING_BLOCKED = 1

  class AllowVpnValueValuesEnum(_messages.Enum):
    r"""Specifies whether VPN creation is allowed.

    Values:
      VPN_ALLOWED: <no description>
      VPN_BLOCKED: <no description>
    """
    VPN_ALLOWED = 0
    VPN_BLOCKED = 1

  class InterfaceTypesValueListEntryValuesEnum(_messages.Enum):
    r"""InterfaceTypesValueListEntryValuesEnum enum type.

    Values:
      GVNIC: GVNIC
      IDPF: IDPF
      IRDMA: IRDMA
      MRDMA: MRDMA
      UNSPECIFIED_NIC_TYPE: No type specified.
      VIRTIO_NET: VIRTIO
    """
    GVNIC = 0
    IDPF = 1
    IRDMA = 2
    MRDMA = 3
    UNSPECIFIED_NIC_TYPE = 4
    VIRTIO_NET = 5

  class SubnetPurposesValueListEntryValuesEnum(_messages.Enum):
    r"""SubnetPurposesValueListEntryValuesEnum enum type.

    Values:
      SUBNET_PURPOSE_CUSTOM_HARDWARE: <no description>
      SUBNET_PURPOSE_PRIVATE: <no description>
    """
    SUBNET_PURPOSE_CUSTOM_HARDWARE = 0
    SUBNET_PURPOSE_PRIVATE = 1

  class SubnetStackTypesValueListEntryValuesEnum(_messages.Enum):
    r"""SubnetStackTypesValueListEntryValuesEnum enum type.

    Values:
      SUBNET_STACK_TYPE_IPV4_IPV6: <no description>
      SUBNET_STACK_TYPE_IPV4_ONLY: <no description>
      SUBNET_STACK_TYPE_IPV6_ONLY: <no description>
    """
    SUBNET_STACK_TYPE_IPV4_IPV6 = 0
    SUBNET_STACK_TYPE_IPV4_ONLY = 1
    SUBNET_STACK_TYPE_IPV6_ONLY = 2

  class UnicastValueValuesEnum(_messages.Enum):
    r"""Specifies which type of unicast is supported.

    Values:
      UNICAST_SDN: <no description>
      UNICAST_ULL: <no description>
    """
    UNICAST_SDN = 0
    UNICAST_ULL = 1

  addressPurposes = _messages.EnumField('AddressPurposesValueListEntryValuesEnum', 1, repeated=True)
  allowAliasIpRanges = _messages.EnumField('AllowAliasIpRangesValueValuesEnum', 2)
  allowAutoModeSubnet = _messages.EnumField('AllowAutoModeSubnetValueValuesEnum', 3)
  allowClassDFirewalls = _messages.EnumField('AllowClassDFirewallsValueValuesEnum', 4)
  allowCloudNat = _messages.EnumField('AllowCloudNatValueValuesEnum', 5)
  allowCloudRouter = _messages.EnumField('AllowCloudRouterValueValuesEnum', 6)
  allowExternalIpAccess = _messages.EnumField('AllowExternalIpAccessValueValuesEnum', 7)
  allowInterconnect = _messages.EnumField('AllowInterconnectValueValuesEnum', 8)
  allowLoadBalancing = _messages.EnumField('AllowLoadBalancingValueValuesEnum', 9)
  allowMultiNicInSameNetwork = _messages.EnumField('AllowMultiNicInSameNetworkValueValuesEnum', 10)
  allowPacketMirroring = _messages.EnumField('AllowPacketMirroringValueValuesEnum', 11)
  allowPrivateGoogleAccess = _messages.EnumField('AllowPrivateGoogleAccessValueValuesEnum', 12)
  allowPsc = _messages.EnumField('AllowPscValueValuesEnum', 13)
  allowSameNetworkUnicast = _messages.EnumField('AllowSameNetworkUnicastValueValuesEnum', 14)
  allowStaticRoutes = _messages.EnumField('AllowStaticRoutesValueValuesEnum', 15)
  allowSubInterfaces = _messages.EnumField('AllowSubInterfacesValueValuesEnum', 16)
  allowVpcPeering = _messages.EnumField('AllowVpcPeeringValueValuesEnum', 17)
  allowVpn = _messages.EnumField('AllowVpnValueValuesEnum', 18)
  interfaceTypes = _messages.EnumField('InterfaceTypesValueListEntryValuesEnum', 19, repeated=True)
  subnetPurposes = _messages.EnumField('SubnetPurposesValueListEntryValuesEnum', 20, repeated=True)
  subnetStackTypes = _messages.EnumField('SubnetStackTypesValueListEntryValuesEnum', 21, repeated=True)
  unicast = _messages.EnumField('UnicastValueValuesEnum', 22)


class NetworkProfilesListResponse(_messages.Message):
  r"""Contains a list of network profiles.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkProfile resources.
    kind: [Output Only] Type of resource. Always compute#networkProfileList
      for network profiles.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('NetworkProfile', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#networkProfileList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class NetworkRoutingConfig(_messages.Message):
  r"""A routing configuration attached to a network resource. The message
  includes the list of routers associated with the network, and a flag
  indicating the type of routing behavior to enforce network-wide.

  Enums:
    BgpBestPathSelectionModeValueValuesEnum: The BGP best path selection
      algorithm to be employed within this network for dynamic routes learned
      by Cloud Routers. Can be LEGACY (default) or STANDARD.
    BgpInterRegionCostValueValuesEnum: Allows to define a preferred approach
      for handling inter-region cost in the selection process when using the
      STANDARD BGP best path selection algorithm. Can be DEFAULT or
      ADD_COST_TO_MED.
    EffectiveBgpInterRegionCostValueValuesEnum: [Output Only] Effective value
      of the bgp_inter_region_cost field.
    RoutingModeValueValuesEnum: The network-wide routing mode to use. If set
      to REGIONAL, this network's Cloud Routers will only advertise routes
      with subnets of this network in the same region as the router. If set to
      GLOBAL, this network's Cloud Routers will advertise routes with all
      subnets of this network, across regions.

  Fields:
    bgpAlwaysCompareMed: Enable comparison of Multi-Exit Discriminators (MED)
      across routes with different neighbor ASNs when using the STANDARD BGP
      best path selection algorithm.
    bgpBestPathSelectionMode: The BGP best path selection algorithm to be
      employed within this network for dynamic routes learned by Cloud
      Routers. Can be LEGACY (default) or STANDARD.
    bgpInterRegionCost: Allows to define a preferred approach for handling
      inter-region cost in the selection process when using the STANDARD BGP
      best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED.
    effectiveBgpAlwaysCompareMed: [Output Only] Effective value of the
      bgp_always_compare_med field.
    effectiveBgpInterRegionCost: [Output Only] Effective value of the
      bgp_inter_region_cost field.
    routingMode: The network-wide routing mode to use. If set to REGIONAL,
      this network's Cloud Routers will only advertise routes with subnets of
      this network in the same region as the router. If set to GLOBAL, this
      network's Cloud Routers will advertise routes with all subnets of this
      network, across regions.
  """

  class BgpBestPathSelectionModeValueValuesEnum(_messages.Enum):
    r"""The BGP best path selection algorithm to be employed within this
    network for dynamic routes learned by Cloud Routers. Can be LEGACY
    (default) or STANDARD.

    Values:
      LEGACY: <no description>
      STANDARD: <no description>
    """
    LEGACY = 0
    STANDARD = 1

  class BgpInterRegionCostValueValuesEnum(_messages.Enum):
    r"""Allows to define a preferred approach for handling inter-region cost
    in the selection process when using the STANDARD BGP best path selection
    algorithm. Can be DEFAULT or ADD_COST_TO_MED.

    Values:
      ADD_COST_TO_MED: <no description>
      DEFAULT: <no description>
    """
    ADD_COST_TO_MED = 0
    DEFAULT = 1

  class EffectiveBgpInterRegionCostValueValuesEnum(_messages.Enum):
    r"""[Output Only] Effective value of the bgp_inter_region_cost field.

    Values:
      ADD_COST_TO_MED: <no description>
      DEFAULT: <no description>
    """
    ADD_COST_TO_MED = 0
    DEFAULT = 1

  class RoutingModeValueValuesEnum(_messages.Enum):
    r"""The network-wide routing mode to use. If set to REGIONAL, this
    network's Cloud Routers will only advertise routes with subnets of this
    network in the same region as the router. If set to GLOBAL, this network's
    Cloud Routers will advertise routes with all subnets of this network,
    across regions.

    Values:
      GLOBAL: <no description>
      REGIONAL: <no description>
    """
    GLOBAL = 0
    REGIONAL = 1

  bgpAlwaysCompareMed = _messages.BooleanField(1)
  bgpBestPathSelectionMode = _messages.EnumField('BgpBestPathSelectionModeValueValuesEnum', 2)
  bgpInterRegionCost = _messages.EnumField('BgpInterRegionCostValueValuesEnum', 3)
  effectiveBgpAlwaysCompareMed = _messages.BooleanField(4)
  effectiveBgpInterRegionCost = _messages.EnumField('EffectiveBgpInterRegionCostValueValuesEnum', 5)
  routingMode = _messages.EnumField('RoutingModeValueValuesEnum', 6)


class NetworksAddPeeringRequest(_messages.Message):
  r"""A NetworksAddPeeringRequest object.

  Fields:
    autoCreateRoutes: This field will be deprecated soon. Use
      exchange_subnet_routes in network_peering instead. Indicates whether
      full mesh connectivity is created and managed automatically between
      peered networks. Currently this field should always be true since Google
      Compute Engine will automatically create and manage subnetwork routes
      between two networks when peering state is ACTIVE.
    exportCustomRoutes: This field will be deprecated soon. Use
      export_custom_routes in network_peering instead. Whether to export the
      custom routes to peer network.
    importCustomRoutes: This field will be deprecated soon. Use
      import_custom_routes in network_peering instead. Whether to import the
      custom routes from peer network.
    name: Name of the peering, which should conform to RFC1035.
    networkPeering: Network peering parameters. In order to specify route
      policies for peering using import and export custom routes, you must
      specify all peering related parameters (name, peer network,
      exchange_subnet_routes) in the network_peering field. The corresponding
      fields in NetworksAddPeeringRequest will be deprecated soon.
    peerNetwork: URL of the peer network. It can be either full URL or partial
      URL. The peer network may belong to a different project. If the partial
      URL does not contain project, it is assumed that the peer network is in
      the same project as the current network.
  """

  autoCreateRoutes = _messages.BooleanField(1)
  exportCustomRoutes = _messages.BooleanField(2)
  importCustomRoutes = _messages.BooleanField(3)
  name = _messages.StringField(4)
  networkPeering = _messages.MessageField('NetworkPeering', 5)
  peerNetwork = _messages.StringField(6)


class NetworksGetEffectiveFirewallsResponse(_messages.Message):
  r"""A NetworksGetEffectiveFirewallsResponse object.

  Fields:
    firewallPolicys: [Output Only] Effective firewalls from firewall policy.
      It returns Global Network Firewall Policies and Hierarchical Firewall
      Policies. Use regionNetworkFirewallPolicies.getEffectiveFirewalls to get
      Regional Network Firewall Policies as well.
    firewalls: Effective firewalls on the network.
    organizationFirewalls: Effective firewalls from organization policies.
  """

  firewallPolicys = _messages.MessageField('NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy', 1, repeated=True)
  firewalls = _messages.MessageField('Firewall', 2, repeated=True)
  organizationFirewalls = _messages.MessageField('NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy', 3, repeated=True)


class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy(_messages.Message):
  r"""A NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy object.

  Enums:
    TypeValueValuesEnum: [Output Only] The type of the firewall policy.

  Fields:
    displayName: [Output Only] Deprecated, please use short name instead. The
      display name of the firewall policy.
    name: [Output Only] The name of the firewall policy.
    packetMirroringRules: [Output Only] The packet mirroring rules that apply
      to the network.
    priority: [Output only] Priority of firewall policy association. Not
      applicable for type=HIERARCHY.
    rules: [Output Only] The rules that apply to the network.
    shortName: [Output Only] The short name of the firewall policy.
    type: [Output Only] The type of the firewall policy.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The type of the firewall policy.

    Values:
      HIERARCHY: <no description>
      NETWORK: <no description>
      SYSTEM: <no description>
      UNSPECIFIED: <no description>
    """
    HIERARCHY = 0
    NETWORK = 1
    SYSTEM = 2
    UNSPECIFIED = 3

  displayName = _messages.StringField(1)
  name = _messages.StringField(2)
  packetMirroringRules = _messages.MessageField('FirewallPolicyRule', 3, repeated=True)
  priority = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  rules = _messages.MessageField('FirewallPolicyRule', 5, repeated=True)
  shortName = _messages.StringField(6)
  type = _messages.EnumField('TypeValueValuesEnum', 7)


class NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy(_messages.Message):
  r"""A pruned SecurityPolicy containing ID and any applicable firewall rules.

  Fields:
    id: [Output Only] The unique identifier for the security policy. This
      identifier is defined by the server.
    rules: The rules that apply to the network.
  """

  id = _messages.IntegerField(1, variant=_messages.Variant.UINT64)
  rules = _messages.MessageField('SecurityPolicyRule', 2, repeated=True)


class NetworksRemovePeeringRequest(_messages.Message):
  r"""A NetworksRemovePeeringRequest object.

  Fields:
    name: Name of the peering, which should conform to RFC1035.
  """

  name = _messages.StringField(1)


class NetworksUpdatePeeringRequest(_messages.Message):
  r"""A NetworksUpdatePeeringRequest object.

  Fields:
    networkPeering: A NetworkPeering attribute.
  """

  networkPeering = _messages.MessageField('NetworkPeering', 1)


class NodeGroup(_messages.Message):
  r"""Represents a sole-tenant Node Group resource. A sole-tenant node is a
  physical server that is dedicated to hosting VM instances only for your
  specific project. Use sole-tenant nodes to keep your instances physically
  separated from instances in other projects, or to group your instances
  together on the same host hardware. For more information, read Sole-tenant
  nodes.

  Enums:
    MaintenanceIntervalValueValuesEnum: Specifies the frequency of planned
      maintenance events. The accepted values are: `AS_NEEDED` and
      `RECURRENT`.
    MaintenancePolicyValueValuesEnum: Specifies how to handle instances when a
      node in the group undergoes maintenance. Set to one of: DEFAULT,
      RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is
      DEFAULT. For more information, see Maintenance policies.
    StatusValueValuesEnum:

  Fields:
    autoscalingPolicy: Specifies how autoscaling should behave.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: A byte attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] The type of the resource. Always compute#nodeGroup for
      node group.
    locationHint: An opaque location hint used to place the Node close to
      other resources. This field is for use by internal tools that use the
      public API. The location hint here on the NodeGroup overrides any
      location_hint present in the NodeTemplate.
    maintenanceInterval: Specifies the frequency of planned maintenance
      events. The accepted values are: `AS_NEEDED` and `RECURRENT`.
    maintenancePolicy: Specifies how to handle instances when a node in the
      group undergoes maintenance. Set to one of: DEFAULT, RESTART_IN_PLACE,
      or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more
      information, see Maintenance policies.
    maintenanceWindow: A NodeGroupMaintenanceWindow attribute.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    nodeTemplate: URL of the node template to create the node group from.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    shareSettings: Share-settings for the node group
    size: [Output Only] The total number of nodes in the node group.
    status: A StatusValueValuesEnum attribute.
    zone: [Output Only] The name of the zone where the node group resides,
      such as us-central1-a.
  """

  class MaintenanceIntervalValueValuesEnum(_messages.Enum):
    r"""Specifies the frequency of planned maintenance events. The accepted
    values are: `AS_NEEDED` and `RECURRENT`.

    Values:
      AS_NEEDED: VMs are eligible to receive infrastructure and hypervisor
        updates as they become available. This may result in more maintenance
        operations (live migrations or terminations) for the VM than the
        PERIODIC and RECURRENT options.
      PERIODIC: VMs receive infrastructure and hypervisor updates on a
        periodic basis, minimizing the number of maintenance operations (live
        migrations or terminations) on an individual VM. This may mean a VM
        will take longer to receive an update than if it was configured for
        AS_NEEDED. Security updates will still be applied as soon as they are
        available.
      RECURRENT: VMs receive infrastructure and hypervisor updates on a
        periodic basis, minimizing the number of maintenance operations (live
        migrations or terminations) on an individual VM. This may mean a VM
        will take longer to receive an update than if it was configured for
        AS_NEEDED. Security updates will still be applied as soon as they are
        available. RECURRENT is used for GEN3 and Slice of Hardware VMs.
    """
    AS_NEEDED = 0
    PERIODIC = 1
    RECURRENT = 2

  class MaintenancePolicyValueValuesEnum(_messages.Enum):
    r"""Specifies how to handle instances when a node in the group undergoes
    maintenance. Set to one of: DEFAULT, RESTART_IN_PLACE, or
    MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more
    information, see Maintenance policies.

    Values:
      DEFAULT: Allow the node and corresponding instances to retain default
        maintenance behavior.
      MAINTENANCE_POLICY_UNSPECIFIED: <no description>
      MIGRATE_WITHIN_NODE_GROUP: When maintenance must be done on a node, the
        instances on that node will be moved to other nodes in the group.
        Instances with onHostMaintenance = MIGRATE will live migrate to their
        destinations while instances with onHostMaintenance = TERMINATE will
        terminate and then restart on their destination nodes if
        automaticRestart = true.
      RESTART_IN_PLACE: Instances in this group will restart on the same node
        when maintenance has completed. Instances must have onHostMaintenance
        = TERMINATE, and they will only restart if automaticRestart = true.
    """
    DEFAULT = 0
    MAINTENANCE_POLICY_UNSPECIFIED = 1
    MIGRATE_WITHIN_NODE_GROUP = 2
    RESTART_IN_PLACE = 3

  class StatusValueValuesEnum(_messages.Enum):
    r"""StatusValueValuesEnum enum type.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3

  autoscalingPolicy = _messages.MessageField('NodeGroupAutoscalingPolicy', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  fingerprint = _messages.BytesField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default='compute#nodeGroup')
  locationHint = _messages.StringField(7)
  maintenanceInterval = _messages.EnumField('MaintenanceIntervalValueValuesEnum', 8)
  maintenancePolicy = _messages.EnumField('MaintenancePolicyValueValuesEnum', 9)
  maintenanceWindow = _messages.MessageField('NodeGroupMaintenanceWindow', 10)
  name = _messages.StringField(11)
  nodeTemplate = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)
  shareSettings = _messages.MessageField('ShareSettings', 15)
  size = _messages.IntegerField(16, variant=_messages.Variant.INT32)
  status = _messages.EnumField('StatusValueValuesEnum', 17)
  zone = _messages.StringField(18)


class NodeGroupAggregatedList(_messages.Message):
  r"""A NodeGroupAggregatedList object.

  Messages:
    ItemsValue: A list of NodeGroupsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeGroupsScopedList resources.
    kind: [Output Only] Type of resource.Always
      compute#nodeGroupAggregatedList for aggregated lists of node groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NodeGroupsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of node groups.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NodeGroupsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NodeGroupsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#nodeGroupAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NodeGroupAutoscalingPolicy(_messages.Message):
  r"""A NodeGroupAutoscalingPolicy object.

  Enums:
    ModeValueValuesEnum: The autoscaling mode. Set to one of: ON, OFF, or
      ONLY_SCALE_OUT. For more information, see Autoscaler modes.

  Fields:
    maxNodes: The maximum number of nodes that the group should have. Must be
      set if autoscaling is enabled. Maximum value allowed is 100.
    minNodes: The minimum number of nodes that the group should have.
    mode: The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For
      more information, see Autoscaler modes.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For
    more information, see Autoscaler modes.

    Values:
      MODE_UNSPECIFIED: <no description>
      OFF: Autoscaling is disabled.
      ON: Autocaling is fully enabled.
      ONLY_SCALE_OUT: Autoscaling will only scale out and will not remove
        nodes.
    """
    MODE_UNSPECIFIED = 0
    OFF = 1
    ON = 2
    ONLY_SCALE_OUT = 3

  maxNodes = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  minNodes = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  mode = _messages.EnumField('ModeValueValuesEnum', 3)


class NodeGroupList(_messages.Message):
  r"""Contains a list of nodeGroups.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeGroup resources.
    kind: [Output Only] Type of resource.Always compute#nodeGroupList for
      lists of node groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NodeGroup', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#nodeGroupList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NodeGroupMaintenanceWindow(_messages.Message):
  r"""Time window specified for daily maintenance operations. GCE's internal
  maintenance will be performed within this window.

  Fields:
    duration: [Output only] A predetermined duration for the window,
      automatically chosen to be the smallest possible in the given scenario.
    maintenanceDuration: [Output only] A predetermined duration for the
      window, automatically chosen to be the smallest possible in the given
      scenario.
    startTime: Start time of the window. This must be in UTC format that
      resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00. For
      example, both 13:00-5 and 08:00 are valid.
  """

  duration = _messages.StringField(1)
  maintenanceDuration = _messages.MessageField('Duration', 2)
  startTime = _messages.StringField(3)


class NodeGroupNode(_messages.Message):
  r"""A NodeGroupNode object.

  Enums:
    CpuOvercommitTypeValueValuesEnum: CPU overcommit.
    StatusValueValuesEnum:

  Fields:
    accelerators: Accelerators for this node.
    consumedResources: Node resources that are reserved by all instances.
    cpuOvercommitType: CPU overcommit.
    disks: Local disk configurations.
    instanceConsumptionData: Instance data that shows consumed resources on
      the node.
    instances: Instances scheduled on this node.
    name: The name of the node.
    nodeType: The type of this node.
    satisfiesPzs: [Output Only] Reserved for future use.
    serverBinding: Binding properties for the physical server.
    serverId: Server ID associated with this node.
    status: A StatusValueValuesEnum attribute.
    totalResources: Total amount of available resources on the node.
    upcomingMaintenance: [Output Only] The information about an upcoming
      maintenance event.
  """

  class CpuOvercommitTypeValueValuesEnum(_messages.Enum):
    r"""CPU overcommit.

    Values:
      CPU_OVERCOMMIT_TYPE_UNSPECIFIED: <no description>
      ENABLED: <no description>
      NONE: <no description>
    """
    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 0
    ENABLED = 1
    NONE = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""StatusValueValuesEnum enum type.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
      REPAIRING: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3
    REPAIRING = 4

  accelerators = _messages.MessageField('AcceleratorConfig', 1, repeated=True)
  consumedResources = _messages.MessageField('InstanceConsumptionInfo', 2)
  cpuOvercommitType = _messages.EnumField('CpuOvercommitTypeValueValuesEnum', 3)
  disks = _messages.MessageField('LocalDisk', 4, repeated=True)
  instanceConsumptionData = _messages.MessageField('InstanceConsumptionData', 5, repeated=True)
  instances = _messages.StringField(6, repeated=True)
  name = _messages.StringField(7)
  nodeType = _messages.StringField(8)
  satisfiesPzs = _messages.BooleanField(9)
  serverBinding = _messages.MessageField('ServerBinding', 10)
  serverId = _messages.StringField(11)
  status = _messages.EnumField('StatusValueValuesEnum', 12)
  totalResources = _messages.MessageField('InstanceConsumptionInfo', 13)
  upcomingMaintenance = _messages.MessageField('UpcomingMaintenance', 14)


class NodeGroupsAddNodesRequest(_messages.Message):
  r"""A NodeGroupsAddNodesRequest object.

  Fields:
    additionalNodeCount: Count of additional nodes to be added to the node
      group.
  """

  additionalNodeCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)


class NodeGroupsDeleteNodesRequest(_messages.Message):
  r"""A NodeGroupsDeleteNodesRequest object.

  Fields:
    nodes: Names of the nodes to delete.
  """

  nodes = _messages.StringField(1, repeated=True)


class NodeGroupsListNodes(_messages.Message):
  r"""A NodeGroupsListNodes object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Node resources.
    kind: [Output Only] The resource type, which is always
      compute.nodeGroupsListNodes for the list of nodes in the specified node
      group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NodeGroupNode', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#nodeGroupsListNodes')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NodeGroupsPerformMaintenanceRequest(_messages.Message):
  r"""A NodeGroupsPerformMaintenanceRequest object.

  Fields:
    nodes: [Required] List of nodes affected by the call.
    startTime: The start time of the schedule. The timestamp is an RFC3339
      string.
  """

  nodes = _messages.StringField(1, repeated=True)
  startTime = _messages.StringField(2)


class NodeGroupsScopedList(_messages.Message):
  r"""A NodeGroupsScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      nodeGroup list is empty.

  Fields:
    nodeGroups: [Output Only] A list of node groups contained in this scope.
    warning: [Output Only] An informational warning that appears when the
      nodeGroup list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the nodeGroup
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  nodeGroups = _messages.MessageField('NodeGroup', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NodeGroupsSetNodeTemplateRequest(_messages.Message):
  r"""A NodeGroupsSetNodeTemplateRequest object.

  Fields:
    nodeTemplate: Full or partial URL of the node template resource to be
      updated for this node group.
  """

  nodeTemplate = _messages.StringField(1)


class NodeGroupsSimulateMaintenanceEventRequest(_messages.Message):
  r"""A NodeGroupsSimulateMaintenanceEventRequest object.

  Fields:
    nodes: Names of the nodes to go under maintenance simulation.
  """

  nodes = _messages.StringField(1, repeated=True)


class NodeTemplate(_messages.Message):
  r"""Represent a sole-tenant Node Template resource. You can use a template
  to define properties for nodes in a node group. For more information, read
  Creating node groups and instances.

  Enums:
    CpuOvercommitTypeValueValuesEnum: CPU overcommit.
    StatusValueValuesEnum: [Output Only] The status of the node template. One
      of the following values: CREATING, READY, and DELETING.

  Messages:
    NodeAffinityLabelsValue: Labels to use for node affinity, which will be
      used in instance scheduling.

  Fields:
    accelerators: A AcceleratorConfig attribute.
    cpuOvercommitType: CPU overcommit.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    disks: A LocalDisk attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] The type of the resource. Always compute#nodeTemplate
      for node templates.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    nodeAffinityLabels: Labels to use for node affinity, which will be used in
      instance scheduling.
    nodeType: The node type to use for nodes group that are created from this
      template.
    nodeTypeFlexibility: Do not use. Instead, use the node_type property.
    region: [Output Only] The name of the region where the node template
      resides, such as us-central1.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serverBinding: Sets the binding properties for the physical server. Valid
      values include: - *[Default]* RESTART_NODE_ON_ANY_SERVER: Restarts VMs
      on any available physical server - RESTART_NODE_ON_MINIMAL_SERVER:
      Restarts VMs on the same physical server whenever possible See Sole-
      tenant node options for more information.
    status: [Output Only] The status of the node template. One of the
      following values: CREATING, READY, and DELETING.
    statusMessage: [Output Only] An optional, human-readable explanation of
      the status.
  """

  class CpuOvercommitTypeValueValuesEnum(_messages.Enum):
    r"""CPU overcommit.

    Values:
      CPU_OVERCOMMIT_TYPE_UNSPECIFIED: <no description>
      ENABLED: <no description>
      NONE: <no description>
    """
    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 0
    ENABLED = 1
    NONE = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the node template. One of the following
    values: CREATING, READY, and DELETING.

    Values:
      CREATING: Resources are being allocated.
      DELETING: The node template is currently being deleted.
      INVALID: Invalid status.
      READY: The node template is ready.
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class NodeAffinityLabelsValue(_messages.Message):
    r"""Labels to use for node affinity, which will be used in instance
    scheduling.

    Messages:
      AdditionalProperty: An additional property for a NodeAffinityLabelsValue
        object.

    Fields:
      additionalProperties: Additional properties of type
        NodeAffinityLabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a NodeAffinityLabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  accelerators = _messages.MessageField('AcceleratorConfig', 1, repeated=True)
  cpuOvercommitType = _messages.EnumField('CpuOvercommitTypeValueValuesEnum', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  disks = _messages.MessageField('LocalDisk', 5, repeated=True)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#nodeTemplate')
  name = _messages.StringField(8)
  nodeAffinityLabels = _messages.MessageField('NodeAffinityLabelsValue', 9)
  nodeType = _messages.StringField(10)
  nodeTypeFlexibility = _messages.MessageField('NodeTemplateNodeTypeFlexibility', 11)
  region = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)
  serverBinding = _messages.MessageField('ServerBinding', 15)
  status = _messages.EnumField('StatusValueValuesEnum', 16)
  statusMessage = _messages.StringField(17)


class NodeTemplateAggregatedList(_messages.Message):
  r"""A NodeTemplateAggregatedList object.

  Messages:
    ItemsValue: A list of NodeTemplatesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeTemplatesScopedList resources.
    kind: [Output Only] Type of resource.Always
      compute#nodeTemplateAggregatedList for aggregated lists of node
      templates.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NodeTemplatesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of node templates.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NodeTemplatesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NodeTemplatesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#nodeTemplateAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NodeTemplateList(_messages.Message):
  r"""Contains a list of node templates.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeTemplate resources.
    kind: [Output Only] Type of resource.Always compute#nodeTemplateList for
      lists of node templates.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NodeTemplate', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#nodeTemplateList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NodeTemplateNodeTypeFlexibility(_messages.Message):
  r"""A NodeTemplateNodeTypeFlexibility object.

  Fields:
    cpus: A string attribute.
    localSsd: A string attribute.
    memory: A string attribute.
  """

  cpus = _messages.StringField(1)
  localSsd = _messages.StringField(2)
  memory = _messages.StringField(3)


class NodeTemplatesScopedList(_messages.Message):
  r"""A NodeTemplatesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      node templates list is empty.

  Fields:
    nodeTemplates: [Output Only] A list of node templates contained in this
      scope.
    warning: [Output Only] An informational warning that appears when the node
      templates list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the node
    templates list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  nodeTemplates = _messages.MessageField('NodeTemplate', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NodeType(_messages.Message):
  r"""Represent a sole-tenant Node Type resource. Each node within a node
  group must have a node type. A node type specifies the total amount of cores
  and memory for that node. Currently, the only available node type is
  n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available
  in multiple zones. For more information read Node types.

  Fields:
    cpuPlatform: [Output Only] The CPU platform used by this node type.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this node
      type.
    description: [Output Only] An optional textual description of the
      resource.
    guestCpus: [Output Only] The number of virtual CPUs that are available to
      the node type.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] The type of the resource. Always compute#nodeType for
      node types.
    localSsdGb: [Output Only] Local SSD available to the node type, defined in
      GB.
    maxVms: [Output Only] Maximum number of VMs that can be created for this
      node type.
    memoryMb: [Output Only] The amount of physical memory available to the
      node type, defined in MB.
    name: [Output Only] Name of the resource.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    zone: [Output Only] The name of the zone where the node type resides, such
      as us-central1-a.
  """

  cpuPlatform = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  deprecated = _messages.MessageField('DeprecationStatus', 3)
  description = _messages.StringField(4)
  guestCpus = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#nodeType')
  localSsdGb = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  maxVms = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  memoryMb = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  name = _messages.StringField(11)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)
  zone = _messages.StringField(14)


class NodeTypeAggregatedList(_messages.Message):
  r"""A NodeTypeAggregatedList object.

  Messages:
    ItemsValue: A list of NodeTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeTypesScopedList resources.
    kind: [Output Only] Type of resource.Always compute#nodeTypeAggregatedList
      for aggregated lists of node types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NodeTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of node types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NodeTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NodeTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#nodeTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NodeTypeList(_messages.Message):
  r"""Contains a list of node types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeType resources.
    kind: [Output Only] Type of resource.Always compute#nodeTypeList for lists
      of node types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NodeType', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#nodeTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NodeTypesScopedList(_messages.Message):
  r"""A NodeTypesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      node types list is empty.

  Fields:
    nodeTypes: [Output Only] A list of node types contained in this scope.
    warning: [Output Only] An informational warning that appears when the node
      types list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the node
    types list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  nodeTypes = _messages.MessageField('NodeType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NotificationEndpoint(_messages.Message):
  r"""Represents a notification endpoint. A notification endpoint resource
  defines an endpoint to receive notifications when there are status changes
  detected by the associated health check service. For more information, see
  Health checks overview.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    grpcSettings: Settings of the gRPC notification endpoint including the
      endpoint URL and the retry duration.
    id: [Output Only] A unique identifier for this resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always
      compute#notificationEndpoint for notification endpoints.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the notification endpoint
      resides. This field applies only to the regional resource. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  grpcSettings = _messages.MessageField('NotificationEndpointGrpcSettings', 3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#notificationEndpoint')
  name = _messages.StringField(6)
  region = _messages.StringField(7)
  selfLink = _messages.StringField(8)


class NotificationEndpointAggregatedList(_messages.Message):
  r"""Contains a list of NotificationEndpointsScopedList.

  Messages:
    ItemsValue: A list of NotificationEndpointsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NotificationEndpointsScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NotificationEndpointsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        NotificationEndpoints.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NotificationEndpointsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NotificationEndpointsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#notificationEndpointAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NotificationEndpointGrpcSettings(_messages.Message):
  r"""Represents a gRPC setting that describes one gRPC notification endpoint
  and the retry duration attempting to send notification to this endpoint.

  Fields:
    authority: Optional. If specified, this field is used to set the authority
      header by the sender of notifications. See
      https://tools.ietf.org/html/rfc7540#section-8.1.2.3
    endpoint: Endpoint to which gRPC notifications are sent. This must be a
      valid gRPCLB DNS name.
    payloadName: Optional. If specified, this field is used to populate the
      "name" field in gRPC requests.
    resendInterval: Optional. This field is used to configure how often to
      send a full update of all non-healthy backends. If unspecified, full
      updates are not sent. If specified, must be in the range between 600
      seconds to 3600 seconds. Nanos are disallowed. Can only be set for
      regional notification endpoints.
    retryDurationSec: How much time (in seconds) is spent attempting
      notification retries until a successful response is received. Default is
      30s. Limit is 20m (1200s). Must be a positive number.
  """

  authority = _messages.StringField(1)
  endpoint = _messages.StringField(2)
  payloadName = _messages.StringField(3)
  resendInterval = _messages.MessageField('Duration', 4)
  retryDurationSec = _messages.IntegerField(5, variant=_messages.Variant.UINT32)


class NotificationEndpointList(_messages.Message):
  r"""A NotificationEndpointList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NotificationEndpoint resources.
    kind: [Output Only] Type of the resource. Always
      compute#notificationEndpoint for notification endpoints.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NotificationEndpoint', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#notificationEndpointList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NotificationEndpointsScopedList(_messages.Message):
  r"""A NotificationEndpointsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of
      notification endpoints when the list is empty.

  Fields:
    resources: A list of NotificationEndpoints contained in this scope.
    warning: Informational warning which replaces the list of notification
      endpoints when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of notification
    endpoints when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  resources = _messages.MessageField('NotificationEndpoint', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class Operation(_messages.Message):
  r"""Represents an Operation resource. Google Compute Engine has three
  Operation resources: *
  [Global](/compute/docs/reference/rest/alpha/globalOperations) *
  [Regional](/compute/docs/reference/rest/alpha/regionOperations) *
  [Zonal](/compute/docs/reference/rest/alpha/zoneOperations) You can use an
  operation resource to manage asynchronous API requests. For more
  information, read Handling API responses. Operations can be global, regional
  or zonal. - For global operations, use the `globalOperations` resource. -
  For regional operations, use the `regionOperations` resource. - For zonal
  operations, use the `zoneOperations` resource. For more information, read
  Global, Regional, and Zonal Resources. Note that completed Operation
  resources have a limited retention period.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the operation, which
      can be one of the following: `PENDING`, `RUNNING`, or `DONE`.

  Messages:
    ErrorValue: [Output Only] If errors are generated during processing of the
      operation, this field will be populated.
    WarningsValueListEntry: A WarningsValueListEntry object.

  Fields:
    clientOperationId: [Output Only] The value of `requestId` if you provided
      it in the request. Not present otherwise.
    creationTimestamp: [Deprecated] This field is deprecated.
    description: [Output Only] A textual description of the operation, which
      is set when the operation is created.
    endTime: [Output Only] The time that this operation was completed. This
      value is in RFC3339 text format.
    error: [Output Only] If errors are generated during processing of the
      operation, this field will be populated.
    httpErrorMessage: [Output Only] If the operation fails, this field
      contains the HTTP error message that was returned, such as `NOT FOUND`.
    httpErrorStatusCode: [Output Only] If the operation fails, this field
      contains the HTTP error status code that was returned. For example, a
      `404` means the resource was not found.
    id: [Output Only] The unique identifier for the operation. This identifier
      is defined by the server.
    insertTime: [Output Only] The time that this operation was requested. This
      value is in RFC3339 text format.
    instancesBulkInsertOperationMetadata: A
      InstancesBulkInsertOperationMetadata attribute.
    kind: [Output Only] Type of the resource. Always `compute#operation` for
      Operation resources.
    name: [Output Only] Name of the operation.
    operationGroupId: [Output Only] An ID that represents a group of
      operations, such as when a group of operations results from a
      `bulkInsert` API request.
    operationType: [Output Only] The type of operation, such as `insert`,
      `update`, or `delete`, and so on.
    progress: [Output Only] An optional progress indicator that ranges from 0
      to 100. There is no requirement that this be linear or support any
      granularity of operations. This should not be used to guess when the
      operation will be complete. This number should monotonically increase as
      the operation progresses.
    region: [Output Only] The URL of the region where the operation resides.
      Only applicable when performing regional operations.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    setCommonInstanceMetadataOperationMetadata: [Output Only] If the operation
      is for projects.setCommonInstanceMetadata, this field will contain
      information on all underlying zonal actions and their state.
    startTime: [Output Only] The time that this operation was started by the
      server. This value is in RFC3339 text format.
    status: [Output Only] The status of the operation, which can be one of the
      following: `PENDING`, `RUNNING`, or `DONE`.
    statusMessage: [Output Only] An optional textual description of the
      current status of the operation.
    targetId: [Output Only] The unique target ID, which identifies a specific
      incarnation of the target resource.
    targetLink: [Output Only] The URL of the resource that the operation
      modifies. For operations related to creating a snapshot, this points to
      the disk that the snapshot was created from.
    user: [Output Only] User who requested the operation, for example:
      `user@example.com` or `alice_smith_identifier
      (global/workforcePools/example-com-us-employees)`.
    warnings: [Output Only] If warning messages are generated during
      processing of the operation, this field will be populated.
    zone: [Output Only] The URL of the zone where the operation resides. Only
      applicable when performing per-zone operations.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the operation, which can be one of the
    following: `PENDING`, `RUNNING`, or `DONE`.

    Values:
      DONE: <no description>
      PENDING: <no description>
      RUNNING: <no description>
    """
    DONE = 0
    PENDING = 1
    RUNNING = 2

  class ErrorValue(_messages.Message):
    r"""[Output Only] If errors are generated during processing of the
    operation, this field will be populated.

    Messages:
      ErrorsValueListEntry: A ErrorsValueListEntry object.

    Fields:
      errors: [Output Only] The array of errors encountered while processing
        this operation.
    """

    class ErrorsValueListEntry(_messages.Message):
      r"""A ErrorsValueListEntry object.

      Messages:
        ErrorDetailsValueListEntry: A ErrorDetailsValueListEntry object.

      Fields:
        code: [Output Only] The error type identifier for this error.
        errorDetails: [Output Only] An optional list of messages that contain
          the error details. There is a set of defined message types to use
          for providing details.The syntax depends on the error code. For
          example, QuotaExceededInfo will have details when the error code is
          QUOTA_EXCEEDED.
        location: [Output Only] Indicates the field in the request that caused
          the error. This property is optional.
        message: [Output Only] An optional, human-readable error message.
      """

      class ErrorDetailsValueListEntry(_messages.Message):
        r"""A ErrorDetailsValueListEntry object.

        Fields:
          errorInfo: A ErrorInfo attribute.
          help: A Help attribute.
          localizedMessage: A LocalizedMessage attribute.
          quotaInfo: A QuotaExceededInfo attribute.
        """

        errorInfo = _messages.MessageField('ErrorInfo', 1)
        help = _messages.MessageField('Help', 2)
        localizedMessage = _messages.MessageField('LocalizedMessage', 3)
        quotaInfo = _messages.MessageField('QuotaExceededInfo', 4)

      code = _messages.StringField(1)
      errorDetails = _messages.MessageField('ErrorDetailsValueListEntry', 2, repeated=True)
      location = _messages.StringField(3)
      message = _messages.StringField(4)

    errors = _messages.MessageField('ErrorsValueListEntry', 1, repeated=True)

  class WarningsValueListEntry(_messages.Message):
    r"""A WarningsValueListEntry object.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  clientOperationId = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  endTime = _messages.StringField(4)
  error = _messages.MessageField('ErrorValue', 5)
  httpErrorMessage = _messages.StringField(6)
  httpErrorStatusCode = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  insertTime = _messages.StringField(9)
  instancesBulkInsertOperationMetadata = _messages.MessageField('InstancesBulkInsertOperationMetadata', 10)
  kind = _messages.StringField(11, default='compute#operation')
  name = _messages.StringField(12)
  operationGroupId = _messages.StringField(13)
  operationType = _messages.StringField(14)
  progress = _messages.IntegerField(15, variant=_messages.Variant.INT32)
  region = _messages.StringField(16)
  selfLink = _messages.StringField(17)
  selfLinkWithId = _messages.StringField(18)
  setCommonInstanceMetadataOperationMetadata = _messages.MessageField('SetCommonInstanceMetadataOperationMetadata', 19)
  startTime = _messages.StringField(20)
  status = _messages.EnumField('StatusValueValuesEnum', 21)
  statusMessage = _messages.StringField(22)
  targetId = _messages.IntegerField(23, variant=_messages.Variant.UINT64)
  targetLink = _messages.StringField(24)
  user = _messages.StringField(25)
  warnings = _messages.MessageField('WarningsValueListEntry', 26, repeated=True)
  zone = _messages.StringField(27)


class OperationAggregatedList(_messages.Message):
  r"""A OperationAggregatedList object.

  Messages:
    ItemsValue: [Output Only] A map of scoped operation lists.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A map of scoped operation lists.
    kind: [Output Only] Type of resource. Always
      `compute#operationAggregatedList` for aggregated lists of operations.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      `maxResults`, use the `nextPageToken` as a value for the query parameter
      `pageToken` in the next list request. Subsequent list requests will have
      their own `nextPageToken` to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""[Output Only] A map of scoped operation lists.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of operations.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A OperationsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('OperationsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#operationAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class OperationList(_messages.Message):
  r"""Contains a list of Operation resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A list of Operation resources.
    kind: [Output Only] Type of resource. Always `compute#operations` for
      Operations resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      `maxResults`, use the `nextPageToken` as a value for the query parameter
      `pageToken` in the next list request. Subsequent list requests will have
      their own `nextPageToken` to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Operation', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#operationList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class OperationsScopedList(_messages.Message):
  r"""A OperationsScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of operations when the list is empty.

  Fields:
    operations: [Output Only] A list of operations contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      operations when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    operations when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  operations = _messages.MessageField('Operation', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class OrganizationSecurityPoliciesListAssociationsResponse(_messages.Message):
  r"""A OrganizationSecurityPoliciesListAssociationsResponse object.

  Fields:
    associations: A list of associations.
    kind: [Output Only] Type of securityPolicy associations. Always
      compute#organizationSecurityPoliciesListAssociations for lists of
      securityPolicy associations.
  """

  associations = _messages.MessageField('SecurityPolicyAssociation', 1, repeated=True)
  kind = _messages.StringField(2, default='compute#organizationSecurityPoliciesListAssociationsResponse')


class OriginAuthenticationMethod(_messages.Message):
  r"""[Deprecated] Configuration for the origin authentication method.
  Configuration for the origin authentication method.

  Fields:
    jwt: A Jwt attribute.
  """

  jwt = _messages.MessageField('Jwt', 1)


class OutlierDetection(_messages.Message):
  r"""Settings controlling the eviction of unhealthy hosts from the load
  balancing pool for the backend service.

  Fields:
    baseEjectionTime: The base time that a backend endpoint is ejected for.
      Defaults to 30000ms or 30s. After a backend endpoint is returned back to
      the load balancing pool, it can be ejected again in another ejection
      analysis. Thus, the total ejection time is equal to the base ejection
      time multiplied by the number of times the backend endpoint has been
      ejected. Defaults to 30000ms or 30s.
    consecutiveErrors: Number of consecutive errors before a backend endpoint
      is ejected from the load balancing pool. When the backend endpoint is
      accessed over HTTP, a 5xx return code qualifies as an error. Defaults to
      5.
    consecutiveGatewayFailure: The number of consecutive gateway failures
      (502, 503, 504 status or connection errors that are mapped to one of
      those status codes) before a consecutive gateway failure ejection
      occurs. Defaults to 3.
    enforcingConsecutiveErrors: The percentage chance that a backend endpoint
      will be ejected when an outlier status is detected through consecutive
      5xx. This setting can be used to disable ejection or to ramp it up
      slowly. Defaults to 0.
    enforcingConsecutiveGatewayFailure: The percentage chance that a backend
      endpoint will be ejected when an outlier status is detected through
      consecutive gateway failures. This setting can be used to disable
      ejection or to ramp it up slowly. Defaults to 100.
    enforcingSuccessRate: The percentage chance that a backend endpoint will
      be ejected when an outlier status is detected through success rate
      statistics. This setting can be used to disable ejection or to ramp it
      up slowly. Defaults to 100. Not supported when the backend service uses
      Serverless NEG.
    interval: Time interval between ejection analysis sweeps. This can result
      in both new ejections and backend endpoints being returned to service.
      The interval is equal to the number of seconds as defined in
      outlierDetection.interval.seconds plus the number of nanoseconds as
      defined in outlierDetection.interval.nanos. Defaults to 1 second.
    maxEjectionPercent: Maximum percentage of backend endpoints in the load
      balancing pool for the backend service that can be ejected if the
      ejection conditions are met. Defaults to 50%.
    successRateMinimumHosts: The number of backend endpoints in the load
      balancing pool that must have enough request volume to detect success
      rate outliers. If the number of backend endpoints is fewer than this
      setting, outlier detection via success rate statistics is not performed
      for any backend endpoint in the load balancing pool. Defaults to 5. Not
      supported when the backend service uses Serverless NEG.
    successRateRequestVolume: The minimum number of total requests that must
      be collected in one interval (as defined by the interval duration above)
      to include this backend endpoint in success rate based outlier
      detection. If the volume is lower than this setting, outlier detection
      via success rate statistics is not performed for that backend endpoint.
      Defaults to 100. Not supported when the backend service uses Serverless
      NEG.
    successRateStdevFactor: This factor is used to determine the ejection
      threshold for success rate outlier ejection. The ejection threshold is
      the difference between the mean success rate, and the product of this
      factor and the standard deviation of the mean success rate: mean -
      (stdev * successRateStdevFactor). This factor is divided by a thousand
      to get a double. That is, if the desired factor is 1.9, the runtime
      value should be 1900. Defaults to 1900. Not supported when the backend
      service uses Serverless NEG.
  """

  baseEjectionTime = _messages.MessageField('Duration', 1)
  consecutiveErrors = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  consecutiveGatewayFailure = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  enforcingConsecutiveErrors = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  enforcingConsecutiveGatewayFailure = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  enforcingSuccessRate = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  interval = _messages.MessageField('Duration', 7)
  maxEjectionPercent = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  successRateMinimumHosts = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  successRateRequestVolume = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  successRateStdevFactor = _messages.IntegerField(11, variant=_messages.Variant.INT32)


class PacketIntervals(_messages.Message):
  r"""Next free: 7

  Enums:
    DurationValueValuesEnum: From how long ago in the past these intervals
      were observed.
    TypeValueValuesEnum: The type of packets for which inter-packet intervals
      were computed.

  Fields:
    avgMs: Average observed inter-packet interval in milliseconds.
    duration: From how long ago in the past these intervals were observed.
    maxMs: Maximum observed inter-packet interval in milliseconds.
    minMs: Minimum observed inter-packet interval in milliseconds.
    numIntervals: Number of inter-packet intervals from which these statistics
      were derived.
    type: The type of packets for which inter-packet intervals were computed.
  """

  class DurationValueValuesEnum(_messages.Enum):
    r"""From how long ago in the past these intervals were observed.

    Values:
      DURATION_UNSPECIFIED: <no description>
      HOUR: <no description>
      MAX: From BfdSession object creation time.
      MINUTE: <no description>
    """
    DURATION_UNSPECIFIED = 0
    HOUR = 1
    MAX = 2
    MINUTE = 3

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of packets for which inter-packet intervals were computed.

    Values:
      LOOPBACK: Only applies to Echo packets. This shows the intervals between
        sending and receiving the same packet.
      RECEIVE: Intervals between received packets.
      TRANSMIT: Intervals between transmitted packets.
      TYPE_UNSPECIFIED: <no description>
    """
    LOOPBACK = 0
    RECEIVE = 1
    TRANSMIT = 2
    TYPE_UNSPECIFIED = 3

  avgMs = _messages.IntegerField(1)
  duration = _messages.EnumField('DurationValueValuesEnum', 2)
  maxMs = _messages.IntegerField(3)
  minMs = _messages.IntegerField(4)
  numIntervals = _messages.IntegerField(5)
  type = _messages.EnumField('TypeValueValuesEnum', 6)


class PacketMirroring(_messages.Message):
  r"""Represents a Packet Mirroring resource. Packet Mirroring clones the
  traffic of specified instances in your Virtual Private Cloud (VPC) network
  and forwards it to a collector destination, such as an instance group of an
  internal TCP/UDP load balancer, for analysis or examination. For more
  information about setting up Packet Mirroring, see Using Packet Mirroring.

  Enums:
    EnableValueValuesEnum: Indicates whether or not this packet mirroring
      takes effect. If set to FALSE, this packet mirroring policy will not be
      enforced on the network. The default is TRUE.

  Fields:
    collectorIlb: The Forwarding Rule resource of type
      loadBalancingScheme=INTERNAL that will be used as collector for mirrored
      traffic. The specified forwarding rule must have isMirroringCollector
      set to true.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    enable: Indicates whether or not this packet mirroring takes effect. If
      set to FALSE, this packet mirroring policy will not be enforced on the
      network. The default is TRUE.
    filter: Filter for mirrored traffic. If unspecified, all IPv4 traffic is
      mirrored.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#packetMirroring
      for packet mirrorings.
    mirroredResources: PacketMirroring mirroredResourceInfos.
      MirroredResourceInfo specifies a set of mirrored VM instances,
      subnetworks and/or tags for which traffic from/to all VM instances will
      be mirrored.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: Specifies the mirrored VPC network. Only packets in this network
      will be mirrored. All mirrored VMs should have a NIC in the given
      network. All mirrored subnetworks should belong to the given network.
    priority: The priority of applying this configuration. Priority is used to
      break ties in cases where there is more than one matching rule. In the
      case of two rules that apply for a given Instance, the one with the
      lowest-numbered priority value wins. Default value is 1000. Valid range
      is 0 through 65535.
    region: [Output Only] URI of the region where the packetMirroring resides.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  class EnableValueValuesEnum(_messages.Enum):
    r"""Indicates whether or not this packet mirroring takes effect. If set to
    FALSE, this packet mirroring policy will not be enforced on the network.
    The default is TRUE.

    Values:
      FALSE: <no description>
      TRUE: <no description>
    """
    FALSE = 0
    TRUE = 1

  collectorIlb = _messages.MessageField('PacketMirroringForwardingRuleInfo', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  enable = _messages.EnumField('EnableValueValuesEnum', 4)
  filter = _messages.MessageField('PacketMirroringFilter', 5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#packetMirroring')
  mirroredResources = _messages.MessageField('PacketMirroringMirroredResourceInfo', 8)
  name = _messages.StringField(9)
  network = _messages.MessageField('PacketMirroringNetworkInfo', 10)
  priority = _messages.IntegerField(11, variant=_messages.Variant.UINT32)
  region = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)


class PacketMirroringAggregatedList(_messages.Message):
  r"""Contains a list of packetMirrorings.

  Messages:
    ItemsValue: A list of PacketMirroring resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PacketMirroring resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of PacketMirroring resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        packetMirrorings.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A PacketMirroringsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('PacketMirroringsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#packetMirroringAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class PacketMirroringFilter(_messages.Message):
  r"""A PacketMirroringFilter object.

  Enums:
    DirectionValueValuesEnum: Direction of traffic to mirror, either INGRESS,
      EGRESS, or BOTH. The default is BOTH.

  Fields:
    IPProtocols: Protocols that apply as filter on mirrored traffic. If no
      protocols are specified, all traffic that matches the specified CIDR
      ranges is mirrored. If neither cidrRanges nor IPProtocols is specified,
      all IPv4 traffic is mirrored.
    cidrRanges: One or more IPv4 or IPv6 CIDR ranges that apply as filters on
      the source (ingress) or destination (egress) IP in the IP header. If no
      ranges are specified, all IPv4 traffic that matches the specified
      IPProtocols is mirrored. If neither cidrRanges nor IPProtocols is
      specified, all IPv4 traffic is mirrored. To mirror all IPv4 and IPv6
      traffic, use "0.0.0.0/0,::/0".
    direction: Direction of traffic to mirror, either INGRESS, EGRESS, or
      BOTH. The default is BOTH.
  """

  class DirectionValueValuesEnum(_messages.Enum):
    r"""Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH. The
    default is BOTH.

    Values:
      BOTH: Default, both directions are mirrored.
      EGRESS: Only egress traffic is mirrored.
      INGRESS: Only ingress traffic is mirrored.
    """
    BOTH = 0
    EGRESS = 1
    INGRESS = 2

  IPProtocols = _messages.StringField(1, repeated=True)
  cidrRanges = _messages.StringField(2, repeated=True)
  direction = _messages.EnumField('DirectionValueValuesEnum', 3)


class PacketMirroringForwardingRuleInfo(_messages.Message):
  r"""A PacketMirroringForwardingRuleInfo object.

  Fields:
    canonicalUrl: [Output Only] Unique identifier for the forwarding rule;
      defined by the server.
    url: Resource URL to the forwarding rule representing the ILB configured
      as destination of the mirrored traffic.
  """

  canonicalUrl = _messages.StringField(1)
  url = _messages.StringField(2)


class PacketMirroringList(_messages.Message):
  r"""Contains a list of PacketMirroring resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PacketMirroring resources.
    kind: [Output Only] Type of resource. Always compute#packetMirroring for
      packetMirrorings.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('PacketMirroring', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#packetMirroringList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class PacketMirroringMirroredResourceInfo(_messages.Message):
  r"""A PacketMirroringMirroredResourceInfo object.

  Fields:
    instances: A set of virtual machine instances that are being mirrored.
      They must live in zones contained in the same region as this
      packetMirroring. Note that this config will apply only to those network
      interfaces of the Instances that belong to the network specified in this
      packetMirroring. You may specify a maximum of 50 Instances.
    subnetworks: A set of subnetworks for which traffic from/to all VM
      instances will be mirrored. They must live in the same region as this
      packetMirroring. You may specify a maximum of 5 subnetworks.
    tags: A set of mirrored tags. Traffic from/to all VM instances that have
      one or more of these tags will be mirrored.
  """

  instances = _messages.MessageField('PacketMirroringMirroredResourceInfoInstanceInfo', 1, repeated=True)
  subnetworks = _messages.MessageField('PacketMirroringMirroredResourceInfoSubnetInfo', 2, repeated=True)
  tags = _messages.StringField(3, repeated=True)


class PacketMirroringMirroredResourceInfoInstanceInfo(_messages.Message):
  r"""A PacketMirroringMirroredResourceInfoInstanceInfo object.

  Fields:
    canonicalUrl: [Output Only] Unique identifier for the instance; defined by
      the server.
    url: Resource URL to the virtual machine instance which is being mirrored.
  """

  canonicalUrl = _messages.StringField(1)
  url = _messages.StringField(2)


class PacketMirroringMirroredResourceInfoSubnetInfo(_messages.Message):
  r"""A PacketMirroringMirroredResourceInfoSubnetInfo object.

  Fields:
    canonicalUrl: [Output Only] Unique identifier for the subnetwork; defined
      by the server.
    url: Resource URL to the subnetwork for which traffic from/to all VM
      instances will be mirrored.
  """

  canonicalUrl = _messages.StringField(1)
  url = _messages.StringField(2)


class PacketMirroringNetworkInfo(_messages.Message):
  r"""A PacketMirroringNetworkInfo object.

  Fields:
    canonicalUrl: [Output Only] Unique identifier for the network; defined by
      the server.
    url: URL of the network resource.
  """

  canonicalUrl = _messages.StringField(1)
  url = _messages.StringField(2)


class PacketMirroringsScopedList(_messages.Message):
  r"""A PacketMirroringsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of
      packetMirrorings when the list is empty.

  Fields:
    packetMirrorings: A list of packetMirrorings contained in this scope.
    warning: Informational warning which replaces the list of packetMirrorings
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of packetMirrorings when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  packetMirrorings = _messages.MessageField('PacketMirroring', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class PartnerMetadata(_messages.Message):
  r"""Model definition of partner_metadata field. To be used in dedicated
  Partner Metadata methods and to be inlined in the Instance and
  InstanceTemplate resources.

  Messages:
    PartnerMetadataValue: Partner Metadata assigned to the instance. A map
      from a subdomain to entries map. Subdomain name must be compliant with
      RFC1035 definition. The total size of all keys and values must be less
      than 2MB. Subdomain 'metadata.compute.googleapis.com' is reserverd for
      instance's metadata.

  Fields:
    fingerprint: Instance-level hash to be used for optimistic locking.
    partnerMetadata: Partner Metadata assigned to the instance. A map from a
      subdomain to entries map. Subdomain name must be compliant with RFC1035
      definition. The total size of all keys and values must be less than 2MB.
      Subdomain 'metadata.compute.googleapis.com' is reserverd for instance's
      metadata.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class PartnerMetadataValue(_messages.Message):
    r"""Partner Metadata assigned to the instance. A map from a subdomain to
    entries map. Subdomain name must be compliant with RFC1035 definition. The
    total size of all keys and values must be less than 2MB. Subdomain
    'metadata.compute.googleapis.com' is reserverd for instance's metadata.

    Messages:
      AdditionalProperty: An additional property for a PartnerMetadataValue
        object.

    Fields:
      additionalProperties: Additional properties of type PartnerMetadataValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a PartnerMetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A StructuredEntries attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StructuredEntries', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  fingerprint = _messages.BytesField(1)
  partnerMetadata = _messages.MessageField('PartnerMetadataValue', 2)


class PathMatcher(_messages.Message):
  r"""A matcher for the path portion of the URL. The BackendService from the
  longest-matched rule will serve the URL. If no rule was matched, the default
  service is used.

  Fields:
    defaultCustomErrorResponsePolicy: defaultCustomErrorResponsePolicy
      specifies how the Load Balancer returns error responses when
      BackendServiceor BackendBucket responds with an error. This policy takes
      effect at the PathMatcher level and applies only when no policy has been
      defined for the error code at lower levels like RouteRule and PathRule
      within this PathMatcher. If an error code does not have a policy defined
      in defaultCustomErrorResponsePolicy, then a policy defined for the error
      code in UrlMap.defaultCustomErrorResponsePolicy takes effect. For
      example, consider a UrlMap with the following configuration: -
      UrlMap.defaultCustomErrorResponsePolicy is configured with policies for
      5xx and 4xx errors - A RouteRule for /coming_soon/ is configured for the
      error code 404. If the request is for www.myotherdomain.com and a 404 is
      encountered, the policy under UrlMap.defaultCustomErrorResponsePolicy
      takes effect. If a 404 response is encountered for the request
      www.example.com/current_events/, the pathMatcher's policy takes effect.
      If however, the request for www.example.com/coming_soon/ encounters a
      404, the policy in RouteRule.customErrorResponsePolicy takes effect. If
      any of the requests in this example encounter a 500 error code, the
      policy at UrlMap.defaultCustomErrorResponsePolicy takes effect. When
      used in conjunction with pathMatcher.defaultRouteAction.retryPolicy,
      retries take precedence. Only once all retries are exhausted, the
      defaultCustomErrorResponsePolicy is applied. While attempting a retry,
      if load balancer is successful in reaching the service, the
      defaultCustomErrorResponsePolicy is ignored and the response from the
      service is returned to the client. defaultCustomErrorResponsePolicy is
      supported only for global external Application Load Balancers.
    defaultRouteAction: defaultRouteAction takes effect when none of the
      pathRules or routeRules match. The load balancer performs advanced
      routing actions, such as URL rewrites and header transformations, before
      forwarding the request to the selected backend. Only one of
      defaultUrlRedirect, defaultService or
      defaultRouteAction.weightedBackendService can be set. URL maps for
      classic Application Load Balancers only support the urlRewrite action
      within a path matcher's defaultRouteAction.
    defaultService: The full or partial URL to the BackendService resource.
      This URL is used if none of the pathRules or routeRules defined by this
      PathMatcher are matched. For example, the following are all valid URLs
      to a BackendService resource: -
      https://www.googleapis.com/compute/v1/projects/project
      /global/backendServices/backendService -
      compute/v1/projects/project/global/backendServices/backendService -
      global/backendServices/backendService If defaultRouteAction is also
      specified, advanced routing actions, such as URL rewrites, take effect
      before sending the request to the backend. Only one of
      defaultUrlRedirect, defaultService or
      defaultRouteAction.weightedBackendService can be set. Authorization
      requires one or more of the following Google IAM permissions on the
      specified resource default_service: - compute.backendBuckets.use -
      compute.backendServices.use
    defaultUrlRedirect: When none of the specified pathRules or routeRules
      match, the request is redirected to a URL specified by
      defaultUrlRedirect. Only one of defaultUrlRedirect, defaultService or
      defaultRouteAction.weightedBackendService can be set. Not supported when
      the URL map is bound to a target gRPC proxy.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    headerAction: Specifies changes to request and response headers that need
      to take effect for the selected backend service. HeaderAction specified
      here are applied after the matching HttpRouteRule HeaderAction and
      before the HeaderAction in the UrlMap HeaderAction is not supported for
      load balancers that have their loadBalancingScheme set to EXTERNAL. Not
      supported when the URL map is bound to a target gRPC proxy that has
      validateForProxyless field set to true.
    name: The name to which this PathMatcher is referred by the HostRule.
    pathRules: The list of path rules. Use this list instead of routeRules
      when routing based on simple path matching is all that's required. The
      order by which path rules are specified does not matter. Matches are
      always done on the longest-path-first basis. For example: a pathRule
      with a path /a/b/c/* will match before /a/b/* irrespective of the order
      in which those paths appear in this list. Within a given pathMatcher,
      only one of pathRules or routeRules must be set.
    routeRules: The list of HTTP route rules. Use this list instead of
      pathRules when advanced route matching and routing actions are desired.
      routeRules are evaluated in order of priority, from the lowest to
      highest number. Within a given pathMatcher, you can set only one of
      pathRules or routeRules.
  """

  defaultCustomErrorResponsePolicy = _messages.MessageField('CustomErrorResponsePolicy', 1)
  defaultRouteAction = _messages.MessageField('HttpRouteAction', 2)
  defaultService = _messages.StringField(3)
  defaultUrlRedirect = _messages.MessageField('HttpRedirectAction', 4)
  description = _messages.StringField(5)
  headerAction = _messages.MessageField('HttpHeaderAction', 6)
  name = _messages.StringField(7)
  pathRules = _messages.MessageField('PathRule', 8, repeated=True)
  routeRules = _messages.MessageField('HttpRouteRule', 9, repeated=True)


class PathRule(_messages.Message):
  r"""A path-matching rule for a URL. If matched, will use the specified
  BackendService to handle the traffic arriving at this URL.

  Fields:
    customErrorResponsePolicy: customErrorResponsePolicy specifies how the
      Load Balancer returns error responses when BackendServiceor
      BackendBucket responds with an error. If a policy for an error code is
      not configured for the PathRule, a policy for the error code configured
      in pathMatcher.defaultCustomErrorResponsePolicy is applied. If one is
      not specified in pathMatcher.defaultCustomErrorResponsePolicy, the
      policy configured in UrlMap.defaultCustomErrorResponsePolicy takes
      effect. For example, consider a UrlMap with the following configuration:
      - UrlMap.defaultCustomErrorResponsePolicy are configured with policies
      for 5xx and 4xx errors - A PathRule for /coming_soon/ is configured for
      the error code 404. If the request is for www.myotherdomain.com and a
      404 is encountered, the policy under
      UrlMap.defaultCustomErrorResponsePolicy takes effect. If a 404 response
      is encountered for the request www.example.com/current_events/, the
      pathMatcher's policy takes effect. If however, the request for
      www.example.com/coming_soon/ encounters a 404, the policy in
      PathRule.customErrorResponsePolicy takes effect. If any of the requests
      in this example encounter a 500 error code, the policy at
      UrlMap.defaultCustomErrorResponsePolicy takes effect.
      customErrorResponsePolicy is supported only for global external
      Application Load Balancers.
    paths: The list of path patterns to match. Each must start with / and the
      only place a * is allowed is at the end following a /. The string fed to
      the path matcher does not include any text after the first ? or #, and
      those chars are not allowed here.
    routeAction: In response to a matching path, the load balancer performs
      advanced routing actions, such as URL rewrites and header
      transformations, before forwarding the request to the selected backend.
      Only one of urlRedirect, service or routeAction.weightedBackendService
      can be set. URL maps for classic Application Load Balancers only support
      the urlRewrite action within a path rule's routeAction.
    service: The full or partial URL of the backend service resource to which
      traffic is directed if this rule is matched. If routeAction is also
      specified, advanced routing actions, such as URL rewrites, take effect
      before sending the request to the backend. Only one of urlRedirect,
      service or routeAction.weightedBackendService can be set.
    urlRedirect: When a path pattern is matched, the request is redirected to
      a URL specified by urlRedirect. Only one of urlRedirect, service or
      routeAction.weightedBackendService can be set. Not supported when the
      URL map is bound to a target gRPC proxy.
  """

  customErrorResponsePolicy = _messages.MessageField('CustomErrorResponsePolicy', 1)
  paths = _messages.StringField(2, repeated=True)
  routeAction = _messages.MessageField('HttpRouteAction', 3)
  service = _messages.StringField(4)
  urlRedirect = _messages.MessageField('HttpRedirectAction', 5)


class PeerAuthenticationMethod(_messages.Message):
  r"""[Deprecated] Configuration for the peer authentication method.
  Configuration for the peer authentication method.

  Fields:
    mtls: Set if mTLS is used for peer authentication.
  """

  mtls = _messages.MessageField('MutualTls', 1)


class PerInstanceConfig(_messages.Message):
  r"""A PerInstanceConfig object.

  Enums:
    StatusValueValuesEnum: The status of applying this per-instance
      configuration on the corresponding managed instance.

  Fields:
    fingerprint: Fingerprint of this per-instance config. This field can be
      used in optimistic locking. It is ignored when inserting a per-instance
      config. An up-to-date fingerprint must be provided in order to update an
      existing per-instance configuration or the field needs to be unset.
    name: The name of a per-instance configuration and its corresponding
      instance. Serves as a merge key during UpdatePerInstanceConfigs
      operations, that is, if a per-instance configuration with the same name
      exists then it will be updated, otherwise a new one will be created for
      the VM instance with the same name. An attempt to create a per-instance
      configuration for a VM instance that either doesn't exist or is not part
      of the group will result in an error.
    preservedState: The intended preserved state for the given instance. Does
      not contain preserved state generated from a stateful policy.
    status: The status of applying this per-instance configuration on the
      corresponding managed instance.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""The status of applying this per-instance configuration on the
    corresponding managed instance.

    Values:
      APPLYING: The per-instance configuration is being applied to the
        instance, but is not yet effective, possibly waiting for the instance
        to, for example, REFRESH.
      DELETING: The per-instance configuration deletion is being applied on
        the instance, possibly waiting for the instance to, for example,
        REFRESH.
      EFFECTIVE: The per-instance configuration is effective on the instance,
        meaning that all disks, ips and metadata specified in this
        configuration are attached or set on the instance.
      NONE: *[Default]* The default status, when no per-instance configuration
        exists.
      UNAPPLIED: The per-instance configuration is set on an instance but not
        been applied yet.
      UNAPPLIED_DELETION: The per-instance configuration has been deleted, but
        the deletion is not yet applied.
    """
    APPLYING = 0
    DELETING = 1
    EFFECTIVE = 2
    NONE = 3
    UNAPPLIED = 4
    UNAPPLIED_DELETION = 5

  fingerprint = _messages.BytesField(1)
  name = _messages.StringField(2)
  preservedState = _messages.MessageField('PreservedState', 3)
  status = _messages.EnumField('StatusValueValuesEnum', 4)


class Permission(_messages.Message):
  r"""[Deprecated] All fields defined in a permission are ANDed.

  Fields:
    constraints: Extra custom constraints. The constraints are ANDed together.
    hosts: Used in Ingress or Egress Gateway cases to specify hosts that the
      policy applies to. Exact match, prefix match, and suffix match are
      supported.
    methods: HTTP method.
    notHosts: Negate of hosts. Specifies exclusions.
    notMethods: Negate of methods. Specifies exclusions.
    notPaths: Negate of paths. Specifies exclusions.
    notPorts: Negate of ports. Specifies exclusions.
    paths: HTTP request paths or gRPC methods. Exact match, prefix match, and
      suffix match are supported.
    ports: Port names or numbers.
  """

  constraints = _messages.MessageField('PermissionConstraint', 1, repeated=True)
  hosts = _messages.StringField(2, repeated=True)
  methods = _messages.StringField(3, repeated=True)
  notHosts = _messages.StringField(4, repeated=True)
  notMethods = _messages.StringField(5, repeated=True)
  notPaths = _messages.StringField(6, repeated=True)
  notPorts = _messages.StringField(7, repeated=True)
  paths = _messages.StringField(8, repeated=True)
  ports = _messages.StringField(9, repeated=True)


class PermissionConstraint(_messages.Message):
  r"""Custom constraint that specifies a key and a list of allowed values for
  Istio attributes.

  Fields:
    key: Key of the constraint.
    values: A list of allowed values.
  """

  key = _messages.StringField(1)
  values = _messages.StringField(2, repeated=True)


class Policy(_messages.Message):
  r"""An Identity and Access Management (IAM) policy, which specifies access
  controls for Google Cloud resources. A `Policy` is a collection of
  `bindings`. A `binding` binds one or more `members`, or principals, to a
  single `role`. Principals can be user accounts, service accounts, Google
  groups, and domains (such as G Suite). A `role` is a named list of
  permissions; each `role` can be an IAM predefined role or a user-created
  custom role. For some types of Google Cloud resources, a `binding` can also
  specify a `condition`, which is a logical expression that allows access to a
  resource only if the expression evaluates to `true`. A condition can add
  constraints based on attributes of the request, the resource, or both. To
  learn which resources support conditions in their IAM policies, see the [IAM
  documentation](https://cloud.google.com/iam/help/conditions/resource-
  policies). **JSON example:** ``` { "bindings": [ { "role":
  "roles/resourcemanager.organizationAdmin", "members": [
  "user:mike@example.com", "group:admins@example.com", "domain:google.com",
  "serviceAccount:my-project-id@appspot.gserviceaccount.com" ] }, { "role":
  "roles/resourcemanager.organizationViewer", "members": [
  "user:eve@example.com" ], "condition": { "title": "expirable access",
  "description": "Does not grant access after Sep 2020", "expression":
  "request.time < timestamp('2020-10-01T00:00:00.000Z')", } } ], "etag":
  "BwWWja0YfJA=", "version": 3 } ``` **YAML example:** ``` bindings: -
  members: - user:mike@example.com - group:admins@example.com -
  domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
  role: roles/resourcemanager.organizationAdmin - members: -
  user:eve@example.com role: roles/resourcemanager.organizationViewer
  condition: title: expirable access description: Does not grant access after
  Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z')
  etag: BwWWja0YfJA= version: 3 ``` For a description of IAM and its features,
  see the [IAM documentation](https://cloud.google.com/iam/docs/).

  Fields:
    auditConfigs: Specifies cloud audit logging configuration for this policy.
    bindings: Associates a list of `members`, or principals, with a `role`.
      Optionally, may specify a `condition` that determines how and when the
      `bindings` are applied. Each of the `bindings` must contain at least one
      principal. The `bindings` in a `Policy` can refer to up to 1,500
      principals; up to 250 of these principals can be Google groups. Each
      occurrence of a principal counts towards these limits. For example, if
      the `bindings` grant 50 different roles to `user:alice@example.com`, and
      not to any other principal, then you can add another 1,450 principals to
      the `bindings` in the `Policy`.
    etag: `etag` is used for optimistic concurrency control as a way to help
      prevent simultaneous updates of a policy from overwriting each other. It
      is strongly suggested that systems make use of the `etag` in the read-
      modify-write cycle to perform policy updates in order to avoid race
      conditions: An `etag` is returned in the response to `getIamPolicy`, and
      systems are expected to put that etag in the request to `setIamPolicy`
      to ensure that their change will be applied to the same version of the
      policy. **Important:** If you use IAM Conditions, you must include the
      `etag` field whenever you call `setIamPolicy`. If you omit this field,
      then IAM allows you to overwrite a version `3` policy with a version `1`
      policy, and all of the conditions in the version `3` policy are lost.
    version: Specifies the format of the policy. Valid values are `0`, `1`,
      and `3`. Requests that specify an invalid value are rejected. Any
      operation that affects conditional role bindings must specify version
      `3`. This requirement applies to the following operations: * Getting a
      policy that includes a conditional role binding * Adding a conditional
      role binding to a policy * Changing a conditional role binding in a
      policy * Removing any role binding, with or without a condition, from a
      policy that includes conditions **Important:** If you use IAM
      Conditions, you must include the `etag` field whenever you call
      `setIamPolicy`. If you omit this field, then IAM allows you to overwrite
      a version `3` policy with a version `1` policy, and all of the
      conditions in the version `3` policy are lost. If a policy does not
      include any conditions, operations on that policy may specify any valid
      version or leave the field unset. To learn which resources support
      conditions in their IAM policies, see the [IAM
      documentation](https://cloud.google.com/iam/help/conditions/resource-
      policies).
  """

  auditConfigs = _messages.MessageField('AuditConfig', 1, repeated=True)
  bindings = _messages.MessageField('Binding', 2, repeated=True)
  etag = _messages.BytesField(3)
  version = _messages.IntegerField(4, variant=_messages.Variant.INT32)


class PreconfiguredWafSet(_messages.Message):
  r"""A PreconfiguredWafSet object.

  Fields:
    expressionSets: List of entities that are currently supported for WAF
      rules.
  """

  expressionSets = _messages.MessageField('WafExpressionSet', 1, repeated=True)


class PreservedState(_messages.Message):
  r"""Preserved state for a given instance.

  Messages:
    DisksValue: Preserved disks defined for this instance. This map is keyed
      with the device names of the disks.
    ExternalIPsValue: Preserved external IPs defined for this instance. This
      map is keyed with the name of the network interface.
    InternalIPsValue: Preserved internal IPs defined for this instance. This
      map is keyed with the name of the network interface.
    MetadataValue: Preserved metadata defined for this instance.

  Fields:
    disks: Preserved disks defined for this instance. This map is keyed with
      the device names of the disks.
    externalIPs: Preserved external IPs defined for this instance. This map is
      keyed with the name of the network interface.
    internalIPs: Preserved internal IPs defined for this instance. This map is
      keyed with the name of the network interface.
    metadata: Preserved metadata defined for this instance.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DisksValue(_messages.Message):
    r"""Preserved disks defined for this instance. This map is keyed with the
    device names of the disks.

    Messages:
      AdditionalProperty: An additional property for a DisksValue object.

    Fields:
      additionalProperties: Additional properties of type DisksValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DisksValue object.

      Fields:
        key: Name of the additional property.
        value: A PreservedStatePreservedDisk attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('PreservedStatePreservedDisk', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ExternalIPsValue(_messages.Message):
    r"""Preserved external IPs defined for this instance. This map is keyed
    with the name of the network interface.

    Messages:
      AdditionalProperty: An additional property for a ExternalIPsValue
        object.

    Fields:
      additionalProperties: Additional properties of type ExternalIPsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ExternalIPsValue object.

      Fields:
        key: Name of the additional property.
        value: A PreservedStatePreservedNetworkIp attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('PreservedStatePreservedNetworkIp', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class InternalIPsValue(_messages.Message):
    r"""Preserved internal IPs defined for this instance. This map is keyed
    with the name of the network interface.

    Messages:
      AdditionalProperty: An additional property for a InternalIPsValue
        object.

    Fields:
      additionalProperties: Additional properties of type InternalIPsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a InternalIPsValue object.

      Fields:
        key: Name of the additional property.
        value: A PreservedStatePreservedNetworkIp attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('PreservedStatePreservedNetworkIp', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class MetadataValue(_messages.Message):
    r"""Preserved metadata defined for this instance.

    Messages:
      AdditionalProperty: An additional property for a MetadataValue object.

    Fields:
      additionalProperties: Additional properties of type MetadataValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a MetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  disks = _messages.MessageField('DisksValue', 1)
  externalIPs = _messages.MessageField('ExternalIPsValue', 2)
  internalIPs = _messages.MessageField('InternalIPsValue', 3)
  metadata = _messages.MessageField('MetadataValue', 4)


class PreservedStatePreservedDisk(_messages.Message):
  r"""A PreservedStatePreservedDisk object.

  Enums:
    AutoDeleteValueValuesEnum: These stateful disks will never be deleted
      during autohealing, update, instance recreate operations. This flag is
      used to configure if the disk should be deleted after it is no longer
      used by the group, e.g. when the given instance or the whole MIG is
      deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted.
    ModeValueValuesEnum: The mode in which to attach this disk, either
      READ_WRITE or READ_ONLY. If not specified, the default is to attach the
      disk in READ_WRITE mode.

  Fields:
    autoDelete: These stateful disks will never be deleted during autohealing,
      update, instance recreate operations. This flag is used to configure if
      the disk should be deleted after it is no longer used by the group, e.g.
      when the given instance or the whole MIG is deleted. Note: disks
      attached in READ_ONLY mode cannot be auto-deleted.
    mode: The mode in which to attach this disk, either READ_WRITE or
      READ_ONLY. If not specified, the default is to attach the disk in
      READ_WRITE mode.
    source: The URL of the disk resource that is stateful and should be
      attached to the VM instance.
  """

  class AutoDeleteValueValuesEnum(_messages.Enum):
    r"""These stateful disks will never be deleted during autohealing, update,
    instance recreate operations. This flag is used to configure if the disk
    should be deleted after it is no longer used by the group, e.g. when the
    given instance or the whole MIG is deleted. Note: disks attached in
    READ_ONLY mode cannot be auto-deleted.

    Values:
      NEVER: <no description>
      ON_PERMANENT_INSTANCE_DELETION: <no description>
    """
    NEVER = 0
    ON_PERMANENT_INSTANCE_DELETION = 1

  class ModeValueValuesEnum(_messages.Enum):
    r"""The mode in which to attach this disk, either READ_WRITE or READ_ONLY.
    If not specified, the default is to attach the disk in READ_WRITE mode.

    Values:
      READ_ONLY: Attaches this disk in read-only mode. Multiple VM instances
        can use a disk in READ_ONLY mode at a time.
      READ_WRITE: *[Default]* Attaches this disk in READ_WRITE mode. Only one
        VM instance at a time can be attached to a disk in READ_WRITE mode.
    """
    READ_ONLY = 0
    READ_WRITE = 1

  autoDelete = _messages.EnumField('AutoDeleteValueValuesEnum', 1)
  mode = _messages.EnumField('ModeValueValuesEnum', 2)
  source = _messages.StringField(3)


class PreservedStatePreservedNetworkIp(_messages.Message):
  r"""A PreservedStatePreservedNetworkIp object.

  Enums:
    AutoDeleteValueValuesEnum: These stateful IPs will never be released
      during autohealing, update or VM instance recreate operations. This flag
      is used to configure if the IP reservation should be deleted after it is
      no longer used by the group, e.g. when the given instance or the whole
      group is deleted.

  Fields:
    autoDelete: These stateful IPs will never be released during autohealing,
      update or VM instance recreate operations. This flag is used to
      configure if the IP reservation should be deleted after it is no longer
      used by the group, e.g. when the given instance or the whole group is
      deleted.
    ipAddress: Ip address representation
  """

  class AutoDeleteValueValuesEnum(_messages.Enum):
    r"""These stateful IPs will never be released during autohealing, update
    or VM instance recreate operations. This flag is used to configure if the
    IP reservation should be deleted after it is no longer used by the group,
    e.g. when the given instance or the whole group is deleted.

    Values:
      NEVER: <no description>
      ON_PERMANENT_INSTANCE_DELETION: <no description>
    """
    NEVER = 0
    ON_PERMANENT_INSTANCE_DELETION = 1

  autoDelete = _messages.EnumField('AutoDeleteValueValuesEnum', 1)
  ipAddress = _messages.MessageField('PreservedStatePreservedNetworkIpIpAddress', 2)


class PreservedStatePreservedNetworkIpIpAddress(_messages.Message):
  r"""A PreservedStatePreservedNetworkIpIpAddress object.

  Fields:
    address: The URL of the reservation for this IP address.
    literal: An IPv4 internal network address to assign to the instance for
      this network interface.
  """

  address = _messages.StringField(1)
  literal = _messages.StringField(2)


class Principal(_messages.Message):
  r"""[Deprecated] All fields defined in a principal are ANDed.

  Messages:
    PropertiesValue: A map of Istio attribute to expected values. Exact match,
      prefix match, and suffix match are supported for values. For example,
      `request.headers[version]: "v1"`. The properties are ANDed together.

  Fields:
    condition: An expression to specify custom condition.
    groups: The groups the principal belongs to. Exact match, prefix match,
      and suffix match are supported.
    ips: IPv4 or IPv6 address or range (In CIDR format)
    namespaces: The namespaces. Exact match, prefix match, and suffix match
      are supported.
    notGroups: Negate of groups. Specifies exclusions.
    notIps: Negate of IPs. Specifies exclusions.
    notNamespaces: Negate of namespaces. Specifies exclusions.
    notUsers: Negate of users. Specifies exclusions.
    properties: A map of Istio attribute to expected values. Exact match,
      prefix match, and suffix match are supported for values. For example,
      `request.headers[version]: "v1"`. The properties are ANDed together.
    users: The user names/IDs or service accounts. Exact match, prefix match,
      and suffix match are supported.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class PropertiesValue(_messages.Message):
    r"""A map of Istio attribute to expected values. Exact match, prefix
    match, and suffix match are supported for values. For example,
    `request.headers[version]: "v1"`. The properties are ANDed together.

    Messages:
      AdditionalProperty: An additional property for a PropertiesValue object.

    Fields:
      additionalProperties: Additional properties of type PropertiesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a PropertiesValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  condition = _messages.StringField(1)
  groups = _messages.StringField(2, repeated=True)
  ips = _messages.StringField(3, repeated=True)
  namespaces = _messages.StringField(4, repeated=True)
  notGroups = _messages.StringField(5, repeated=True)
  notIps = _messages.StringField(6, repeated=True)
  notNamespaces = _messages.StringField(7, repeated=True)
  notUsers = _messages.StringField(8, repeated=True)
  properties = _messages.MessageField('PropertiesValue', 9)
  users = _messages.StringField(10, repeated=True)


class Project(_messages.Message):
  r"""Represents a Project resource. A project is used to organize resources
  in a Google Cloud Platform environment. For more information, read about the
  Resource Hierarchy.

  Enums:
    CloudArmorTierValueValuesEnum: [Output Only] The Cloud Armor tier for this
      project. It can be one of the following values: CA_STANDARD,
      CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be
      CA_STANDARD.
    DefaultNetworkTierValueValuesEnum: This signifies the default network tier
      used for configuring resources of the project and can only take the
      following values: PREMIUM, STANDARD. Initially the default network tier
      is PREMIUM.
    ManagedProtectionTierValueValuesEnum: [Output Only] The Cloud Armor
      Managed Protection (CAMP) tier for this project. It can be one of the
      following values: CA_STANDARD, CAMP_PLUS_PAYGO. If this field is not
      specified, it is assumed to be CA_STANDARD.
    VmDnsSettingValueValuesEnum: [Output Only] Default internal DNS setting
      used by VMs running in this project.
    XpnProjectStatusValueValuesEnum: [Output Only] The role this project has
      in a shared VPC configuration. Currently, only projects with the host
      role, which is specified by the value HOST, are differentiated.

  Fields:
    cloudArmorTier: [Output Only] The Cloud Armor tier for this project. It
      can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If
      this field is not specified, it is assumed to be CA_STANDARD.
    commonInstanceMetadata: Metadata key/value pairs available to all
      instances contained in this project. See Custom metadata for more
      information.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    defaultNetworkTier: This signifies the default network tier used for
      configuring resources of the project and can only take the following
      values: PREMIUM, STANDARD. Initially the default network tier is
      PREMIUM.
    defaultServiceAccount: [Output Only] Default service account used by VMs
      running in this project.
    description: An optional textual description of the resource.
    enabledFeatures: An optional list of restricted features enabled for use
      on this project.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server. This is *not* the project ID, and is just a
      unique ID used by Compute Engine to identify resources.
    kind: [Output Only] Type of the resource. Always compute#project for
      projects.
    managedProtectionTier: [Output Only] The Cloud Armor Managed Protection
      (CAMP) tier for this project. It can be one of the following values:
      CA_STANDARD, CAMP_PLUS_PAYGO. If this field is not specified, it is
      assumed to be CA_STANDARD.
    name: The project ID. For example: my-example-project. Use the project ID
      to make requests to Compute Engine.
    quotas: [Output Only] Quotas assigned to this project.
    selfLink: [Output Only] Server-defined URL for the resource.
    usageExportLocation: An optional naming prefix for daily usage reports and
      the Google Cloud Storage bucket where they are stored.
    vmDnsSetting: [Output Only] Default internal DNS setting used by VMs
      running in this project.
    xpnProjectStatus: [Output Only] The role this project has in a shared VPC
      configuration. Currently, only projects with the host role, which is
      specified by the value HOST, are differentiated.
  """

  class CloudArmorTierValueValuesEnum(_messages.Enum):
    r"""[Output Only] The Cloud Armor tier for this project. It can be one of
    the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is
    not specified, it is assumed to be CA_STANDARD.

    Values:
      CA_ENTERPRISE_ANNUAL: Enterprise tier protection billed annually.
      CA_ENTERPRISE_PAYGO: Enterprise tier protection billed monthly.
      CA_STANDARD: Standard protection.
    """
    CA_ENTERPRISE_ANNUAL = 0
    CA_ENTERPRISE_PAYGO = 1
    CA_STANDARD = 2

  class DefaultNetworkTierValueValuesEnum(_messages.Enum):
    r"""This signifies the default network tier used for configuring resources
    of the project and can only take the following values: PREMIUM, STANDARD.
    Initially the default network tier is PREMIUM.

    Values:
      FIXED_STANDARD: Public internet quality with fixed bandwidth.
      PREMIUM: High quality, Google-grade network tier, support for all
        networking products.
      SELECT: Price competitive network tier, support for all networking
        products.
      STANDARD: Public internet quality, only limited support for other
        networking products.
      STANDARD_OVERRIDES_FIXED_STANDARD: (Output only) Temporary tier for
        FIXED_STANDARD when fixed standard tier is expired or not configured.
    """
    FIXED_STANDARD = 0
    PREMIUM = 1
    SELECT = 2
    STANDARD = 3
    STANDARD_OVERRIDES_FIXED_STANDARD = 4

  class ManagedProtectionTierValueValuesEnum(_messages.Enum):
    r"""[Output Only] The Cloud Armor Managed Protection (CAMP) tier for this
    project. It can be one of the following values: CA_STANDARD,
    CAMP_PLUS_PAYGO. If this field is not specified, it is assumed to be
    CA_STANDARD.

    Values:
      CAMP_PLUS_ANNUAL: Plus tier protection annual.
      CAMP_PLUS_PAYGO: Plus tier protection monthly.
      CA_STANDARD: Standard protection.
    """
    CAMP_PLUS_ANNUAL = 0
    CAMP_PLUS_PAYGO = 1
    CA_STANDARD = 2

  class VmDnsSettingValueValuesEnum(_messages.Enum):
    r"""[Output Only] Default internal DNS setting used by VMs running in this
    project.

    Values:
      GLOBAL_DEFAULT: <no description>
      UNSPECIFIED_VM_DNS_SETTING: <no description>
      ZONAL_DEFAULT: <no description>
      ZONAL_ONLY: <no description>
    """
    GLOBAL_DEFAULT = 0
    UNSPECIFIED_VM_DNS_SETTING = 1
    ZONAL_DEFAULT = 2
    ZONAL_ONLY = 3

  class XpnProjectStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The role this project has in a shared VPC configuration.
    Currently, only projects with the host role, which is specified by the
    value HOST, are differentiated.

    Values:
      HOST: <no description>
      UNSPECIFIED_XPN_PROJECT_STATUS: <no description>
    """
    HOST = 0
    UNSPECIFIED_XPN_PROJECT_STATUS = 1

  cloudArmorTier = _messages.EnumField('CloudArmorTierValueValuesEnum', 1)
  commonInstanceMetadata = _messages.MessageField('Metadata', 2)
  creationTimestamp = _messages.StringField(3)
  defaultNetworkTier = _messages.EnumField('DefaultNetworkTierValueValuesEnum', 4)
  defaultServiceAccount = _messages.StringField(5)
  description = _messages.StringField(6)
  enabledFeatures = _messages.StringField(7, repeated=True)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(9, default='compute#project')
  managedProtectionTier = _messages.EnumField('ManagedProtectionTierValueValuesEnum', 10)
  name = _messages.StringField(11)
  quotas = _messages.MessageField('Quota', 12, repeated=True)
  selfLink = _messages.StringField(13)
  usageExportLocation = _messages.MessageField('UsageExportLocation', 14)
  vmDnsSetting = _messages.EnumField('VmDnsSettingValueValuesEnum', 15)
  xpnProjectStatus = _messages.EnumField('XpnProjectStatusValueValuesEnum', 16)


class ProjectsDisableXpnResourceRequest(_messages.Message):
  r"""A ProjectsDisableXpnResourceRequest object.

  Fields:
    xpnResource: Service resource (a.k.a service project) ID.
  """

  xpnResource = _messages.MessageField('XpnResourceId', 1)


class ProjectsEnableXpnResourceRequest(_messages.Message):
  r"""A ProjectsEnableXpnResourceRequest object.

  Fields:
    xpnResource: Service resource (a.k.a service project) ID.
  """

  xpnResource = _messages.MessageField('XpnResourceId', 1)


class ProjectsGetXpnResources(_messages.Message):
  r"""A ProjectsGetXpnResources object.

  Fields:
    kind: [Output Only] Type of resource. Always
      compute#projectsGetXpnResources for lists of service resources (a.k.a
      service projects)
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    resources: Service resources (a.k.a service projects) attached to this
      project as their shared VPC host.
  """

  kind = _messages.StringField(1, default='compute#projectsGetXpnResources')
  nextPageToken = _messages.StringField(2)
  resources = _messages.MessageField('XpnResourceId', 3, repeated=True)


class ProjectsListXpnHostsRequest(_messages.Message):
  r"""A ProjectsListXpnHostsRequest object.

  Fields:
    organization: Optional organization ID managed by Cloud Resource Manager,
      for which to list shared VPC host projects. If not specified, the
      organization will be inferred from the project.
    returnPartialPage: Opt-in for partial page behavior which provides a
      partial filled page (number of items on which may be smaller than
      maxResults) within the API deadline. If opt-in, then the user should
      rely on if nextPageToken is empty in the response to determine if there
      is a next page. Empty page is also valid and possible. The default value
      is false.
  """

  organization = _messages.StringField(1)
  returnPartialPage = _messages.BooleanField(2)


class ProjectsSetCloudArmorTierRequest(_messages.Message):
  r"""A ProjectsSetCloudArmorTierRequest object.

  Enums:
    CloudArmorTierValueValuesEnum: Managed protection tier to be set.

  Fields:
    cloudArmorTier: Managed protection tier to be set.
  """

  class CloudArmorTierValueValuesEnum(_messages.Enum):
    r"""Managed protection tier to be set.

    Values:
      CA_ENTERPRISE_ANNUAL: Enterprise tier protection billed annually.
      CA_ENTERPRISE_PAYGO: Enterprise tier protection billed monthly.
      CA_STANDARD: Standard protection.
    """
    CA_ENTERPRISE_ANNUAL = 0
    CA_ENTERPRISE_PAYGO = 1
    CA_STANDARD = 2

  cloudArmorTier = _messages.EnumField('CloudArmorTierValueValuesEnum', 1)


class ProjectsSetDefaultNetworkTierRequest(_messages.Message):
  r"""A ProjectsSetDefaultNetworkTierRequest object.

  Enums:
    NetworkTierValueValuesEnum: Default network tier to be set.

  Fields:
    networkTier: Default network tier to be set.
  """

  class NetworkTierValueValuesEnum(_messages.Enum):
    r"""Default network tier to be set.

    Values:
      FIXED_STANDARD: Public internet quality with fixed bandwidth.
      PREMIUM: High quality, Google-grade network tier, support for all
        networking products.
      SELECT: Price competitive network tier, support for all networking
        products.
      STANDARD: Public internet quality, only limited support for other
        networking products.
      STANDARD_OVERRIDES_FIXED_STANDARD: (Output only) Temporary tier for
        FIXED_STANDARD when fixed standard tier is expired or not configured.
    """
    FIXED_STANDARD = 0
    PREMIUM = 1
    SELECT = 2
    STANDARD = 3
    STANDARD_OVERRIDES_FIXED_STANDARD = 4

  networkTier = _messages.EnumField('NetworkTierValueValuesEnum', 1)


class ProjectsSetDefaultServiceAccountRequest(_messages.Message):
  r"""A ProjectsSetDefaultServiceAccountRequest object.

  Fields:
    email: Email address of the service account.
  """

  email = _messages.StringField(1)


class ProjectsSetManagedProtectionTierRequest(_messages.Message):
  r"""A ProjectsSetManagedProtectionTierRequest object.

  Enums:
    ManagedProtectionTierValueValuesEnum: Managed protection tier to be set.

  Fields:
    managedProtectionTier: Managed protection tier to be set.
  """

  class ManagedProtectionTierValueValuesEnum(_messages.Enum):
    r"""Managed protection tier to be set.

    Values:
      CAMP_PLUS_ANNUAL: Plus tier protection annual.
      CAMP_PLUS_PAYGO: Plus tier protection monthly.
      CA_STANDARD: Standard protection.
    """
    CAMP_PLUS_ANNUAL = 0
    CAMP_PLUS_PAYGO = 1
    CA_STANDARD = 2

  managedProtectionTier = _messages.EnumField('ManagedProtectionTierValueValuesEnum', 1)


class PublicAdvertisedPrefix(_messages.Message):
  r"""A public advertised prefix represents an aggregated IP prefix or
  netblock which customers bring to cloud. The IP prefix is a single unit of
  route advertisement and is announced globally to the internet.

  Enums:
    ByoipApiVersionValueValuesEnum: [Output Only] The version of BYOIP API.
    PdpScopeValueValuesEnum: Specifies how child public delegated prefix will
      be scoped. It could be one of following values: - `REGIONAL`: The public
      delegated prefix is regional only. The provisioning will take a few
      minutes. - `GLOBAL`: The public delegated prefix is global only. The
      provisioning will take ~4 weeks. - `GLOBAL_AND_REGIONAL` [output only]:
      The public delegated prefixes is BYOIP V1 legacy prefix. This is output
      only value and no longer supported in BYOIP V2.
    StatusValueValuesEnum: The status of the public advertised prefix.
      Possible values include: - `INITIAL`: RPKI validation is complete. -
      `PTR_CONFIGURED`: User has configured the PTR. - `VALIDATED`: Reverse
      DNS lookup is successful. - `REVERSE_DNS_LOOKUP_FAILED`: Reverse DNS
      lookup failed. - `PREFIX_CONFIGURATION_IN_PROGRESS`: The prefix is being
      configured. - `PREFIX_CONFIGURATION_COMPLETE`: The prefix is fully
      configured. - `PREFIX_REMOVAL_IN_PROGRESS`: The prefix is being removed.

  Fields:
    byoipApiVersion: [Output Only] The version of BYOIP API.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    dnsVerificationIp: The address to be used for reverse DNS verification.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-
      date fingerprint must be provided in order to update the
      PublicAdvertisedPrefix, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a PublicAdvertisedPrefix.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    ipCidrRange: The address range, in CIDR format, represented by this public
      advertised prefix.
    kind: [Output Only] Type of the resource. Always
      compute#publicAdvertisedPrefix for public advertised prefixes.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    pdpScope: Specifies how child public delegated prefix will be scoped. It
      could be one of following values: - `REGIONAL`: The public delegated
      prefix is regional only. The provisioning will take a few minutes. -
      `GLOBAL`: The public delegated prefix is global only. The provisioning
      will take ~4 weeks. - `GLOBAL_AND_REGIONAL` [output only]: The public
      delegated prefixes is BYOIP V1 legacy prefix. This is output only value
      and no longer supported in BYOIP V2.
    publicDelegatedPrefixs: [Output Only] The list of public delegated
      prefixes that exist for this public advertised prefix.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
    sharedSecret: [Output Only] The shared secret to be used for reverse DNS
      verification.
    status: The status of the public advertised prefix. Possible values
      include: - `INITIAL`: RPKI validation is complete. - `PTR_CONFIGURED`:
      User has configured the PTR. - `VALIDATED`: Reverse DNS lookup is
      successful. - `REVERSE_DNS_LOOKUP_FAILED`: Reverse DNS lookup failed. -
      `PREFIX_CONFIGURATION_IN_PROGRESS`: The prefix is being configured. -
      `PREFIX_CONFIGURATION_COMPLETE`: The prefix is fully configured. -
      `PREFIX_REMOVAL_IN_PROGRESS`: The prefix is being removed.
  """

  class ByoipApiVersionValueValuesEnum(_messages.Enum):
    r"""[Output Only] The version of BYOIP API.

    Values:
      V1: This public advertised prefix can be used to create both regional
        and global public delegated prefixes. It usually takes 4 weeks to
        create or delete a public delegated prefix. The BGP status cannot be
        changed.
      V2: This public advertised prefix can only be used to create regional
        public delegated prefixes. Public delegated prefix creation and
        deletion takes minutes and the BGP status can be modified.
    """
    V1 = 0
    V2 = 1

  class PdpScopeValueValuesEnum(_messages.Enum):
    r"""Specifies how child public delegated prefix will be scoped. It could
    be one of following values: - `REGIONAL`: The public delegated prefix is
    regional only. The provisioning will take a few minutes. - `GLOBAL`: The
    public delegated prefix is global only. The provisioning will take ~4
    weeks. - `GLOBAL_AND_REGIONAL` [output only]: The public delegated
    prefixes is BYOIP V1 legacy prefix. This is output only value and no
    longer supported in BYOIP V2.

    Values:
      GLOBAL: The public delegated prefix is global only. The provisioning
        will take ~4 weeks.
      GLOBAL_AND_REGIONAL: The public delegated prefixes is BYOIP V1 legacy
        prefix. This is output only value and no longer supported in BYOIP V2.
      REGIONAL: The public delegated prefix is regional only. The provisioning
        will take a few minutes.
    """
    GLOBAL = 0
    GLOBAL_AND_REGIONAL = 1
    REGIONAL = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""The status of the public advertised prefix. Possible values include: -
    `INITIAL`: RPKI validation is complete. - `PTR_CONFIGURED`: User has
    configured the PTR. - `VALIDATED`: Reverse DNS lookup is successful. -
    `REVERSE_DNS_LOOKUP_FAILED`: Reverse DNS lookup failed. -
    `PREFIX_CONFIGURATION_IN_PROGRESS`: The prefix is being configured. -
    `PREFIX_CONFIGURATION_COMPLETE`: The prefix is fully configured. -
    `PREFIX_REMOVAL_IN_PROGRESS`: The prefix is being removed.

    Values:
      ANNOUNCED_TO_INTERNET: The prefix is announced to Internet.
      INITIAL: RPKI validation is complete.
      PREFIX_CONFIGURATION_COMPLETE: The prefix is fully configured.
      PREFIX_CONFIGURATION_IN_PROGRESS: The prefix is being configured.
      PREFIX_REMOVAL_IN_PROGRESS: The prefix is being removed.
      PTR_CONFIGURED: User has configured the PTR.
      READY_TO_ANNOUNCE: The prefix is currently withdrawn but ready to be
        announced.
      REVERSE_DNS_LOOKUP_FAILED: Reverse DNS lookup failed.
      VALIDATED: Reverse DNS lookup is successful.
    """
    ANNOUNCED_TO_INTERNET = 0
    INITIAL = 1
    PREFIX_CONFIGURATION_COMPLETE = 2
    PREFIX_CONFIGURATION_IN_PROGRESS = 3
    PREFIX_REMOVAL_IN_PROGRESS = 4
    PTR_CONFIGURED = 5
    READY_TO_ANNOUNCE = 6
    REVERSE_DNS_LOOKUP_FAILED = 7
    VALIDATED = 8

  byoipApiVersion = _messages.EnumField('ByoipApiVersionValueValuesEnum', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  dnsVerificationIp = _messages.StringField(4)
  fingerprint = _messages.BytesField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  ipCidrRange = _messages.StringField(7)
  kind = _messages.StringField(8, default='compute#publicAdvertisedPrefix')
  name = _messages.StringField(9)
  pdpScope = _messages.EnumField('PdpScopeValueValuesEnum', 10)
  publicDelegatedPrefixs = _messages.MessageField('PublicAdvertisedPrefixPublicDelegatedPrefix', 11, repeated=True)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)
  sharedSecret = _messages.StringField(14)
  status = _messages.EnumField('StatusValueValuesEnum', 15)


class PublicAdvertisedPrefixList(_messages.Message):
  r"""A PublicAdvertisedPrefixList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PublicAdvertisedPrefix resources.
    kind: [Output Only] Type of the resource. Always
      compute#publicAdvertisedPrefix for public advertised prefixes.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('PublicAdvertisedPrefix', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#publicAdvertisedPrefixList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class PublicAdvertisedPrefixPublicDelegatedPrefix(_messages.Message):
  r"""Represents a CIDR range which can be used to assign addresses.

  Fields:
    ipRange: The IP address range of the public delegated prefix
    name: The name of the public delegated prefix
    project: The project number of the public delegated prefix
    region: The region of the public delegated prefix if it is regional. If
      absent, the prefix is global.
    status: The status of the public delegated prefix. Possible values are:
      INITIALIZING: The public delegated prefix is being initialized and
      addresses cannot be created yet. ANNOUNCED: The public delegated prefix
      is active.
  """

  ipRange = _messages.StringField(1)
  name = _messages.StringField(2)
  project = _messages.StringField(3)
  region = _messages.StringField(4)
  status = _messages.StringField(5)


class PublicDelegatedPrefix(_messages.Message):
  r"""A PublicDelegatedPrefix resource represents an IP block within a
  PublicAdvertisedPrefix that is configured within a single cloud scope
  (global or region). IPs in the block can be allocated to resources within
  that scope. Public delegated prefixes may be further broken up into smaller
  IP blocks in the same scope as the parent block.

  Enums:
    ByoipApiVersionValueValuesEnum: [Output Only] The version of BYOIP API.
    ModeValueValuesEnum: The public delegated prefix mode for IPv6 only.
    StatusValueValuesEnum: [Output Only] The status of the public delegated
      prefix, which can be one of following values: - `INITIALIZING` The
      public delegated prefix is being initialized and addresses cannot be
      created yet. - `READY_TO_ANNOUNCE` The public delegated prefix is a live
      migration prefix and is active. - `ANNOUNCED` The public delegated
      prefix is active. - `DELETING` The public delegated prefix is being
      deprovsioned.

  Fields:
    allocatablePrefixLength: The allocatable prefix length supported by this
      public delegated prefix. This field is optional and cannot be set for
      prefixes in DELEGATION mode. It cannot be set for IPv4 prefixes either,
      and it always defaults to 32.
    byoipApiVersion: [Output Only] The version of BYOIP API.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a new PublicDelegatedPrefix. An up-to-
      date fingerprint must be provided in order to update the
      PublicDelegatedPrefix, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a PublicDelegatedPrefix.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    ipCidrRange: The IP address range, in CIDR format, represented by this
      public delegated prefix.
    isLiveMigration: If true, the prefix will be live migrated.
    kind: [Output Only] Type of the resource. Always
      compute#publicDelegatedPrefix for public delegated prefixes.
    mode: The public delegated prefix mode for IPv6 only.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    parentPrefix: The URL of parent prefix. Either PublicAdvertisedPrefix or
      PublicDelegatedPrefix.
    publicDelegatedSubPrefixs: The list of sub public delegated prefixes that
      exist for this public delegated prefix.
    region: [Output Only] URL of the region where the public delegated prefix
      resides. This field applies only to the region resource. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
    status: [Output Only] The status of the public delegated prefix, which can
      be one of following values: - `INITIALIZING` The public delegated prefix
      is being initialized and addresses cannot be created yet. -
      `READY_TO_ANNOUNCE` The public delegated prefix is a live migration
      prefix and is active. - `ANNOUNCED` The public delegated prefix is
      active. - `DELETING` The public delegated prefix is being deprovsioned.
  """

  class ByoipApiVersionValueValuesEnum(_messages.Enum):
    r"""[Output Only] The version of BYOIP API.

    Values:
      V1: This public delegated prefix usually takes 4 weeks to delete, and
        the BGP status cannot be changed. Announce and Withdraw APIs can not
        be used on this prefix.
      V2: This public delegated prefix takes minutes to delete. Announce and
        Withdraw APIs can be used on this prefix to change the BGP status.
    """
    V1 = 0
    V2 = 1

  class ModeValueValuesEnum(_messages.Enum):
    r"""The public delegated prefix mode for IPv6 only.

    Values:
      DELEGATION: The public delegated prefix is used for further sub-
        delegation only. Such prefixes cannot set allocatablePrefixLength.
      EXTERNAL_IPV6_FORWARDING_RULE_CREATION: The public delegated prefix is
        used for creating forwarding rules only. Such prefixes cannot set
        publicDelegatedSubPrefixes.
      EXTERNAL_IPV6_SUBNETWORK_CREATION: The public delegated prefix is used
        for creating dual-mode subnetworks only. Such prefixes cannot set
        publicDelegatedSubPrefixes.
    """
    DELEGATION = 0
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 1
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the public delegated prefix, which can be
    one of following values: - `INITIALIZING` The public delegated prefix is
    being initialized and addresses cannot be created yet. -
    `READY_TO_ANNOUNCE` The public delegated prefix is a live migration prefix
    and is active. - `ANNOUNCED` The public delegated prefix is active. -
    `DELETING` The public delegated prefix is being deprovsioned.

    Values:
      ANNOUNCED: The public delegated prefix is active.
      ANNOUNCED_TO_GOOGLE: The prefix is announced within Google network.
      ANNOUNCED_TO_INTERNET: The prefix is announced to Internet and within
        Google.
      DELETING: The public delegated prefix is being deprovsioned.
      INITIALIZING: The public delegated prefix is being initialized and
        addresses cannot be created yet.
      READY_TO_ANNOUNCE: The public delegated prefix is currently withdrawn
        but ready to be announced.
    """
    ANNOUNCED = 0
    ANNOUNCED_TO_GOOGLE = 1
    ANNOUNCED_TO_INTERNET = 2
    DELETING = 3
    INITIALIZING = 4
    READY_TO_ANNOUNCE = 5

  allocatablePrefixLength = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  byoipApiVersion = _messages.EnumField('ByoipApiVersionValueValuesEnum', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  fingerprint = _messages.BytesField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  ipCidrRange = _messages.StringField(7)
  isLiveMigration = _messages.BooleanField(8)
  kind = _messages.StringField(9, default='compute#publicDelegatedPrefix')
  mode = _messages.EnumField('ModeValueValuesEnum', 10)
  name = _messages.StringField(11)
  parentPrefix = _messages.StringField(12)
  publicDelegatedSubPrefixs = _messages.MessageField('PublicDelegatedPrefixPublicDelegatedSubPrefix', 13, repeated=True)
  region = _messages.StringField(14)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  status = _messages.EnumField('StatusValueValuesEnum', 17)


class PublicDelegatedPrefixAggregatedList(_messages.Message):
  r"""A PublicDelegatedPrefixAggregatedList object.

  Messages:
    ItemsValue: A list of PublicDelegatedPrefixesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PublicDelegatedPrefixesScopedList resources.
    kind: [Output Only] Type of the resource. Always
      compute#publicDelegatedPrefixAggregatedList for aggregated lists of
      public delegated prefixes.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of PublicDelegatedPrefixesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of PublicDelegatedPrefixes.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A PublicDelegatedPrefixesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('PublicDelegatedPrefixesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#publicDelegatedPrefixAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class PublicDelegatedPrefixList(_messages.Message):
  r"""A PublicDelegatedPrefixList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PublicDelegatedPrefix resources.
    kind: [Output Only] Type of the resource. Always
      compute#publicDelegatedPrefixList for public delegated prefixes.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('PublicDelegatedPrefix', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#publicDelegatedPrefixList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class PublicDelegatedPrefixPublicDelegatedSubPrefix(_messages.Message):
  r"""Represents a sub PublicDelegatedPrefix.

  Enums:
    ModeValueValuesEnum: The PublicDelegatedSubPrefix mode for IPv6 only.
    StatusValueValuesEnum: [Output Only] The status of the sub public
      delegated prefix.

  Fields:
    allocatablePrefixLength: The allocatable prefix length supported by this
      PublicDelegatedSubPrefix.
    delegateeProject: Name of the project scoping this
      PublicDelegatedSubPrefix.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    ipCidrRange: The IP address range, in CIDR format, represented by this sub
      public delegated prefix.
    isAddress: Whether the sub prefix is delegated to create Address resources
      in the delegatee project.
    mode: The PublicDelegatedSubPrefix mode for IPv6 only.
    name: The name of the sub public delegated prefix.
    region: [Output Only] The region of the sub public delegated prefix if it
      is regional. If absent, the sub prefix is global.
    status: [Output Only] The status of the sub public delegated prefix.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""The PublicDelegatedSubPrefix mode for IPv6 only.

    Values:
      DELEGATION: The public delegated prefix is used for further sub-
        delegation only. Such prefixes cannot set allocatablePrefixLength.
      EXTERNAL_IPV6_FORWARDING_RULE_CREATION: The public delegated prefix is
        used for creating forwarding rules only. Such prefixes cannot set
        publicDelegatedSubPrefixes.
      EXTERNAL_IPV6_SUBNETWORK_CREATION: The public delegated prefix is used
        for creating dual-mode subnetworks only. Such prefixes cannot set
        publicDelegatedSubPrefixes.
    """
    DELEGATION = 0
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 1
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the sub public delegated prefix.

    Values:
      ACTIVE: <no description>
      INACTIVE: <no description>
    """
    ACTIVE = 0
    INACTIVE = 1

  allocatablePrefixLength = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  delegateeProject = _messages.StringField(2)
  description = _messages.StringField(3)
  ipCidrRange = _messages.StringField(4)
  isAddress = _messages.BooleanField(5)
  mode = _messages.EnumField('ModeValueValuesEnum', 6)
  name = _messages.StringField(7)
  region = _messages.StringField(8)
  status = _messages.EnumField('StatusValueValuesEnum', 9)


class PublicDelegatedPrefixesScopedList(_messages.Message):
  r"""A PublicDelegatedPrefixesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of public delegated prefixes when the list is empty.

  Fields:
    publicDelegatedPrefixes: [Output Only] A list of PublicDelegatedPrefixes
      contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      public delegated prefixes when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of public
    delegated prefixes when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  publicDelegatedPrefixes = _messages.MessageField('PublicDelegatedPrefix', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class QueuedResource(_messages.Message):
  r"""QueuedResource represents a request for future capacity. The capacity is
  delivered in the form of other GCE resources, either Instances or
  Reservations.

  Enums:
    StateValueValuesEnum: [Output only] High-level status of the request.

  Fields:
    bulkInsertInstanceResource: Specification of VM instances to create.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#queuedResource
      for QueuedResources.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    queuingPolicy: Queuing parameters for the requested capacity.
    selfLink: [Output only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    state: [Output only] High-level status of the request.
    status: [Output only] Result of queuing and provisioning based on deferred
      capacity.
    zone: [Output Only] URL of the zone where the resource resides. Only
      applicable for zonal resources. You must specify this field as part of
      the HTTP request URL. It is not settable as a field in the request body.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output only] High-level status of the request.

    Values:
      ACCEPTED: The request was created successfully and was accepted for
        provisioning when the capacity becomes available.
      CANCELLED: The request was canceled by the user.
      CREATING: QueuedResource is being created and may still fail creation.
      DELETING: The request is being deleted.
      FAILED: The request failed before or during provisioning.
      PROVISIONING: The target resource(s) are being provisioned.
      STATE_UNSPECIFIED: <no description>
      SUCCEEDED: The request succeeded.
    """
    ACCEPTED = 0
    CANCELLED = 1
    CREATING = 2
    DELETING = 3
    FAILED = 4
    PROVISIONING = 5
    STATE_UNSPECIFIED = 6
    SUCCEEDED = 7

  bulkInsertInstanceResource = _messages.MessageField('BulkInsertInstanceResource', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#queuedResource')
  name = _messages.StringField(6)
  queuingPolicy = _messages.MessageField('QueuingPolicy', 7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  state = _messages.EnumField('StateValueValuesEnum', 10)
  status = _messages.MessageField('QueuedResourceStatus', 11)
  zone = _messages.StringField(12)


class QueuedResourceList(_messages.Message):
  r"""A QueuedResourceList object.

  Messages:
    WarningValue: Informational warning message.

  Fields:
    id: Unique identifier for the resource; defined by the server.
    items: A list of QueuedResource resources.
    kind: Type of resource.
    nextPageToken: This token allows you to get the next page of results for
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output only] Server-defined URL for this resource.
    unreachables: [Output only] Unreachable resources.
    warning: Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('QueuedResource', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#queuedResourceList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class QueuedResourceStatus(_messages.Message):
  r"""A QueuedResourceStatus object.

  Fields:
    failedData: A QueuedResourceStatusFailedData attribute.
    provisioningOperations: A string attribute.
    queuingPolicy: A QueuingPolicy attribute.
  """

  failedData = _messages.MessageField('QueuedResourceStatusFailedData', 1)
  provisioningOperations = _messages.StringField(2, repeated=True)
  queuingPolicy = _messages.MessageField('QueuingPolicy', 3)


class QueuedResourceStatusFailedData(_messages.Message):
  r"""A QueuedResourceStatusFailedData object.

  Messages:
    ErrorValue: A ErrorValue object.

  Fields:
    error: A ErrorValue attribute.
  """

  class ErrorValue(_messages.Message):
    r"""A ErrorValue object.

    Messages:
      ErrorsValueListEntry: A ErrorsValueListEntry object.

    Fields:
      errors: [Output Only] The array of errors encountered while processing
        this operation.
    """

    class ErrorsValueListEntry(_messages.Message):
      r"""A ErrorsValueListEntry object.

      Messages:
        ErrorDetailsValueListEntry: A ErrorDetailsValueListEntry object.

      Fields:
        code: [Output Only] The error type identifier for this error.
        errorDetails: [Output Only] An optional list of messages that contain
          the error details. There is a set of defined message types to use
          for providing details.The syntax depends on the error code. For
          example, QuotaExceededInfo will have details when the error code is
          QUOTA_EXCEEDED.
        location: [Output Only] Indicates the field in the request that caused
          the error. This property is optional.
        message: [Output Only] An optional, human-readable error message.
      """

      class ErrorDetailsValueListEntry(_messages.Message):
        r"""A ErrorDetailsValueListEntry object.

        Fields:
          errorInfo: A ErrorInfo attribute.
          help: A Help attribute.
          localizedMessage: A LocalizedMessage attribute.
          quotaInfo: A QuotaExceededInfo attribute.
        """

        errorInfo = _messages.MessageField('ErrorInfo', 1)
        help = _messages.MessageField('Help', 2)
        localizedMessage = _messages.MessageField('LocalizedMessage', 3)
        quotaInfo = _messages.MessageField('QuotaExceededInfo', 4)

      code = _messages.StringField(1)
      errorDetails = _messages.MessageField('ErrorDetailsValueListEntry', 2, repeated=True)
      location = _messages.StringField(3)
      message = _messages.StringField(4)

    errors = _messages.MessageField('ErrorsValueListEntry', 1, repeated=True)

  error = _messages.MessageField('ErrorValue', 1)


class QueuedResourcesAggregatedList(_messages.Message):
  r"""A QueuedResourcesAggregatedList object.

  Messages:
    ItemsValue: A list of QueuedResourcesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of QueuedResourcesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#queuedResourcesAggregatedList for lists of QueuedResource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of QueuedResourcesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of queued
        resources.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A QueuedResourcesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('QueuedResourcesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#queuedResources')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class QueuedResourcesScopedList(_messages.Message):
  r"""A QueuedResourcesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    queuedResources: List of QueuedResources contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  queuedResources = _messages.MessageField('QueuedResource', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class QueuingPolicy(_messages.Message):
  r"""Queuing parameters for the requested deferred capacity.

  Fields:
    validUntilDuration: Relative deadline for waiting for capacity.
    validUntilTime: Absolute deadline for waiting for capacity in RFC3339 text
      format.
  """

  validUntilDuration = _messages.MessageField('Duration', 1)
  validUntilTime = _messages.StringField(2)


class Quota(_messages.Message):
  r"""A quotas entry.

  Enums:
    MetricValueValuesEnum: [Output Only] Name of the quota metric.

  Fields:
    limit: [Output Only] Quota limit for this metric.
    metric: [Output Only] Name of the quota metric.
    owner: [Output Only] Owning resource. This is the resource on which this
      quota is applied.
    usage: [Output Only] Current usage of this metric.
  """

  class MetricValueValuesEnum(_messages.Enum):
    r"""[Output Only] Name of the quota metric.

    Values:
      A2_CPUS: <no description>
      AFFINITY_GROUPS: <no description>
      AMD_S9300_GPUS: <no description>
      AUTOSCALERS: <no description>
      BACKEND_BUCKETS: <no description>
      BACKEND_SERVICES: <no description>
      C2D_CPUS: <no description>
      C2_CPUS: <no description>
      C3_CPUS: <no description>
      COMMITMENTS: <no description>
      COMMITTED_A2_CPUS: <no description>
      COMMITTED_C2D_CPUS: <no description>
      COMMITTED_C2_CPUS: <no description>
      COMMITTED_C3_CPUS: <no description>
      COMMITTED_CPUS: <no description>
      COMMITTED_E2_CPUS: <no description>
      COMMITTED_LICENSES: <no description>
      COMMITTED_LOCAL_SSD_TOTAL_GB: <no description>
      COMMITTED_M3_CPUS: <no description>
      COMMITTED_MEMORY_OPTIMIZED_CPUS: <no description>
      COMMITTED_N2A_CPUS: <no description>
      COMMITTED_N2D_CPUS: <no description>
      COMMITTED_N2_CPUS: <no description>
      COMMITTED_NVIDIA_A100_80GB_GPUS: <no description>
      COMMITTED_NVIDIA_A100_GPUS: <no description>
      COMMITTED_NVIDIA_H100_GPUS: <no description>
      COMMITTED_NVIDIA_K80_GPUS: <no description>
      COMMITTED_NVIDIA_L4_GPUS: <no description>
      COMMITTED_NVIDIA_P100_GPUS: <no description>
      COMMITTED_NVIDIA_P4_GPUS: <no description>
      COMMITTED_NVIDIA_T4_GPUS: <no description>
      COMMITTED_NVIDIA_V100_GPUS: <no description>
      COMMITTED_T2A_CPUS: <no description>
      COMMITTED_T2D_CPUS: <no description>
      COMMITTED_Z3_CPUS: <no description>
      CPUS: Guest CPUs
      CPUS_ALL_REGIONS: <no description>
      DISKS_TOTAL_GB: <no description>
      E2_CPUS: <no description>
      EXTERNAL_MANAGED_FORWARDING_RULES: <no description>
      EXTERNAL_NETWORK_LB_FORWARDING_RULES: <no description>
      EXTERNAL_PROTOCOL_FORWARDING_RULES: <no description>
      EXTERNAL_VPN_GATEWAYS: <no description>
      FIREWALLS: <no description>
      FORWARDING_RULES: <no description>
      GLOBAL_EXTERNAL_MANAGED_BACKEND_SERVICES: <no description>
      GLOBAL_EXTERNAL_MANAGED_FORWARDING_RULES: <no description>
      GLOBAL_EXTERNAL_PROXY_LB_BACKEND_SERVICES: <no description>
      GLOBAL_INTERNAL_ADDRESSES: <no description>
      GLOBAL_INTERNAL_MANAGED_BACKEND_SERVICES: <no description>
      GLOBAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES: <no description>
      GPUS_ALL_REGIONS: <no description>
      HDB_TOTAL_GB: <no description>
      HDB_TOTAL_IOPS: <no description>
      HDB_TOTAL_THROUGHPUT: <no description>
      HEALTH_CHECKS: <no description>
      IMAGES: <no description>
      INSTANCES: <no description>
      INSTANCE_GROUPS: <no description>
      INSTANCE_GROUP_MANAGERS: <no description>
      INSTANCE_TEMPLATES: <no description>
      INTERCONNECTS: <no description>
      INTERCONNECT_ATTACHMENTS_PER_REGION: <no description>
      INTERCONNECT_ATTACHMENTS_TOTAL_MBPS: <no description>
      INTERCONNECT_TOTAL_GBPS: <no description>
      INTERNAL_ADDRESSES: <no description>
      INTERNAL_TRAFFIC_DIRECTOR_FORWARDING_RULES: <no description>
      IN_PLACE_SNAPSHOTS: <no description>
      IN_USE_ADDRESSES: <no description>
      IN_USE_BACKUP_SCHEDULES: <no description>
      IN_USE_MAINTENANCE_WINDOWS: <no description>
      IN_USE_SNAPSHOT_SCHEDULES: <no description>
      LOCAL_SSD_TOTAL_GB: <no description>
      M1_CPUS: <no description>
      M2_CPUS: <no description>
      M3_CPUS: <no description>
      MACHINE_IMAGES: <no description>
      N2A_CPUS: <no description>
      N2D_CPUS: <no description>
      N2_CPUS: <no description>
      NETWORKS: <no description>
      NETWORK_ATTACHMENTS: <no description>
      NETWORK_ENDPOINT_GROUPS: <no description>
      NETWORK_FIREWALL_POLICIES: <no description>
      NET_LB_SECURITY_POLICIES_PER_REGION: <no description>
      NET_LB_SECURITY_POLICY_RULES_PER_REGION: <no description>
      NET_LB_SECURITY_POLICY_RULE_ATTRIBUTES_PER_REGION: <no description>
      NODE_GROUPS: <no description>
      NODE_TEMPLATES: <no description>
      NVIDIA_A100_80GB_GPUS: <no description>
      NVIDIA_A100_GPUS: <no description>
      NVIDIA_K80_GPUS: <no description>
      NVIDIA_L4_GPUS: <no description>
      NVIDIA_P100_GPUS: <no description>
      NVIDIA_P100_VWS_GPUS: <no description>
      NVIDIA_P4_GPUS: <no description>
      NVIDIA_P4_VWS_GPUS: <no description>
      NVIDIA_T4_GPUS: <no description>
      NVIDIA_T4_VWS_GPUS: <no description>
      NVIDIA_V100_GPUS: <no description>
      PACKET_MIRRORINGS: <no description>
      PD_EXTREME_TOTAL_PROVISIONED_IOPS: <no description>
      PREEMPTIBLE_CPUS: <no description>
      PREEMPTIBLE_LOCAL_SSD_GB: <no description>
      PREEMPTIBLE_NVIDIA_A100_80GB_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_A100_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_H100_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_K80_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_L4_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_P100_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_P100_VWS_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_P4_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_P4_VWS_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_T4_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_T4_VWS_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_V100_GPUS: <no description>
      PREEMPTIBLE_TPU_LITE_DEVICE_V4: <no description>
      PREEMPTIBLE_TPU_LITE_DEVICE_V5: <no description>
      PREEMPTIBLE_TPU_LITE_PODSLICE_V5: <no description>
      PREEMPTIBLE_TPU_PODSLICE_V4: <no description>
      PRIVATE_V6_ACCESS_SUBNETWORKS: <no description>
      PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK: <no description>
      PSC_INTERNAL_LB_FORWARDING_RULES: <no description>
      PUBLIC_ADVERTISED_PREFIXES: <no description>
      PUBLIC_DELEGATED_PREFIXES: <no description>
      QUEUED_RESOURCES: <no description>
      REGIONAL_AUTOSCALERS: <no description>
      REGIONAL_EXTERNAL_MANAGED_BACKEND_SERVICES: <no description>
      REGIONAL_EXTERNAL_NETWORK_LB_BACKEND_SERVICES: <no description>
      REGIONAL_INSTANCE_GROUP_MANAGERS: <no description>
      REGIONAL_INTERNAL_LB_BACKEND_SERVICES: <no description>
      REGIONAL_INTERNAL_MANAGED_BACKEND_SERVICES: <no description>
      REGIONAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES: <no description>
      RESERVATIONS: <no description>
      RESOURCE_POLICIES: <no description>
      ROUTERS: <no description>
      ROUTES: <no description>
      SECURITY_POLICIES: <no description>
      SECURITY_POLICIES_PER_REGION: <no description>
      SECURITY_POLICY_ADVANCED_RULES_PER_REGION: <no description>
      SECURITY_POLICY_CEVAL_RULES: <no description>
      SECURITY_POLICY_RULES: <no description>
      SECURITY_POLICY_RULES_PER_REGION: <no description>
      SERVICE_ATTACHMENTS: <no description>
      SNAPSHOTS: The total number of snapshots allowed for a single project.
      SSD_TOTAL_GB: <no description>
      SSL_CERTIFICATES: <no description>
      SSL_POLICIES: <no description>
      STATIC_ADDRESSES: <no description>
      STATIC_BYOIP_ADDRESSES: <no description>
      STATIC_EXTERNAL_IPV6_ADDRESS_RANGES: <no description>
      SUBNETWORKS: <no description>
      T2A_CPUS: <no description>
      T2D_CPUS: <no description>
      TARGET_HTTPS_PROXIES: <no description>
      TARGET_HTTP_PROXIES: <no description>
      TARGET_INSTANCES: <no description>
      TARGET_POOLS: <no description>
      TARGET_SSL_PROXIES: <no description>
      TARGET_TCP_PROXIES: <no description>
      TARGET_VPN_GATEWAYS: <no description>
      TPU_LITE_DEVICE_V4: <no description>
      TPU_LITE_DEVICE_V5: <no description>
      TPU_LITE_PODSLICE_V5: <no description>
      TPU_PODSLICE_V4: <no description>
      URL_MAPS: <no description>
      VARIABLE_IPV6_PUBLIC_DELEGATED_PREFIXES: <no description>
      VPN_GATEWAYS: <no description>
      VPN_TUNNELS: <no description>
      XPN_SERVICE_PROJECTS: <no description>
    """
    A2_CPUS = 0
    AFFINITY_GROUPS = 1
    AMD_S9300_GPUS = 2
    AUTOSCALERS = 3
    BACKEND_BUCKETS = 4
    BACKEND_SERVICES = 5
    C2D_CPUS = 6
    C2_CPUS = 7
    C3_CPUS = 8
    COMMITMENTS = 9
    COMMITTED_A2_CPUS = 10
    COMMITTED_C2D_CPUS = 11
    COMMITTED_C2_CPUS = 12
    COMMITTED_C3_CPUS = 13
    COMMITTED_CPUS = 14
    COMMITTED_E2_CPUS = 15
    COMMITTED_LICENSES = 16
    COMMITTED_LOCAL_SSD_TOTAL_GB = 17
    COMMITTED_M3_CPUS = 18
    COMMITTED_MEMORY_OPTIMIZED_CPUS = 19
    COMMITTED_N2A_CPUS = 20
    COMMITTED_N2D_CPUS = 21
    COMMITTED_N2_CPUS = 22
    COMMITTED_NVIDIA_A100_80GB_GPUS = 23
    COMMITTED_NVIDIA_A100_GPUS = 24
    COMMITTED_NVIDIA_H100_GPUS = 25
    COMMITTED_NVIDIA_K80_GPUS = 26
    COMMITTED_NVIDIA_L4_GPUS = 27
    COMMITTED_NVIDIA_P100_GPUS = 28
    COMMITTED_NVIDIA_P4_GPUS = 29
    COMMITTED_NVIDIA_T4_GPUS = 30
    COMMITTED_NVIDIA_V100_GPUS = 31
    COMMITTED_T2A_CPUS = 32
    COMMITTED_T2D_CPUS = 33
    COMMITTED_Z3_CPUS = 34
    CPUS = 35
    CPUS_ALL_REGIONS = 36
    DISKS_TOTAL_GB = 37
    E2_CPUS = 38
    EXTERNAL_MANAGED_FORWARDING_RULES = 39
    EXTERNAL_NETWORK_LB_FORWARDING_RULES = 40
    EXTERNAL_PROTOCOL_FORWARDING_RULES = 41
    EXTERNAL_VPN_GATEWAYS = 42
    FIREWALLS = 43
    FORWARDING_RULES = 44
    GLOBAL_EXTERNAL_MANAGED_BACKEND_SERVICES = 45
    GLOBAL_EXTERNAL_MANAGED_FORWARDING_RULES = 46
    GLOBAL_EXTERNAL_PROXY_LB_BACKEND_SERVICES = 47
    GLOBAL_INTERNAL_ADDRESSES = 48
    GLOBAL_INTERNAL_MANAGED_BACKEND_SERVICES = 49
    GLOBAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES = 50
    GPUS_ALL_REGIONS = 51
    HDB_TOTAL_GB = 52
    HDB_TOTAL_IOPS = 53
    HDB_TOTAL_THROUGHPUT = 54
    HEALTH_CHECKS = 55
    IMAGES = 56
    INSTANCES = 57
    INSTANCE_GROUPS = 58
    INSTANCE_GROUP_MANAGERS = 59
    INSTANCE_TEMPLATES = 60
    INTERCONNECTS = 61
    INTERCONNECT_ATTACHMENTS_PER_REGION = 62
    INTERCONNECT_ATTACHMENTS_TOTAL_MBPS = 63
    INTERCONNECT_TOTAL_GBPS = 64
    INTERNAL_ADDRESSES = 65
    INTERNAL_TRAFFIC_DIRECTOR_FORWARDING_RULES = 66
    IN_PLACE_SNAPSHOTS = 67
    IN_USE_ADDRESSES = 68
    IN_USE_BACKUP_SCHEDULES = 69
    IN_USE_MAINTENANCE_WINDOWS = 70
    IN_USE_SNAPSHOT_SCHEDULES = 71
    LOCAL_SSD_TOTAL_GB = 72
    M1_CPUS = 73
    M2_CPUS = 74
    M3_CPUS = 75
    MACHINE_IMAGES = 76
    N2A_CPUS = 77
    N2D_CPUS = 78
    N2_CPUS = 79
    NETWORKS = 80
    NETWORK_ATTACHMENTS = 81
    NETWORK_ENDPOINT_GROUPS = 82
    NETWORK_FIREWALL_POLICIES = 83
    NET_LB_SECURITY_POLICIES_PER_REGION = 84
    NET_LB_SECURITY_POLICY_RULES_PER_REGION = 85
    NET_LB_SECURITY_POLICY_RULE_ATTRIBUTES_PER_REGION = 86
    NODE_GROUPS = 87
    NODE_TEMPLATES = 88
    NVIDIA_A100_80GB_GPUS = 89
    NVIDIA_A100_GPUS = 90
    NVIDIA_K80_GPUS = 91
    NVIDIA_L4_GPUS = 92
    NVIDIA_P100_GPUS = 93
    NVIDIA_P100_VWS_GPUS = 94
    NVIDIA_P4_GPUS = 95
    NVIDIA_P4_VWS_GPUS = 96
    NVIDIA_T4_GPUS = 97
    NVIDIA_T4_VWS_GPUS = 98
    NVIDIA_V100_GPUS = 99
    PACKET_MIRRORINGS = 100
    PD_EXTREME_TOTAL_PROVISIONED_IOPS = 101
    PREEMPTIBLE_CPUS = 102
    PREEMPTIBLE_LOCAL_SSD_GB = 103
    PREEMPTIBLE_NVIDIA_A100_80GB_GPUS = 104
    PREEMPTIBLE_NVIDIA_A100_GPUS = 105
    PREEMPTIBLE_NVIDIA_H100_GPUS = 106
    PREEMPTIBLE_NVIDIA_K80_GPUS = 107
    PREEMPTIBLE_NVIDIA_L4_GPUS = 108
    PREEMPTIBLE_NVIDIA_P100_GPUS = 109
    PREEMPTIBLE_NVIDIA_P100_VWS_GPUS = 110
    PREEMPTIBLE_NVIDIA_P4_GPUS = 111
    PREEMPTIBLE_NVIDIA_P4_VWS_GPUS = 112
    PREEMPTIBLE_NVIDIA_T4_GPUS = 113
    PREEMPTIBLE_NVIDIA_T4_VWS_GPUS = 114
    PREEMPTIBLE_NVIDIA_V100_GPUS = 115
    PREEMPTIBLE_TPU_LITE_DEVICE_V4 = 116
    PREEMPTIBLE_TPU_LITE_DEVICE_V5 = 117
    PREEMPTIBLE_TPU_LITE_PODSLICE_V5 = 118
    PREEMPTIBLE_TPU_PODSLICE_V4 = 119
    PRIVATE_V6_ACCESS_SUBNETWORKS = 120
    PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK = 121
    PSC_INTERNAL_LB_FORWARDING_RULES = 122
    PUBLIC_ADVERTISED_PREFIXES = 123
    PUBLIC_DELEGATED_PREFIXES = 124
    QUEUED_RESOURCES = 125
    REGIONAL_AUTOSCALERS = 126
    REGIONAL_EXTERNAL_MANAGED_BACKEND_SERVICES = 127
    REGIONAL_EXTERNAL_NETWORK_LB_BACKEND_SERVICES = 128
    REGIONAL_INSTANCE_GROUP_MANAGERS = 129
    REGIONAL_INTERNAL_LB_BACKEND_SERVICES = 130
    REGIONAL_INTERNAL_MANAGED_BACKEND_SERVICES = 131
    REGIONAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES = 132
    RESERVATIONS = 133
    RESOURCE_POLICIES = 134
    ROUTERS = 135
    ROUTES = 136
    SECURITY_POLICIES = 137
    SECURITY_POLICIES_PER_REGION = 138
    SECURITY_POLICY_ADVANCED_RULES_PER_REGION = 139
    SECURITY_POLICY_CEVAL_RULES = 140
    SECURITY_POLICY_RULES = 141
    SECURITY_POLICY_RULES_PER_REGION = 142
    SERVICE_ATTACHMENTS = 143
    SNAPSHOTS = 144
    SSD_TOTAL_GB = 145
    SSL_CERTIFICATES = 146
    SSL_POLICIES = 147
    STATIC_ADDRESSES = 148
    STATIC_BYOIP_ADDRESSES = 149
    STATIC_EXTERNAL_IPV6_ADDRESS_RANGES = 150
    SUBNETWORKS = 151
    T2A_CPUS = 152
    T2D_CPUS = 153
    TARGET_HTTPS_PROXIES = 154
    TARGET_HTTP_PROXIES = 155
    TARGET_INSTANCES = 156
    TARGET_POOLS = 157
    TARGET_SSL_PROXIES = 158
    TARGET_TCP_PROXIES = 159
    TARGET_VPN_GATEWAYS = 160
    TPU_LITE_DEVICE_V4 = 161
    TPU_LITE_DEVICE_V5 = 162
    TPU_LITE_PODSLICE_V5 = 163
    TPU_PODSLICE_V4 = 164
    URL_MAPS = 165
    VARIABLE_IPV6_PUBLIC_DELEGATED_PREFIXES = 166
    VPN_GATEWAYS = 167
    VPN_TUNNELS = 168
    XPN_SERVICE_PROJECTS = 169

  limit = _messages.FloatField(1)
  metric = _messages.EnumField('MetricValueValuesEnum', 2)
  owner = _messages.StringField(3)
  usage = _messages.FloatField(4)


class QuotaExceededInfo(_messages.Message):
  r"""Additional details for quota exceeded error for resource quota.

  Enums:
    RolloutStatusValueValuesEnum: Rollout status of the future quota limit.

  Messages:
    DimensionsValue: The map holding related quota dimensions.

  Fields:
    dimensions: The map holding related quota dimensions.
    futureLimit: Future quota limit being rolled out. The limit's unit depends
      on the quota type or metric.
    limit: Current effective quota limit. The limit's unit depends on the
      quota type or metric.
    limitName: The name of the quota limit.
    metricName: The Compute Engine quota metric name.
    rolloutStatus: Rollout status of the future quota limit.
  """

  class RolloutStatusValueValuesEnum(_messages.Enum):
    r"""Rollout status of the future quota limit.

    Values:
      IN_PROGRESS: IN_PROGRESS - A rollout is in process which will change the
        limit value to future limit.
      ROLLOUT_STATUS_UNSPECIFIED: ROLLOUT_STATUS_UNSPECIFIED - Rollout status
        is not specified. The default value.
    """
    IN_PROGRESS = 0
    ROLLOUT_STATUS_UNSPECIFIED = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DimensionsValue(_messages.Message):
    r"""The map holding related quota dimensions.

    Messages:
      AdditionalProperty: An additional property for a DimensionsValue object.

    Fields:
      additionalProperties: Additional properties of type DimensionsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DimensionsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  dimensions = _messages.MessageField('DimensionsValue', 1)
  futureLimit = _messages.FloatField(2)
  limit = _messages.FloatField(3)
  limitName = _messages.StringField(4)
  metricName = _messages.StringField(5)
  rolloutStatus = _messages.EnumField('RolloutStatusValueValuesEnum', 6)


class RbacPolicy(_messages.Message):
  r"""A RbacPolicy object.

  Fields:
    name: Name of the RbacPolicy.
    permissions: The list of permissions.
    principals: The list of principals.
  """

  name = _messages.StringField(1)
  permissions = _messages.MessageField('Permission', 2, repeated=True)
  principals = _messages.MessageField('Principal', 3, repeated=True)


class Reference(_messages.Message):
  r"""Represents a reference to a resource.

  Fields:
    kind: [Output Only] Type of the resource. Always compute#reference for
      references.
    referenceType: A description of the reference type with no implied
      semantics. Possible values include: 1. MEMBER_OF
    referrer: URL of the resource which refers to the target.
    target: URL of the resource to which this reference points.
  """

  kind = _messages.StringField(1, default='compute#reference')
  referenceType = _messages.StringField(2)
  referrer = _messages.StringField(3)
  target = _messages.StringField(4)


class Region(_messages.Message):
  r"""Represents a Region resource. A region is a geographical area where a
  resource is located. For more information, read Regions and Zones.

  Enums:
    StatusValueValuesEnum: [Output Only] Status of the region, either UP or
      DOWN.

  Messages:
    QuotaStatusWarningValue: [Output Only] Warning of fetching the `quotas`
      field for this region. This field is populated only if fetching of the
      `quotas` field fails.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      region.
    description: [Output Only] Textual description of the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#region for
      regions.
    name: [Output Only] Name of the resource.
    quotaStatusWarning: [Output Only] Warning of fetching the `quotas` field
      for this region. This field is populated only if fetching of the
      `quotas` field fails.
    quotas: [Output Only] Quotas assigned to this region.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] Status of the region, either UP or DOWN.
    supportsPzs: [Output Only] Reserved for future use.
    zones: [Output Only] A list of zones available in this region, in the form
      of resource URLs.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] Status of the region, either UP or DOWN.

    Values:
      DOWN: <no description>
      UP: <no description>
    """
    DOWN = 0
    UP = 1

  class QuotaStatusWarningValue(_messages.Message):
    r"""[Output Only] Warning of fetching the `quotas` field for this region.
    This field is populated only if fetching of the `quotas` field fails.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  creationTimestamp = _messages.StringField(1)
  deprecated = _messages.MessageField('DeprecationStatus', 2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#region')
  name = _messages.StringField(6)
  quotaStatusWarning = _messages.MessageField('QuotaStatusWarningValue', 7)
  quotas = _messages.MessageField('Quota', 8, repeated=True)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)
  status = _messages.EnumField('StatusValueValuesEnum', 11)
  supportsPzs = _messages.BooleanField(12)
  zones = _messages.StringField(13, repeated=True)


class RegionAddressesMoveRequest(_messages.Message):
  r"""A RegionAddressesMoveRequest object.

  Fields:
    description: An optional destination address description if intended to be
      different from the source.
    destinationAddress: The URL of the destination address to move to. This
      can be a full or partial URL. For example, the following are all valid
      URLs to a address: -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /addresses/address - projects/project/regions/region/addresses/address
      Note that destination project must be different from the source project.
      So /regions/region/addresses/address is not valid partial url.
  """

  description = _messages.StringField(1)
  destinationAddress = _messages.StringField(2)


class RegionAutoscalerList(_messages.Message):
  r"""Contains a list of autoscalers.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Autoscaler resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Autoscaler', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#regionAutoscalerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionCommitmentsUpdateReservationsRequest(_messages.Message):
  r"""A RegionCommitmentsUpdateReservationsRequest object.

  Fields:
    reservations: A list of two reservations to transfer GPUs and Local SSD
      disks between.
  """

  reservations = _messages.MessageField('Reservation', 1, repeated=True)


class RegionDiskTypeList(_messages.Message):
  r"""A RegionDiskTypeList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of DiskType resources.
    kind: [Output Only] Type of resource. Always compute#regionDiskTypeList
      for region disk types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('DiskType', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#regionDiskTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionDisksAddResourcePoliciesRequest(_messages.Message):
  r"""A RegionDisksAddResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be added to this disk.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class RegionDisksRemoveResourcePoliciesRequest(_messages.Message):
  r"""A RegionDisksRemoveResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be removed from this disk.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class RegionDisksResizeRequest(_messages.Message):
  r"""A RegionDisksResizeRequest object.

  Fields:
    sizeGb: The new size of the regional persistent disk, which is specified
      in GB.
  """

  sizeGb = _messages.IntegerField(1)


class RegionDisksStartAsyncReplicationRequest(_messages.Message):
  r"""A RegionDisksStartAsyncReplicationRequest object.

  Fields:
    asyncSecondaryDisk: The secondary disk to start asynchronous replication
      to. You can provide this as a partial or full URL to the resource. For
      example, the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /disks/disk -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /disks/disk - projects/project/zones/zone/disks/disk -
      projects/project/regions/region/disks/disk - zones/zone/disks/disk -
      regions/region/disks/disk
  """

  asyncSecondaryDisk = _messages.StringField(1)


class RegionInstanceGroupList(_messages.Message):
  r"""Contains a list of InstanceGroup resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroup resources.
    kind: The resource type.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroup', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#regionInstanceGroupList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionInstanceGroupManagerDeleteInstanceConfigReq(_messages.Message):
  r"""RegionInstanceGroupManagers.deletePerInstanceConfigs

  Fields:
    names: The list of instance names for which we want to delete per-instance
      configs on this managed instance group.
  """

  names = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagerList(_messages.Message):
  r"""Contains a list of managed instance groups.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroupManager resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManagerList for a list of managed instance groups
      that exist in th regional scope.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroupManager', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#regionInstanceGroupManagerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionInstanceGroupManagerPatchInstanceConfigReq(_messages.Message):
  r"""RegionInstanceGroupManagers.patchPerInstanceConfigs

  Fields:
    perInstanceConfigs: The list of per-instance configurations to insert or
      patch on this managed instance group.
  """

  perInstanceConfigs = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class RegionInstanceGroupManagerResizeRequestsListResponse(_messages.Message):
  r"""A RegionInstanceGroupManagerResizeRequestsListResponse object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Resize Request resources.
    kind: [Output Only] Type of the resource. Always
      compute#regionInstanceGroupManagerResizeRequestList for a list of Resize
      Requests.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('InstanceGroupManagerResizeRequest', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#regionInstanceGroupManagerResizeRequestList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class RegionInstanceGroupManagerUpdateInstanceConfigReq(_messages.Message):
  r"""RegionInstanceGroupManagers.updatePerInstanceConfigs

  Fields:
    perInstanceConfigs: The list of per-instance configurations to insert or
      patch on this managed instance group.
  """

  perInstanceConfigs = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class RegionInstanceGroupManagersAbandonInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersAbandonInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to abandon. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagersApplyUpdatesRequest(_messages.Message):
  r"""RegionInstanceGroupManagers.applyUpdatesToInstances

  Enums:
    MaximalActionValueValuesEnum: The maximal action that should be performed
      on the instances. By default REPLACE. This field is deprecated, please
      use most_disruptive_allowed_action.
    MinimalActionValueValuesEnum: The minimal action that you want to perform
      on each instance during the update: - REPLACE: At minimum, delete the
      instance and create it again. - RESTART: Stop the instance and start it
      again. - REFRESH: Do not stop the instance and limit disruption as much
      as possible. - NONE: Do not disrupt the instance at all. By default, the
      minimum action is NONE. If your update requires a more disruptive action
      than you set with this flag, the necessary action is performed to
      execute the update.
    MostDisruptiveAllowedActionValueValuesEnum: The most disruptive action
      that you want to perform on each instance during the update: - REPLACE:
      Delete the instance and create it again. - RESTART: Stop the instance
      and start it again. - REFRESH: Do not stop the instance and limit
      disruption as much as possible. - NONE: Do not disrupt the instance at
      all. By default, the most disruptive allowed action is REPLACE. If your
      update requires a more disruptive action than you set with this flag,
      the update request will fail.

  Fields:
    allInstances: Flag to update all instances instead of specified list of
      "instances". If the flag is set to true then the instances may not be
      specified in the request.
    instances: The list of URLs of one or more instances for which you want to
      apply updates. Each URL can be a full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
    maximalAction: The maximal action that should be performed on the
      instances. By default REPLACE. This field is deprecated, please use
      most_disruptive_allowed_action.
    minimalAction: The minimal action that you want to perform on each
      instance during the update: - REPLACE: At minimum, delete the instance
      and create it again. - RESTART: Stop the instance and start it again. -
      REFRESH: Do not stop the instance and limit disruption as much as
      possible. - NONE: Do not disrupt the instance at all. By default, the
      minimum action is NONE. If your update requires a more disruptive action
      than you set with this flag, the necessary action is performed to
      execute the update.
    mostDisruptiveAllowedAction: The most disruptive action that you want to
      perform on each instance during the update: - REPLACE: Delete the
      instance and create it again. - RESTART: Stop the instance and start it
      again. - REFRESH: Do not stop the instance and limit disruption as much
      as possible. - NONE: Do not disrupt the instance at all. By default, the
      most disruptive allowed action is REPLACE. If your update requires a
      more disruptive action than you set with this flag, the update request
      will fail.
  """

  class MaximalActionValueValuesEnum(_messages.Enum):
    r"""The maximal action that should be performed on the instances. By
    default REPLACE. This field is deprecated, please use
    most_disruptive_allowed_action.

    Values:
      NONE: Do not perform any action.
      REFRESH: Do not stop the instance.
      REPLACE: (Default.) Replace the instance according to the replacement
        method option.
      RESTART: Stop the instance and start it again.
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MinimalActionValueValuesEnum(_messages.Enum):
    r"""The minimal action that you want to perform on each instance during
    the update: - REPLACE: At minimum, delete the instance and create it
    again. - RESTART: Stop the instance and start it again. - REFRESH: Do not
    stop the instance and limit disruption as much as possible. - NONE: Do not
    disrupt the instance at all. By default, the minimum action is NONE. If
    your update requires a more disruptive action than you set with this flag,
    the necessary action is performed to execute the update.

    Values:
      NONE: Do not perform any action.
      REFRESH: Do not stop the instance.
      REPLACE: (Default.) Replace the instance according to the replacement
        method option.
      RESTART: Stop the instance and start it again.
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MostDisruptiveAllowedActionValueValuesEnum(_messages.Enum):
    r"""The most disruptive action that you want to perform on each instance
    during the update: - REPLACE: Delete the instance and create it again. -
    RESTART: Stop the instance and start it again. - REFRESH: Do not stop the
    instance and limit disruption as much as possible. - NONE: Do not disrupt
    the instance at all. By default, the most disruptive allowed action is
    REPLACE. If your update requires a more disruptive action than you set
    with this flag, the update request will fail.

    Values:
      NONE: Do not perform any action.
      REFRESH: Do not stop the instance.
      REPLACE: (Default.) Replace the instance according to the replacement
        method option.
      RESTART: Stop the instance and start it again.
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  allInstances = _messages.BooleanField(1)
  instances = _messages.StringField(2, repeated=True)
  maximalAction = _messages.EnumField('MaximalActionValueValuesEnum', 3)
  minimalAction = _messages.EnumField('MinimalActionValueValuesEnum', 4)
  mostDisruptiveAllowedAction = _messages.EnumField('MostDisruptiveAllowedActionValueValuesEnum', 5)


class RegionInstanceGroupManagersCreateInstancesRequest(_messages.Message):
  r"""RegionInstanceGroupManagers.createInstances

  Fields:
    instances: [Required] List of specifications of per-instance configs.
  """

  instances = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class RegionInstanceGroupManagersDeleteInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersDeleteInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to delete. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
    skipInstancesOnValidationError: Specifies whether the request should
      proceed despite the inclusion of instances that are not members of the
      group or that are already in the process of being deleted or abandoned.
      If this field is set to `false` and such an instance is specified in the
      request, the operation fails. The operation always fails if the request
      contains a malformed instance URL or a reference to an instance that
      exists in a zone or region other than the group's zone or region.
  """

  instances = _messages.StringField(1, repeated=True)
  skipInstancesOnValidationError = _messages.BooleanField(2)


class RegionInstanceGroupManagersListErrorsResponse(_messages.Message):
  r"""A RegionInstanceGroupManagersListErrorsResponse object.

  Fields:
    items: [Output Only] The list of errors of the managed instance group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
  """

  items = _messages.MessageField('InstanceManagedByIgmError', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class RegionInstanceGroupManagersListInstanceConfigsResp(_messages.Message):
  r"""A RegionInstanceGroupManagersListInstanceConfigsResp object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    items: [Output Only] The list of PerInstanceConfig.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  items = _messages.MessageField('PerInstanceConfig', 1, repeated=True)
  nextPageToken = _messages.StringField(2)
  warning = _messages.MessageField('WarningValue', 3)


class RegionInstanceGroupManagersListInstancesResponse(_messages.Message):
  r"""A RegionInstanceGroupManagersListInstancesResponse object.

  Fields:
    managedInstances: A list of managed instances.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
  """

  managedInstances = _messages.MessageField('ManagedInstance', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class RegionInstanceGroupManagersRecreateRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersRecreateRequest object.

  Fields:
    instances: The URLs of one or more instances to recreate. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagersResizeAdvancedRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersResizeAdvancedRequest object.

  Fields:
    noCreationRetries: If this flag is true, the managed instance group
      attempts to create all instances initiated by this resize request only
      once. If there is an error during creation, the managed instance group
      does not retry create this instance, and we will decrease the targetSize
      of the request instead. If the flag is false, the group attempts to
      recreate each instance continuously until it succeeds. This flag matters
      only in the first attempt of creation of an instance. After an instance
      is successfully created while this flag is enabled, the instance behaves
      the same way as all the other instances created with a regular resize
      request. In particular, if a running instance dies unexpectedly at a
      later time and needs to be recreated, this mode does not affect the
      recreation behavior in that scenario. This flag is applicable only to
      the current resize request. It does not influence other resize requests
      in any way. You can see which instances ar being created in which mode
      by calling the get or listManagedInstances API.
    targetSize: The number of running instances that the managed instance
      group should maintain at any given time. The group automatically adds or
      removes instances to maintain the number of instances specified by this
      parameter.
  """

  noCreationRetries = _messages.BooleanField(1)
  targetSize = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class RegionInstanceGroupManagersResumeInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersResumeInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to resume. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagersSetAutoHealingRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersSetAutoHealingRequest object.

  Fields:
    autoHealingPolicies: A InstanceGroupManagerAutoHealingPolicy attribute.
  """

  autoHealingPolicies = _messages.MessageField('InstanceGroupManagerAutoHealingPolicy', 1, repeated=True)


class RegionInstanceGroupManagersSetTargetPoolsRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersSetTargetPoolsRequest object.

  Fields:
    fingerprint: Fingerprint of the target pools information, which is a hash
      of the contents. This field is used for optimistic locking when you
      update the target pool entries. This field is optional.
    targetPools: The URL of all TargetPool resources to which instances in the
      instanceGroup field are added. The target pools automatically apply to
      all of the instances in the managed instance group.
  """

  fingerprint = _messages.BytesField(1)
  targetPools = _messages.StringField(2, repeated=True)


class RegionInstanceGroupManagersSetTemplateRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersSetTemplateRequest object.

  Fields:
    instanceTemplate: URL of the InstanceTemplate resource from which all new
      instances will be created.
  """

  instanceTemplate = _messages.StringField(1)


class RegionInstanceGroupManagersStartInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersStartInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to start. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagersStopInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersStopInstancesRequest object.

  Fields:
    forceStop: If this flag is set to true, the Instance Group Manager will
      proceed to stop the instances, skipping initialization on them.
    instances: The URLs of one or more instances to stop. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  forceStop = _messages.BooleanField(1)
  instances = _messages.StringField(2, repeated=True)


class RegionInstanceGroupManagersSuspendInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersSuspendInstancesRequest object.

  Fields:
    forceSuspend: If this flag is set to true, the Instance Group Manager will
      proceed to suspend the instances, skipping initialization on them.
    instances: The URLs of one or more instances to suspend. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  forceSuspend = _messages.BooleanField(1)
  instances = _messages.StringField(2, repeated=True)


class RegionInstanceGroupsListInstances(_messages.Message):
  r"""A RegionInstanceGroupsListInstances object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceWithNamedPorts resources.
    kind: The resource type.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceWithNamedPorts', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#regionInstanceGroupsListInstances')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionInstanceGroupsListInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupsListInstancesRequest object.

  Enums:
    InstanceStateValueValuesEnum: Instances in which state should be returned.
      Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances.

  Fields:
    instanceState: Instances in which state should be returned. Valid options
      are: 'ALL', 'RUNNING'. By default, it lists all instances.
    portName: Name of port user is interested in. It is optional. If it is
      set, only information about this ports will be returned. If it is not
      set, all the named ports will be returned. Always lists all instances.
  """

  class InstanceStateValueValuesEnum(_messages.Enum):
    r"""Instances in which state should be returned. Valid options are: 'ALL',
    'RUNNING'. By default, it lists all instances.

    Values:
      ALL: Matches any status of the instances, running, non-running and
        others.
      RUNNING: Instance is in RUNNING state if it is running.
    """
    ALL = 0
    RUNNING = 1

  instanceState = _messages.EnumField('InstanceStateValueValuesEnum', 1)
  portName = _messages.StringField(2)


class RegionInstanceGroupsSetNamedPortsRequest(_messages.Message):
  r"""A RegionInstanceGroupsSetNamedPortsRequest object.

  Fields:
    fingerprint: The fingerprint of the named ports information for this
      instance group. Use this optional property to prevent conflicts when
      multiple users change the named ports settings concurrently. Obtain the
      fingerprint with the instanceGroups.get method. Then, include the
      fingerprint in your request to ensure that you do not overwrite changes
      that were applied from another concurrent request.
    namedPorts: The list of named ports to set for this instance group.
  """

  fingerprint = _messages.BytesField(1)
  namedPorts = _messages.MessageField('NamedPort', 2, repeated=True)


class RegionList(_messages.Message):
  r"""Contains a list of region resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Region resources.
    kind: [Output Only] Type of resource. Always compute#regionList for lists
      of regions.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Region', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#regionList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionNetworkEndpointGroupsAttachEndpointsRequest(_messages.Message):
  r"""A RegionNetworkEndpointGroupsAttachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be attached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class RegionNetworkEndpointGroupsDetachEndpointsRequest(_messages.Message):
  r"""A RegionNetworkEndpointGroupsDetachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be detached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse(_messages.Message):
  r"""A RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse object.

  Fields:
    firewallPolicys: [Output only] Effective firewalls from firewall policy.
      It applies to Regional Network Firewall Policies in the specified
      region, Global Network Firewall Policies and Hierachial Firewall
      Policies which are associated with the network.
    firewalls: Effective firewalls on the network.
  """

  firewallPolicys = _messages.MessageField('RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy', 1, repeated=True)
  firewalls = _messages.MessageField('Firewall', 2, repeated=True)


class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy(_messages.Message):
  r"""A RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFir
  ewallPolicy object.

  Enums:
    TypeValueValuesEnum: [Output Only] The type of the firewall policy. Can be
      one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL,
      SYSTEM_REGIONAL.

  Fields:
    displayName: [Output Only] The display name of the firewall policy.
    name: [Output Only] The name of the firewall policy.
    packetMirroringRules: [Output only] The packet mirroring rules that apply
      to the network.
    priority: [Output only] Priority of firewall policy association. Not
      applicable for type=HIERARCHY.
    rules: [Output only] The rules that apply to the network.
    type: [Output Only] The type of the firewall policy. Can be one of
      HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The type of the firewall policy. Can be one of
    HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.

    Values:
      HIERARCHY: <no description>
      NETWORK: <no description>
      NETWORK_REGIONAL: <no description>
      SYSTEM_GLOBAL: <no description>
      SYSTEM_REGIONAL: <no description>
      UNSPECIFIED: <no description>
    """
    HIERARCHY = 0
    NETWORK = 1
    NETWORK_REGIONAL = 2
    SYSTEM_GLOBAL = 3
    SYSTEM_REGIONAL = 4
    UNSPECIFIED = 5

  displayName = _messages.StringField(1)
  name = _messages.StringField(2)
  packetMirroringRules = _messages.MessageField('FirewallPolicyRule', 3, repeated=True)
  priority = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  rules = _messages.MessageField('FirewallPolicyRule', 5, repeated=True)
  type = _messages.EnumField('TypeValueValuesEnum', 6)


class RegionSetLabelsRequest(_messages.Message):
  r"""A RegionSetLabelsRequest object.

  Messages:
    LabelsValue: The labels to set for this resource.

  Fields:
    labelFingerprint: The fingerprint of the previous set of labels for this
      resource, used to detect conflicts. The fingerprint is initially
      generated by Compute Engine and changes after every request to modify or
      update labels. You must always provide an up-to-date fingerprint hash in
      order to update or change labels. Make a get() request to the resource
      to get the latest fingerprint.
    labels: The labels to set for this resource.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""The labels to set for this resource.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class RegionSetPolicyRequest(_messages.Message):
  r"""A RegionSetPolicyRequest object.

  Fields:
    bindings: Flatten Policy to create a backwacd compatible wire-format.
      Deprecated. Use 'policy' to specify bindings.
    etag: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify the etag.
    policy: REQUIRED: The complete policy to be applied to the 'resource'. The
      size of the policy is limited to a few 10s of KB. An empty policy is in
      general a valid policy but certain services (like Projects) might reject
      them.
  """

  bindings = _messages.MessageField('Binding', 1, repeated=True)
  etag = _messages.BytesField(2)
  policy = _messages.MessageField('Policy', 3)


class RegionTargetHttpsProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A RegionTargetHttpsProxiesSetSslCertificatesRequest object.

  Fields:
    sslCertificates: New set of SslCertificate resources to associate with
      this TargetHttpsProxy resource.
  """

  sslCertificates = _messages.StringField(1, repeated=True)


class RegionUrlMapsValidateRequest(_messages.Message):
  r"""A RegionUrlMapsValidateRequest object.

  Fields:
    resource: Content of the UrlMap to be validated.
  """

  resource = _messages.MessageField('UrlMap', 1)


class RegionWaitForReplicationCatchUpRequest(_messages.Message):
  r"""A RegionWaitForReplicationCatchUpRequest object.

  Fields:
    maxWaitDuration: A string attribute.
  """

  maxWaitDuration = _messages.StringField(1)


class ReliabilityRisk(_messages.Message):
  r"""Represents a ReliabilityRisk resource.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional textual description of the resource; provided
      when the resource is created.
    details: [Output Only] Details of the reliability risk resource
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#reliabilityRisk for
      reliability risks.
    name: Name of the resource. The name must be 1-63 characters long and
      comply with RFC1035.
    recommendation: The recommendations to mitigate the risk.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  details = _messages.MessageField('RiskDetails', 3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#reliabilityRisk')
  name = _messages.StringField(6)
  recommendation = _messages.MessageField('RiskRecommendation', 7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)


class ReliabilityRisksListResponse(_messages.Message):
  r"""A ReliabilityRisksListResponse object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ReliabilityRisk resources.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ReliabilityRisk', 3, repeated=True)
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class ReplicationDetails(_messages.Message):
  r"""A ReplicationDetails object.

  Fields:
    lastReplicationTime: The last sync time of the device pair.
    secondsSinceLastReplication: Replication lag in seconds. This will only be
      populated if device is in replicating state. Note that the value is
      calculated sometime during request processing and at the instant the
      client receives the response, the current replication_lag may have
      changed.
  """

  lastReplicationTime = _messages.StringField(1)
  secondsSinceLastReplication = _messages.IntegerField(2)


class ReplicationDiskPair(_messages.Message):
  r"""A ReplicationDiskPair object.

  Fields:
    primaryDisk: URL of the primary disk.
    secondaryDisk: URL of the secondary disk.
  """

  primaryDisk = _messages.StringField(1)
  secondaryDisk = _messages.StringField(2)


class RequestMirrorPolicy(_messages.Message):
  r"""A policy that specifies how requests intended for the route's backends
  are shadowed to a separate mirrored backend service. The load balancer
  doesn't wait for responses from the shadow service. Before sending traffic
  to the shadow service, the host or authority header is suffixed with
  -shadow.

  Fields:
    backendService: The full or partial URL to the BackendService resource
      being mirrored to. The backend service configured for a mirroring policy
      must reference backends that are of the same type as the original
      backend service matched in the URL map. Serverless NEG backends are not
      currently supported as a mirrored backend service.
    mirrorPercent: The percentage of requests to be mirrored to
      `backend_service`.
  """

  backendService = _messages.StringField(1)
  mirrorPercent = _messages.FloatField(2)


class Reservation(_messages.Message):
  r"""Represents a reservation resource. A reservation ensures that capacity
  is held in a specific zone even if the reserved VMs are not running. For
  more information, read Reserving zonal resources.

  Enums:
    DeploymentTypeValueValuesEnum: Specifies the deployment strategy for this
      reservation.
    ReservationModeValueValuesEnum: [Output only] Indicates the reservation
      mode of the reservation.
    StatusValueValuesEnum: [Output Only] The status of the reservation. -
      CREATING: Reservation resources are being allocated. - READY:
      Reservation resources have been allocated, and the reservation is ready
      for use. - DELETING: Reservation deletion is in progress. - UPDATING:
      Reservation update is in progress.

  Messages:
    ResourcePoliciesValue: Resource policies to be added to this reservation.
      The key is defined by user, and the value is resource policy url. This
      is to define placement policy with reservation.

  Fields:
    aggregateReservation: Reservation for aggregated resources, providing
      shape flexibility.
    commitment: [Output Only] Full or partial URL to a parent commitment. This
      field displays for reservations that are tied to a commitment.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deleteAfterDuration: Duration time relative to reservation creation when
      Compute Engine will automatically delete this resource.
    deleteAtTime: Absolute time in future when the reservation will be auto-
      deleted by Compute Engine. Timestamp is represented in RFC3339 text
      format.
    deploymentType: Specifies the deployment strategy for this reservation.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    enableEmergentMaintenance: Indicates if this group of VMs have emergent
      maintenance enabled.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#reservations for
      reservations.
    linkedCommitments: [Output Only] Full or partial URL to parent
      commitments. This field displays for reservations that are tied to
      multiple commitments.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    reservationMode: [Output only] Indicates the reservation mode of the
      reservation.
    reservationSharingPolicy: Specify the reservation sharing policy. If
      unspecified, the reservation will not be shared with Google Cloud
      managed services.
    resourcePolicies: Resource policies to be added to this reservation. The
      key is defined by user, and the value is resource policy url. This is to
      define placement policy with reservation.
    resourceStatus: [Output Only] Status information for Reservation resource.
    satisfiesPzs: [Output Only] Reserved for future use.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    shareSettings: Specify share-settings to create a shared reservation. This
      property is optional. For more information about the syntax and options
      for this field and its subfields, see the guide for creating a shared
      reservation.
    specificReservation: Reservation for instances with specific machine
      shapes.
    specificReservationRequired: Indicates whether the reservation can be
      consumed by VMs with affinity for "any" reservation. If the field is
      set, then only VMs that target the reservation by name can consume from
      this reservation.
    status: [Output Only] The status of the reservation. - CREATING:
      Reservation resources are being allocated. - READY: Reservation
      resources have been allocated, and the reservation is ready for use. -
      DELETING: Reservation deletion is in progress. - UPDATING: Reservation
      update is in progress.
    zone: Zone in which the reservation resides. A zone must be provided if
      the reservation is created within a commitment.
  """

  class DeploymentTypeValueValuesEnum(_messages.Enum):
    r"""Specifies the deployment strategy for this reservation.

    Values:
      DENSE: The reserved capacity is made up of densely deployed reservation
        blocks.
      DEPLOYMENT_TYPE_UNSPECIFIED: <no description>
      FLEXIBLE: The reserved capacity is made up of highly flexible, logical
        reservation blocks.
    """
    DENSE = 0
    DEPLOYMENT_TYPE_UNSPECIFIED = 1
    FLEXIBLE = 2

  class ReservationModeValueValuesEnum(_messages.Enum):
    r"""[Output only] Indicates the reservation mode of the reservation.

    Values:
      CALENDAR: The delivered reservations terminate at specified endtime
        along with terminating VMs running on it. The price for this
        reservation is different from on-demand. Currently offered for A3+
        GPUs and TPUs only.
      DEFAULT: The delivered reservations do not terminate VMs at the end of
        reservations. On-demand pricing and available for all VM families.
        This is default mode.
      RESERVATION_MODE_UNSPECIFIED: <no description>
    """
    CALENDAR = 0
    DEFAULT = 1
    RESERVATION_MODE_UNSPECIFIED = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the reservation. - CREATING: Reservation
    resources are being allocated. - READY: Reservation resources have been
    allocated, and the reservation is ready for use. - DELETING: Reservation
    deletion is in progress. - UPDATING: Reservation update is in progress.

    Values:
      CREATING: Reservation resources are being allocated.
      DELETING: Reservation deletion is in progress.
      INVALID: <no description>
      READY: Reservation resources have been allocated, and the reservation is
        ready for use.
      UPDATING: Reservation update is in progress.
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3
    UPDATING = 4

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ResourcePoliciesValue(_messages.Message):
    r"""Resource policies to be added to this reservation. The key is defined
    by user, and the value is resource policy url. This is to define placement
    policy with reservation.

    Messages:
      AdditionalProperty: An additional property for a ResourcePoliciesValue
        object.

    Fields:
      additionalProperties: Additional properties of type
        ResourcePoliciesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ResourcePoliciesValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  aggregateReservation = _messages.MessageField('AllocationAggregateReservation', 1)
  commitment = _messages.StringField(2)
  creationTimestamp = _messages.StringField(3)
  deleteAfterDuration = _messages.MessageField('Duration', 4)
  deleteAtTime = _messages.StringField(5)
  deploymentType = _messages.EnumField('DeploymentTypeValueValuesEnum', 6)
  description = _messages.StringField(7)
  enableEmergentMaintenance = _messages.BooleanField(8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(10, default='compute#reservation')
  linkedCommitments = _messages.StringField(11, repeated=True)
  name = _messages.StringField(12)
  reservationMode = _messages.EnumField('ReservationModeValueValuesEnum', 13)
  reservationSharingPolicy = _messages.MessageField('AllocationReservationSharingPolicy', 14)
  resourcePolicies = _messages.MessageField('ResourcePoliciesValue', 15)
  resourceStatus = _messages.MessageField('AllocationResourceStatus', 16)
  satisfiesPzs = _messages.BooleanField(17)
  selfLink = _messages.StringField(18)
  selfLinkWithId = _messages.StringField(19)
  shareSettings = _messages.MessageField('ShareSettings', 20)
  specificReservation = _messages.MessageField('AllocationSpecificSKUReservation', 21)
  specificReservationRequired = _messages.BooleanField(22)
  status = _messages.EnumField('StatusValueValuesEnum', 23)
  zone = _messages.StringField(24)


class ReservationAffinity(_messages.Message):
  r"""Specifies the reservations that this instance can consume from.

  Enums:
    ConsumeReservationTypeValueValuesEnum: Specifies the type of reservation
      from which this instance can consume resources: ANY_RESERVATION
      (default), SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming
      reserved instances for examples.

  Fields:
    consumeReservationType: Specifies the type of reservation from which this
      instance can consume resources: ANY_RESERVATION (default),
      SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved
      instances for examples.
    key: Corresponds to the label key of a reservation resource. To target a
      SPECIFIC_RESERVATION by name, specify googleapis.com/reservation-name as
      the key and specify the name of your reservation as its value.
    values: Corresponds to the label values of a reservation resource. This
      can be either a name to a reservation in the same project or
      "projects/different-project/reservations/some-reservation-name" to
      target a shared reservation in the same zone but in a different project.
  """

  class ConsumeReservationTypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of reservation from which this instance can consume
    resources: ANY_RESERVATION (default), SPECIFIC_RESERVATION, or
    NO_RESERVATION. See Consuming reserved instances for examples.

    Values:
      ANY_RESERVATION: Consume any allocation available.
      NO_RESERVATION: Do not consume from any allocated capacity.
      SPECIFIC_RESERVATION: Must consume from a specific reservation. Must
        specify key value fields for specifying the reservations.
      SPECIFIC_THEN_ANY_RESERVATION: Prefer to consume from a specific
        reservation, but still consume any reservation available if the
        specified reservation is not available or exhausted. Must specify key
        value fields for specifying the reservations.
      SPECIFIC_THEN_NO_RESERVATION: Prefer to consume from a specific
        reservation, but still consume from the on-demand pool if the
        specified reservation is exhausted. Must specify key value fields for
        specifying the reservations.
      UNSPECIFIED: <no description>
    """
    ANY_RESERVATION = 0
    NO_RESERVATION = 1
    SPECIFIC_RESERVATION = 2
    SPECIFIC_THEN_ANY_RESERVATION = 3
    SPECIFIC_THEN_NO_RESERVATION = 4
    UNSPECIFIED = 5

  consumeReservationType = _messages.EnumField('ConsumeReservationTypeValueValuesEnum', 1)
  key = _messages.StringField(2)
  values = _messages.StringField(3, repeated=True)


class ReservationAggregatedList(_messages.Message):
  r"""Contains a list of reservations.

  Messages:
    ItemsValue: A list of Allocation resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Allocation resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of Allocation resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        reservations.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A ReservationsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ReservationsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#reservationAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class ReservationBlock(_messages.Message):
  r"""Represents a reservation block resource.

  Enums:
    StatusValueValuesEnum: [Output Only] Status of the reservation block.

  Fields:
    count: [Output Only] The number of resources that are allocated in this
      reservation block.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    inUseCount: [Output Only] The number of instances that are currently in
      use on this reservation block.
    kind: [Output Only] Type of the resource. Always compute#reservationBlock
      for reservation blocks.
    locationPrefix: [Output Only] Obfuscated location where this reservation
      block physically resides in format /CCCC/GGGG. This matches the tripod
      specified in the VM topology information. Example: /USEAB1/0101/ is the
      location prefix in /USEAB1/0101/031/003
    name: [Output Only] The name of this reservation block generated by Google
      Compute Engine. The name must be 1-63 characters long, and comply with
      RFC1035 @pattern [a-z](?:[-a-z0-9]{0,61}[a-z0-9])?
    physicalTopology: [Output Only] The physical topology of the reservation
      block.
    reservationMaintenance: [Output Only] Maintenance information for this
      reservation block.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] Status of the reservation block.
    zone: [Output Only] Zone in which the reservation block resides.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] Status of the reservation block.

    Values:
      CREATING: Resources are being allocated for the reservation block.
      DELETING: Reservation block is currently being deleted.
      INVALID: <no description>
      READY: Reservation block has allocated all its resources.
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3

  count = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creationTimestamp = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  inUseCount = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  kind = _messages.StringField(5, default='compute#reservationBlock')
  locationPrefix = _messages.StringField(6)
  name = _messages.StringField(7)
  physicalTopology = _messages.MessageField('ReservationBlockPhysicalTopology', 8)
  reservationMaintenance = _messages.MessageField('GroupMaintenanceInfo', 9)
  selfLink = _messages.StringField(10)
  selfLinkWithId = _messages.StringField(11)
  status = _messages.EnumField('StatusValueValuesEnum', 12)
  zone = _messages.StringField(13)


class ReservationBlockPhysicalTopology(_messages.Message):
  r"""A ReservationBlockPhysicalTopology object.

  Fields:
    block: The hash of the capacity block within the cluster.
    cluster: The cluster name of the reservation block.
  """

  block = _messages.StringField(1)
  cluster = _messages.StringField(2)


class ReservationBlocksGetResponse(_messages.Message):
  r"""A ReservationBlocksGetResponse object.

  Fields:
    resource: A ReservationBlock attribute.
  """

  resource = _messages.MessageField('ReservationBlock', 1)


class ReservationBlocksListResponse(_messages.Message):
  r"""A list of reservation blocks under a single reservation.

  Messages:
    WarningValue: Informational warning message.

  Fields:
    id: Unique identifier for the resource; defined by the server.
    items: A list of reservation block resources.
    kind: Type of the resource. Always compute#reservationBlock for a list of
      reservation blocks.
    nextPageToken: This token allows you to get the next page of results for
      list requests. If the number of results is larger than maxResults, use
      the nextPageToken as a value for the query parameter pageToken in the
      next list request. Subsequent list requests will have their own
      nextPageToken to continue paging through the results.
    selfLink: Server-defined URL for this resource.
    warning: Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ReservationBlock', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#reservationBlock')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ReservationList(_messages.Message):
  r"""A ReservationList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A list of Allocation resources.
    kind: [Output Only] Type of resource.Always compute#reservationsList for
      listsof reservations
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Reservation', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#reservationList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ReservationsBlocksPerformMaintenanceRequest(_messages.Message):
  r"""A ReservationsBlocksPerformMaintenanceRequest object.

  Enums:
    MaintenanceScopeValueValuesEnum: Specifies if all, running or unused hosts
      are in scope for this request.

  Fields:
    maintenanceScope: Specifies if all, running or unused hosts are in scope
      for this request.
  """

  class MaintenanceScopeValueValuesEnum(_messages.Enum):
    r"""Specifies if all, running or unused hosts are in scope for this
    request.

    Values:
      ALL: Trigger maintenance for all hosts belonging to this reservation
        irrespective of whether VMs are running on them or not.
      MAINTENANCE_SCOPE_UNSPECIFIED: Internal only
      RUNNING_VMS: Trigger maintenance only on the hosts belonging to this
        reservation which have VMs running on them.
      UNUSED_CAPACITY: Trigger maintenance only on the hosts belonging to this
        reservation which do not have any VMs running on them. This is not
        allowed for Standard ExR
    """
    ALL = 0
    MAINTENANCE_SCOPE_UNSPECIFIED = 1
    RUNNING_VMS = 2
    UNUSED_CAPACITY = 3

  maintenanceScope = _messages.EnumField('MaintenanceScopeValueValuesEnum', 1)


class ReservationsPerformMaintenanceRequest(_messages.Message):
  r"""A ReservationsPerformMaintenanceRequest object.

  Enums:
    MaintenanceScopeValueValuesEnum: Specifies if all, running or unused hosts
      are in scope for this request.

  Fields:
    maintenanceScope: Specifies if all, running or unused hosts are in scope
      for this request.
  """

  class MaintenanceScopeValueValuesEnum(_messages.Enum):
    r"""Specifies if all, running or unused hosts are in scope for this
    request.

    Values:
      ALL: Trigger maintenance for all hosts belonging to this reservation
        irrespective of whether VMs are running on them or not.
      MAINTENANCE_SCOPE_UNSPECIFIED: Internal only
      RUNNING_VMS: Trigger maintenance only on the hosts belonging to this
        reservation which have VMs running on them.
      UNUSED_CAPACITY: Trigger maintenance only on the hosts belonging to this
        reservation which do not have any VMs running on them. This is not
        allowed for Standard ExR
    """
    ALL = 0
    MAINTENANCE_SCOPE_UNSPECIFIED = 1
    RUNNING_VMS = 2
    UNUSED_CAPACITY = 3

  maintenanceScope = _messages.EnumField('MaintenanceScopeValueValuesEnum', 1)


class ReservationsResizeRequest(_messages.Message):
  r"""A ReservationsResizeRequest object.

  Fields:
    specificSkuCount: Number of allocated resources can be resized with
      minimum = 1 and maximum = 1000.
  """

  specificSkuCount = _messages.IntegerField(1)


class ReservationsScopedList(_messages.Message):
  r"""A ReservationsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of
      reservations when the list is empty.

  Fields:
    reservations: A list of reservations contained in this scope.
    warning: Informational warning which replaces the list of reservations
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of reservations when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  reservations = _messages.MessageField('Reservation', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ResourceCommitment(_messages.Message):
  r"""Commitment for a particular hardware resource (a commitment is composed
  of one or more of these).

  Enums:
    TypeValueValuesEnum: The type of hardware resource that you want to
      specify. You can specify any of the following values: - VCPU - MEMORY -
      LOCAL_SSD - ACCELERATOR Specify as a separate entry in the list for each
      individual resource type.

  Fields:
    acceleratorType: Name of the accelerator type or GPU resource. Specify
      this field only when the type of hardware resource is ACCELERATOR.
    amount: The quantity of the hardware resource that you want to commit to
      purchasing (in a type-dependent unit). - For vCPUs, you must specify an
      integer value. - For memory, you specify the amount of MB that you want.
      The value you specify must be a multiple of 256 MB, with up to 6.5 GB of
      memory per every vCPU. - For GPUs, you must specify an integer value. -
      For Local SSD disks, you must specify the amount in GB. The size of a
      single Local SSD disk is 375 GB.
    type: The type of hardware resource that you want to specify. You can
      specify any of the following values: - VCPU - MEMORY - LOCAL_SSD -
      ACCELERATOR Specify as a separate entry in the list for each individual
      resource type.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of hardware resource that you want to specify. You can
    specify any of the following values: - VCPU - MEMORY - LOCAL_SSD -
    ACCELERATOR Specify as a separate entry in the list for each individual
    resource type.

    Values:
      ACCELERATOR: <no description>
      LOCAL_SSD: <no description>
      MEMORY: <no description>
      UNSPECIFIED: <no description>
      VCPU: <no description>
    """
    ACCELERATOR = 0
    LOCAL_SSD = 1
    MEMORY = 2
    UNSPECIFIED = 3
    VCPU = 4

  acceleratorType = _messages.StringField(1)
  amount = _messages.IntegerField(2)
  type = _messages.EnumField('TypeValueValuesEnum', 3)


class ResourceGroupReference(_messages.Message):
  r"""A ResourceGroupReference object.

  Fields:
    group: A URI referencing one of the instance groups or network endpoint
      groups listed in the backend service.
  """

  group = _messages.StringField(1)


class ResourcePoliciesScopedList(_messages.Message):
  r"""A ResourcePoliciesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of
      resourcePolicies when the list is empty.

  Fields:
    resourcePolicies: A list of resourcePolicies contained in this scope.
    warning: Informational warning which replaces the list of resourcePolicies
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of resourcePolicies when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  resourcePolicies = _messages.MessageField('ResourcePolicy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ResourcePolicy(_messages.Message):
  r"""Represents a Resource Policy resource. You can use resource policies to
  schedule actions for some Compute Engine resources. For example, you can use
  them to schedule persistent disk snapshots.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of resource policy
      creation.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: A string attribute.
    diskConsistencyGroupPolicy: Resource policy for disk consistency groups.
    groupPlacementPolicy: Resource policy for instances for placement
      configuration.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    instanceSchedulePolicy: Resource policy for scheduling instance
      operations.
    kind: [Output Only] Type of the resource. Always compute#resource_policies
      for resource policies.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    region: A string attribute.
    resourceStatus: [Output Only] The system status of the resource policy.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    snapshotSchedulePolicy: Resource policy for persistent disks for creating
      snapshots.
    status: [Output Only] The status of resource policy creation.
    vmMaintenancePolicy: Resource policy applicable to VMs for infrastructure
      maintenance.
    workloadPolicy: A ResourcePolicyWorkloadPolicy attribute.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of resource policy creation.

    Values:
      CREATING: Resource policy is being created.
      DELETING: Resource policy is being deleted.
      EXPIRED: Resource policy is expired and will not run again.
      INVALID: <no description>
      READY: Resource policy is ready to be used.
    """
    CREATING = 0
    DELETING = 1
    EXPIRED = 2
    INVALID = 3
    READY = 4

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  diskConsistencyGroupPolicy = _messages.MessageField('ResourcePolicyDiskConsistencyGroupPolicy', 3)
  groupPlacementPolicy = _messages.MessageField('ResourcePolicyGroupPlacementPolicy', 4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  instanceSchedulePolicy = _messages.MessageField('ResourcePolicyInstanceSchedulePolicy', 6)
  kind = _messages.StringField(7, default='compute#resourcePolicy')
  name = _messages.StringField(8)
  region = _messages.StringField(9)
  resourceStatus = _messages.MessageField('ResourcePolicyResourceStatus', 10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  snapshotSchedulePolicy = _messages.MessageField('ResourcePolicySnapshotSchedulePolicy', 13)
  status = _messages.EnumField('StatusValueValuesEnum', 14)
  vmMaintenancePolicy = _messages.MessageField('ResourcePolicyVmMaintenancePolicy', 15)
  workloadPolicy = _messages.MessageField('ResourcePolicyWorkloadPolicy', 16)


class ResourcePolicyAggregatedList(_messages.Message):
  r"""Contains a list of resourcePolicies.

  Messages:
    ItemsValue: A list of ResourcePolicy resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ResourcePolicy resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of ResourcePolicy resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        resourcePolicies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A ResourcePoliciesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ResourcePoliciesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#resourcePolicyAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class ResourcePolicyDailyCycle(_messages.Message):
  r"""Time window specified for daily operations.

  Fields:
    daysInCycle: Defines a schedule with units measured in days. The value
      determines how many days pass between the start of each cycle.
    duration: [Output only] A predetermined duration for the window,
      automatically chosen to be the smallest possible in the given scenario.
    startTime: Start time of the window. This must be in UTC format that
      resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00. For
      example, both 13:00-5 and 08:00 are valid.
  """

  daysInCycle = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  duration = _messages.StringField(2)
  startTime = _messages.StringField(3)


class ResourcePolicyDiskConsistencyGroupPolicy(_messages.Message):
  r"""Resource policy for disk consistency groups."""


class ResourcePolicyGroupPlacementPolicy(_messages.Message):
  r"""A GroupPlacementPolicy specifies resource placement configuration. It
  specifies the failure bucket separation

  Enums:
    CollocationValueValuesEnum: Specifies network collocation
    ScopeValueValuesEnum: Scope specifies the availability domain to which the
      VMs should be spread.

  Fields:
    availabilityDomainCount: The number of availability domains to spread
      instances across. If two instances are in different availability domain,
      they are not in the same low latency network.
    collocation: Specifies network collocation
    gpuTopology: Specifies the shape of the GPU slice, in slice based GPU
      families eg. A4X.
    maxDistance: Specifies the number of max logical switches.
    scope: Scope specifies the availability domain to which the VMs should be
      spread.
    sliceCount: Specifies the number of slices in a multislice workload.
    tpuTopology: Specifies the shape of the TPU slice
    vmCount: Number of VMs in this placement group. Google does not recommend
      that you use this field unless you use a compact policy and you want
      your policy to work only if it contains this exact number of VMs.
  """

  class CollocationValueValuesEnum(_messages.Enum):
    r"""Specifies network collocation

    Values:
      CLUSTERED: Specifies collocation option that provides tight collocation
        with minimum network latency.
      COLLOCATED: <no description>
      MAX_SPREAD: Specifies collocation option that provides spreading across
        clusters.
      UNSPECIFIED_COLLOCATION: <no description>
    """
    CLUSTERED = 0
    COLLOCATED = 1
    MAX_SPREAD = 2
    UNSPECIFIED_COLLOCATION = 3

  class ScopeValueValuesEnum(_messages.Enum):
    r"""Scope specifies the availability domain to which the VMs should be
    spread.

    Values:
      HOST: Specifies availability domain scope across hosts. VMs will be
        spread across different hosts.
      UNSPECIFIED_SCOPE: VMs will be spread across different instrastructure
        to not share power, host and networking.
    """
    HOST = 0
    UNSPECIFIED_SCOPE = 1

  availabilityDomainCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  collocation = _messages.EnumField('CollocationValueValuesEnum', 2)
  gpuTopology = _messages.StringField(3)
  maxDistance = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  scope = _messages.EnumField('ScopeValueValuesEnum', 5)
  sliceCount = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  tpuTopology = _messages.StringField(7)
  vmCount = _messages.IntegerField(8, variant=_messages.Variant.INT32)


class ResourcePolicyHourlyCycle(_messages.Message):
  r"""Time window specified for hourly operations.

  Fields:
    duration: [Output only] Duration of the time window, automatically chosen
      to be smallest possible in the given scenario.
    hoursInCycle: Defines a schedule with units measured in hours. The value
      determines how many hours pass between the start of each cycle.
    startTime: Time within the window to start the operations. It must be in
      format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
  """

  duration = _messages.StringField(1)
  hoursInCycle = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  startTime = _messages.StringField(3)


class ResourcePolicyInstanceSchedulePolicy(_messages.Message):
  r"""An InstanceSchedulePolicy specifies when and how frequent certain
  operations are performed on the instance.

  Fields:
    expirationTime: The expiration time of the schedule. The timestamp is an
      RFC3339 string.
    startTime: The start time of the schedule. The timestamp is an RFC3339
      string.
    timeZone: Specifies the time zone to be used in interpreting
      Schedule.schedule. The value of this field must be a time zone name from
      the tz database: https://wikipedia.org/wiki/Tz_database.
    vmStartSchedule: Specifies the schedule for starting instances.
    vmStopSchedule: Specifies the schedule for stopping instances.
  """

  expirationTime = _messages.StringField(1)
  startTime = _messages.StringField(2)
  timeZone = _messages.StringField(3)
  vmStartSchedule = _messages.MessageField('ResourcePolicyInstanceSchedulePolicySchedule', 4)
  vmStopSchedule = _messages.MessageField('ResourcePolicyInstanceSchedulePolicySchedule', 5)


class ResourcePolicyInstanceSchedulePolicySchedule(_messages.Message):
  r"""Schedule for an instance operation.

  Fields:
    schedule: Specifies the frequency for the operation, using the unix-cron
      format.
  """

  schedule = _messages.StringField(1)


class ResourcePolicyList(_messages.Message):
  r"""A ResourcePolicyList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A list of ResourcePolicy resources.
    kind: [Output Only] Type of resource.Always compute#resourcePoliciesList
      for listsof resourcePolicies
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ResourcePolicy', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#resourcePolicyList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  warning = _messages.MessageField('WarningValue', 7)


class ResourcePolicyResourceStatus(_messages.Message):
  r"""Contains output only fields. Use this sub-message for all output fields
  set on ResourcePolicy. The internal structure of this "status" field should
  mimic the structure of ResourcePolicy proto specification.

  Fields:
    instanceSchedulePolicy: [Output Only] Specifies a set of output values
      reffering to the instance_schedule_policy system status. This field
      should have the same name as corresponding policy field.
  """

  instanceSchedulePolicy = _messages.MessageField('ResourcePolicyResourceStatusInstanceSchedulePolicyStatus', 1)


class ResourcePolicyResourceStatusInstanceSchedulePolicyStatus(_messages.Message):
  r"""A ResourcePolicyResourceStatusInstanceSchedulePolicyStatus object.

  Fields:
    lastRunStartTime: [Output Only] The last time the schedule successfully
      ran. The timestamp is an RFC3339 string.
    nextRunStartTime: [Output Only] The next time the schedule is planned to
      run. The actual time might be slightly different. The timestamp is an
      RFC3339 string.
  """

  lastRunStartTime = _messages.StringField(1)
  nextRunStartTime = _messages.StringField(2)


class ResourcePolicySnapshotSchedulePolicy(_messages.Message):
  r"""A snapshot schedule policy specifies when and how frequently snapshots
  are to be created for the target disk. Also specifies how many and how long
  these scheduled snapshots should be retained.

  Fields:
    retentionPolicy: Retention policy applied to snapshots created by this
      resource policy.
    schedule: A Vm Maintenance Policy specifies what kind of infrastructure
      maintenance we are allowed to perform on this VM and when. Schedule that
      is applied to disks covered by this policy.
    snapshotProperties: Properties with which snapshots are created such as
      labels, encryption keys.
  """

  retentionPolicy = _messages.MessageField('ResourcePolicySnapshotSchedulePolicyRetentionPolicy', 1)
  schedule = _messages.MessageField('ResourcePolicySnapshotSchedulePolicySchedule', 2)
  snapshotProperties = _messages.MessageField('ResourcePolicySnapshotSchedulePolicySnapshotProperties', 3)


class ResourcePolicySnapshotSchedulePolicyRetentionPolicy(_messages.Message):
  r"""Policy for retention of scheduled snapshots.

  Enums:
    OnPolicySwitchValueValuesEnum:
    OnSourceDiskDeleteValueValuesEnum: Specifies the behavior to apply to
      scheduled snapshots when the source disk is deleted.

  Fields:
    maxRetentionDays: Maximum age of the snapshot that is allowed to be kept.
    onPolicySwitch: A OnPolicySwitchValueValuesEnum attribute.
    onSourceDiskDelete: Specifies the behavior to apply to scheduled snapshots
      when the source disk is deleted.
  """

  class OnPolicySwitchValueValuesEnum(_messages.Enum):
    r"""OnPolicySwitchValueValuesEnum enum type.

    Values:
      DO_NOT_RETROACTIVELY_APPLY: <no description>
      RETROACTIVELY_APPLY: <no description>
      UNSPECIFIED_ON_POLICY_SWITCH: <no description>
    """
    DO_NOT_RETROACTIVELY_APPLY = 0
    RETROACTIVELY_APPLY = 1
    UNSPECIFIED_ON_POLICY_SWITCH = 2

  class OnSourceDiskDeleteValueValuesEnum(_messages.Enum):
    r"""Specifies the behavior to apply to scheduled snapshots when the source
    disk is deleted.

    Values:
      APPLY_RETENTION_POLICY: <no description>
      KEEP_AUTO_SNAPSHOTS: <no description>
      UNSPECIFIED_ON_SOURCE_DISK_DELETE: <no description>
    """
    APPLY_RETENTION_POLICY = 0
    KEEP_AUTO_SNAPSHOTS = 1
    UNSPECIFIED_ON_SOURCE_DISK_DELETE = 2

  maxRetentionDays = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  onPolicySwitch = _messages.EnumField('OnPolicySwitchValueValuesEnum', 2)
  onSourceDiskDelete = _messages.EnumField('OnSourceDiskDeleteValueValuesEnum', 3)


class ResourcePolicySnapshotSchedulePolicySchedule(_messages.Message):
  r"""A schedule for disks where the schedueled operations are performed.

  Fields:
    dailySchedule: A ResourcePolicyDailyCycle attribute.
    hourlySchedule: A ResourcePolicyHourlyCycle attribute.
    weeklySchedule: A ResourcePolicyWeeklyCycle attribute.
  """

  dailySchedule = _messages.MessageField('ResourcePolicyDailyCycle', 1)
  hourlySchedule = _messages.MessageField('ResourcePolicyHourlyCycle', 2)
  weeklySchedule = _messages.MessageField('ResourcePolicyWeeklyCycle', 3)


class ResourcePolicySnapshotSchedulePolicySnapshotProperties(_messages.Message):
  r"""Specified snapshot properties for scheduled snapshots created by this
  policy.

  Messages:
    LabelsValue: Labels to apply to scheduled snapshots. These can be later
      modified by the setLabels method. Label values may be empty.

  Fields:
    chainName: Chain name that the snapshot is created in.
    guestFlush: Indication to perform a 'guest aware' snapshot.
    labels: Labels to apply to scheduled snapshots. These can be later
      modified by the setLabels method. Label values may be empty.
    region: Region where the snapshot is scoped to.
    storageLocations: Cloud Storage bucket storage location of the auto
      snapshot (regional or multi-regional).
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to scheduled snapshots. These can be later modified by
    the setLabels method. Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  chainName = _messages.StringField(1)
  guestFlush = _messages.BooleanField(2)
  labels = _messages.MessageField('LabelsValue', 3)
  region = _messages.StringField(4)
  storageLocations = _messages.StringField(5, repeated=True)


class ResourcePolicyVmMaintenancePolicy(_messages.Message):
  r"""A ResourcePolicyVmMaintenancePolicy object.

  Fields:
    concurrencyControlGroup: A
      ResourcePolicyVmMaintenancePolicyConcurrencyControl attribute.
    maintenanceWindow: Maintenance windows that are applied to VMs covered by
      this policy.
  """

  concurrencyControlGroup = _messages.MessageField('ResourcePolicyVmMaintenancePolicyConcurrencyControl', 1)
  maintenanceWindow = _messages.MessageField('ResourcePolicyVmMaintenancePolicyMaintenanceWindow', 2)


class ResourcePolicyVmMaintenancePolicyConcurrencyControl(_messages.Message):
  r"""A concurrency control configuration. Defines a group config that, when
  attached to an instance, recognizes that instance as part of a group of
  instances where only up the concurrency_limit of instances in that group can
  undergo simultaneous maintenance. For more information: go/concurrency-
  control-design-doc

  Fields:
    concurrencyLimit: A integer attribute.
  """

  concurrencyLimit = _messages.IntegerField(1, variant=_messages.Variant.INT32)


class ResourcePolicyVmMaintenancePolicyMaintenanceWindow(_messages.Message):
  r"""A maintenance window for VMs. When set, we restrict our maintenance
  operations to this window.

  Fields:
    dailyMaintenanceWindow: A ResourcePolicyDailyCycle attribute.
  """

  dailyMaintenanceWindow = _messages.MessageField('ResourcePolicyDailyCycle', 1)


class ResourcePolicyWeeklyCycle(_messages.Message):
  r"""Time window specified for weekly operations.

  Fields:
    dayOfWeeks: Up to 7 intervals/windows, one for each day of the week.
  """

  dayOfWeeks = _messages.MessageField('ResourcePolicyWeeklyCycleDayOfWeek', 1, repeated=True)


class ResourcePolicyWeeklyCycleDayOfWeek(_messages.Message):
  r"""A ResourcePolicyWeeklyCycleDayOfWeek object.

  Enums:
    DayValueValuesEnum: Defines a schedule that runs on specific days of the
      week. Specify one or more days. The following options are available:
      MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.

  Fields:
    day: Defines a schedule that runs on specific days of the week. Specify
      one or more days. The following options are available: MONDAY, TUESDAY,
      WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
    duration: [Output only] Duration of the time window, automatically chosen
      to be smallest possible in the given scenario.
    startTime: Time within the window to start the operations. It must be in
      format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
  """

  class DayValueValuesEnum(_messages.Enum):
    r"""Defines a schedule that runs on specific days of the week. Specify one
    or more days. The following options are available: MONDAY, TUESDAY,
    WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.

    Values:
      FRIDAY: <no description>
      INVALID: <no description>
      MONDAY: <no description>
      SATURDAY: <no description>
      SUNDAY: <no description>
      THURSDAY: <no description>
      TUESDAY: <no description>
      WEDNESDAY: <no description>
    """
    FRIDAY = 0
    INVALID = 1
    MONDAY = 2
    SATURDAY = 3
    SUNDAY = 4
    THURSDAY = 5
    TUESDAY = 6
    WEDNESDAY = 7

  day = _messages.EnumField('DayValueValuesEnum', 1)
  duration = _messages.StringField(2)
  startTime = _messages.StringField(3)


class ResourcePolicyWorkloadPolicy(_messages.Message):
  r"""Represents the workload policy.

  Enums:
    MaxTopologyDistanceValueValuesEnum:
    TypeValueValuesEnum:

  Fields:
    acceleratorTopology: A string attribute.
    maxTopologyDistance: A MaxTopologyDistanceValueValuesEnum attribute.
    type: A TypeValueValuesEnum attribute.
  """

  class MaxTopologyDistanceValueValuesEnum(_messages.Enum):
    r"""MaxTopologyDistanceValueValuesEnum enum type.

    Values:
      BLOCK: VMs must be provisioned in the same block.
      CLUSTER: VMs must be provisioned in the same cluster.
      SUBBLOCK: VMs must be provisioned in the same subblock.
    """
    BLOCK = 0
    CLUSTER = 1
    SUBBLOCK = 2

  class TypeValueValuesEnum(_messages.Enum):
    r"""TypeValueValuesEnum enum type.

    Values:
      HIGH_AVAILABILITY: VMs will be provisioned in such a way which provides
        high availability.
      HIGH_THROUGHPUT: VMs will be provisioned in such a way which provides
        high throughput.
    """
    HIGH_AVAILABILITY = 0
    HIGH_THROUGHPUT = 1

  acceleratorTopology = _messages.StringField(1)
  maxTopologyDistance = _messages.EnumField('MaxTopologyDistanceValueValuesEnum', 2)
  type = _messages.EnumField('TypeValueValuesEnum', 3)


class ResourceStatus(_messages.Message):
  r"""Contains output only fields. Use this sub-message for actual values set
  on Instance attributes as compared to the value requested by the user
  (intent) in their instance CRUD calls.

  Messages:
    ServiceIntegrationStatusesValue: [Output Only] Represents the status of
      the service integration specs defined by the user in
      instance.serviceIntegrationSpecs.

  Fields:
    acceleratorStatus: [Output Only] Accelerators status show results of GPU
      scans. These scans are specialized diagnostic tests designed to uncover
      latent manufacturing defects or other issues that could potentially lead
      to data corruption or impede the customer's ability to efficiently
      execute GPU workloads.
    effectiveInstanceMetadata: [Output Only] Effective metadata is a field
      that consolidates project, zonal instance settings, and instance-level
      predefined metadata keys to provide the overridden value for those
      metadata keys at the instance level.
    lastInstanceTerminationDetails: [Output Only] Contains last termination
      details why the instance was terminated.
    physicalHost: [Output Only] The precise location of your instance within
      the zone's data center, including the block, sub-block, and host. The
      field is formatted as follows: blockId/subBlockId/hostId.
    physicalHostTopology: [Output Only] A series of fields containing the
      global name of the Compute Engine cluster, as well as the ID of the
      block, sub-block, and host on which the running instance is located.
    scheduling: A ResourceStatusScheduling attribute.
    serviceIntegrationStatuses: [Output Only] Represents the status of the
      service integration specs defined by the user in
      instance.serviceIntegrationSpecs.
    shutdownDetails: [Output Only] Details about the instance stopping state.
    upcomingMaintenance: A UpcomingMaintenance attribute.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ServiceIntegrationStatusesValue(_messages.Message):
    r"""[Output Only] Represents the status of the service integration specs
    defined by the user in instance.serviceIntegrationSpecs.

    Messages:
      AdditionalProperty: An additional property for a
        ServiceIntegrationStatusesValue object.

    Fields:
      additionalProperties: Additional properties of type
        ServiceIntegrationStatusesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ServiceIntegrationStatusesValue object.

      Fields:
        key: Name of the additional property.
        value: A ResourceStatusServiceIntegrationStatus attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ResourceStatusServiceIntegrationStatus', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  acceleratorStatus = _messages.MessageField('ResourceStatusAcceleratorStatus', 1, repeated=True)
  effectiveInstanceMetadata = _messages.MessageField('ResourceStatusEffectiveInstanceMetadata', 2)
  lastInstanceTerminationDetails = _messages.MessageField('ResourceStatusLastInstanceTerminationDetails', 3)
  physicalHost = _messages.StringField(4)
  physicalHostTopology = _messages.MessageField('ResourceStatusPhysicalHostTopology', 5)
  scheduling = _messages.MessageField('ResourceStatusScheduling', 6)
  serviceIntegrationStatuses = _messages.MessageField('ServiceIntegrationStatusesValue', 7)
  shutdownDetails = _messages.MessageField('ResourceStatusShutdownDetails', 8)
  upcomingMaintenance = _messages.MessageField('UpcomingMaintenance', 9)


class ResourceStatusAcceleratorStatus(_messages.Message):
  r"""The status of an individual accelerator resource.

  Fields:
    passedScans: The details of scans that passed for an accelerator.
    recommendedScans: The details of recommended scans for an accelerator.
    serialNumber: The serial number of the accelerator.
    uuid: The UUID of the accelerator.
  """

  passedScans = _messages.MessageField('ResourceStatusAcceleratorStatusPassedScan', 1, repeated=True)
  recommendedScans = _messages.MessageField('ResourceStatusAcceleratorStatusRecommendedScan', 2, repeated=True)
  serialNumber = _messages.StringField(3)
  uuid = _messages.StringField(4)


class ResourceStatusAcceleratorStatusPassedScan(_messages.Message):
  r"""A ResourceStatusAcceleratorStatusPassedScan object.

  Fields:
    endTime: The end time of the passed scan in RFC3339 text format.
    name: A string attribute.
    startTime: The start time of the passed scan in RFC3339 text format.
    version: A string attribute.
  """

  endTime = _messages.StringField(1)
  name = _messages.StringField(2)
  startTime = _messages.StringField(3)
  version = _messages.StringField(4)


class ResourceStatusAcceleratorStatusRecommendedScan(_messages.Message):
  r"""A ResourceStatusAcceleratorStatusRecommendedScan object.

  Fields:
    estimatedDuration: A Duration attribute.
    name: A string attribute.
    version: A string attribute.
  """

  estimatedDuration = _messages.MessageField('Duration', 1)
  name = _messages.StringField(2)
  version = _messages.StringField(3)


class ResourceStatusEffectiveInstanceMetadata(_messages.Message):
  r"""Effective values of predefined metadata keys for an instance.

  Fields:
    enableOsloginMetadataValue: Effective enable-oslogin value at Instance
      level.
    vmDnsSettingMetadataValue: Effective VM DNS setting at Instance level.
  """

  enableOsloginMetadataValue = _messages.BooleanField(1)
  vmDnsSettingMetadataValue = _messages.StringField(2)


class ResourceStatusLastInstanceTerminationDetails(_messages.Message):
  r"""A ResourceStatusLastInstanceTerminationDetails object.

  Enums:
    TerminationReasonValueValuesEnum: Reason for termination

  Fields:
    terminationReason: Reason for termination
  """

  class TerminationReasonValueValuesEnum(_messages.Enum):
    r"""Reason for termination

    Values:
      BAD_BILLING_ACCOUNT: Terminated due to bad billing
      CLOUD_ABUSE_DETECTED: Terminated by Cloud Abuse team
      DISK_ERROR: Terminated due to disk errors
      FREE_TRIAL_EXPIRED: Terminated due to free trial expired
      INSTANCE_UPDATE_REQUIRED_RESTART: Instance.update initiated which
        required RESTART
      INTERNAL_ERROR: Terminated due to internal error
      KMS_REJECTION: Terminated due to Key Management Service (KMS) key
        failure.
      MANAGED_INSTANCE_GROUP: Terminated by managed instance group
      OS_TERMINATED: Terminated from the OS level
      PREEMPTED: Terminated due to preemption
      SCHEDULED_STOP: Terminated due to scheduled stop
      SHUTDOWN_DUE_TO_HOST_ERROR: Terminated due to host error
      SHUTDOWN_DUE_TO_MAINTENANCE: Terminated due to maintenance
      USER_TERMINATED: Terminated by user
    """
    BAD_BILLING_ACCOUNT = 0
    CLOUD_ABUSE_DETECTED = 1
    DISK_ERROR = 2
    FREE_TRIAL_EXPIRED = 3
    INSTANCE_UPDATE_REQUIRED_RESTART = 4
    INTERNAL_ERROR = 5
    KMS_REJECTION = 6
    MANAGED_INSTANCE_GROUP = 7
    OS_TERMINATED = 8
    PREEMPTED = 9
    SCHEDULED_STOP = 10
    SHUTDOWN_DUE_TO_HOST_ERROR = 11
    SHUTDOWN_DUE_TO_MAINTENANCE = 12
    USER_TERMINATED = 13

  terminationReason = _messages.EnumField('TerminationReasonValueValuesEnum', 1)


class ResourceStatusPhysicalHostTopology(_messages.Message):
  r"""Represents the physical host topology of the host on which the VM is
  running.

  Fields:
    block: [Output Only] The ID of the block in which the running instance is
      located. Instances within the same block experience low network latency.
    cluster: [Output Only] The global name of the Compute Engine cluster where
      the running instance is located.
    host: [Output Only] The ID of the host on which the running instance is
      located. Instances on the same host experience the lowest possible
      network latency.
    subblock: [Output Only] The ID of the sub-block in which the running
      instance is located. Instances in the same sub-block experience lower
      network latency than instances in the same block.
  """

  block = _messages.StringField(1)
  cluster = _messages.StringField(2)
  host = _messages.StringField(3)
  subblock = _messages.StringField(4)


class ResourceStatusScheduling(_messages.Message):
  r"""A ResourceStatusScheduling object.

  Fields:
    availabilityDomain: Specifies the availability domain to place the
      instance in. The value must be a number between 1 and the number of
      availability domains specified in the spread placement policy attached
      to the instance.
    terminationTimestamp: Time in future when the instance will be terminated
      in RFC3339 text format.
  """

  availabilityDomain = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  terminationTimestamp = _messages.StringField(2)


class ResourceStatusServiceIntegrationStatus(_messages.Message):
  r"""Represents the status of integration between instance and another
  service. See go/gce-backupdr-design for more details.

  Fields:
    backupDr: A ResourceStatusServiceIntegrationStatusBackupDRStatus
      attribute.
  """

  backupDr = _messages.MessageField('ResourceStatusServiceIntegrationStatusBackupDRStatus', 1)


class ResourceStatusServiceIntegrationStatusBackupDRStatus(_messages.Message):
  r"""Message defining compute perspective of the result of integration with
  Backup and DR. FAILED status indicates that the operation specified did not
  complete correctly and should be retried with the same value.

  Enums:
    StateValueValuesEnum: Enum representing the registration state of a Backup
      and DR backup plan for the instance.

  Fields:
    integrationDetails: The PlanReference object created by Backup and DR to
      maintain the actual status of backups. May still be present if removing
      the backup plan fails.
    state: Enum representing the registration state of a Backup and DR backup
      plan for the instance.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""Enum representing the registration state of a Backup and DR backup
    plan for the instance.

    Values:
      ACTIVE: The operation was successful and Backup and DR is trying to
        protect the instance with the specified backup plan. Check resource
        pointed to in integration_details for more information.
      CREATING: GCE is trying to attach the backup plan to the instance.
      DELETING: GCE is trying to remove the backup plan from the instance.
      FAILED: The operation failed, specifying the same value in
        BackupDrSpec.plan again (including null for delete) will attempt to
        repair the integration
      STATE_UNSPECIFIED: Default value, should not be found on instances.
    """
    ACTIVE = 0
    CREATING = 1
    DELETING = 2
    FAILED = 3
    STATE_UNSPECIFIED = 4

  integrationDetails = _messages.StringField(1)
  state = _messages.EnumField('StateValueValuesEnum', 2)


class ResourceStatusShutdownDetails(_messages.Message):
  r"""Specifies if the instance is in `PENDING_STOP` state or there is a
  programmed stop scheduled.

  Enums:
    StopStateValueValuesEnum: Current stopping state of the instance.
    TargetStateValueValuesEnum: Target instance state.

  Fields:
    maxDuration: The duration for graceful shutdown. Only applicable when
      `stop_state=PENDING_STOP`.
    requestTimestamp: Past timestamp indicating the beginning of current
      `stopState` in RFC3339 text format.
    stopState: Current stopping state of the instance.
    targetState: Target instance state.
  """

  class StopStateValueValuesEnum(_messages.Enum):
    r"""Current stopping state of the instance.

    Values:
      PENDING_STOP: The instance is gracefully shutting down.
      STOPPING: The instance is stopping.
    """
    PENDING_STOP = 0
    STOPPING = 1

  class TargetStateValueValuesEnum(_messages.Enum):
    r"""Target instance state.

    Values:
      DELETED: The instance will be deleted.
      STOPPED: The instance will be stopped.
    """
    DELETED = 0
    STOPPED = 1

  maxDuration = _messages.MessageField('Duration', 1)
  requestTimestamp = _messages.StringField(2)
  stopState = _messages.EnumField('StopStateValueValuesEnum', 3)
  targetState = _messages.EnumField('TargetStateValueValuesEnum', 4)


class RiskDetails(_messages.Message):
  r"""Details about a risk.

  Enums:
    SeverityValueValuesEnum: The severity of the risk.
    TypeValueValuesEnum: The type of risk.

  Fields:
    duration: The duration of the risk since it was detected.
    globalDnsInsight: A RiskDetailsGlobalDnsInsight attribute.
    lastUpdateTimestamp: The last time the risk was updated.
    severity: The severity of the risk.
    type: The type of risk.
  """

  class SeverityValueValuesEnum(_messages.Enum):
    r"""The severity of the risk.

    Values:
      CRITICAL: Critical severity.
      HIGH: High severity.
      LOW: Low severity.
      MEDIUM: Medium severity.
      SEVERITY_UNSPECIFIED: No severity specified. The default value.
    """
    CRITICAL = 0
    HIGH = 1
    LOW = 2
    MEDIUM = 3
    SEVERITY_UNSPECIFIED = 4

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of risk.

    Values:
      GLOBAL_DNS: Risk type related to global DNS.
      RISK_TYPE_UNSPECIFIED: Default value. This value is unused.
    """
    GLOBAL_DNS = 0
    RISK_TYPE_UNSPECIFIED = 1

  duration = _messages.StringField(1)
  globalDnsInsight = _messages.MessageField('RiskDetailsGlobalDnsInsight', 2)
  lastUpdateTimestamp = _messages.StringField(3)
  severity = _messages.EnumField('SeverityValueValuesEnum', 4)
  type = _messages.EnumField('TypeValueValuesEnum', 5)


class RiskDetailsGlobalDnsInsight(_messages.Message):
  r"""A RiskDetailsGlobalDnsInsight object.

  Fields:
    projectDefaultIsGlobalDns: Whether the project default DNS setting is
      global or not.
    queryObservationWindow: The observation window for the query counts.
    riskyQueryCount: The number of queries that are risky. This will always be
      less than total_query_count.
    totalQueryCount: The total number of queries in the observation window.
  """

  projectDefaultIsGlobalDns = _messages.BooleanField(1)
  queryObservationWindow = _messages.StringField(2)
  riskyQueryCount = _messages.IntegerField(3)
  totalQueryCount = _messages.IntegerField(4)


class RiskRecommendation(_messages.Message):
  r"""Recommendation with reference url.

  Fields:
    content: Mitigation guide for the risk.
    referenceUrl: URL referencing a more detailed mitigation guide.
  """

  content = _messages.StringField(1)
  referenceUrl = _messages.StringField(2)


class RolloutPolicy(_messages.Message):
  r"""A rollout policy configuration.

  Messages:
    LocationRolloutPoliciesValue: Location based rollout policies to apply to
      the resource. Currently only zone names are supported and must be
      represented as valid URLs, like: zones/us-central1-a. The value expects
      an RFC3339 timestamp on or after which the update is considered rolled
      out to the specified location.

  Fields:
    defaultRolloutTime: An optional RFC3339 timestamp on or after which the
      update is considered rolled out to any zone that is not explicitly
      stated.
    locationRolloutPolicies: Location based rollout policies to apply to the
      resource. Currently only zone names are supported and must be
      represented as valid URLs, like: zones/us-central1-a. The value expects
      an RFC3339 timestamp on or after which the update is considered rolled
      out to the specified location.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LocationRolloutPoliciesValue(_messages.Message):
    r"""Location based rollout policies to apply to the resource. Currently
    only zone names are supported and must be represented as valid URLs, like:
    zones/us-central1-a. The value expects an RFC3339 timestamp on or after
    which the update is considered rolled out to the specified location.

    Messages:
      AdditionalProperty: An additional property for a
        LocationRolloutPoliciesValue object.

    Fields:
      additionalProperties: Additional properties of type
        LocationRolloutPoliciesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LocationRolloutPoliciesValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  defaultRolloutTime = _messages.StringField(1)
  locationRolloutPolicies = _messages.MessageField('LocationRolloutPoliciesValue', 2)


class Route(_messages.Message):
  r"""Represents a Route resource. A route defines a path from VM instances in
  the VPC network to a specific destination. This destination can be inside or
  outside the VPC network. For more information, read the Routes overview.

  Enums:
    IlbRouteBehaviorOnUnhealthyValueValuesEnum: ILB route behavior when ILB is
      deemed unhealthy based on user specified threshold on the Backend
      Service of the internal load balancing.
    NextHopOriginValueValuesEnum: [Output Only] Indicates the origin of the
      route. Can be IGP (Interior Gateway Protocol), EGP (Exterior Gateway
      Protocol), or INCOMPLETE.
    RouteStatusValueValuesEnum: [Output only] The status of the route.
    RouteTypeValueValuesEnum: [Output Only] The type of this route, which can
      be one of the following values: - 'TRANSIT' for a transit route that
      this router learned from another Cloud Router and will readvertise to
      one of its BGP peers - 'SUBNET' for a route from a subnet of the VPC -
      'BGP' for a route learned from a BGP peer of this router - 'STATIC' for
      a static route

  Messages:
    WarningsValueListEntry: A WarningsValueListEntry object.

  Fields:
    allowConflictingSubnetworks: Whether this route can conflict with existing
      subnetworks. Setting this to true allows this route to conflict with
      subnetworks that have already been configured on the corresponding
      network.
    asPaths: [Output Only] AS path.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this field
      when you create the resource.
    destRange: The destination range of outgoing packets that this route
      applies to. Both IPv4 and IPv6 are supported. Must specify an IPv4 range
      (e.g. 192.0.2.0/24) or an IPv6 range in RFC 4291 format (e.g.
      2001:db8::/32). IPv6 range will be displayed using RFC 5952 compressed
      format.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ilbRouteBehaviorOnUnhealthy: ILB route behavior when ILB is deemed
      unhealthy based on user specified threshold on the Backend Service of
      the internal load balancing.
    kind: [Output Only] Type of this resource. Always compute#routes for Route
      resources.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character
      must be a lowercase letter, and all following characters (except for the
      last character) must be a dash, lowercase letter, or digit. The last
      character must be a lowercase letter or digit.
    network: Fully-qualified URL of the network that this route applies to.
    nextHopGateway: The URL to a gateway that should handle matching packets.
      You can only specify the internet gateway using a full or partial valid
      URL: projects/ project/global/gateways/default-internet-gateway
    nextHopHub: [Output Only] The full resource name of the Network
      Connectivity Center hub that will handle matching packets.
    nextHopIlb: The URL to a forwarding rule of type
      loadBalancingScheme=INTERNAL that should handle matching packets or the
      IP address of the forwarding Rule. For example, the following are all
      valid URLs: -
      https://www.googleapis.com/compute/v1/projects/project/regions/region
      /forwardingRules/forwardingRule -
      regions/region/forwardingRules/forwardingRule If an IP address is
      provided, must specify an IPv4 address in dot-decimal notation or an
      IPv6 address in RFC 4291 format. For example, the following are all
      valid IP addresses: - 10.128.0.56 - 2001:db8::2d9:51:0:0 -
      2001:db8:0:0:2d9:51:0:0 IPv6 addresses will be displayed using RFC 5952
      compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an
      IPv4-mapped IPv6 address.
    nextHopInstance: The URL to an instance that should handle matching
      packets. You can specify this as a full or partial URL. For example: htt
      ps://www.googleapis.com/compute/v1/projects/project/zones/zone/instances
      /
    nextHopInterRegionCost: [Output only] Internal fixed region-to-region cost
      that Google Cloud calculates based on factors such as network
      performance, distance, and available bandwidth between regions.
    nextHopInterconnectAttachment: [Output Only] The URL to an
      InterconnectAttachment which is the next hop for the route. This field
      will only be populated for the dynamic routes generated by Cloud Router
      with a linked interconnectAttachment.
    nextHopIp: The network IP address of an instance that should handle
      matching packets. Both IPv6 address and IPv4 addresses are supported.
      Must specify an IPv4 address in dot-decimal notation (e.g. 192.0.2.99)
      or an IPv6 address in RFC 4291 format (e.g. 2001:db8::2d9:51:0:0 or
      2001:db8:0:0:2d9:51:0:0). IPv6 addresses will be displayed using RFC
      5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an
      IPv4-mapped IPv6 address.
    nextHopMed: [Output Only] Multi-Exit Discriminator, a BGP route metric
      that indicates the desirability of a particular route in a network.
    nextHopNetwork: The URL of the local network if it should handle matching
      packets.
    nextHopOrigin: [Output Only] Indicates the origin of the route. Can be IGP
      (Interior Gateway Protocol), EGP (Exterior Gateway Protocol), or
      INCOMPLETE.
    nextHopPeering: [Output Only] The network peering name that should handle
      matching packets, which should conform to RFC1035.
    nextHopVpnTunnel: The URL to a VpnTunnel that should handle matching
      packets.
    priority: The priority of this route. Priority is used to break ties in
      cases where there is more than one matching route of equal prefix
      length. In cases where multiple routes have equal prefix length, the one
      with the lowest-numbered priority value wins. The default value is
      `1000`. The priority value must be from `0` to `65535`, inclusive.
    routeStatus: [Output only] The status of the route.
    routeType: [Output Only] The type of this route, which can be one of the
      following values: - 'TRANSIT' for a transit route that this router
      learned from another Cloud Router and will readvertise to one of its BGP
      peers - 'SUBNET' for a route from a subnet of the VPC - 'BGP' for a
      route learned from a BGP peer of this router - 'STATIC' for a static
      route
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    tags: A list of instance tags to which this route applies.
    warnings: [Output Only] If potential misconfigurations are detected for
      this route, this field will be populated with warning messages.
  """

  class IlbRouteBehaviorOnUnhealthyValueValuesEnum(_messages.Enum):
    r"""ILB route behavior when ILB is deemed unhealthy based on user
    specified threshold on the Backend Service of the internal load balancing.

    Values:
      DO_NOT_WITHDRAW_ROUTE_IF_ILB_UNHEALTHY: Do not Withdraw route if the ILB
        is deemed unhealthy based on user specified threshold on the Backend
        Service of the ILB. This is default behavior for ilb as next hop route
        without IlbRouteBehavior.
      WITHDRAW_ROUTE_IF_ILB_UNHEALTHY: Withdraw route if the ILB is deemed
        unhealthy based on user specified threshold on the Backend Service of
        the internal load balancing. Currently the withdrawn route will be
        reinserted when the backends are restored to healthy. If you wish to
        prevent the re-insertion of the route and trigger the fall-back at
        your discretion, override the health result from the backends to
        signal as healthy only when ready to fallback.
    """
    DO_NOT_WITHDRAW_ROUTE_IF_ILB_UNHEALTHY = 0
    WITHDRAW_ROUTE_IF_ILB_UNHEALTHY = 1

  class NextHopOriginValueValuesEnum(_messages.Enum):
    r"""[Output Only] Indicates the origin of the route. Can be IGP (Interior
    Gateway Protocol), EGP (Exterior Gateway Protocol), or INCOMPLETE.

    Values:
      EGP: <no description>
      IGP: <no description>
      INCOMPLETE: <no description>
    """
    EGP = 0
    IGP = 1
    INCOMPLETE = 2

  class RouteStatusValueValuesEnum(_messages.Enum):
    r"""[Output only] The status of the route.

    Values:
      ACTIVE: This route is processed and active.
      DROPPED: The route is dropped due to the VPC exceeding the dynamic route
        limit. For dynamic route limit, please refer to the Learned route
        example
      INACTIVE: This route is processed but inactive due to failure from the
        backend. The backend may have rejected the route
      PENDING: This route is being processed internally. The status will
        change once processed.
    """
    ACTIVE = 0
    DROPPED = 1
    INACTIVE = 2
    PENDING = 3

  class RouteTypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The type of this route, which can be one of the
    following values: - 'TRANSIT' for a transit route that this router learned
    from another Cloud Router and will readvertise to one of its BGP peers -
    'SUBNET' for a route from a subnet of the VPC - 'BGP' for a route learned
    from a BGP peer of this router - 'STATIC' for a static route

    Values:
      BGP: <no description>
      STATIC: <no description>
      SUBNET: <no description>
      TRANSIT: <no description>
    """
    BGP = 0
    STATIC = 1
    SUBNET = 2
    TRANSIT = 3

  class WarningsValueListEntry(_messages.Message):
    r"""A WarningsValueListEntry object.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  allowConflictingSubnetworks = _messages.BooleanField(1)
  asPaths = _messages.MessageField('RouteAsPath', 2, repeated=True)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  destRange = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  ilbRouteBehaviorOnUnhealthy = _messages.EnumField('IlbRouteBehaviorOnUnhealthyValueValuesEnum', 7)
  kind = _messages.StringField(8, default='compute#route')
  name = _messages.StringField(9)
  network = _messages.StringField(10)
  nextHopGateway = _messages.StringField(11)
  nextHopHub = _messages.StringField(12)
  nextHopIlb = _messages.StringField(13)
  nextHopInstance = _messages.StringField(14)
  nextHopInterRegionCost = _messages.IntegerField(15, variant=_messages.Variant.UINT32)
  nextHopInterconnectAttachment = _messages.StringField(16)
  nextHopIp = _messages.StringField(17)
  nextHopMed = _messages.IntegerField(18, variant=_messages.Variant.UINT32)
  nextHopNetwork = _messages.StringField(19)
  nextHopOrigin = _messages.EnumField('NextHopOriginValueValuesEnum', 20)
  nextHopPeering = _messages.StringField(21)
  nextHopVpnTunnel = _messages.StringField(22)
  priority = _messages.IntegerField(23, variant=_messages.Variant.UINT32)
  routeStatus = _messages.EnumField('RouteStatusValueValuesEnum', 24)
  routeType = _messages.EnumField('RouteTypeValueValuesEnum', 25)
  selfLink = _messages.StringField(26)
  selfLinkWithId = _messages.StringField(27)
  tags = _messages.StringField(28, repeated=True)
  warnings = _messages.MessageField('WarningsValueListEntry', 29, repeated=True)


class RouteAsPath(_messages.Message):
  r"""A RouteAsPath object.

  Enums:
    PathSegmentTypeValueValuesEnum: [Output Only] The type of the AS Path,
      which can be one of the following values: - 'AS_SET': unordered set of
      autonomous systems that the route in has traversed - 'AS_SEQUENCE':
      ordered set of autonomous systems that the route has traversed -
      'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the
      local confederation that the route has traversed - 'AS_CONFED_SET':
      unordered set of Member Autonomous Systems in the local confederation
      that the route has traversed

  Fields:
    asLists: [Output Only] The AS numbers of the AS Path.
    pathSegmentType: [Output Only] The type of the AS Path, which can be one
      of the following values: - 'AS_SET': unordered set of autonomous systems
      that the route in has traversed - 'AS_SEQUENCE': ordered set of
      autonomous systems that the route has traversed - 'AS_CONFED_SEQUENCE':
      ordered set of Member Autonomous Systems in the local confederation that
      the route has traversed - 'AS_CONFED_SET': unordered set of Member
      Autonomous Systems in the local confederation that the route has
      traversed
  """

  class PathSegmentTypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The type of the AS Path, which can be one of the
    following values: - 'AS_SET': unordered set of autonomous systems that the
    route in has traversed - 'AS_SEQUENCE': ordered set of autonomous systems
    that the route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member
    Autonomous Systems in the local confederation that the route has traversed
    - 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local
    confederation that the route has traversed

    Values:
      AS_CONFED_SEQUENCE: <no description>
      AS_CONFED_SET: <no description>
      AS_SEQUENCE: <no description>
      AS_SET: <no description>
    """
    AS_CONFED_SEQUENCE = 0
    AS_CONFED_SET = 1
    AS_SEQUENCE = 2
    AS_SET = 3

  asLists = _messages.IntegerField(1, repeated=True, variant=_messages.Variant.UINT32)
  pathSegmentType = _messages.EnumField('PathSegmentTypeValueValuesEnum', 2)


class RouteList(_messages.Message):
  r"""Contains a list of Route resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Route resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Route', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#routeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RoutePolicy(_messages.Message):
  r"""A RoutePolicy object.

  Enums:
    TypeValueValuesEnum:

  Fields:
    description: An optional description of route policy.
    fingerprint: A fingerprint for the Route Policy being applied to this
      Router, which is essentially a hash of the Route Policy used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update Route Policy.
      You must always provide an up-to-date fingerprint hash in order to
      update or change labels. To see the latest fingerprint, make a
      getRoutePolicy() request to retrieve a Route Policy.
    name: Route Policy name, which must be a resource ID segment and unique
      within all the router's Route Policies. Name should conform to RFC1035.
    terms: List of terms (the order in the list is not important, they are
      evaluated in order of priority). Order of policies is not retained and
      might change when getting policy later.
    type: A TypeValueValuesEnum attribute.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""TypeValueValuesEnum enum type.

    Values:
      ROUTE_POLICY_TYPE_EXPORT: The Route Policy is an Export Policy.
      ROUTE_POLICY_TYPE_IMPORT: The Route Policy is an Import Policy.
    """
    ROUTE_POLICY_TYPE_EXPORT = 0
    ROUTE_POLICY_TYPE_IMPORT = 1

  description = _messages.StringField(1)
  fingerprint = _messages.BytesField(2)
  name = _messages.StringField(3)
  terms = _messages.MessageField('RoutePolicyPolicyTerm', 4, repeated=True)
  type = _messages.EnumField('TypeValueValuesEnum', 5)


class RoutePolicyPolicyTerm(_messages.Message):
  r"""A RoutePolicyPolicyTerm object.

  Fields:
    actions: CEL expressions to evaluate to modify a route when this term
      matches.
    match: CEL expression evaluated against a route to determine if this term
      applies. When not set, the term applies to all routes.
    priority: The evaluation priority for this term, which must be between 0
      (inclusive) and 2^31 (exclusive), and unique within the list.
  """

  actions = _messages.MessageField('Expr', 1, repeated=True)
  match = _messages.MessageField('Expr', 2)
  priority = _messages.IntegerField(3, variant=_messages.Variant.INT32)


class Router(_messages.Message):
  r"""Represents a Cloud Router resource. For more information about Cloud
  Router, read the Cloud Router overview.

  Fields:
    bgp: BGP information specific to this router.
    bgpPeers: BGP information that must be configured into the routing stack
      to establish BGP peering. This information must specify the peer ASN and
      either the interface name, IP address, or peer IP address. Please refer
      to RFC4273.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    encryptedInterconnectRouter: Indicates if a router is dedicated for use
      with encrypted VLAN attachments (interconnectAttachments).
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interfaces: Router interfaces. To create a BGP peer that uses a router
      interface, the interface must have one of the following fields
      specified: - linkedVpnTunnel - linkedInterconnectAttachment - subnetwork
      You can create a router interface without any of these fields specified.
      However, you cannot create a BGP peer that uses that interface.
    kind: [Output Only] Type of resource. Always compute#router for routers.
    md5AuthenticationKeys: Keys used for MD5 authentication.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    nats: A list of NAT services created in this router.
    nccGateway: URI of the ncc_gateway to which this router associated.
    network: URI of the network to which this router belongs.
    region: [Output Only] URI of the region where the router resides. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  bgp = _messages.MessageField('RouterBgp', 1)
  bgpPeers = _messages.MessageField('RouterBgpPeer', 2, repeated=True)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  encryptedInterconnectRouter = _messages.BooleanField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  interfaces = _messages.MessageField('RouterInterface', 7, repeated=True)
  kind = _messages.StringField(8, default='compute#router')
  md5AuthenticationKeys = _messages.MessageField('RouterMd5AuthenticationKey', 9, repeated=True)
  name = _messages.StringField(10)
  nats = _messages.MessageField('RouterNat', 11, repeated=True)
  nccGateway = _messages.StringField(12)
  network = _messages.StringField(13)
  region = _messages.StringField(14)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)


class RouterAdvertisedIpRange(_messages.Message):
  r"""Description-tagged IP ranges for the router to advertise.

  Fields:
    description: User-specified description for the IP range.
    range: The IP range to advertise. The value must be a CIDR-formatted
      string.
  """

  description = _messages.StringField(1)
  range = _messages.StringField(2)


class RouterAggregatedList(_messages.Message):
  r"""Contains a list of routers.

  Messages:
    ItemsValue: A list of Router resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Router resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of Router resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of routers.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A RoutersScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('RoutersScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#routerAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class RouterBgp(_messages.Message):
  r"""A RouterBgp object.

  Enums:
    AdvertiseModeValueValuesEnum: User-specified flag to indicate which mode
      to use for advertisement. The options are DEFAULT or CUSTOM.
    AdvertisedGroupsValueListEntryValuesEnum:

  Fields:
    advertiseMode: User-specified flag to indicate which mode to use for
      advertisement. The options are DEFAULT or CUSTOM.
    advertisedGroups: User-specified list of prefix groups to advertise in
      custom mode. This field can only be populated if advertise_mode is
      CUSTOM and is advertised to all peers of the router. These groups will
      be advertised in addition to any specified prefixes. Leave this field
      blank to advertise no custom groups.
    advertisedIpRanges: User-specified list of individual IP ranges to
      advertise in custom mode. This field can only be populated if
      advertise_mode is CUSTOM and is advertised to all peers of the router.
      These IP ranges will be advertised in addition to any specified groups.
      Leave this field blank to advertise no custom IP ranges.
    asn: Local BGP Autonomous System Number (ASN). Must be an RFC6996 private
      ASN, either 16-bit or 32-bit. The value will be fixed for this router
      resource. All VPN tunnels that link to this router will have the same
      local ASN.
    identifierRange: Explicitly specifies a range of valid BGP Identifiers for
      this Router. It is provided as a link-local IPv4 range (from
      169.254.0.0/16), of size at least /30, even if the BGP sessions are over
      IPv6. It must not overlap with any IPv4 BGP session ranges. Other
      vendors commonly call this "router ID".
    keepaliveInterval: The interval in seconds between BGP keepalive messages
      that are sent to the peer. Hold time is three times the interval at
      which keepalive messages are sent, and the hold time is the maximum
      number of seconds allowed to elapse between successive keepalive
      messages that BGP receives from a peer. BGP will use the smaller of
      either the local hold time value or the peer's hold time value as the
      hold time for the BGP connection between the two peers. If set, this
      value must be between 20 and 60. The default is 20.
  """

  class AdvertiseModeValueValuesEnum(_messages.Enum):
    r"""User-specified flag to indicate which mode to use for advertisement.
    The options are DEFAULT or CUSTOM.

    Values:
      CUSTOM: <no description>
      DEFAULT: <no description>
    """
    CUSTOM = 0
    DEFAULT = 1

  class AdvertisedGroupsValueListEntryValuesEnum(_messages.Enum):
    r"""AdvertisedGroupsValueListEntryValuesEnum enum type.

    Values:
      ALL_PEER_VPC_SUBNETS: Advertise peer subnets of the router's VPC.
      ALL_SUBNETS: Advertise all available subnets (including peer VPC
        subnets).
      ALL_VPC_SUBNETS: Advertise the router's own VPC subnets.
    """
    ALL_PEER_VPC_SUBNETS = 0
    ALL_SUBNETS = 1
    ALL_VPC_SUBNETS = 2

  advertiseMode = _messages.EnumField('AdvertiseModeValueValuesEnum', 1)
  advertisedGroups = _messages.EnumField('AdvertisedGroupsValueListEntryValuesEnum', 2, repeated=True)
  advertisedIpRanges = _messages.MessageField('RouterAdvertisedIpRange', 3, repeated=True)
  asn = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  identifierRange = _messages.StringField(5)
  keepaliveInterval = _messages.IntegerField(6, variant=_messages.Variant.UINT32)


class RouterBgpPeer(_messages.Message):
  r"""A RouterBgpPeer object.

  Enums:
    AdvertiseModeValueValuesEnum: User-specified flag to indicate which mode
      to use for advertisement.
    AdvertisedGroupsValueListEntryValuesEnum:
    EnableValueValuesEnum: The status of the BGP peer connection. If set to
      FALSE, any active session with the peer is terminated and all associated
      routing information is removed. If set to TRUE, the peer connection can
      be established with routing information. The default is TRUE.
    ManagementTypeValueValuesEnum: [Output Only] The resource that configures
      and manages this BGP peer. - MANAGED_BY_USER is the default value and
      can be managed by you or other users - MANAGED_BY_ATTACHMENT is a BGP
      peer that is configured and managed by Cloud Interconnect, specifically
      by an InterconnectAttachment of type PARTNER. Google automatically
      creates, updates, and deletes this type of BGP peer when the PARTNER
      InterconnectAttachment is created, updated, or deleted.

  Fields:
    advertiseMode: User-specified flag to indicate which mode to use for
      advertisement.
    advertisedGroups: User-specified list of prefix groups to advertise in
      custom mode, which currently supports the following option: -
      ALL_SUBNETS: Advertises all of the router's own VPC subnets. This
      excludes any routes learned for subnets that use VPC Network Peering.
      Note that this field can only be populated if advertise_mode is CUSTOM
      and overrides the list defined for the router (in the "bgp" message).
      These groups are advertised in addition to any specified prefixes. Leave
      this field blank to advertise no custom groups.
    advertisedIpRanges: User-specified list of individual IP ranges to
      advertise in custom mode. This field can only be populated if
      advertise_mode is CUSTOM and overrides the list defined for the router
      (in the "bgp" message). These IP ranges are advertised in addition to
      any specified groups. Leave this field blank to advertise no custom IP
      ranges.
    advertisedRoutePriority: The priority of routes advertised to this BGP
      peer. Where there is more than one matching route of maximum length, the
      routes with the lowest priority value win.
    bfd: BFD configuration for the BGP peering.
    customLearnedIpRanges: A list of user-defined custom learned route IP
      address ranges for a BGP session.
    customLearnedRoutePriority: The user-defined custom learned route priority
      for a BGP session. This value is applied to all custom learned route
      ranges for the session. You can choose a value from `0` to `65335`. If
      you don't provide a value, Google Cloud assigns a priority of `100` to
      the ranges.
    enable: The status of the BGP peer connection. If set to FALSE, any active
      session with the peer is terminated and all associated routing
      information is removed. If set to TRUE, the peer connection can be
      established with routing information. The default is TRUE.
    enableIpv4: Enable IPv4 traffic over BGP Peer. It is enabled by default if
      the peerIpAddress is version 4.
    enableIpv6: Enable IPv6 traffic over BGP Peer. It is enabled by default if
      the peerIpAddress is version 6.
    exportPolicies: List of export policies applied to this peer, in the order
      they must be evaluated. The name must correspond to an existing policy
      that has ROUTE_POLICY_TYPE_EXPORT type.
    importPolicies: List of import policies applied to this peer, in the order
      they must be evaluated. The name must correspond to an existing policy
      that has ROUTE_POLICY_TYPE_IMPORT type.
    interfaceName: Name of the interface the BGP peer is associated with.
    ipAddress: IP address of the interface inside Google Cloud Platform.
    ipv4NexthopAddress: IPv4 address of the interface inside Google Cloud
      Platform.
    ipv6NexthopAddress: IPv6 address of the interface inside Google Cloud
      Platform.
    managementType: [Output Only] The resource that configures and manages
      this BGP peer. - MANAGED_BY_USER is the default value and can be managed
      by you or other users - MANAGED_BY_ATTACHMENT is a BGP peer that is
      configured and managed by Cloud Interconnect, specifically by an
      InterconnectAttachment of type PARTNER. Google automatically creates,
      updates, and deletes this type of BGP peer when the PARTNER
      InterconnectAttachment is created, updated, or deleted.
    md5AuthenticationKeyName: Present if MD5 authentication is enabled for the
      peering. Must be the name of one of the entries in the
      Router.md5_authentication_keys. The field must comply with RFC1035.
    name: Name of this BGP peer. The name must be 1-63 characters long, and
      comply with RFC1035. Specifically, the name must be 1-63 characters long
      and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    peerAsn: Peer BGP Autonomous System Number (ASN). Each BGP interface may
      use a different value.
    peerIpAddress: IP address of the BGP interface outside Google Cloud
      Platform.
    peerIpv4NexthopAddress: IPv4 address of the BGP interface outside Google
      Cloud Platform.
    peerIpv6NexthopAddress: IPv6 address of the BGP interface outside Google
      Cloud Platform.
    routerApplianceInstance: URI of the VM instance that is used as third-
      party router appliances such as Next Gen Firewalls, Virtual Routers, or
      Router Appliances. The VM instance must be located in zones contained in
      the same region as this Cloud Router. The VM instance is the peer side
      of the BGP session.
  """

  class AdvertiseModeValueValuesEnum(_messages.Enum):
    r"""User-specified flag to indicate which mode to use for advertisement.

    Values:
      CUSTOM: <no description>
      DEFAULT: <no description>
    """
    CUSTOM = 0
    DEFAULT = 1

  class AdvertisedGroupsValueListEntryValuesEnum(_messages.Enum):
    r"""AdvertisedGroupsValueListEntryValuesEnum enum type.

    Values:
      ALL_PEER_VPC_SUBNETS: Advertise peer subnets of the router's VPC.
      ALL_SUBNETS: Advertise all available subnets (including peer VPC
        subnets).
      ALL_VPC_SUBNETS: Advertise the router's own VPC subnets.
    """
    ALL_PEER_VPC_SUBNETS = 0
    ALL_SUBNETS = 1
    ALL_VPC_SUBNETS = 2

  class EnableValueValuesEnum(_messages.Enum):
    r"""The status of the BGP peer connection. If set to FALSE, any active
    session with the peer is terminated and all associated routing information
    is removed. If set to TRUE, the peer connection can be established with
    routing information. The default is TRUE.

    Values:
      FALSE: <no description>
      TRUE: <no description>
    """
    FALSE = 0
    TRUE = 1

  class ManagementTypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The resource that configures and manages this BGP peer.
    - MANAGED_BY_USER is the default value and can be managed by you or other
    users - MANAGED_BY_ATTACHMENT is a BGP peer that is configured and managed
    by Cloud Interconnect, specifically by an InterconnectAttachment of type
    PARTNER. Google automatically creates, updates, and deletes this type of
    BGP peer when the PARTNER InterconnectAttachment is created, updated, or
    deleted.

    Values:
      MANAGED_BY_ATTACHMENT: The BGP peer is automatically created for PARTNER
        type InterconnectAttachment; Google will automatically create/delete
        this BGP peer when the PARTNER InterconnectAttachment is
        created/deleted, and Google will update the ipAddress and
        peerIpAddress when the PARTNER InterconnectAttachment is provisioned.
        This type of BGP peer cannot be created or deleted, but can be
        modified for all fields except for name, ipAddress and peerIpAddress.
      MANAGED_BY_USER: Default value, the BGP peer is manually created and
        managed by user.
    """
    MANAGED_BY_ATTACHMENT = 0
    MANAGED_BY_USER = 1

  advertiseMode = _messages.EnumField('AdvertiseModeValueValuesEnum', 1)
  advertisedGroups = _messages.EnumField('AdvertisedGroupsValueListEntryValuesEnum', 2, repeated=True)
  advertisedIpRanges = _messages.MessageField('RouterAdvertisedIpRange', 3, repeated=True)
  advertisedRoutePriority = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  bfd = _messages.MessageField('RouterBgpPeerBfd', 5)
  customLearnedIpRanges = _messages.MessageField('RouterBgpPeerCustomLearnedIpRange', 6, repeated=True)
  customLearnedRoutePriority = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  enable = _messages.EnumField('EnableValueValuesEnum', 8)
  enableIpv4 = _messages.BooleanField(9)
  enableIpv6 = _messages.BooleanField(10)
  exportPolicies = _messages.StringField(11, repeated=True)
  importPolicies = _messages.StringField(12, repeated=True)
  interfaceName = _messages.StringField(13)
  ipAddress = _messages.StringField(14)
  ipv4NexthopAddress = _messages.StringField(15)
  ipv6NexthopAddress = _messages.StringField(16)
  managementType = _messages.EnumField('ManagementTypeValueValuesEnum', 17)
  md5AuthenticationKeyName = _messages.StringField(18)
  name = _messages.StringField(19)
  peerAsn = _messages.IntegerField(20, variant=_messages.Variant.UINT32)
  peerIpAddress = _messages.StringField(21)
  peerIpv4NexthopAddress = _messages.StringField(22)
  peerIpv6NexthopAddress = _messages.StringField(23)
  routerApplianceInstance = _messages.StringField(24)


class RouterBgpPeerBfd(_messages.Message):
  r"""A RouterBgpPeerBfd object.

  Enums:
    ModeValueValuesEnum: The BFD session initialization mode for this BGP
      peer. If set to ACTIVE, the Cloud Router will initiate the BFD session
      for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
      peer router to initiate the BFD session for this BGP peer. If set to
      DISABLED, BFD is disabled for this BGP peer. The default is PASSIVE.
    PacketModeValueValuesEnum: The BFD packet mode for this BGP peer. If set
      to CONTROL_AND_ECHO, BFD echo mode is enabled for this BGP peer. In this
      mode, if the peer router also has BFD echo mode enabled, BFD echo
      packets will be sent to the other router. If the peer router does not
      have BFD echo mode enabled, only control packets will be sent. If set to
      CONTROL_ONLY, BFD echo mode is disabled for this BGP peer. If this
      router and the peer router have a multihop connection, this should be
      set to CONTROL_ONLY as BFD echo mode is only supported on singlehop
      connections. The default is CONTROL_AND_ECHO.
    SessionInitializationModeValueValuesEnum: The BFD session initialization
      mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate
      the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router
      will wait for the peer router to initiate the BFD session for this BGP
      peer. If set to DISABLED, BFD is disabled for this BGP peer. The default
      is DISABLED.

  Fields:
    minReceiveInterval: The minimum interval, in milliseconds, between BFD
      control packets received from the peer router. The actual value is
      negotiated between the two routers and is equal to the greater of this
      value and the transmit interval of the other router. If set, this value
      must be between 1000 and 30000. The default is 1000.
    minTransmitInterval: The minimum interval, in milliseconds, between BFD
      control packets transmitted to the peer router. The actual value is
      negotiated between the two routers and is equal to the greater of this
      value and the corresponding receive interval of the other router. If
      set, this value must be between 1000 and 30000. The default is 1000.
    mode: The BFD session initialization mode for this BGP peer. If set to
      ACTIVE, the Cloud Router will initiate the BFD session for this BGP
      peer. If set to PASSIVE, the Cloud Router will wait for the peer router
      to initiate the BFD session for this BGP peer. If set to DISABLED, BFD
      is disabled for this BGP peer. The default is PASSIVE.
    multiplier: The number of consecutive BFD packets that must be missed
      before BFD declares that a peer is unavailable. If set, the value must
      be a value between 5 and 16. The default is 5.
    packetMode: The BFD packet mode for this BGP peer. If set to
      CONTROL_AND_ECHO, BFD echo mode is enabled for this BGP peer. In this
      mode, if the peer router also has BFD echo mode enabled, BFD echo
      packets will be sent to the other router. If the peer router does not
      have BFD echo mode enabled, only control packets will be sent. If set to
      CONTROL_ONLY, BFD echo mode is disabled for this BGP peer. If this
      router and the peer router have a multihop connection, this should be
      set to CONTROL_ONLY as BFD echo mode is only supported on singlehop
      connections. The default is CONTROL_AND_ECHO.
    sessionInitializationMode: The BFD session initialization mode for this
      BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD
      session for this BGP peer. If set to PASSIVE, the Cloud Router will wait
      for the peer router to initiate the BFD session for this BGP peer. If
      set to DISABLED, BFD is disabled for this BGP peer. The default is
      DISABLED.
    slowTimerInterval: The minimum interval, in milliseconds, between BFD
      control packets transmitted to and received from the peer router when
      BFD echo mode is enabled on both routers. The actual transmit and
      receive intervals are negotiated between the two routers and are equal
      to the greater of this value and the corresponding interval on the other
      router. If set, this value must be between 1000 and 30000. The default
      is 5000.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""The BFD session initialization mode for this BGP peer. If set to
    ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer.
    If set to PASSIVE, the Cloud Router will wait for the peer router to
    initiate the BFD session for this BGP peer. If set to DISABLED, BFD is
    disabled for this BGP peer. The default is PASSIVE.

    Values:
      ACTIVE: <no description>
      DISABLED: <no description>
      PASSIVE: <no description>
    """
    ACTIVE = 0
    DISABLED = 1
    PASSIVE = 2

  class PacketModeValueValuesEnum(_messages.Enum):
    r"""The BFD packet mode for this BGP peer. If set to CONTROL_AND_ECHO, BFD
    echo mode is enabled for this BGP peer. In this mode, if the peer router
    also has BFD echo mode enabled, BFD echo packets will be sent to the other
    router. If the peer router does not have BFD echo mode enabled, only
    control packets will be sent. If set to CONTROL_ONLY, BFD echo mode is
    disabled for this BGP peer. If this router and the peer router have a
    multihop connection, this should be set to CONTROL_ONLY as BFD echo mode
    is only supported on singlehop connections. The default is
    CONTROL_AND_ECHO.

    Values:
      CONTROL_AND_ECHO: <no description>
      CONTROL_ONLY: <no description>
    """
    CONTROL_AND_ECHO = 0
    CONTROL_ONLY = 1

  class SessionInitializationModeValueValuesEnum(_messages.Enum):
    r"""The BFD session initialization mode for this BGP peer. If set to
    ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer.
    If set to PASSIVE, the Cloud Router will wait for the peer router to
    initiate the BFD session for this BGP peer. If set to DISABLED, BFD is
    disabled for this BGP peer. The default is DISABLED.

    Values:
      ACTIVE: <no description>
      DISABLED: <no description>
      PASSIVE: <no description>
    """
    ACTIVE = 0
    DISABLED = 1
    PASSIVE = 2

  minReceiveInterval = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  minTransmitInterval = _messages.IntegerField(2, variant=_messages.Variant.UINT32)
  mode = _messages.EnumField('ModeValueValuesEnum', 3)
  multiplier = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  packetMode = _messages.EnumField('PacketModeValueValuesEnum', 5)
  sessionInitializationMode = _messages.EnumField('SessionInitializationModeValueValuesEnum', 6)
  slowTimerInterval = _messages.IntegerField(7, variant=_messages.Variant.UINT32)


class RouterBgpPeerCustomLearnedIpRange(_messages.Message):
  r"""A RouterBgpPeerCustomLearnedIpRange object.

  Fields:
    range: The custom learned route IP address range. Must be a valid CIDR-
      formatted prefix. If an IP address is provided without a subnet mask, it
      is interpreted as, for IPv4, a `/32` singular IP address range, and, for
      IPv6, `/128`.
  """

  range = _messages.StringField(1)


class RouterInterface(_messages.Message):
  r"""A RouterInterface object.

  Enums:
    IpVersionValueValuesEnum: IP version of this interface.
    ManagementTypeValueValuesEnum: [Output Only] The resource that configures
      and manages this interface. - MANAGED_BY_USER is the default value and
      can be managed directly by users. - MANAGED_BY_ATTACHMENT is an
      interface that is configured and managed by Cloud Interconnect,
      specifically, by an InterconnectAttachment of type PARTNER. Google
      automatically creates, updates, and deletes this type of interface when
      the PARTNER InterconnectAttachment is created, updated, or deleted.

  Fields:
    ipRange: IP address and range of the interface. - For Internet Protocol
      version 4 (IPv4), the IP range must be in the RFC3927 link-local IP
      address space. The value must be a CIDR-formatted string, for example,
      169.254.0.1/30. Note: Do not truncate the IP address, as it represents
      the IP address of the interface. - For Internet Protocol version 6
      (IPv6), the value must be a unique local address (ULA) range from
      fdff:1::/64 with a mask length of 126 or less. This value should be a
      CIDR-formatted string, for example, fdff:1::1/112. Within the router's
      VPC, this IPv6 prefix will be reserved exclusively for this connection
      and cannot be used for any other purpose.
    ipVersion: IP version of this interface.
    linkedInterconnectAttachment: URI of the linked Interconnect attachment.
      It must be in the same region as the router. Each interface can have one
      linked resource, which can be a VPN tunnel, an Interconnect attachment,
      or a subnetwork.
    linkedVpnTunnel: URI of the linked VPN tunnel, which must be in the same
      region as the router. Each interface can have one linked resource, which
      can be a VPN tunnel, an Interconnect attachment, or a subnetwork.
    managementType: [Output Only] The resource that configures and manages
      this interface. - MANAGED_BY_USER is the default value and can be
      managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that
      is configured and managed by Cloud Interconnect, specifically, by an
      InterconnectAttachment of type PARTNER. Google automatically creates,
      updates, and deletes this type of interface when the PARTNER
      InterconnectAttachment is created, updated, or deleted.
    name: Name of this interface entry. The name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    privateIpAddress: The regional private internal IP address that is used to
      establish BGP sessions to a VM instance acting as a third-party Router
      Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN
      VM.
    redundantInterface: Name of the interface that will be redundant with the
      current interface you are creating. The redundantInterface must belong
      to the same Cloud Router as the interface here. To establish the BGP
      session to a Router Appliance VM, you must create two BGP peers. The two
      BGP peers must be attached to two separate interfaces that are redundant
      with each other. The redundant_interface must be 1-63 characters long,
      and comply with RFC1035. Specifically, the redundant_interface must be
      1-63 characters long and match the regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a
      lowercase letter, and all following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash.
    subnetwork: The URI of the subnetwork resource that this interface belongs
      to, which must be in the same region as the Cloud Router. When you
      establish a BGP session to a VM instance using this interface, the VM
      instance must belong to the same subnetwork as the subnetwork specified
      here.
  """

  class IpVersionValueValuesEnum(_messages.Enum):
    r"""IP version of this interface.

    Values:
      IPV4: <no description>
      IPV6: <no description>
    """
    IPV4 = 0
    IPV6 = 1

  class ManagementTypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The resource that configures and manages this interface.
    - MANAGED_BY_USER is the default value and can be managed directly by
    users. - MANAGED_BY_ATTACHMENT is an interface that is configured and
    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
    of type PARTNER. Google automatically creates, updates, and deletes this
    type of interface when the PARTNER InterconnectAttachment is created,
    updated, or deleted.

    Values:
      MANAGED_BY_ATTACHMENT: The interface is automatically created for
        PARTNER type InterconnectAttachment, Google will automatically
        create/update/delete this interface when the PARTNER
        InterconnectAttachment is created/provisioned/deleted. This type of
        interface cannot be manually managed by user.
      MANAGED_BY_USER: Default value, the interface is manually created and
        managed by user.
    """
    MANAGED_BY_ATTACHMENT = 0
    MANAGED_BY_USER = 1

  ipRange = _messages.StringField(1)
  ipVersion = _messages.EnumField('IpVersionValueValuesEnum', 2)
  linkedInterconnectAttachment = _messages.StringField(3)
  linkedVpnTunnel = _messages.StringField(4)
  managementType = _messages.EnumField('ManagementTypeValueValuesEnum', 5)
  name = _messages.StringField(6)
  privateIpAddress = _messages.StringField(7)
  redundantInterface = _messages.StringField(8)
  subnetwork = _messages.StringField(9)


class RouterList(_messages.Message):
  r"""Contains a list of Router resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Router resources.
    kind: [Output Only] Type of resource. Always compute#router for routers.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Router', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#routerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RouterMd5AuthenticationKey(_messages.Message):
  r"""A RouterMd5AuthenticationKey object.

  Fields:
    key: [Input only] Value of the key. For patch and update calls, it can be
      skipped to copy the value from the previous configuration. This is
      allowed if the key with the same name existed before the operation.
      Maximum length is 80 characters. Can only contain printable ASCII
      characters.
    name: Name used to identify the key. Must be unique within a router. Must
      be referenced by exactly one bgpPeer. Must comply with RFC1035.
  """

  key = _messages.StringField(1)
  name = _messages.StringField(2)


class RouterNat(_messages.Message):
  r"""Represents a Nat resource. It enables the VMs within the specified
  subnetworks to access Internet without external IP addresses. It specifies a
  list of subnetworks (and the ranges within) that want to use NAT. Customers
  can also provide the external IPs that would be used for NAT. GCP would
  auto-allocate ephemeral IPs if no external IPs are provided.

  Enums:
    AutoNetworkTierValueValuesEnum: The network tier to use when automatically
      reserving NAT IP addresses. Must be one of: PREMIUM, STANDARD. If not
      specified, then the current project-level default tier is used.
    EndpointTypesValueListEntryValuesEnum:
    NatIpAllocateOptionValueValuesEnum: Specify the NatIpAllocateOption, which
      can take one of the following values: - MANUAL_ONLY: Uses only Nat IP
      addresses provided by customers. When there are not enough specified Nat
      IPs, the Nat service fails for new VMs. - AUTO_ONLY: Nat IPs are
      allocated by Google Cloud Platform; customers can't specify any Nat IPs.
      When choosing AUTO_ONLY, then nat_ip should be empty.
    SourceSubnetworkIpRangesToNatValueValuesEnum: Specify the Nat option,
      which can take one of the following values: -
      ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork
      are allowed to Nat. - ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the
      primary IP ranges in every Subnetwork are allowed to Nat. -
      LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified
      in the field subnetwork below) The default is
      SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field
      contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should not be any
      other Router.Nat section in any Router for this network in this region.
    SourceSubnetworkIpRangesToNat64ValueValuesEnum: Specify the Nat option for
      NAT64, which can take one of the following values: -
      ALL_IPV6_SUBNETWORKS: All of the IP ranges in every Subnetwork are
      allowed to Nat. - LIST_OF_IPV6_SUBNETWORKS: A list of Subnetworks are
      allowed to Nat (specified in the field nat64_subnetwork below) The
      default is NAT64_OPTION_UNSPECIFIED. Note that if this field contains
      NAT64_ALL_V6_SUBNETWORKS no other Router.Nat section in this region can
      also enable NAT64 for any Subnetworks in this network. Other Router.Nat
      sections can still be present to enable NAT44 only.
    TypeValueValuesEnum: Indicates whether this NAT is used for public or
      private IP translation. If unspecified, it defaults to PUBLIC.

  Fields:
    autoNetworkTier: The network tier to use when automatically reserving NAT
      IP addresses. Must be one of: PREMIUM, STANDARD. If not specified, then
      the current project-level default tier is used.
    drainNatIps: A list of URLs of the IP resources to be drained. These IPs
      must be valid static external IPs that have been assigned to the NAT.
      These IPs should be used for updating/patching a NAT only.
    enableDynamicPortAllocation: Enable Dynamic Port Allocation. If not
      specified, it is disabled by default. If set to true, - Dynamic Port
      Allocation will be enabled on this NAT config. -
      enableEndpointIndependentMapping cannot be set to true. - If minPorts is
      set, minPortsPerVm must be set to a power of two greater than or equal
      to 32. If minPortsPerVm is not set, a minimum of 32 ports will be
      allocated to a VM from this NAT config.
    enableEndpointIndependentMapping: A boolean attribute.
    endpointTypes: List of NAT-ted endpoint types supported by the Nat
      Gateway. If the list is empty, then it will be equivalent to include
      ENDPOINT_TYPE_VM
    icmpIdleTimeoutSec: Timeout (in seconds) for ICMP connections. Defaults to
      30s if not set.
    logConfig: Configure logging on this NAT.
    maxPortsPerVm: Maximum number of ports allocated to a VM from this NAT
      config when Dynamic Port Allocation is enabled. If Dynamic Port
      Allocation is not enabled, this field has no effect. If Dynamic Port
      Allocation is enabled, and this field is set, it must be set to a power
      of two greater than minPortsPerVm, or 64 if minPortsPerVm is not set. If
      Dynamic Port Allocation is enabled and this field is not set, a maximum
      of 65536 ports will be allocated to a VM from this NAT config.
    minPortsPerVm: Minimum number of ports allocated to a VM from this NAT
      config. If not set, a default number of ports is allocated to a VM. This
      is rounded up to the nearest power of 2. For example, if the value of
      this field is 50, at least 64 ports are allocated to a VM.
    name: Unique name of this Nat service. The name must be 1-63 characters
      long and comply with RFC1035.
    nat64Subnetworks: List of Subnetwork resources whose traffic should be
      translated by NAT64 Gateway. It is used only when
      LIST_OF_IPV6_SUBNETWORKS is selected for the
      SubnetworkIpRangeToNat64Option above.
    natIpAllocateOption: Specify the NatIpAllocateOption, which can take one
      of the following values: - MANUAL_ONLY: Uses only Nat IP addresses
      provided by customers. When there are not enough specified Nat IPs, the
      Nat service fails for new VMs. - AUTO_ONLY: Nat IPs are allocated by
      Google Cloud Platform; customers can't specify any Nat IPs. When
      choosing AUTO_ONLY, then nat_ip should be empty.
    natIps: A list of URLs of the IP resources used for this Nat service.
      These IP addresses must be valid static external IP addresses assigned
      to the project.
    rules: A list of rules associated with this NAT.
    sourceSubnetworkIpRangesToNat: Specify the Nat option, which can take one
      of the following values: - ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP
      ranges in every Subnetwork are allowed to Nat. -
      ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in
      every Subnetwork are allowed to Nat. - LIST_OF_SUBNETWORKS: A list of
      Subnetworks are allowed to Nat (specified in the field subnetwork below)
      The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that
      if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should
      not be any other Router.Nat section in any Router for this network in
      this region.
    sourceSubnetworkIpRangesToNat64: Specify the Nat option for NAT64, which
      can take one of the following values: - ALL_IPV6_SUBNETWORKS: All of the
      IP ranges in every Subnetwork are allowed to Nat. -
      LIST_OF_IPV6_SUBNETWORKS: A list of Subnetworks are allowed to Nat
      (specified in the field nat64_subnetwork below) The default is
      NAT64_OPTION_UNSPECIFIED. Note that if this field contains
      NAT64_ALL_V6_SUBNETWORKS no other Router.Nat section in this region can
      also enable NAT64 for any Subnetworks in this network. Other Router.Nat
      sections can still be present to enable NAT44 only.
    subnetworks: A list of Subnetwork resources whose traffic should be
      translated by NAT Gateway. It is used only when LIST_OF_SUBNETWORKS is
      selected for the SubnetworkIpRangeToNatOption above.
    tcpEstablishedIdleTimeoutSec: Timeout (in seconds) for TCP established
      connections. Defaults to 1200s if not set.
    tcpTimeWaitTimeoutSec: Timeout (in seconds) for TCP connections that are
      in TIME_WAIT state. Defaults to 120s if not set.
    tcpTransitoryIdleTimeoutSec: Timeout (in seconds) for TCP transitory
      connections. Defaults to 30s if not set.
    type: Indicates whether this NAT is used for public or private IP
      translation. If unspecified, it defaults to PUBLIC.
    udpIdleTimeoutSec: Timeout (in seconds) for UDP connections. Defaults to
      30s if not set.
  """

  class AutoNetworkTierValueValuesEnum(_messages.Enum):
    r"""The network tier to use when automatically reserving NAT IP addresses.
    Must be one of: PREMIUM, STANDARD. If not specified, then the current
    project-level default tier is used.

    Values:
      FIXED_STANDARD: Public internet quality with fixed bandwidth.
      PREMIUM: High quality, Google-grade network tier, support for all
        networking products.
      SELECT: Price competitive network tier, support for all networking
        products.
      STANDARD: Public internet quality, only limited support for other
        networking products.
      STANDARD_OVERRIDES_FIXED_STANDARD: (Output only) Temporary tier for
        FIXED_STANDARD when fixed standard tier is expired or not configured.
    """
    FIXED_STANDARD = 0
    PREMIUM = 1
    SELECT = 2
    STANDARD = 3
    STANDARD_OVERRIDES_FIXED_STANDARD = 4

  class EndpointTypesValueListEntryValuesEnum(_messages.Enum):
    r"""EndpointTypesValueListEntryValuesEnum enum type.

    Values:
      ENDPOINT_TYPE_MANAGED_PROXY_LB: This is used for regional Application
        Load Balancers (internal and external) and regional proxy Network Load
        Balancers (internal and external) endpoints.
      ENDPOINT_TYPE_SWG: This is used for Secure Web Gateway endpoints.
      ENDPOINT_TYPE_VM: This is the default.
    """
    ENDPOINT_TYPE_MANAGED_PROXY_LB = 0
    ENDPOINT_TYPE_SWG = 1
    ENDPOINT_TYPE_VM = 2

  class NatIpAllocateOptionValueValuesEnum(_messages.Enum):
    r"""Specify the NatIpAllocateOption, which can take one of the following
    values: - MANUAL_ONLY: Uses only Nat IP addresses provided by customers.
    When there are not enough specified Nat IPs, the Nat service fails for new
    VMs. - AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform;
    customers can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip
    should be empty.

    Values:
      AUTO_ONLY: Nat IPs are allocated by GCP; customers can not specify any
        Nat IPs.
      MANUAL_ONLY: Only use Nat IPs provided by customers. When specified Nat
        IPs are not enough then the Nat service fails for new VMs.
    """
    AUTO_ONLY = 0
    MANUAL_ONLY = 1

  class SourceSubnetworkIpRangesToNat64ValueValuesEnum(_messages.Enum):
    r"""Specify the Nat option for NAT64, which can take one of the following
    values: - ALL_IPV6_SUBNETWORKS: All of the IP ranges in every Subnetwork
    are allowed to Nat. - LIST_OF_IPV6_SUBNETWORKS: A list of Subnetworks are
    allowed to Nat (specified in the field nat64_subnetwork below) The default
    is NAT64_OPTION_UNSPECIFIED. Note that if this field contains
    NAT64_ALL_V6_SUBNETWORKS no other Router.Nat section in this region can
    also enable NAT64 for any Subnetworks in this network. Other Router.Nat
    sections can still be present to enable NAT44 only.

    Values:
      ALL_IPV6_SUBNETWORKS: NAT64 is enabled for all the IPv6 subnet ranges.
        In dual stack subnets, NAT64 will only be enabled for IPv6-only VMs.
      LIST_OF_IPV6_SUBNETWORKS: NAT64 is enabled for a list of IPv6 subnet
        ranges. In dual stack subnets, NAT64 will only be enabled for
        IPv6-only VMs. If this option is used, the nat64_subnetworks field
        must be specified.
    """
    ALL_IPV6_SUBNETWORKS = 0
    LIST_OF_IPV6_SUBNETWORKS = 1

  class SourceSubnetworkIpRangesToNatValueValuesEnum(_messages.Enum):
    r"""Specify the Nat option, which can take one of the following values: -
    ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork
    are allowed to Nat. - ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the
    primary IP ranges in every Subnetwork are allowed to Nat. -
    LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified
    in the field subnetwork below) The default is
    SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field
    contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should not be any other
    Router.Nat section in any Router for this network in this region.

    Values:
      ALL_SUBNETWORKS_ALL_IP_RANGES: All the IP ranges in every Subnetwork are
        allowed to Nat.
      ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All the primary IP ranges in
        every Subnetwork are allowed to Nat.
      LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified
        in the field subnetwork below)
    """
    ALL_SUBNETWORKS_ALL_IP_RANGES = 0
    ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES = 1
    LIST_OF_SUBNETWORKS = 2

  class TypeValueValuesEnum(_messages.Enum):
    r"""Indicates whether this NAT is used for public or private IP
    translation. If unspecified, it defaults to PUBLIC.

    Values:
      PRIVATE: NAT used for private IP translation.
      PUBLIC: NAT used for public IP translation. This is the default.
    """
    PRIVATE = 0
    PUBLIC = 1

  autoNetworkTier = _messages.EnumField('AutoNetworkTierValueValuesEnum', 1)
  drainNatIps = _messages.StringField(2, repeated=True)
  enableDynamicPortAllocation = _messages.BooleanField(3)
  enableEndpointIndependentMapping = _messages.BooleanField(4)
  endpointTypes = _messages.EnumField('EndpointTypesValueListEntryValuesEnum', 5, repeated=True)
  icmpIdleTimeoutSec = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  logConfig = _messages.MessageField('RouterNatLogConfig', 7)
  maxPortsPerVm = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  minPortsPerVm = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  name = _messages.StringField(10)
  nat64Subnetworks = _messages.MessageField('RouterNatSubnetworkToNat64', 11, repeated=True)
  natIpAllocateOption = _messages.EnumField('NatIpAllocateOptionValueValuesEnum', 12)
  natIps = _messages.StringField(13, repeated=True)
  rules = _messages.MessageField('RouterNatRule', 14, repeated=True)
  sourceSubnetworkIpRangesToNat = _messages.EnumField('SourceSubnetworkIpRangesToNatValueValuesEnum', 15)
  sourceSubnetworkIpRangesToNat64 = _messages.EnumField('SourceSubnetworkIpRangesToNat64ValueValuesEnum', 16)
  subnetworks = _messages.MessageField('RouterNatSubnetworkToNat', 17, repeated=True)
  tcpEstablishedIdleTimeoutSec = _messages.IntegerField(18, variant=_messages.Variant.INT32)
  tcpTimeWaitTimeoutSec = _messages.IntegerField(19, variant=_messages.Variant.INT32)
  tcpTransitoryIdleTimeoutSec = _messages.IntegerField(20, variant=_messages.Variant.INT32)
  type = _messages.EnumField('TypeValueValuesEnum', 21)
  udpIdleTimeoutSec = _messages.IntegerField(22, variant=_messages.Variant.INT32)


class RouterNatLogConfig(_messages.Message):
  r"""Configuration of logging on a NAT.

  Enums:
    FilterValueValuesEnum: Specify the desired filtering of logs on this NAT.
      If unspecified, logs are exported for all connections handled by this
      NAT. This option can take one of the following values: - ERRORS_ONLY:
      Export logs only for connection failures. - TRANSLATIONS_ONLY: Export
      logs only for successful connections. - ALL: Export logs for all
      connections, successful and unsuccessful.

  Fields:
    enable: Indicates whether or not to export logs. This is false by default.
    filter: Specify the desired filtering of logs on this NAT. If unspecified,
      logs are exported for all connections handled by this NAT. This option
      can take one of the following values: - ERRORS_ONLY: Export logs only
      for connection failures. - TRANSLATIONS_ONLY: Export logs only for
      successful connections. - ALL: Export logs for all connections,
      successful and unsuccessful.
  """

  class FilterValueValuesEnum(_messages.Enum):
    r"""Specify the desired filtering of logs on this NAT. If unspecified,
    logs are exported for all connections handled by this NAT. This option can
    take one of the following values: - ERRORS_ONLY: Export logs only for
    connection failures. - TRANSLATIONS_ONLY: Export logs only for successful
    connections. - ALL: Export logs for all connections, successful and
    unsuccessful.

    Values:
      ALL: Export logs for all (successful and unsuccessful) connections.
      ERRORS_ONLY: Export logs for connection failures only.
      TRANSLATIONS_ONLY: Export logs for successful connections only.
    """
    ALL = 0
    ERRORS_ONLY = 1
    TRANSLATIONS_ONLY = 2

  enable = _messages.BooleanField(1)
  filter = _messages.EnumField('FilterValueValuesEnum', 2)


class RouterNatRule(_messages.Message):
  r"""A RouterNatRule object.

  Fields:
    action: The action to be enforced for traffic that matches this rule.
    description: An optional description of this rule.
    match: CEL expression that specifies the match condition that egress
      traffic from a VM is evaluated against. If it evaluates to true, the
      corresponding `action` is enforced. The following examples are valid
      match expressions for public NAT: `inIpRange(destination.ip,
      '1.1.0.0/16') || inIpRange(destination.ip, '2.2.0.0/16')`
      `destination.ip == '1.1.0.1' || destination.ip == '8.8.8.8'` The
      following example is a valid match expression for private NAT:
      `nexthop.hub == '//networkconnectivity.googleapis.com/projects/my-
      project/locations/global/hubs/hub-1'`
    ruleNumber: An integer uniquely identifying a rule in the list. The rule
      number must be a positive value between 0 and 65000, and must be unique
      among rules within a NAT.
  """

  action = _messages.MessageField('RouterNatRuleAction', 1)
  description = _messages.StringField(2)
  match = _messages.StringField(3)
  ruleNumber = _messages.IntegerField(4, variant=_messages.Variant.UINT32)


class RouterNatRuleAction(_messages.Message):
  r"""A RouterNatRuleAction object.

  Fields:
    sourceNatActiveIps: A list of URLs of the IP resources used for this NAT
      rule. These IP addresses must be valid static external IP addresses
      assigned to the project. This field is used for public NAT.
    sourceNatActiveRanges: A list of URLs of the subnetworks used as source
      ranges for this NAT Rule. These subnetworks must have purpose set to
      PRIVATE_NAT. This field is used for private NAT.
    sourceNatDrainIps: A list of URLs of the IP resources to be drained. These
      IPs must be valid static external IPs that have been assigned to the
      NAT. These IPs should be used for updating/patching a NAT rule only.
      This field is used for public NAT.
    sourceNatDrainRanges: A list of URLs of subnetworks representing source
      ranges to be drained. This is only supported on patch/update, and these
      subnetworks must have previously been used as active ranges in this NAT
      Rule. This field is used for private NAT.
  """

  sourceNatActiveIps = _messages.StringField(1, repeated=True)
  sourceNatActiveRanges = _messages.StringField(2, repeated=True)
  sourceNatDrainIps = _messages.StringField(3, repeated=True)
  sourceNatDrainRanges = _messages.StringField(4, repeated=True)


class RouterNatSubnetworkToNat(_messages.Message):
  r"""Defines the IP ranges that want to use NAT for a subnetwork.

  Enums:
    SourceIpRangesToNatValueListEntryValuesEnum:

  Fields:
    name: URL for the subnetwork resource that will use NAT.
    secondaryIpRangeNames: A list of the secondary ranges of the Subnetwork
      that are allowed to use NAT. This can be populated only if
      "LIST_OF_SECONDARY_IP_RANGES" is one of the values in
      source_ip_ranges_to_nat.
    sourceIpRangesToNat: Specify the options for NAT ranges in the Subnetwork.
      All options of a single value are valid except
      NAT_IP_RANGE_OPTION_UNSPECIFIED. The only valid option with multiple
      values is: ["PRIMARY_IP_RANGE", "LIST_OF_SECONDARY_IP_RANGES"] Default:
      [ALL_IP_RANGES]
  """

  class SourceIpRangesToNatValueListEntryValuesEnum(_messages.Enum):
    r"""SourceIpRangesToNatValueListEntryValuesEnum enum type.

    Values:
      ALL_IP_RANGES: The primary and all the secondary ranges are allowed to
        Nat.
      LIST_OF_SECONDARY_IP_RANGES: A list of secondary ranges are allowed to
        Nat.
      PRIMARY_IP_RANGE: The primary range is allowed to Nat.
    """
    ALL_IP_RANGES = 0
    LIST_OF_SECONDARY_IP_RANGES = 1
    PRIMARY_IP_RANGE = 2

  name = _messages.StringField(1)
  secondaryIpRangeNames = _messages.StringField(2, repeated=True)
  sourceIpRangesToNat = _messages.EnumField('SourceIpRangesToNatValueListEntryValuesEnum', 3, repeated=True)


class RouterNatSubnetworkToNat64(_messages.Message):
  r"""Specifies a subnetwork to enable NAT64.

  Fields:
    name: URL for the subnetwork resource that will use NAT64.
  """

  name = _messages.StringField(1)


class RouterStatus(_messages.Message):
  r"""A RouterStatus object.

  Fields:
    bestRoutes: A list of the best dynamic routes for this Cloud Router's
      Virtual Private Cloud (VPC) network in the same region as this Cloud
      Router. Lists all of the best routes per prefix that are programmed into
      this region's VPC data plane. When global dynamic routing mode is turned
      on in the VPC network, this list can include cross-region dynamic routes
      from Cloud Routers in other regions.
    bestRoutesForRouter: A list of the best BGP routes learned by this Cloud
      Router. It is possible that routes listed might not be programmed into
      the data plane, if the Google Cloud control plane finds a more optimal
      route for a prefix than a route learned by this Cloud Router.
    bgpPeerStatus: A RouterStatusBgpPeerStatus attribute.
    natStatus: A RouterStatusNatStatus attribute.
    nccGateway: URI of the ncc_gateway to which this router associated.
    network: URI of the network to which this router belongs.
  """

  bestRoutes = _messages.MessageField('Route', 1, repeated=True)
  bestRoutesForRouter = _messages.MessageField('Route', 2, repeated=True)
  bgpPeerStatus = _messages.MessageField('RouterStatusBgpPeerStatus', 3, repeated=True)
  natStatus = _messages.MessageField('RouterStatusNatStatus', 4, repeated=True)
  nccGateway = _messages.StringField(5)
  network = _messages.StringField(6)


class RouterStatusBgpPeerStatus(_messages.Message):
  r"""A RouterStatusBgpPeerStatus object.

  Enums:
    StatusValueValuesEnum: Status of the BGP peer: {UP, DOWN}
    StatusReasonValueValuesEnum: Indicates why particular status was returned.

  Fields:
    advertisedRoutes: Routes that were advertised to the remote BGP peer
    bfdStatus: A BfdStatus attribute.
    enableIpv4: Enable IPv4 traffic over BGP Peer. It is enabled by default if
      the peerIpAddress is version 4.
    enableIpv6: Enable IPv6 traffic over BGP Peer. It is enabled by default if
      the peerIpAddress is version 6.
    ipAddress: IP address of the local BGP interface.
    ipv4NexthopAddress: IPv4 address of the local BGP interface.
    ipv6NexthopAddress: IPv6 address of the local BGP interface.
    linkedVpnTunnel: URL of the VPN tunnel that this BGP peer controls.
    md5AuthEnabled: Informs whether MD5 authentication is enabled on this BGP
      peer.
    name: Name of this BGP peer. Unique within the Routers resource.
    numLearnedRoutes: Number of routes learned from the remote BGP Peer.
    peerIpAddress: IP address of the remote BGP interface.
    peerIpv4NexthopAddress: IPv4 address of the remote BGP interface.
    peerIpv6NexthopAddress: IPv6 address of the remote BGP interface.
    routerApplianceInstance: [Output only] URI of the VM instance that is used
      as third-party router appliances such as Next Gen Firewalls, Virtual
      Routers, or Router Appliances. The VM instance is the peer side of the
      BGP session.
    state: The state of the BGP session. For a list of possible values for
      this field, see BGP session states.
    status: Status of the BGP peer: {UP, DOWN}
    statusReason: Indicates why particular status was returned.
    uptime: Time this session has been up. Format: 14 years, 51 weeks, 6 days,
      23 hours, 59 minutes, 59 seconds
    uptimeSeconds: Time this session has been up, in seconds. Format: 145
  """

  class StatusReasonValueValuesEnum(_messages.Enum):
    r"""Indicates why particular status was returned.

    Values:
      IPV4_PEER_ON_IPV6_ONLY_CONNECTION: BGP peer disabled because it requires
        IPv4 but the underlying connection is IPv6-only.
      IPV6_PEER_ON_IPV4_ONLY_CONNECTION: BGP peer disabled because it requires
        IPv6 but the underlying connection is IPv4-only.
      MD5_AUTH_INTERNAL_PROBLEM: Indicates internal problems with
        configuration of MD5 authentication. This particular reason can only
        be returned when md5AuthEnabled is true and status is DOWN.
      STATUS_REASON_UNSPECIFIED: <no description>
    """
    IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 0
    IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 1
    MD5_AUTH_INTERNAL_PROBLEM = 2
    STATUS_REASON_UNSPECIFIED = 3

  class StatusValueValuesEnum(_messages.Enum):
    r"""Status of the BGP peer: {UP, DOWN}

    Values:
      DOWN: <no description>
      UNKNOWN: <no description>
      UP: <no description>
    """
    DOWN = 0
    UNKNOWN = 1
    UP = 2

  advertisedRoutes = _messages.MessageField('Route', 1, repeated=True)
  bfdStatus = _messages.MessageField('BfdStatus', 2)
  enableIpv4 = _messages.BooleanField(3)
  enableIpv6 = _messages.BooleanField(4)
  ipAddress = _messages.StringField(5)
  ipv4NexthopAddress = _messages.StringField(6)
  ipv6NexthopAddress = _messages.StringField(7)
  linkedVpnTunnel = _messages.StringField(8)
  md5AuthEnabled = _messages.BooleanField(9)
  name = _messages.StringField(10)
  numLearnedRoutes = _messages.IntegerField(11, variant=_messages.Variant.UINT32)
  peerIpAddress = _messages.StringField(12)
  peerIpv4NexthopAddress = _messages.StringField(13)
  peerIpv6NexthopAddress = _messages.StringField(14)
  routerApplianceInstance = _messages.StringField(15)
  state = _messages.StringField(16)
  status = _messages.EnumField('StatusValueValuesEnum', 17)
  statusReason = _messages.EnumField('StatusReasonValueValuesEnum', 18)
  uptime = _messages.StringField(19)
  uptimeSeconds = _messages.StringField(20)


class RouterStatusNatStatus(_messages.Message):
  r"""Status of a NAT contained in this router.

  Fields:
    autoAllocatedNatIps: A list of IPs auto-allocated for NAT. Example:
      ["1.1.1.1", "129.2.16.89"]
    drainAutoAllocatedNatIps: A list of IPs auto-allocated for NAT that are in
      drain mode. Example: ["1.1.1.1", "179.12.26.133"].
    drainUserAllocatedNatIps: A list of IPs user-allocated for NAT that are in
      drain mode. Example: ["1.1.1.1", "179.12.26.133"].
    minExtraNatIpsNeeded: The number of extra IPs to allocate. This will be
      greater than 0 only if user-specified IPs are NOT enough to allow all
      configured VMs to use NAT. This value is meaningful only when auto-
      allocation of NAT IPs is *not* used.
    name: Unique name of this NAT.
    numVmEndpointsWithNatMappings: Number of VM endpoints (i.e., Nics) that
      can use NAT.
    ruleStatus: Status of rules in this NAT.
    userAllocatedNatIpResources: A list of fully qualified URLs of reserved IP
      address resources.
    userAllocatedNatIps: A list of IPs user-allocated for NAT. They will be
      raw IP strings like "179.12.26.133".
  """

  autoAllocatedNatIps = _messages.StringField(1, repeated=True)
  drainAutoAllocatedNatIps = _messages.StringField(2, repeated=True)
  drainUserAllocatedNatIps = _messages.StringField(3, repeated=True)
  minExtraNatIpsNeeded = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  name = _messages.StringField(5)
  numVmEndpointsWithNatMappings = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  ruleStatus = _messages.MessageField('RouterStatusNatStatusNatRuleStatus', 7, repeated=True)
  userAllocatedNatIpResources = _messages.StringField(8, repeated=True)
  userAllocatedNatIps = _messages.StringField(9, repeated=True)


class RouterStatusNatStatusNatRuleStatus(_messages.Message):
  r"""Status of a NAT Rule contained in this NAT.

  Fields:
    activeNatIps: A list of active IPs for NAT. Example: ["1.1.1.1",
      "179.12.26.133"].
    drainNatIps: A list of IPs for NAT that are in drain mode. Example:
      ["1.1.1.1", "179.12.26.133"].
    minExtraIpsNeeded: The number of extra IPs to allocate. This will be
      greater than 0 only if the existing IPs in this NAT Rule are NOT enough
      to allow all configured VMs to use NAT.
    numVmEndpointsWithNatMappings: Number of VM endpoints (i.e., NICs) that
      have NAT Mappings from this NAT Rule.
    ruleNumber: Rule number of the rule.
  """

  activeNatIps = _messages.StringField(1, repeated=True)
  drainNatIps = _messages.StringField(2, repeated=True)
  minExtraIpsNeeded = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  numVmEndpointsWithNatMappings = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  ruleNumber = _messages.IntegerField(5, variant=_messages.Variant.INT32)


class RouterStatusResponse(_messages.Message):
  r"""A RouterStatusResponse object.

  Fields:
    kind: Type of resource.
    result: A RouterStatus attribute.
  """

  kind = _messages.StringField(1, default='compute#routerStatusResponse')
  result = _messages.MessageField('RouterStatus', 2)


class RoutersGetNamedSetResponse(_messages.Message):
  r"""A RoutersGetNamedSetResponse object.

  Fields:
    etag: end_interface: MixerGetResponseWithEtagBuilder
    resource: A NamedSet attribute.
  """

  etag = _messages.StringField(1)
  resource = _messages.MessageField('NamedSet', 2)


class RoutersGetRoutePolicyResponse(_messages.Message):
  r"""A RoutersGetRoutePolicyResponse object.

  Fields:
    etag: end_interface: MixerGetResponseWithEtagBuilder
    resource: A RoutePolicy attribute.
  """

  etag = _messages.StringField(1)
  resource = _messages.MessageField('RoutePolicy', 2)


class RoutersListBgpRoutes(_messages.Message):
  r"""A RoutersListBgpRoutes object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#routersListBgpRoutes
      for lists of bgp routes.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    result: [Output Only] A list of bgp routes.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  kind = _messages.StringField(3, default='compute#routersListBgpRoutes')
  nextPageToken = _messages.StringField(4)
  result = _messages.MessageField('BgpRoute', 5, repeated=True)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class RoutersListNamedSets(_messages.Message):
  r"""A RoutersListNamedSets object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#routersListNamedSets
      for lists of named sets.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    result: [Output Only] A list of named sets.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  kind = _messages.StringField(3, default='compute#routersListNamedSets')
  nextPageToken = _messages.StringField(4)
  result = _messages.MessageField('NamedSet', 5, repeated=True)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class RoutersListRoutePolicies(_messages.Message):
  r"""A RoutersListRoutePolicies object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always
      compute#routersListRoutePolicies for lists of route policies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    result: [Output Only] A list of route policies.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  kind = _messages.StringField(3, default='compute#routersListRoutePolicies')
  nextPageToken = _messages.StringField(4)
  result = _messages.MessageField('RoutePolicy', 5, repeated=True)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class RoutersPreviewResponse(_messages.Message):
  r"""A RoutersPreviewResponse object.

  Fields:
    resource: Preview of given router.
  """

  resource = _messages.MessageField('Router', 1)


class RoutersScopedList(_messages.Message):
  r"""A RoutersScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of routers
      when the list is empty.

  Fields:
    routers: A list of routers contained in this scope.
    warning: Informational warning which replaces the list of routers when the
      list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of routers when the list
    is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  routers = _messages.MessageField('Router', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class SSLHealthCheck(_messages.Message):
  r"""A SSLHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how a port is selected for
      health checking. Can be one of the following values: USE_FIXED_PORT:
      Specifies a port number explicitly using the port field in the health
      check. Supported by backend services for passthrough load balancers and
      backend services for proxy load balancers. Not supported by target
      pools. The health check supports all backends supported by the backend
      service provided the backend can be health checked. For example,
      GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint
      groups, and instance group backends. USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: Provides an indirect method of specifying the health
      check port by referring to the backend service. Only supported by
      backend services for proxy load balancers. Not supported by target
      pools. Not supported by backend services for passthrough load balancers.
      Supports all backends that can be health checked; for example,
      GCE_VM_IP_PORT network endpoint groups and instance group backends. For
      GCE_VM_IP_PORT network endpoint group backends, the health check uses
      the port number specified for each endpoint in the network endpoint
      group. For instance group backends, the health check uses the port
      number determined by looking up the backend service's named port in the
      instance group's list of named ports.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    port: The TCP port number to which the health check prober sends packets.
      The default value is 443. Valid values are 1 through 65535.
    portName: Not supported.
    portSpecification: Specifies how a port is selected for health checking.
      Can be one of the following values: USE_FIXED_PORT: Specifies a port
      number explicitly using the port field in the health check. Supported by
      backend services for passthrough load balancers and backend services for
      proxy load balancers. Not supported by target pools. The health check
      supports all backends supported by the backend service provided the
      backend can be health checked. For example, GCE_VM_IP network endpoint
      groups, GCE_VM_IP_PORT network endpoint groups, and instance group
      backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an
      indirect method of specifying the health check port by referring to the
      backend service. Only supported by backend services for proxy load
      balancers. Not supported by target pools. Not supported by backend
      services for passthrough load balancers. Supports all backends that can
      be health checked; for example, GCE_VM_IP_PORT network endpoint groups
      and instance group backends. For GCE_VM_IP_PORT network endpoint group
      backends, the health check uses the port number specified for each
      endpoint in the network endpoint group. For instance group backends, the
      health check uses the port number determined by looking up the backend
      service's named port in the instance group's list of named ports.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    request: Instructs the health check prober to send this exact ASCII
      string, up to 1024 bytes in length, after establishing the TCP
      connection and SSL handshake.
    response: Creates a content-based SSL health check. In addition to
      establishing a TCP connection and the TLS handshake, you can configure
      the health check to pass only when the backend sends this exact response
      ASCII string, up to 1024 bytes in length. For details, see:
      https://cloud.google.com/load-balancing/docs/health-check-
      concepts#criteria-protocol-ssl-tcp
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how a port is selected for health checking. Can be one of
    the following values: USE_FIXED_PORT: Specifies a port number explicitly
    using the port field in the health check. Supported by backend services
    for passthrough load balancers and backend services for proxy load
    balancers. Not supported by target pools. The health check supports all
    backends supported by the backend service provided the backend can be
    health checked. For example, GCE_VM_IP network endpoint groups,
    GCE_VM_IP_PORT network endpoint groups, and instance group backends.
    USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect
    method of specifying the health check port by referring to the backend
    service. Only supported by backend services for proxy load balancers. Not
    supported by target pools. Not supported by backend services for
    passthrough load balancers. Supports all backends that can be health
    checked; for example, GCE_VM_IP_PORT network endpoint groups and instance
    group backends. For GCE_VM_IP_PORT network endpoint group backends, the
    health check uses the port number specified for each endpoint in the
    network endpoint group. For instance group backends, the health check uses
    the port number determined by looking up the backend service's named port
    in the instance group's list of named ports.

    Values:
      USE_FIXED_PORT: The port number in the health check's port is used for
        health checking. Applies to network endpoint group and instance group
        backends.
      USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: For network endpoint group backends, the health check
        uses the port number specified on each endpoint in the network
        endpoint group. For instance group backends, the health check uses the
        port number specified for the backend service's named port defined in
        the instance group's named ports.
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  port = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  portName = _messages.StringField(2)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 3)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 4)
  request = _messages.StringField(5)
  response = _messages.StringField(6)


class SavedAttachedDisk(_messages.Message):
  r"""DEPRECATED: Please use compute#savedDisk instead. An instance-attached
  disk resource.

  Enums:
    InterfaceValueValuesEnum: Specifies the disk interface to use for
      attaching this disk, which is either SCSI or NVME.
    ModeValueValuesEnum: The mode in which this disk is attached to the source
      instance, either READ_WRITE or READ_ONLY.
    StorageBytesStatusValueValuesEnum: [Output Only] An indicator whether
      storageBytes is in a stable state or it is being adjusted as a result of
      shared storage reallocation. This status can either be UPDATING, meaning
      the size of the snapshot is being updated, or UP_TO_DATE, meaning the
      size of the snapshot is up-to-date.
    TypeValueValuesEnum: Specifies the type of the attached disk, either
      SCRATCH or PERSISTENT.

  Fields:
    autoDelete: Specifies whether the disk will be auto-deleted when the
      instance is deleted (but not when the disk is detached from the
      instance).
    boot: Indicates that this is a boot disk. The virtual machine will use the
      first partition of the disk for its root filesystem.
    deviceName: Specifies the name of the disk attached to the source
      instance.
    diskEncryptionKey: The encryption key for the disk.
    diskSizeGb: The size of the disk in base-2 GB.
    diskType: [Output Only] URL of the disk type resource. For example:
      projects/project /zones/zone/diskTypes/pd-standard or pd-ssd
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read Enabling guest
      operating system features to see a list of available options.
    index: Specifies zero-based index of the disk that is attached to the
      source instance.
    interface: Specifies the disk interface to use for attaching this disk,
      which is either SCSI or NVME.
    kind: [Output Only] Type of the resource. Always compute#attachedDisk for
      attached disks.
    licenses: [Output Only] Any valid publicly visible licenses.
    mode: The mode in which this disk is attached to the source instance,
      either READ_WRITE or READ_ONLY.
    source: Specifies a URL of the disk attached to the source instance.
    storageBytes: [Output Only] A size of the storage used by the disk's
      snapshot by this machine image.
    storageBytesStatus: [Output Only] An indicator whether storageBytes is in
      a stable state or it is being adjusted as a result of shared storage
      reallocation. This status can either be UPDATING, meaning the size of
      the snapshot is being updated, or UP_TO_DATE, meaning the size of the
      snapshot is up-to-date.
    type: Specifies the type of the attached disk, either SCRATCH or
      PERSISTENT.
  """

  class InterfaceValueValuesEnum(_messages.Enum):
    r"""Specifies the disk interface to use for attaching this disk, which is
    either SCSI or NVME.

    Values:
      NVDIMM: <no description>
      NVME: <no description>
      SCSI: <no description>
    """
    NVDIMM = 0
    NVME = 1
    SCSI = 2

  class ModeValueValuesEnum(_messages.Enum):
    r"""The mode in which this disk is attached to the source instance, either
    READ_WRITE or READ_ONLY.

    Values:
      READ_ONLY: Attaches this disk in read-only mode. Multiple virtual
        machines can use a disk in read-only mode at a time.
      READ_WRITE: *[Default]* Attaches this disk in read-write mode. Only one
        virtual machine at a time can be attached to a disk in read-write
        mode.
    """
    READ_ONLY = 0
    READ_WRITE = 1

  class StorageBytesStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] An indicator whether storageBytes is in a stable state
    or it is being adjusted as a result of shared storage reallocation. This
    status can either be UPDATING, meaning the size of the snapshot is being
    updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.

    Values:
      UPDATING: <no description>
      UP_TO_DATE: <no description>
    """
    UPDATING = 0
    UP_TO_DATE = 1

  class TypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of the attached disk, either SCRATCH or PERSISTENT.

    Values:
      PERSISTENT: <no description>
      SCRATCH: <no description>
    """
    PERSISTENT = 0
    SCRATCH = 1

  autoDelete = _messages.BooleanField(1)
  boot = _messages.BooleanField(2)
  deviceName = _messages.StringField(3)
  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 4)
  diskSizeGb = _messages.IntegerField(5)
  diskType = _messages.StringField(6)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 7, repeated=True)
  index = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  interface = _messages.EnumField('InterfaceValueValuesEnum', 9)
  kind = _messages.StringField(10, default='compute#savedAttachedDisk')
  licenses = _messages.StringField(11, repeated=True)
  mode = _messages.EnumField('ModeValueValuesEnum', 12)
  source = _messages.StringField(13)
  storageBytes = _messages.IntegerField(14)
  storageBytesStatus = _messages.EnumField('StorageBytesStatusValueValuesEnum', 15)
  type = _messages.EnumField('TypeValueValuesEnum', 16)


class SavedDisk(_messages.Message):
  r"""An instance-attached disk resource.

  Enums:
    ArchitectureValueValuesEnum: [Output Only] The architecture of the
      attached disk.
    StorageBytesStatusValueValuesEnum: [Output Only] An indicator whether
      storageBytes is in a stable state or it is being adjusted as a result of
      shared storage reallocation. This status can either be UPDATING, meaning
      the size of the snapshot is being updated, or UP_TO_DATE, meaning the
      size of the snapshot is up-to-date.

  Fields:
    architecture: [Output Only] The architecture of the attached disk.
    kind: [Output Only] Type of the resource. Always compute#savedDisk for
      attached disks.
    sourceDisk: Specifies a URL of the disk attached to the source instance.
    storageBytes: [Output Only] Size of the individual disk snapshot used by
      this machine image.
    storageBytesStatus: [Output Only] An indicator whether storageBytes is in
      a stable state or it is being adjusted as a result of shared storage
      reallocation. This status can either be UPDATING, meaning the size of
      the snapshot is being updated, or UP_TO_DATE, meaning the size of the
      snapshot is up-to-date.
  """

  class ArchitectureValueValuesEnum(_messages.Enum):
    r"""[Output Only] The architecture of the attached disk.

    Values:
      ARCHITECTURE_UNSPECIFIED: Default value indicating Architecture is not
        set.
      ARM64: Machines with architecture ARM64
      X86_64: Machines with architecture X86_64
    """
    ARCHITECTURE_UNSPECIFIED = 0
    ARM64 = 1
    X86_64 = 2

  class StorageBytesStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] An indicator whether storageBytes is in a stable state
    or it is being adjusted as a result of shared storage reallocation. This
    status can either be UPDATING, meaning the size of the snapshot is being
    updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.

    Values:
      UPDATING: <no description>
      UP_TO_DATE: <no description>
    """
    UPDATING = 0
    UP_TO_DATE = 1

  architecture = _messages.EnumField('ArchitectureValueValuesEnum', 1)
  kind = _messages.StringField(2, default='compute#savedDisk')
  sourceDisk = _messages.StringField(3)
  storageBytes = _messages.IntegerField(4)
  storageBytesStatus = _messages.EnumField('StorageBytesStatusValueValuesEnum', 5)


class ScalingScheduleStatus(_messages.Message):
  r"""A ScalingScheduleStatus object.

  Enums:
    StateValueValuesEnum: [Output Only] The current state of a scaling
      schedule.

  Fields:
    lastStartTime: [Output Only] The last time the scaling schedule became
      active. Note: this is a timestamp when a schedule actually became
      active, not when it was planned to do so. The timestamp is in RFC3339
      text format.
    nextStartTime: [Output Only] The next time the scaling schedule is to
      become active. Note: this is a timestamp when a schedule is planned to
      run, but the actual time might be slightly different. The timestamp is
      in RFC3339 text format.
    state: [Output Only] The current state of a scaling schedule.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current state of a scaling schedule.

    Values:
      ACTIVE: The current autoscaling recommendation is influenced by this
        scaling schedule.
      DISABLED: This scaling schedule has been disabled by the user.
      OBSOLETE: This scaling schedule will never become active again.
      READY: The current autoscaling recommendation is not influenced by this
        scaling schedule.
    """
    ACTIVE = 0
    DISABLED = 1
    OBSOLETE = 2
    READY = 3

  lastStartTime = _messages.StringField(1)
  nextStartTime = _messages.StringField(2)
  state = _messages.EnumField('StateValueValuesEnum', 3)


class Scheduling(_messages.Message):
  r"""Sets the scheduling options for an Instance.

  Enums:
    InstanceTerminationActionValueValuesEnum: Specifies the termination action
      for the instance.
    MaintenanceIntervalValueValuesEnum: Specifies the frequency of planned
      maintenance events. The accepted values are: `PERIODIC`.
    OnHostMaintenanceValueValuesEnum: Defines the maintenance behavior for
      this instance. For standard instances, the default behavior is MIGRATE.
      For preemptible instances, the default and only possible behavior is
      TERMINATE. For more information, see Set VM host maintenance policy.
    ProvisioningModelValueValuesEnum: Specifies the provisioning model of the
      instance.
    WindowsLicenseOptimizationModeValueValuesEnum: Represents the Windows
      Server License Optimization Mode of the VM. If unspecified, the default
      mode is `OFF`.

  Fields:
    automaticRestart: Specifies whether the instance should be automatically
      restarted if it is terminated by Compute Engine (not terminated by a
      user). You can only set the automatic restart option for standard
      instances. Preemptible instances cannot be automatically restarted. By
      default, this is set to true so an instance is automatically restarted
      if it is terminated by Compute Engine.
    availabilityDomain: Specifies the availability domain to place the
      instance in. The value must be a number between 1 and the number of
      availability domains specified in the spread placement policy attached
      to the instance.
    currentCpus: Current number of vCPUs available for VM. 0 or unset means
      default vCPUs of the current machine type.
    currentMemoryMb: Current amount of memory (in MB) available for VM. 0 or
      unset means default amount of memory of the current machine type.
    gracefulShutdown: A SchedulingGracefulShutdown attribute.
    hostErrorTimeoutSeconds: Specify the time in seconds for host error
      detection, the value must be within the range of [90, 330] with the
      increment of 30, if unset, the default behavior of host error recovery
      will be used.
    instanceTerminationAction: Specifies the termination action for the
      instance.
    latencyTolerant: Defines whether the instance is tolerant of higher cpu
      latency. This can only be set during instance creation, or when the
      instance is not currently running. It must not be set if the preemptible
      option is also set.
    localSsdRecoveryTimeout: Specifies the maximum amount of time a Local Ssd
      Vm should wait while recovery of the Local Ssd state is attempted. Its
      value should be in between 0 and 168 hours with hour granularity and the
      default value being 1 hour.
    locationHint: An opaque location hint used to place the instance close to
      other resources. This field is for use by internal tools that use the
      public API.
    maintenanceFreezeDurationHours: Specifies the number of hours after VM
      instance creation where the VM won't be scheduled for maintenance.
    maintenanceInterval: Specifies the frequency of planned maintenance
      events. The accepted values are: `PERIODIC`.
    maxRunDuration: Specifies the max run duration for the given instance. If
      specified, the instance termination action will be performed at the end
      of the run duration.
    minNodeCpus: The minimum number of virtual CPUs this instance will consume
      when running on a sole-tenant node.
    nodeAffinities: A set of node affinity and anti-affinity configurations.
      Refer to Configuring node affinity for more information. Overrides
      reservationAffinity.
    onHostMaintenance: Defines the maintenance behavior for this instance. For
      standard instances, the default behavior is MIGRATE. For preemptible
      instances, the default and only possible behavior is TERMINATE. For more
      information, see Set VM host maintenance policy.
    onInstanceStopAction: A SchedulingOnInstanceStopAction attribute.
    preemptible: Defines whether the instance is preemptible. This can only be
      set during instance creation or while the instance is stopped and
      therefore, in a `TERMINATED` state. See Instance Life Cycle for more
      information on the possible instance states.
    provisioningModel: Specifies the provisioning model of the instance.
    shutdownTimeout: Timeout between GCE ACPI G2 Soft Off and ACPI G3
      Mechanical Off during shutdown operation of VM. For Standard VMs values
      between 0s and 120s are allowed. For Spot and Preemptible VMs supported
      values are between 0s and 30s. If no value is specified for
      shutdownDuration, default values are 90s for Standard VMs and 30s for
      Spot/Preemptible VMs.
    terminationTime: Specifies the timestamp, when the instance will be
      terminated, in RFC3339 text format. If specified, the instance
      termination action will be performed at the termination time.
    windowsLicenseOptimizationMode: Represents the Windows Server License
      Optimization Mode of the VM. If unspecified, the default mode is `OFF`.
  """

  class InstanceTerminationActionValueValuesEnum(_messages.Enum):
    r"""Specifies the termination action for the instance.

    Values:
      DELETE: Delete the VM.
      INSTANCE_TERMINATION_ACTION_UNSPECIFIED: Default value. This value is
        unused.
      STOP: Stop the VM without storing in-memory content. default action.
    """
    DELETE = 0
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 1
    STOP = 2

  class MaintenanceIntervalValueValuesEnum(_messages.Enum):
    r"""Specifies the frequency of planned maintenance events. The accepted
    values are: `PERIODIC`.

    Values:
      AS_NEEDED: VMs are eligible to receive infrastructure and hypervisor
        updates as they become available. This may result in more maintenance
        operations (live migrations or terminations) for the VM than the
        PERIODIC and RECURRENT options.
      PERIODIC: VMs receive infrastructure and hypervisor updates on a
        periodic basis, minimizing the number of maintenance operations (live
        migrations or terminations) on an individual VM. This may mean a VM
        will take longer to receive an update than if it was configured for
        AS_NEEDED. Security updates will still be applied as soon as they are
        available.
      RECURRENT: VMs receive infrastructure and hypervisor updates on a
        periodic basis, minimizing the number of maintenance operations (live
        migrations or terminations) on an individual VM. This may mean a VM
        will take longer to receive an update than if it was configured for
        AS_NEEDED. Security updates will still be applied as soon as they are
        available. RECURRENT is used for GEN3 and Slice of Hardware VMs.
    """
    AS_NEEDED = 0
    PERIODIC = 1
    RECURRENT = 2

  class OnHostMaintenanceValueValuesEnum(_messages.Enum):
    r"""Defines the maintenance behavior for this instance. For standard
    instances, the default behavior is MIGRATE. For preemptible instances, the
    default and only possible behavior is TERMINATE. For more information, see
    Set VM host maintenance policy.

    Values:
      MIGRATE: *[Default]* Allows Compute Engine to automatically migrate
        instances out of the way of maintenance events.
      TERMINATE: Tells Compute Engine to terminate and (optionally) restart
        the instance away from the maintenance activity. If you would like
        your instance to be restarted, set the automaticRestart flag to true.
        Your instance may be restarted more than once, and it may be restarted
        outside the window of maintenance events.
    """
    MIGRATE = 0
    TERMINATE = 1

  class ProvisioningModelValueValuesEnum(_messages.Enum):
    r"""Specifies the provisioning model of the instance.

    Values:
      FLEX_START: Instance is provisioned using the Flex Start provisioning
        model and has a limited runtime.
      RESERVATION_BOUND: Bound to the lifecycle of the reservation in which it
        is provisioned.
      SPOT: Heavily discounted, no guaranteed runtime.
      STANDARD: Standard provisioning with user controlled runtime, no
        discounts.
    """
    FLEX_START = 0
    RESERVATION_BOUND = 1
    SPOT = 2
    STANDARD = 3

  class WindowsLicenseOptimizationModeValueValuesEnum(_messages.Enum):
    r"""Represents the Windows Server License Optimization Mode of the VM. If
    unspecified, the default mode is `OFF`.

    Values:
      AUTO: "Automatically maximize savings and minimize performance impact by
        matching license optimization mode to current CPU utilization.
      BALANCED: Significant license cost savings via moderate throttles (40%
        baseline, 10 minute maximum burst at full utilization).
      COST_OPTIMIZED: Maximum license cost savings via restrictive throttles
        (20% baseline, 3.75 minute maximum burst at full utilization).
      OFF: No license cost savings with maximum CPU performance.
      PERFORMANCE: Moderate license cost savings via least restrictive
        throttles (60% baseline, 22.5 minute maximum burst at full
        utilization).
      UNSPECIFIED: Unspecified license optimization mode defaults to `OFF`.
    """
    AUTO = 0
    BALANCED = 1
    COST_OPTIMIZED = 2
    OFF = 3
    PERFORMANCE = 4
    UNSPECIFIED = 5

  automaticRestart = _messages.BooleanField(1)
  availabilityDomain = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  currentCpus = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  currentMemoryMb = _messages.IntegerField(4)
  gracefulShutdown = _messages.MessageField('SchedulingGracefulShutdown', 5)
  hostErrorTimeoutSeconds = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  instanceTerminationAction = _messages.EnumField('InstanceTerminationActionValueValuesEnum', 7)
  latencyTolerant = _messages.BooleanField(8)
  localSsdRecoveryTimeout = _messages.MessageField('Duration', 9)
  locationHint = _messages.StringField(10)
  maintenanceFreezeDurationHours = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  maintenanceInterval = _messages.EnumField('MaintenanceIntervalValueValuesEnum', 12)
  maxRunDuration = _messages.MessageField('Duration', 13)
  minNodeCpus = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  nodeAffinities = _messages.MessageField('SchedulingNodeAffinity', 15, repeated=True)
  onHostMaintenance = _messages.EnumField('OnHostMaintenanceValueValuesEnum', 16)
  onInstanceStopAction = _messages.MessageField('SchedulingOnInstanceStopAction', 17)
  preemptible = _messages.BooleanField(18)
  provisioningModel = _messages.EnumField('ProvisioningModelValueValuesEnum', 19)
  shutdownTimeout = _messages.MessageField('Duration', 20)
  terminationTime = _messages.StringField(21)
  windowsLicenseOptimizationMode = _messages.EnumField('WindowsLicenseOptimizationModeValueValuesEnum', 22)


class SchedulingGracefulShutdown(_messages.Message):
  r"""The configuration for gracefully shutting down the instance.

  Fields:
    enabled: Opts-in for graceful shutdown.
    maxDuration: The time allotted for the instance to gracefully shut down.
      If the graceful shutdown isn't complete after this time, then the
      instance transitions to the STOPPING state.
  """

  enabled = _messages.BooleanField(1)
  maxDuration = _messages.MessageField('Duration', 2)


class SchedulingNodeAffinity(_messages.Message):
  r"""Node Affinity: the configuration of desired nodes onto which this
  Instance could be scheduled.

  Enums:
    OperatorValueValuesEnum: Defines the operation of node selection. Valid
      operators are IN for affinity and NOT_IN for anti-affinity.

  Fields:
    key: Corresponds to the label key of Node resource.
    operator: Defines the operation of node selection. Valid operators are IN
      for affinity and NOT_IN for anti-affinity.
    values: Corresponds to the label values of Node resource.
  """

  class OperatorValueValuesEnum(_messages.Enum):
    r"""Defines the operation of node selection. Valid operators are IN for
    affinity and NOT_IN for anti-affinity.

    Values:
      IN: Requires Compute Engine to seek for matched nodes.
      NOT_IN: Requires Compute Engine to avoid certain nodes.
      OPERATOR_UNSPECIFIED: <no description>
    """
    IN = 0
    NOT_IN = 1
    OPERATOR_UNSPECIFIED = 2

  key = _messages.StringField(1)
  operator = _messages.EnumField('OperatorValueValuesEnum', 2)
  values = _messages.StringField(3, repeated=True)


class SchedulingOnInstanceStopAction(_messages.Message):
  r"""Defines the behaviour for instances with the instance_termination_action
  STOP.

  Fields:
    discardLocalSsd: If true, the contents of any attached Local SSD disks
      will be discarded else, the Local SSD data will be preserved when the
      instance is stopped at the end of the run duration/termination time.
  """

  discardLocalSsd = _messages.BooleanField(1)


class Screenshot(_messages.Message):
  r"""An instance's screenshot.

  Fields:
    contents: [Output Only] The Base64-encoded screenshot data.
    kind: [Output Only] Type of the resource. Always compute#screenshot for
      the screenshots.
  """

  contents = _messages.StringField(1)
  kind = _messages.StringField(2, default='compute#screenshot')


class SdsConfig(_messages.Message):
  r"""[Deprecated] The configuration to access the SDS server. The
  configuration to access the SDS server.

  Fields:
    grpcServiceConfig: The configuration to access the SDS server over GRPC.
  """

  grpcServiceConfig = _messages.MessageField('GrpcServiceConfig', 1)


class SecurityPoliciesAggregatedList(_messages.Message):
  r"""A SecurityPoliciesAggregatedList object.

  Messages:
    ItemsValue: A list of SecurityPoliciesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SecurityPoliciesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#securityPolicyAggregatedList for lists of Security Policies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of SecurityPoliciesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of security
        policies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A SecurityPoliciesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SecurityPoliciesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#securityPoliciesAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class SecurityPoliciesListPreconfiguredExpressionSetsResponse(_messages.Message):
  r"""A SecurityPoliciesListPreconfiguredExpressionSetsResponse object.

  Fields:
    preconfiguredExpressionSets: A SecurityPoliciesWafConfig attribute.
  """

  preconfiguredExpressionSets = _messages.MessageField('SecurityPoliciesWafConfig', 1)


class SecurityPoliciesScopedList(_messages.Message):
  r"""A SecurityPoliciesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of security
      policies when the list is empty.

  Fields:
    securityPolicies: A list of SecurityPolicies contained in this scope.
    warning: Informational warning which replaces the list of security
      policies when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of security policies
    when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  securityPolicies = _messages.MessageField('SecurityPolicy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class SecurityPoliciesWafConfig(_messages.Message):
  r"""A SecurityPoliciesWafConfig object.

  Fields:
    wafRules: A PreconfiguredWafSet attribute.
  """

  wafRules = _messages.MessageField('PreconfiguredWafSet', 1)


class SecurityPolicy(_messages.Message):
  r"""Represents a Google Cloud Armor security policy resource. Only external
  backend services that use load balancers can reference a security policy.
  For more information, see Google Cloud Armor security policy overview.

  Enums:
    TypeValueValuesEnum: The type indicates the intended use of the security
      policy. - CLOUD_ARMOR: Cloud Armor backend security policies can be
      configured to filter incoming HTTP requests targeting backend services.
      They filter requests before they hit the origin servers. -
      CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can be configured
      to filter incoming HTTP requests targeting backend services (including
      Cloud CDN-enabled) as well as backend buckets (Cloud Storage). They
      filter requests before the request is served from Google's cache. -
      CLOUD_ARMOR_INTERNAL_SERVICE: Cloud Armor internal service policies can
      be configured to filter HTTP requests targeting services managed by
      Traffic Director in a service mesh. They filter requests before the
      request is served from the application. - CLOUD_ARMOR_NETWORK: Cloud
      Armor network policies can be configured to filter packets targeting
      network load balancing resources such as backend services, target pools,
      target instances, and instances with external IPs. They filter requests
      before the request is served from the application. This field can be set
      only at resource creation time.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    adaptiveProtectionConfig: A SecurityPolicyAdaptiveProtectionConfig
      attribute.
    advancedOptionsConfig: A SecurityPolicyAdvancedOptionsConfig attribute.
    associations: A list of associations that belong to this policy.
    cloudArmorConfig: A SecurityPolicyCloudArmorConfig attribute.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    ddosProtectionConfig: A SecurityPolicyDdosProtectionConfig attribute.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    displayName: User-provided name of the organization security policy. The
      name should be unique in the organization in which the security policy
      is created. This should only be used when SecurityPolicyType is
      FIREWALL. The name must be 1-63 characters long, and comply with
      https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be
      1-63 characters long and match the regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a
      lowercase letter, and all following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash.
    fingerprint: Specifies a fingerprint for this resource, which is
      essentially a hash of the metadata's contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update metadata. You must
      always provide an up-to-date fingerprint hash in order to update or
      change metadata, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make get() request to
      the security policy.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output only] Type of the resource. Always compute#securityPolicyfor
      security policies
    labelFingerprint: A fingerprint for the labels being applied to this
      security policy, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels. To see the latest fingerprint, make get() request to the
      security policy.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    parent: [Output Only] The parent of the security policy.
    recaptchaOptionsConfig: A SecurityPolicyRecaptchaOptionsConfig attribute.
    region: [Output Only] URL of the region where the regional security policy
      resides. This field is not applicable to global security policies.
    ruleTupleCount: [Output Only] Total count of all security policy rule
      tuples. A security policy can not exceed a set number of tuples.
    rules: A list of rules that belong to this policy. There must always be a
      default rule which is a rule with priority 2147483647 and match all
      condition (for the match condition this means match "*" for srcIpRanges
      and for the networkMatch condition every field must be either match "*"
      or not set). If no rules are provided when creating a security policy, a
      default rule with action "allow" will be added.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    shortName: User-provided name of the organization security policy. The
      name should be unique in the organization in which the security policy
      is created. This should only be used when SecurityPolicyType is
      CLOUD_ARMOR. The name must be 1-63 characters long, and comply with
      https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be
      1-63 characters long and match the regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a
      lowercase letter, and all following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash.
    type: The type indicates the intended use of the security policy. -
      CLOUD_ARMOR: Cloud Armor backend security policies can be configured to
      filter incoming HTTP requests targeting backend services. They filter
      requests before they hit the origin servers. - CLOUD_ARMOR_EDGE: Cloud
      Armor edge security policies can be configured to filter incoming HTTP
      requests targeting backend services (including Cloud CDN-enabled) as
      well as backend buckets (Cloud Storage). They filter requests before the
      request is served from Google's cache. - CLOUD_ARMOR_INTERNAL_SERVICE:
      Cloud Armor internal service policies can be configured to filter HTTP
      requests targeting services managed by Traffic Director in a service
      mesh. They filter requests before the request is served from the
      application. - CLOUD_ARMOR_NETWORK: Cloud Armor network policies can be
      configured to filter packets targeting network load balancing resources
      such as backend services, target pools, target instances, and instances
      with external IPs. They filter requests before the request is served
      from the application. This field can be set only at resource creation
      time.
    userDefinedFields: Definitions of user-defined fields for
      CLOUD_ARMOR_NETWORK policies. A user-defined field consists of up to 4
      bytes extracted from a fixed offset in the packet, relative to the IPv4,
      IPv6, TCP, or UDP header, with an optional mask to select certain bits.
      Rules may then specify matching values for these fields. Example:
      userDefinedFields: - name: "ipv4_fragment_offset" base: IPV4 offset: 6
      size: 2 mask: "0x1fff"
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type indicates the intended use of the security policy. -
    CLOUD_ARMOR: Cloud Armor backend security policies can be configured to
    filter incoming HTTP requests targeting backend services. They filter
    requests before they hit the origin servers. - CLOUD_ARMOR_EDGE: Cloud
    Armor edge security policies can be configured to filter incoming HTTP
    requests targeting backend services (including Cloud CDN-enabled) as well
    as backend buckets (Cloud Storage). They filter requests before the
    request is served from Google's cache. - CLOUD_ARMOR_INTERNAL_SERVICE:
    Cloud Armor internal service policies can be configured to filter HTTP
    requests targeting services managed by Traffic Director in a service mesh.
    They filter requests before the request is served from the application. -
    CLOUD_ARMOR_NETWORK: Cloud Armor network policies can be configured to
    filter packets targeting network load balancing resources such as backend
    services, target pools, target instances, and instances with external IPs.
    They filter requests before the request is served from the application.
    This field can be set only at resource creation time.

    Values:
      CLOUD_ARMOR: <no description>
      CLOUD_ARMOR_EDGE: <no description>
      CLOUD_ARMOR_INTERNAL_SERVICE: <no description>
      CLOUD_ARMOR_NETWORK: <no description>
      FIREWALL: <no description>
    """
    CLOUD_ARMOR = 0
    CLOUD_ARMOR_EDGE = 1
    CLOUD_ARMOR_INTERNAL_SERVICE = 2
    CLOUD_ARMOR_NETWORK = 3
    FIREWALL = 4

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  adaptiveProtectionConfig = _messages.MessageField('SecurityPolicyAdaptiveProtectionConfig', 1)
  advancedOptionsConfig = _messages.MessageField('SecurityPolicyAdvancedOptionsConfig', 2)
  associations = _messages.MessageField('SecurityPolicyAssociation', 3, repeated=True)
  cloudArmorConfig = _messages.MessageField('SecurityPolicyCloudArmorConfig', 4)
  creationTimestamp = _messages.StringField(5)
  ddosProtectionConfig = _messages.MessageField('SecurityPolicyDdosProtectionConfig', 6)
  description = _messages.StringField(7)
  displayName = _messages.StringField(8)
  fingerprint = _messages.BytesField(9)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(11, default='compute#securityPolicy')
  labelFingerprint = _messages.BytesField(12)
  labels = _messages.MessageField('LabelsValue', 13)
  name = _messages.StringField(14)
  parent = _messages.StringField(15)
  recaptchaOptionsConfig = _messages.MessageField('SecurityPolicyRecaptchaOptionsConfig', 16)
  region = _messages.StringField(17)
  ruleTupleCount = _messages.IntegerField(18, variant=_messages.Variant.INT32)
  rules = _messages.MessageField('SecurityPolicyRule', 19, repeated=True)
  selfLink = _messages.StringField(20)
  selfLinkWithId = _messages.StringField(21)
  shortName = _messages.StringField(22)
  type = _messages.EnumField('TypeValueValuesEnum', 23)
  userDefinedFields = _messages.MessageField('SecurityPolicyUserDefinedField', 24, repeated=True)


class SecurityPolicyAdaptiveProtectionConfig(_messages.Message):
  r"""Configuration options for Cloud Armor Adaptive Protection (CAAP).

  Fields:
    autoDeployConfig: A SecurityPolicyAdaptiveProtectionConfigAutoDeployConfig
      attribute.
    layer7DdosDefenseConfig: If set to true, enables Cloud Armor Machine
      Learning.
  """

  autoDeployConfig = _messages.MessageField('SecurityPolicyAdaptiveProtectionConfigAutoDeployConfig', 1)
  layer7DdosDefenseConfig = _messages.MessageField('SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig', 2)


class SecurityPolicyAdaptiveProtectionConfigAutoDeployConfig(_messages.Message):
  r"""Configuration options for Adaptive Protection auto-deploy feature.

  Fields:
    confidenceThreshold: A number attribute.
    expirationSec: A integer attribute.
    impactedBaselineThreshold: A number attribute.
    loadThreshold: A number attribute.
  """

  confidenceThreshold = _messages.FloatField(1, variant=_messages.Variant.FLOAT)
  expirationSec = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  impactedBaselineThreshold = _messages.FloatField(3, variant=_messages.Variant.FLOAT)
  loadThreshold = _messages.FloatField(4, variant=_messages.Variant.FLOAT)


class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig(_messages.Message):
  r"""Configuration options for L7 DDoS detection. This field is only
  supported in Global Security Policies of type CLOUD_ARMOR.

  Enums:
    RuleVisibilityValueValuesEnum: Rule visibility can be one of the
      following: STANDARD - opaque rules. (default) PREMIUM - transparent
      rules. This field is only supported in Global Security Policies of type
      CLOUD_ARMOR.

  Fields:
    enable: If set to true, enables CAAP for L7 DDoS detection. This field is
      only supported in Global Security Policies of type CLOUD_ARMOR.
    ruleVisibility: Rule visibility can be one of the following: STANDARD -
      opaque rules. (default) PREMIUM - transparent rules. This field is only
      supported in Global Security Policies of type CLOUD_ARMOR.
    thresholdConfigs: Configuration options for layer7 adaptive protection for
      various customizable thresholds.
  """

  class RuleVisibilityValueValuesEnum(_messages.Enum):
    r"""Rule visibility can be one of the following: STANDARD - opaque rules.
    (default) PREMIUM - transparent rules. This field is only supported in
    Global Security Policies of type CLOUD_ARMOR.

    Values:
      PREMIUM: <no description>
      STANDARD: <no description>
    """
    PREMIUM = 0
    STANDARD = 1

  enable = _messages.BooleanField(1)
  ruleVisibility = _messages.EnumField('RuleVisibilityValueValuesEnum', 2)
  thresholdConfigs = _messages.MessageField('SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig', 3, repeated=True)


class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig(_messages.Message):
  r"""A
  SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
  object.

  Fields:
    autoDeployConfidenceThreshold: A number attribute.
    autoDeployExpirationSec: A integer attribute.
    autoDeployImpactedBaselineThreshold: A number attribute.
    autoDeployLoadThreshold: A number attribute.
    detectionAbsoluteQps: A number attribute.
    detectionLoadThreshold: A number attribute.
    detectionRelativeToBaselineQps: A number attribute.
    name: The name must be 1-63 characters long, and comply with RFC1035. The
      name must be unique within the security policy.
    trafficGranularityConfigs: Configuration options for enabling Adaptive
      Protection to operate on specified granular traffic units.
  """

  autoDeployConfidenceThreshold = _messages.FloatField(1, variant=_messages.Variant.FLOAT)
  autoDeployExpirationSec = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  autoDeployImpactedBaselineThreshold = _messages.FloatField(3, variant=_messages.Variant.FLOAT)
  autoDeployLoadThreshold = _messages.FloatField(4, variant=_messages.Variant.FLOAT)
  detectionAbsoluteQps = _messages.FloatField(5, variant=_messages.Variant.FLOAT)
  detectionLoadThreshold = _messages.FloatField(6, variant=_messages.Variant.FLOAT)
  detectionRelativeToBaselineQps = _messages.FloatField(7, variant=_messages.Variant.FLOAT)
  name = _messages.StringField(8)
  trafficGranularityConfigs = _messages.MessageField('SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig', 9, repeated=True)


class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig(_messages.Message):
  r"""Configurations to specifc granular traffic units processed by Adaptive
  Protection.

  Enums:
    TypeValueValuesEnum: Type of this configuration.

  Fields:
    enableEachUniqueValue: If enabled, traffic matching each unique value for
      the specified type constitutes a separate traffic unit. It can only be
      set to true if `value` is empty.
    type: Type of this configuration.
    value: Requests that match this value constitute a granular traffic unit.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""Type of this configuration.

    Values:
      HTTP_HEADER_HOST: <no description>
      HTTP_PATH: <no description>
      UNSPECIFIED_TYPE: <no description>
    """
    HTTP_HEADER_HOST = 0
    HTTP_PATH = 1
    UNSPECIFIED_TYPE = 2

  enableEachUniqueValue = _messages.BooleanField(1)
  type = _messages.EnumField('TypeValueValuesEnum', 2)
  value = _messages.StringField(3)


class SecurityPolicyAdvancedOptionsConfig(_messages.Message):
  r"""A SecurityPolicyAdvancedOptionsConfig object.

  Enums:
    JsonParsingValueValuesEnum:
    LogLevelValueValuesEnum:

  Fields:
    jsonCustomConfig: Custom configuration to apply the JSON parsing. Only
      applicable when json_parsing is set to STANDARD.
    jsonParsing: A JsonParsingValueValuesEnum attribute.
    logLevel: A LogLevelValueValuesEnum attribute.
    requestBodyInspectionSize: The maximum request size chosen by the customer
      with Waf enabled. Currently only "8KB" and "128KB" are supported. Values
      are case insensitive.
    userIpRequestHeaders: An optional list of case-insensitive request header
      names to use for resolving the callers client IP address.
  """

  class JsonParsingValueValuesEnum(_messages.Enum):
    r"""JsonParsingValueValuesEnum enum type.

    Values:
      DISABLED: <no description>
      STANDARD: <no description>
      STANDARD_WITH_GRAPHQL: <no description>
    """
    DISABLED = 0
    STANDARD = 1
    STANDARD_WITH_GRAPHQL = 2

  class LogLevelValueValuesEnum(_messages.Enum):
    r"""LogLevelValueValuesEnum enum type.

    Values:
      NORMAL: <no description>
      VERBOSE: <no description>
    """
    NORMAL = 0
    VERBOSE = 1

  jsonCustomConfig = _messages.MessageField('SecurityPolicyAdvancedOptionsConfigJsonCustomConfig', 1)
  jsonParsing = _messages.EnumField('JsonParsingValueValuesEnum', 2)
  logLevel = _messages.EnumField('LogLevelValueValuesEnum', 3)
  requestBodyInspectionSize = _messages.StringField(4)
  userIpRequestHeaders = _messages.StringField(5, repeated=True)


class SecurityPolicyAdvancedOptionsConfigJsonCustomConfig(_messages.Message):
  r"""A SecurityPolicyAdvancedOptionsConfigJsonCustomConfig object.

  Fields:
    contentTypes: A list of custom Content-Type header values to apply the
      JSON parsing. As per RFC 1341, a Content-Type header value has the
      following format: Content-Type := type "/" subtype *[";" parameter] When
      configuring a custom Content-Type header value, only the type/subtype
      needs to be specified, and the parameters should be excluded.
  """

  contentTypes = _messages.StringField(1, repeated=True)


class SecurityPolicyAssociation(_messages.Message):
  r"""A SecurityPolicyAssociation object.

  Fields:
    attachmentId: The resource that the security policy is attached to.
    displayName: [Output Only] The display name of the security policy of the
      association.
    excludedFolders: A list of folders to exclude from the security policy.
    excludedProjects: A list of projects to exclude from the security policy.
    name: The name for an association.
    securityPolicyId: [Output Only] The security policy ID of the association.
    shortName: [Output Only] The short name of the security policy of the
      association.
  """

  attachmentId = _messages.StringField(1)
  displayName = _messages.StringField(2)
  excludedFolders = _messages.StringField(3, repeated=True)
  excludedProjects = _messages.StringField(4, repeated=True)
  name = _messages.StringField(5)
  securityPolicyId = _messages.StringField(6)
  shortName = _messages.StringField(7)


class SecurityPolicyCloudArmorConfig(_messages.Message):
  r"""Configuration options for Cloud Armor.

  Fields:
    enableMl: If set to true, enables Cloud Armor Machine Learning.
  """

  enableMl = _messages.BooleanField(1)


class SecurityPolicyDdosProtectionConfig(_messages.Message):
  r"""A SecurityPolicyDdosProtectionConfig object.

  Enums:
    DdosProtectionValueValuesEnum:

  Fields:
    ddosProtection: A DdosProtectionValueValuesEnum attribute.
  """

  class DdosProtectionValueValuesEnum(_messages.Enum):
    r"""DdosProtectionValueValuesEnum enum type.

    Values:
      ADVANCED: <no description>
      ADVANCED_PREVIEW: <no description>
      STANDARD: <no description>
    """
    ADVANCED = 0
    ADVANCED_PREVIEW = 1
    STANDARD = 2

  ddosProtection = _messages.EnumField('DdosProtectionValueValuesEnum', 1)


class SecurityPolicyList(_messages.Message):
  r"""A SecurityPolicyList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SecurityPolicy resources.
    kind: [Output Only] Type of resource. Always compute#securityPolicyList
      for listsof securityPolicies
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('SecurityPolicy', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#securityPolicyList')
  nextPageToken = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class SecurityPolicyRecaptchaOptionsConfig(_messages.Message):
  r"""A SecurityPolicyRecaptchaOptionsConfig object.

  Fields:
    redirectSiteKey: An optional field to supply a reCAPTCHA site key to be
      used for all the rules using the redirect action with the type of
      GOOGLE_RECAPTCHA under the security policy. The specified site key needs
      to be created from the reCAPTCHA API. The user is responsible for the
      validity of the specified site key. If not specified, a Google-managed
      site key is used. This field is only supported in Global Security
      Policies of type CLOUD_ARMOR.
  """

  redirectSiteKey = _messages.StringField(1)


class SecurityPolicyReference(_messages.Message):
  r"""A SecurityPolicyReference object.

  Fields:
    securityPolicy: A string attribute.
  """

  securityPolicy = _messages.StringField(1)


class SecurityPolicyRule(_messages.Message):
  r"""Represents a rule that describes one or more match conditions along with
  the action to be taken when traffic matches this condition (allow or deny).

  Enums:
    DirectionValueValuesEnum: The direction in which this rule applies. This
      field may only be specified when versioned_expr is set to FIREWALL.
    RuleManagedProtectionTierValueValuesEnum: [Output Only] The minimum
      managed protection tier required for this rule. [Deprecated] Use
      requiredManagedProtectionTiers instead.

  Fields:
    action: The Action to perform when the rule is matched. The following are
      the valid actions: - allow: allow access to target. - deny(STATUS): deny
      access to target, returns the HTTP response code specified. Valid values
      for `STATUS` are 403, 404, and 502. - rate_based_ban: limit client
      traffic to the configured threshold and ban the client if the traffic
      exceeds the threshold. Configure parameters for this action in
      RateLimitOptions. Requires rate_limit_options to be set. - redirect:
      redirect to a different target. This can either be an internal reCAPTCHA
      redirect, or an external URL-based redirect via a 302 response.
      Parameters for this action can be configured via redirectOptions. This
      action is only supported in Global Security Policies of type
      CLOUD_ARMOR. - throttle: limit client traffic to the configured
      threshold. Configure parameters for this action in rateLimitOptions.
      Requires rate_limit_options to be set for this.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    direction: The direction in which this rule applies. This field may only
      be specified when versioned_expr is set to FIREWALL.
    enableLogging: Denotes whether to enable logging for a particular rule. If
      logging is enabled, logs will be exported to the configured export
      destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub.
      Note: you cannot enable logging on "goto_next" rules. This field may
      only be specified when the versioned_expr is set to FIREWALL.
    headerAction: Optional, additional actions that are performed on headers.
      This field is only supported in Global Security Policies of type
      CLOUD_ARMOR.
    kind: [Output only] Type of the resource. Always
      compute#securityPolicyRule for security policy rules
    match: A match condition that incoming traffic is evaluated against. If it
      evaluates to true, the corresponding 'action' is enforced.
    networkMatch: A match condition that incoming packets are evaluated
      against for CLOUD_ARMOR_NETWORK security policies. If it matches, the
      corresponding 'action' is enforced. The match criteria for a rule
      consists of built-in match fields (like 'srcIpRanges') and potentially
      multiple user-defined match fields ('userDefinedFields'). Field values
      may be extracted directly from the packet or derived from it (e.g.
      'srcRegionCodes'). Some fields may not be present in every packet (e.g.
      'srcPorts'). A user-defined field is only present if the base header is
      found in the packet and the entire field is in bounds. Each match field
      may specify which values can match it, listing one or more ranges,
      prefixes, or exact values that are considered a match for the field. A
      field value must be present in order to match a specified match field.
      If no match values are specified for a match field, then any field value
      is considered to match it, and it's not required to be present. For
      strings specifying '*' is also equivalent to match all. For a packet to
      match a rule, all specified match fields must match the corresponding
      field values derived from the packet. Example: networkMatch:
      srcIpRanges: - "192.0.2.0/24" - "198.51.100.0/24" userDefinedFields: -
      name: "ipv4_fragment_offset" values: - "1-0x1fff" The above match
      condition matches packets with a source IP in 192.0.2.0/24 or
      198.51.100.0/24 and a user-defined field named "ipv4_fragment_offset"
      with a value between 1 and 0x1fff inclusive.
    preconfiguredWafConfig: Preconfigured WAF configuration to be applied for
      the rule. If the rule does not evaluate preconfigured WAF rules, i.e.,
      if evaluatePreconfiguredWaf() is not used, this field will have no
      effect.
    preview: If set to true, the specified action is not enforced.
    priority: An integer indicating the priority of a rule in the list. The
      priority must be a positive value between 0 and 2147483647. Rules are
      evaluated from highest to lowest priority where 0 is the highest
      priority and 2147483647 is the lowest priority.
    rateLimitOptions: Must be specified if the action is "rate_based_ban" or
      "throttle". Cannot be specified for any other actions.
    redirectOptions: Parameters defining the redirect action. Cannot be
      specified for any other actions. This field is only supported in Global
      Security Policies of type CLOUD_ARMOR.
    redirectTarget: This must be specified for redirect actions. Cannot be
      specified for any other actions.
    ruleManagedProtectionTier: [Output Only] The minimum managed protection
      tier required for this rule. [Deprecated] Use
      requiredManagedProtectionTiers instead.
    ruleNumber: Identifier for the rule. This is only unique within the given
      security policy. This can only be set during rule creation, if rule
      number is not specified it will be generated by the server.
    ruleTupleCount: [Output Only] Calculation of the complexity of a single
      firewall security policy rule.
    targetResources: A list of network resource URLs to which this rule
      applies. This field allows you to control which network's VMs get this
      rule. If this field is left blank, all VMs within the organization will
      receive the rule. This field may only be specified when versioned_expr
      is set to FIREWALL.
    targetServiceAccounts: A list of service accounts indicating the sets of
      instances that are applied with this rule.
  """

  class DirectionValueValuesEnum(_messages.Enum):
    r"""The direction in which this rule applies. This field may only be
    specified when versioned_expr is set to FIREWALL.

    Values:
      EGRESS: <no description>
      INGRESS: <no description>
    """
    EGRESS = 0
    INGRESS = 1

  class RuleManagedProtectionTierValueValuesEnum(_messages.Enum):
    r"""[Output Only] The minimum managed protection tier required for this
    rule. [Deprecated] Use requiredManagedProtectionTiers instead.

    Values:
      CAMP_PLUS_ANNUAL: Plus tier protection annual.
      CAMP_PLUS_PAYGO: Plus tier protection monthly.
      CA_STANDARD: Standard protection.
    """
    CAMP_PLUS_ANNUAL = 0
    CAMP_PLUS_PAYGO = 1
    CA_STANDARD = 2

  action = _messages.StringField(1)
  description = _messages.StringField(2)
  direction = _messages.EnumField('DirectionValueValuesEnum', 3)
  enableLogging = _messages.BooleanField(4)
  headerAction = _messages.MessageField('SecurityPolicyRuleHttpHeaderAction', 5)
  kind = _messages.StringField(6, default='compute#securityPolicyRule')
  match = _messages.MessageField('SecurityPolicyRuleMatcher', 7)
  networkMatch = _messages.MessageField('SecurityPolicyRuleNetworkMatcher', 8)
  preconfiguredWafConfig = _messages.MessageField('SecurityPolicyRulePreconfiguredWafConfig', 9)
  preview = _messages.BooleanField(10)
  priority = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  rateLimitOptions = _messages.MessageField('SecurityPolicyRuleRateLimitOptions', 12)
  redirectOptions = _messages.MessageField('SecurityPolicyRuleRedirectOptions', 13)
  redirectTarget = _messages.StringField(14)
  ruleManagedProtectionTier = _messages.EnumField('RuleManagedProtectionTierValueValuesEnum', 15)
  ruleNumber = _messages.IntegerField(16)
  ruleTupleCount = _messages.IntegerField(17, variant=_messages.Variant.INT32)
  targetResources = _messages.StringField(18, repeated=True)
  targetServiceAccounts = _messages.StringField(19, repeated=True)


class SecurityPolicyRuleHttpHeaderAction(_messages.Message):
  r"""A SecurityPolicyRuleHttpHeaderAction object.

  Fields:
    requestHeadersToAdds: The list of request headers to add or overwrite if
      they're already present.
  """

  requestHeadersToAdds = _messages.MessageField('SecurityPolicyRuleHttpHeaderActionHttpHeaderOption', 1, repeated=True)


class SecurityPolicyRuleHttpHeaderActionHttpHeaderOption(_messages.Message):
  r"""A SecurityPolicyRuleHttpHeaderActionHttpHeaderOption object.

  Fields:
    headerName: The name of the header to set.
    headerValue: The value to set the named header to.
  """

  headerName = _messages.StringField(1)
  headerValue = _messages.StringField(2)


class SecurityPolicyRuleMatcher(_messages.Message):
  r"""Represents a match condition that incoming traffic is evaluated against.
  Exactly one field must be specified.

  Enums:
    VersionedExprValueValuesEnum: Preconfigured versioned expression. If this
      field is specified, config must also be specified. Available
      preconfigured expressions along with their requirements are: SRC_IPS_V1
      - must specify the corresponding src_ip_range field in config.

  Fields:
    config: The configuration options available when specifying
      versioned_expr. This field must be specified if versioned_expr is
      specified and cannot be specified if versioned_expr is not specified.
    expr: User defined CEVAL expression. A CEVAL expression is used to specify
      match criteria such as origin.ip, source.region_code and contents in the
      request header. Expressions containing `evaluateThreatIntelligence`
      require Cloud Armor Managed Protection Plus tier and are not supported
      in Edge Policies nor in Regional Policies. Expressions containing
      `evaluatePreconfiguredExpr('sourceiplist-*')` require Cloud Armor
      Managed Protection Plus tier and are only supported in Global Security
      Policies.
    exprOptions: The configuration options available when specifying a user
      defined CEVAL expression (i.e., 'expr').
    versionedExpr: Preconfigured versioned expression. If this field is
      specified, config must also be specified. Available preconfigured
      expressions along with their requirements are: SRC_IPS_V1 - must specify
      the corresponding src_ip_range field in config.
  """

  class VersionedExprValueValuesEnum(_messages.Enum):
    r"""Preconfigured versioned expression. If this field is specified, config
    must also be specified. Available preconfigured expressions along with
    their requirements are: SRC_IPS_V1 - must specify the corresponding
    src_ip_range field in config.

    Values:
      FIREWALL: <no description>
      SRC_IPS_V1: Matches the source IP address of a request to the IP ranges
        supplied in config.
    """
    FIREWALL = 0
    SRC_IPS_V1 = 1

  config = _messages.MessageField('SecurityPolicyRuleMatcherConfig', 1)
  expr = _messages.MessageField('Expr', 2)
  exprOptions = _messages.MessageField('SecurityPolicyRuleMatcherExprOptions', 3)
  versionedExpr = _messages.EnumField('VersionedExprValueValuesEnum', 4)


class SecurityPolicyRuleMatcherConfig(_messages.Message):
  r"""A SecurityPolicyRuleMatcherConfig object.

  Fields:
    destIpRanges: CIDR IP address range. This field may only be specified when
      versioned_expr is set to FIREWALL.
    destPorts: Pairs of IP protocols and ports that the rule should match.
      This field may only be specified when versioned_expr is set to FIREWALL.
    layer4Configs: Pairs of IP protocols and ports that the rule should match.
      This field may only be specified when versioned_expr is set to FIREWALL.
    srcIpRanges: CIDR IP address range. Maximum number of src_ip_ranges
      allowed is 10.
  """

  destIpRanges = _messages.StringField(1, repeated=True)
  destPorts = _messages.MessageField('SecurityPolicyRuleMatcherConfigDestinationPort', 2, repeated=True)
  layer4Configs = _messages.MessageField('SecurityPolicyRuleMatcherConfigLayer4Config', 3, repeated=True)
  srcIpRanges = _messages.StringField(4, repeated=True)


class SecurityPolicyRuleMatcherConfigDestinationPort(_messages.Message):
  r"""A SecurityPolicyRuleMatcherConfigDestinationPort object.

  Fields:
    ipProtocol: The IP protocol to which this rule applies. The protocol type
      is required when creating a firewall rule. This value can either be one
      of the following well known protocol strings (tcp, udp, icmp, esp, ah,
      ipip, sctp), or the IP protocol number.
    ports: An optional list of ports to which this rule applies. This field is
      only applicable for UDP or TCP protocol. Each entry must be either an
      integer or a range. If not specified, this rule applies to connections
      through any port. Example inputs include: ["22"], ["80","443"], and
      ["12345-12349"]. This field may only be specified when versioned_expr is
      set to FIREWALL.
  """

  ipProtocol = _messages.StringField(1)
  ports = _messages.StringField(2, repeated=True)


class SecurityPolicyRuleMatcherConfigLayer4Config(_messages.Message):
  r"""A SecurityPolicyRuleMatcherConfigLayer4Config object.

  Fields:
    ipProtocol: The IP protocol to which this rule applies. The protocol type
      is required when creating a firewall rule. This value can either be one
      of the following well known protocol strings (tcp, udp, icmp, esp, ah,
      ipip, sctp), or the IP protocol number.
    ports: An optional list of ports to which this rule applies. This field is
      only applicable for UDP or TCP protocol. Each entry must be either an
      integer or a range. If not specified, this rule applies to connections
      through any port. Example inputs include: ["22"], ["80","443"], and
      ["12345-12349"]. This field may only be specified when versioned_expr is
      set to FIREWALL.
  """

  ipProtocol = _messages.StringField(1)
  ports = _messages.StringField(2, repeated=True)


class SecurityPolicyRuleMatcherExprOptions(_messages.Message):
  r"""A SecurityPolicyRuleMatcherExprOptions object.

  Fields:
    recaptchaOptions: reCAPTCHA configuration options to be applied for the
      rule. If the rule does not evaluate reCAPTCHA tokens, this field has no
      effect.
  """

  recaptchaOptions = _messages.MessageField('SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions', 1)


class SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions(_messages.Message):
  r"""A SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions object.

  Fields:
    actionTokenSiteKeys: A list of site keys to be used during the validation
      of reCAPTCHA action-tokens. The provided site keys need to be created
      from reCAPTCHA API under the same project where the security policy is
      created.
    sessionTokenSiteKeys: A list of site keys to be used during the validation
      of reCAPTCHA session-tokens. The provided site keys need to be created
      from reCAPTCHA API under the same project where the security policy is
      created.
  """

  actionTokenSiteKeys = _messages.StringField(1, repeated=True)
  sessionTokenSiteKeys = _messages.StringField(2, repeated=True)


class SecurityPolicyRuleNetworkMatcher(_messages.Message):
  r"""Represents a match condition that incoming network traffic is evaluated
  against.

  Fields:
    destIpRanges: Destination IPv4/IPv6 addresses or CIDR prefixes, in
      standard text format.
    destPorts: Destination port numbers for TCP/UDP/SCTP. Each element can be
      a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023").
    ipProtocols: IPv4 protocol / IPv6 next header (after extension headers).
      Each element can be an 8-bit unsigned decimal number (e.g. "6"), range
      (e.g. "253-254"), or one of the following protocol names: "tcp", "udp",
      "icmp", "esp", "ah", "ipip", or "sctp".
    srcAsns: BGP Autonomous System Number associated with the source IP
      address.
    srcIpRanges: Source IPv4/IPv6 addresses or CIDR prefixes, in standard text
      format.
    srcPorts: Source port numbers for TCP/UDP/SCTP. Each element can be a
      16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023").
    srcRegionCodes: Two-letter ISO 3166-1 alpha-2 country code associated with
      the source IP address.
    userDefinedFields: User-defined fields. Each element names a defined field
      and lists the matching values for that field.
  """

  destIpRanges = _messages.StringField(1, repeated=True)
  destPorts = _messages.StringField(2, repeated=True)
  ipProtocols = _messages.StringField(3, repeated=True)
  srcAsns = _messages.IntegerField(4, repeated=True, variant=_messages.Variant.UINT32)
  srcIpRanges = _messages.StringField(5, repeated=True)
  srcPorts = _messages.StringField(6, repeated=True)
  srcRegionCodes = _messages.StringField(7, repeated=True)
  userDefinedFields = _messages.MessageField('SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch', 8, repeated=True)


class SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch(_messages.Message):
  r"""A SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch object.

  Fields:
    name: Name of the user-defined field, as given in the definition.
    values: Matching values of the field. Each element can be a 32-bit
      unsigned decimal or hexadecimal (starting with "0x") number (e.g. "64")
      or range (e.g. "0x400-0x7ff").
  """

  name = _messages.StringField(1)
  values = _messages.StringField(2, repeated=True)


class SecurityPolicyRulePreconfiguredWafConfig(_messages.Message):
  r"""A SecurityPolicyRulePreconfiguredWafConfig object.

  Fields:
    exclusions: A list of exclusions to apply during preconfigured WAF
      evaluation.
  """

  exclusions = _messages.MessageField('SecurityPolicyRulePreconfiguredWafConfigExclusion', 1, repeated=True)


class SecurityPolicyRulePreconfiguredWafConfigExclusion(_messages.Message):
  r"""A SecurityPolicyRulePreconfiguredWafConfigExclusion object.

  Fields:
    requestCookiesToExclude: A list of request cookie names whose value will
      be excluded from inspection during preconfigured WAF evaluation.
    requestHeadersToExclude: A list of request header names whose value will
      be excluded from inspection during preconfigured WAF evaluation.
    requestQueryParamsToExclude: A list of request query parameter names whose
      value will be excluded from inspection during preconfigured WAF
      evaluation. Note that the parameter can be in the query string or in the
      POST body.
    requestUrisToExclude: A list of request URIs from the request line to be
      excluded from inspection during preconfigured WAF evaluation. When
      specifying this field, the query or fragment part should be excluded.
    targetRuleIds: A list of target rule IDs under the WAF rule set to apply
      the preconfigured WAF exclusion. If omitted, it refers to all the rule
      IDs under the WAF rule set.
    targetRuleSet: Target WAF rule set to apply the preconfigured WAF
      exclusion.
  """

  requestCookiesToExclude = _messages.MessageField('SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams', 1, repeated=True)
  requestHeadersToExclude = _messages.MessageField('SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams', 2, repeated=True)
  requestQueryParamsToExclude = _messages.MessageField('SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams', 3, repeated=True)
  requestUrisToExclude = _messages.MessageField('SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams', 4, repeated=True)
  targetRuleIds = _messages.StringField(5, repeated=True)
  targetRuleSet = _messages.StringField(6)


class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams(_messages.Message):
  r"""A SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams object.

  Enums:
    OpValueValuesEnum: The match operator for the field.

  Fields:
    op: The match operator for the field.
    val: The value of the field.
  """

  class OpValueValuesEnum(_messages.Enum):
    r"""The match operator for the field.

    Values:
      CONTAINS: The operator matches if the field value contains the specified
        value.
      ENDS_WITH: The operator matches if the field value ends with the
        specified value.
      EQUALS: The operator matches if the field value equals the specified
        value.
      EQUALS_ANY: The operator matches if the field value is any value.
      STARTS_WITH: The operator matches if the field value starts with the
        specified value.
    """
    CONTAINS = 0
    ENDS_WITH = 1
    EQUALS = 2
    EQUALS_ANY = 3
    STARTS_WITH = 4

  op = _messages.EnumField('OpValueValuesEnum', 1)
  val = _messages.StringField(2)


class SecurityPolicyRuleRateLimitOptions(_messages.Message):
  r"""A SecurityPolicyRuleRateLimitOptions object.

  Enums:
    EnforceOnKeyValueValuesEnum: Determines the key to enforce the
      rate_limit_threshold on. Possible values are: - ALL: A single rate limit
      threshold is applied to all the requests matching this rule. This is the
      default value if "enforceOnKey" is not configured. - IP: The source IP
      address of the request is the key. Each IP has this limit enforced
      separately. - HTTP_HEADER: The value of the HTTP header whose name is
      configured under "enforceOnKeyName". The key value is truncated to the
      first 128 bytes of the header value. If no such header is present in the
      request, the key type defaults to ALL. - XFF_IP: The first IP address
      (i.e. the originating client IP address) specified in the list of IPs
      under X-Forwarded-For HTTP header. If no such header is present or the
      value is not a valid IP, the key defaults to the source IP address of
      the request i.e. key type IP. - HTTP_COOKIE: The value of the HTTP
      cookie whose name is configured under "enforceOnKeyName". The key value
      is truncated to the first 128 bytes of the cookie value. If no such
      cookie is present in the request, the key type defaults to ALL. -
      HTTP_PATH: The URL path of the HTTP request. The key value is truncated
      to the first 128 bytes. - SNI: Server name indication in the TLS session
      of the HTTPS request. The key value is truncated to the first 128 bytes.
      The key type defaults to ALL on a HTTP session. - REGION_CODE: The
      country/region from which the request originates. - TLS_JA3_FINGERPRINT:
      JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
      HTTP/3. If not available, the key type defaults to ALL. - USER_IP: The
      IP address of the originating client, which is resolved based on
      "userIpRequestHeaders" configured with the security policy. If there is
      no "userIpRequestHeaders" configuration or an IP address cannot be
      resolved from it, the key type defaults to IP. - TLS_JA4_FINGERPRINT:
      JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
      HTTP/3. If not available, the key type defaults to ALL.

  Fields:
    banDurationSec: Can only be specified if the action for the rule is
      "rate_based_ban". If specified, determines the time (in seconds) the
      traffic will continue to be banned by the rate limit after the rate
      falls below the threshold.
    banThreshold: Can only be specified if the action for the rule is
      "rate_based_ban". If specified, the key will be banned for the
      configured 'ban_duration_sec' when the number of requests that exceed
      the 'rate_limit_threshold' also exceed this 'ban_threshold'.
    conformAction: Action to take for requests that are under the configured
      rate limit threshold. Valid option is "allow" only.
    enforceOnKey: Determines the key to enforce the rate_limit_threshold on.
      Possible values are: - ALL: A single rate limit threshold is applied to
      all the requests matching this rule. This is the default value if
      "enforceOnKey" is not configured. - IP: The source IP address of the
      request is the key. Each IP has this limit enforced separately. -
      HTTP_HEADER: The value of the HTTP header whose name is configured under
      "enforceOnKeyName". The key value is truncated to the first 128 bytes of
      the header value. If no such header is present in the request, the key
      type defaults to ALL. - XFF_IP: The first IP address (i.e. the
      originating client IP address) specified in the list of IPs under
      X-Forwarded-For HTTP header. If no such header is present or the value
      is not a valid IP, the key defaults to the source IP address of the
      request i.e. key type IP. - HTTP_COOKIE: The value of the HTTP cookie
      whose name is configured under "enforceOnKeyName". The key value is
      truncated to the first 128 bytes of the cookie value. If no such cookie
      is present in the request, the key type defaults to ALL. - HTTP_PATH:
      The URL path of the HTTP request. The key value is truncated to the
      first 128 bytes. - SNI: Server name indication in the TLS session of the
      HTTPS request. The key value is truncated to the first 128 bytes. The
      key type defaults to ALL on a HTTP session. - REGION_CODE: The
      country/region from which the request originates. - TLS_JA3_FINGERPRINT:
      JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
      HTTP/3. If not available, the key type defaults to ALL. - USER_IP: The
      IP address of the originating client, which is resolved based on
      "userIpRequestHeaders" configured with the security policy. If there is
      no "userIpRequestHeaders" configuration or an IP address cannot be
      resolved from it, the key type defaults to IP. - TLS_JA4_FINGERPRINT:
      JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
      HTTP/3. If not available, the key type defaults to ALL.
    enforceOnKeyConfigs: If specified, any combination of values of
      enforce_on_key_type/enforce_on_key_name is treated as the key on which
      ratelimit threshold/action is enforced. You can specify up to 3
      enforce_on_key_configs. If enforce_on_key_configs is specified,
      enforce_on_key must not be specified.
    enforceOnKeyName: Rate limit key name applicable only for the following
      key types: HTTP_HEADER -- Name of the HTTP header whose value is taken
      as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is
      taken as the key value.
    exceedAction: Action to take for requests that are above the configured
      rate limit threshold, to either deny with a specified HTTP response
      code, or redirect to a different endpoint. Valid options are
      `deny(STATUS)`, where valid values for `STATUS` are 403, 404, 429, and
      502, and `redirect`, where the redirect parameters come from
      `exceedRedirectOptions` below. The `redirect` action is only supported
      in Global Security Policies of type CLOUD_ARMOR.
    exceedActionRpcStatus: Specified gRPC response status for proxyless gRPC
      requests that are above the configured rate limit threshold
    exceedRedirectOptions: Parameters defining the redirect action that is
      used as the exceed action. Cannot be specified if the exceed action is
      not redirect. This field is only supported in Global Security Policies
      of type CLOUD_ARMOR.
    rateLimitThreshold: Threshold at which to begin ratelimiting.
  """

  class EnforceOnKeyValueValuesEnum(_messages.Enum):
    r"""Determines the key to enforce the rate_limit_threshold on. Possible
    values are: - ALL: A single rate limit threshold is applied to all the
    requests matching this rule. This is the default value if "enforceOnKey"
    is not configured. - IP: The source IP address of the request is the key.
    Each IP has this limit enforced separately. - HTTP_HEADER: The value of
    the HTTP header whose name is configured under "enforceOnKeyName". The key
    value is truncated to the first 128 bytes of the header value. If no such
    header is present in the request, the key type defaults to ALL. - XFF_IP:
    The first IP address (i.e. the originating client IP address) specified in
    the list of IPs under X-Forwarded-For HTTP header. If no such header is
    present or the value is not a valid IP, the key defaults to the source IP
    address of the request i.e. key type IP. - HTTP_COOKIE: The value of the
    HTTP cookie whose name is configured under "enforceOnKeyName". The key
    value is truncated to the first 128 bytes of the cookie value. If no such
    cookie is present in the request, the key type defaults to ALL. -
    HTTP_PATH: The URL path of the HTTP request. The key value is truncated to
    the first 128 bytes. - SNI: Server name indication in the TLS session of
    the HTTPS request. The key value is truncated to the first 128 bytes. The
    key type defaults to ALL on a HTTP session. - REGION_CODE: The
    country/region from which the request originates. - TLS_JA3_FINGERPRINT:
    JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
    HTTP/3. If not available, the key type defaults to ALL. - USER_IP: The IP
    address of the originating client, which is resolved based on
    "userIpRequestHeaders" configured with the security policy. If there is no
    "userIpRequestHeaders" configuration or an IP address cannot be resolved
    from it, the key type defaults to IP. - TLS_JA4_FINGERPRINT: JA4 TLS/SSL
    fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not
    available, the key type defaults to ALL.

    Values:
      ALL: <no description>
      ALL_IPS: <no description>
      HTTP_COOKIE: <no description>
      HTTP_HEADER: <no description>
      HTTP_PATH: <no description>
      IP: <no description>
      REGION_CODE: <no description>
      SNI: <no description>
      TLS_JA3_FINGERPRINT: <no description>
      TLS_JA4_FINGERPRINT: <no description>
      USER_IP: <no description>
      XFF_IP: <no description>
    """
    ALL = 0
    ALL_IPS = 1
    HTTP_COOKIE = 2
    HTTP_HEADER = 3
    HTTP_PATH = 4
    IP = 5
    REGION_CODE = 6
    SNI = 7
    TLS_JA3_FINGERPRINT = 8
    TLS_JA4_FINGERPRINT = 9
    USER_IP = 10
    XFF_IP = 11

  banDurationSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  banThreshold = _messages.MessageField('SecurityPolicyRuleRateLimitOptionsThreshold', 2)
  conformAction = _messages.StringField(3)
  enforceOnKey = _messages.EnumField('EnforceOnKeyValueValuesEnum', 4)
  enforceOnKeyConfigs = _messages.MessageField('SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig', 5, repeated=True)
  enforceOnKeyName = _messages.StringField(6)
  exceedAction = _messages.StringField(7)
  exceedActionRpcStatus = _messages.MessageField('SecurityPolicyRuleRateLimitOptionsRpcStatus', 8)
  exceedRedirectOptions = _messages.MessageField('SecurityPolicyRuleRedirectOptions', 9)
  rateLimitThreshold = _messages.MessageField('SecurityPolicyRuleRateLimitOptionsThreshold', 10)


class SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig(_messages.Message):
  r"""A SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig object.

  Enums:
    EnforceOnKeyTypeValueValuesEnum: Determines the key to enforce the
      rate_limit_threshold on. Possible values are: - ALL: A single rate limit
      threshold is applied to all the requests matching this rule. This is the
      default value if "enforceOnKeyConfigs" is not configured. - IP: The
      source IP address of the request is the key. Each IP has this limit
      enforced separately. - HTTP_HEADER: The value of the HTTP header whose
      name is configured under "enforceOnKeyName". The key value is truncated
      to the first 128 bytes of the header value. If no such header is present
      in the request, the key type defaults to ALL. - XFF_IP: The first IP
      address (i.e. the originating client IP address) specified in the list
      of IPs under X-Forwarded-For HTTP header. If no such header is present
      or the value is not a valid IP, the key defaults to the source IP
      address of the request i.e. key type IP. - HTTP_COOKIE: The value of the
      HTTP cookie whose name is configured under "enforceOnKeyName". The key
      value is truncated to the first 128 bytes of the cookie value. If no
      such cookie is present in the request, the key type defaults to ALL. -
      HTTP_PATH: The URL path of the HTTP request. The key value is truncated
      to the first 128 bytes. - SNI: Server name indication in the TLS session
      of the HTTPS request. The key value is truncated to the first 128 bytes.
      The key type defaults to ALL on a HTTP session. - REGION_CODE: The
      country/region from which the request originates. - TLS_JA3_FINGERPRINT:
      JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
      HTTP/3. If not available, the key type defaults to ALL. - USER_IP: The
      IP address of the originating client, which is resolved based on
      "userIpRequestHeaders" configured with the security policy. If there is
      no "userIpRequestHeaders" configuration or an IP address cannot be
      resolved from it, the key type defaults to IP. - TLS_JA4_FINGERPRINT:
      JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
      HTTP/3. If not available, the key type defaults to ALL.

  Fields:
    enforceOnKeyName: Rate limit key name applicable only for the following
      key types: HTTP_HEADER -- Name of the HTTP header whose value is taken
      as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is
      taken as the key value.
    enforceOnKeyType: Determines the key to enforce the rate_limit_threshold
      on. Possible values are: - ALL: A single rate limit threshold is applied
      to all the requests matching this rule. This is the default value if
      "enforceOnKeyConfigs" is not configured. - IP: The source IP address of
      the request is the key. Each IP has this limit enforced separately. -
      HTTP_HEADER: The value of the HTTP header whose name is configured under
      "enforceOnKeyName". The key value is truncated to the first 128 bytes of
      the header value. If no such header is present in the request, the key
      type defaults to ALL. - XFF_IP: The first IP address (i.e. the
      originating client IP address) specified in the list of IPs under
      X-Forwarded-For HTTP header. If no such header is present or the value
      is not a valid IP, the key defaults to the source IP address of the
      request i.e. key type IP. - HTTP_COOKIE: The value of the HTTP cookie
      whose name is configured under "enforceOnKeyName". The key value is
      truncated to the first 128 bytes of the cookie value. If no such cookie
      is present in the request, the key type defaults to ALL. - HTTP_PATH:
      The URL path of the HTTP request. The key value is truncated to the
      first 128 bytes. - SNI: Server name indication in the TLS session of the
      HTTPS request. The key value is truncated to the first 128 bytes. The
      key type defaults to ALL on a HTTP session. - REGION_CODE: The
      country/region from which the request originates. - TLS_JA3_FINGERPRINT:
      JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
      HTTP/3. If not available, the key type defaults to ALL. - USER_IP: The
      IP address of the originating client, which is resolved based on
      "userIpRequestHeaders" configured with the security policy. If there is
      no "userIpRequestHeaders" configuration or an IP address cannot be
      resolved from it, the key type defaults to IP. - TLS_JA4_FINGERPRINT:
      JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or
      HTTP/3. If not available, the key type defaults to ALL.
  """

  class EnforceOnKeyTypeValueValuesEnum(_messages.Enum):
    r"""Determines the key to enforce the rate_limit_threshold on. Possible
    values are: - ALL: A single rate limit threshold is applied to all the
    requests matching this rule. This is the default value if
    "enforceOnKeyConfigs" is not configured. - IP: The source IP address of
    the request is the key. Each IP has this limit enforced separately. -
    HTTP_HEADER: The value of the HTTP header whose name is configured under
    "enforceOnKeyName". The key value is truncated to the first 128 bytes of
    the header value. If no such header is present in the request, the key
    type defaults to ALL. - XFF_IP: The first IP address (i.e. the originating
    client IP address) specified in the list of IPs under X-Forwarded-For HTTP
    header. If no such header is present or the value is not a valid IP, the
    key defaults to the source IP address of the request i.e. key type IP. -
    HTTP_COOKIE: The value of the HTTP cookie whose name is configured under
    "enforceOnKeyName". The key value is truncated to the first 128 bytes of
    the cookie value. If no such cookie is present in the request, the key
    type defaults to ALL. - HTTP_PATH: The URL path of the HTTP request. The
    key value is truncated to the first 128 bytes. - SNI: Server name
    indication in the TLS session of the HTTPS request. The key value is
    truncated to the first 128 bytes. The key type defaults to ALL on a HTTP
    session. - REGION_CODE: The country/region from which the request
    originates. - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client
    connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type
    defaults to ALL. - USER_IP: The IP address of the originating client,
    which is resolved based on "userIpRequestHeaders" configured with the
    security policy. If there is no "userIpRequestHeaders" configuration or an
    IP address cannot be resolved from it, the key type defaults to IP. -
    TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the client connects using
    HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.

    Values:
      ALL: <no description>
      ALL_IPS: <no description>
      HTTP_COOKIE: <no description>
      HTTP_HEADER: <no description>
      HTTP_PATH: <no description>
      IP: <no description>
      REGION_CODE: <no description>
      SNI: <no description>
      TLS_JA3_FINGERPRINT: <no description>
      TLS_JA4_FINGERPRINT: <no description>
      USER_IP: <no description>
      XFF_IP: <no description>
    """
    ALL = 0
    ALL_IPS = 1
    HTTP_COOKIE = 2
    HTTP_HEADER = 3
    HTTP_PATH = 4
    IP = 5
    REGION_CODE = 6
    SNI = 7
    TLS_JA3_FINGERPRINT = 8
    TLS_JA4_FINGERPRINT = 9
    USER_IP = 10
    XFF_IP = 11

  enforceOnKeyName = _messages.StringField(1)
  enforceOnKeyType = _messages.EnumField('EnforceOnKeyTypeValueValuesEnum', 2)


class SecurityPolicyRuleRateLimitOptionsRpcStatus(_messages.Message):
  r"""Simplified google.rpc.Status type (omitting details).

  Fields:
    code: The status code, which should be an enum value of google.rpc.Code.
    message: A developer-facing error message, which should be in English.
  """

  code = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  message = _messages.StringField(2)


class SecurityPolicyRuleRateLimitOptionsThreshold(_messages.Message):
  r"""A SecurityPolicyRuleRateLimitOptionsThreshold object.

  Fields:
    count: Number of HTTP(S) requests for calculating the threshold.
    intervalSec: Interval over which the threshold is computed.
  """

  count = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  intervalSec = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class SecurityPolicyRuleRedirectOptions(_messages.Message):
  r"""A SecurityPolicyRuleRedirectOptions object.

  Enums:
    TypeValueValuesEnum: Type of the redirect action.

  Fields:
    target: Target for the redirect action. This is required if the type is
      EXTERNAL_302 and cannot be specified for GOOGLE_RECAPTCHA.
    type: Type of the redirect action.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""Type of the redirect action.

    Values:
      EXTERNAL_302: <no description>
      GOOGLE_RECAPTCHA: <no description>
    """
    EXTERNAL_302 = 0
    GOOGLE_RECAPTCHA = 1

  target = _messages.StringField(1)
  type = _messages.EnumField('TypeValueValuesEnum', 2)


class SecurityPolicyUserDefinedField(_messages.Message):
  r"""A SecurityPolicyUserDefinedField object.

  Enums:
    BaseValueValuesEnum: The base relative to which 'offset' is measured.
      Possible values are: - IPV4: Points to the beginning of the IPv4 header.
      - IPV6: Points to the beginning of the IPv6 header. - TCP: Points to the
      beginning of the TCP header, skipping over any IPv4 options or IPv6
      extension headers. Not present for non-first fragments. - UDP: Points to
      the beginning of the UDP header, skipping over any IPv4 options or IPv6
      extension headers. Not present for non-first fragments. required

  Fields:
    base: The base relative to which 'offset' is measured. Possible values
      are: - IPV4: Points to the beginning of the IPv4 header. - IPV6: Points
      to the beginning of the IPv6 header. - TCP: Points to the beginning of
      the TCP header, skipping over any IPv4 options or IPv6 extension
      headers. Not present for non-first fragments. - UDP: Points to the
      beginning of the UDP header, skipping over any IPv4 options or IPv6
      extension headers. Not present for non-first fragments. required
    mask: If specified, apply this mask (bitwise AND) to the field to ignore
      bits before matching. Encoded as a hexadecimal number (starting with
      "0x"). The last byte of the field (in network byte order) corresponds to
      the least significant byte of the mask.
    name: The name of this field. Must be unique within the policy.
    offset: Offset of the first byte of the field (in network byte order)
      relative to 'base'.
    size: Size of the field in bytes. Valid values: 1-4.
  """

  class BaseValueValuesEnum(_messages.Enum):
    r"""The base relative to which 'offset' is measured. Possible values are:
    - IPV4: Points to the beginning of the IPv4 header. - IPV6: Points to the
    beginning of the IPv6 header. - TCP: Points to the beginning of the TCP
    header, skipping over any IPv4 options or IPv6 extension headers. Not
    present for non-first fragments. - UDP: Points to the beginning of the UDP
    header, skipping over any IPv4 options or IPv6 extension headers. Not
    present for non-first fragments. required

    Values:
      IPV4: <no description>
      IPV6: <no description>
      TCP: <no description>
      UDP: <no description>
    """
    IPV4 = 0
    IPV6 = 1
    TCP = 2
    UDP = 3

  base = _messages.EnumField('BaseValueValuesEnum', 1)
  mask = _messages.StringField(2)
  name = _messages.StringField(3)
  offset = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  size = _messages.IntegerField(5, variant=_messages.Variant.INT32)


class SecuritySettings(_messages.Message):
  r"""The authentication and authorization settings for a BackendService.

  Fields:
    authentication: [Deprecated] Use clientTlsPolicy instead.
    authenticationPolicy: [Deprecated] Authentication policy defines what
      authentication methods can be accepted on backends, and if
      authenticated, which method/certificate will set the request principal.
      request principal.
    authorizationConfig: [Deprecated] Authorization config defines the Role
      Based Access Control (RBAC) config. Authorization config defines the
      Role Based Access Control (RBAC) config.
    awsV4Authentication: The configuration needed to generate a signature for
      access to private storage buckets that support AWS's Signature Version 4
      for authentication. Allowed only for INTERNET_IP_PORT and
      INTERNET_FQDN_PORT NEG backends.
    clientTlsPolicy: Optional. A URL referring to a
      networksecurity.ClientTlsPolicy resource that describes how clients
      should authenticate with this service's backends. clientTlsPolicy only
      applies to a global BackendService with the loadBalancingScheme set to
      INTERNAL_SELF_MANAGED. If left blank, communications are not encrypted.
    clientTlsSettings: [Deprecated] TLS Settings for the backend service.
    subjectAltNames: Optional. A list of Subject Alternative Names (SANs) that
      the client verifies during a mutual TLS handshake with an
      server/endpoint for this BackendService. When the server presents its
      X.509 certificate to the client, the client inspects the certificate's
      subjectAltName field. If the field contains one of the specified values,
      the communication continues. Otherwise, it fails. This additional check
      enables the client to verify that the server is authorized to run the
      requested service. Note that the contents of the server certificate's
      subjectAltName field are configured by the Public Key Infrastructure
      which provisions server identities. Only applies to a global
      BackendService with loadBalancingScheme set to INTERNAL_SELF_MANAGED.
      Only applies when BackendService has an attached clientTlsPolicy with
      clientCertificate (mTLS mode).
  """

  authentication = _messages.StringField(1)
  authenticationPolicy = _messages.MessageField('AuthenticationPolicy', 2)
  authorizationConfig = _messages.MessageField('AuthorizationConfig', 3)
  awsV4Authentication = _messages.MessageField('AWSV4Signature', 4)
  clientTlsPolicy = _messages.StringField(5)
  clientTlsSettings = _messages.MessageField('ClientTlsSettings', 6)
  subjectAltNames = _messages.StringField(7, repeated=True)


class SerialPortOutput(_messages.Message):
  r"""An instance serial console output.

  Fields:
    contents: [Output Only] The contents of the console output.
    kind: [Output Only] Type of the resource. Always compute#serialPortOutput
      for serial port output.
    next: [Output Only] The position of the next byte of content, regardless
      of whether the content exists, following the output returned in the
      `contents` property. Use this value in the next request as the start
      parameter.
    selfLink: [Output Only] Server-defined URL for this resource.
    start: The starting byte position of the output that was returned. This
      should match the start parameter sent with the request. If the serial
      console output exceeds the size of the buffer (1 MB), older output is
      overwritten by newer content. The output start value will indicate the
      byte position of the output that was returned, which might be different
      than the `start` value that was specified in the request.
  """

  contents = _messages.StringField(1)
  kind = _messages.StringField(2, default='compute#serialPortOutput')
  next = _messages.IntegerField(3)
  selfLink = _messages.StringField(4)
  start = _messages.IntegerField(5)


class ServerBinding(_messages.Message):
  r"""A ServerBinding object.

  Enums:
    TypeValueValuesEnum:

  Fields:
    type: A TypeValueValuesEnum attribute.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""TypeValueValuesEnum enum type.

    Values:
      RESTART_NODE_ON_ANY_SERVER: Node may associate with any physical server
        over its lifetime.
      RESTART_NODE_ON_MINIMAL_SERVERS: Node may associate with minimal
        physical servers over its lifetime.
      SERVER_BINDING_TYPE_UNSPECIFIED: <no description>
    """
    RESTART_NODE_ON_ANY_SERVER = 0
    RESTART_NODE_ON_MINIMAL_SERVERS = 1
    SERVER_BINDING_TYPE_UNSPECIFIED = 2

  type = _messages.EnumField('TypeValueValuesEnum', 1)


class ServerTlsSettings(_messages.Message):
  r"""The TLS settings for the server.

  Enums:
    TlsModeValueValuesEnum: Indicates whether connections should be secured
      using TLS. The value of this field determines how TLS is enforced. This
      field can be set to one of the following: - SIMPLE Secure connections
      with standard TLS semantics. - MUTUAL Secure connections to the backends
      using mutual TLS by presenting client certificates for authentication.

  Fields:
    proxyTlsContext: Configures the mechanism to obtain security certificates
      and identity information.
    subjectAltNames: A list of alternate names to verify the subject identity
      in the certificate presented by the client.
    tlsMode: Indicates whether connections should be secured using TLS. The
      value of this field determines how TLS is enforced. This field can be
      set to one of the following: - SIMPLE Secure connections with standard
      TLS semantics. - MUTUAL Secure connections to the backends using mutual
      TLS by presenting client certificates for authentication.
  """

  class TlsModeValueValuesEnum(_messages.Enum):
    r"""Indicates whether connections should be secured using TLS. The value
    of this field determines how TLS is enforced. This field can be set to one
    of the following: - SIMPLE Secure connections with standard TLS semantics.
    - MUTUAL Secure connections to the backends using mutual TLS by presenting
    client certificates for authentication.

    Values:
      INVALID: <no description>
      MUTUAL: Secure connections to the backends using mutual TLS by
        presenting client certificates for authentication.
      SIMPLE: Secure connections with standard TLS semantics.
    """
    INVALID = 0
    MUTUAL = 1
    SIMPLE = 2

  proxyTlsContext = _messages.MessageField('TlsContext', 1)
  subjectAltNames = _messages.StringField(2, repeated=True)
  tlsMode = _messages.EnumField('TlsModeValueValuesEnum', 3)


class ServiceAccount(_messages.Message):
  r"""A service account.

  Fields:
    email: Email address of the service account.
    scopes: The list of scopes to be made available for this service account.
  """

  email = _messages.StringField(1)
  scopes = _messages.StringField(2, repeated=True)


class ServiceAttachment(_messages.Message):
  r"""Represents a ServiceAttachment resource. A service attachment represents
  a service that a producer has exposed. It encapsulates the load balancer
  which fronts the service runs and a list of NAT IP ranges that the producers
  uses to represent the consumers connecting to the service.

  Enums:
    ConnectionPreferenceValueValuesEnum: The connection preference of service
      attachment. The value can be set to ACCEPT_AUTOMATIC. An
      ACCEPT_AUTOMATIC service attachment is one that always accepts the
      connection from consumer forwarding rules.

  Fields:
    connectedEndpoints: [Output Only] An array of connections for all the
      consumers connected to this service attachment.
    connectionPreference: The connection preference of service attachment. The
      value can be set to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service
      attachment is one that always accepts the connection from consumer
      forwarding rules.
    consumerAcceptLists: Specifies which consumer projects or networks are
      allowed to connect to the service attachment. Each project or network
      has a connection limit. A given service attachment can manage
      connections at either the project or network level. Therefore, both the
      accept and reject lists for a given service attachment must contain
      either only projects or only networks.
    consumerRejectLists: Specifies a list of projects or networks that are not
      allowed to connect to this service attachment. The project can be
      specified using its project ID or project number and the network can be
      specified using its URL. A given service attachment can manage
      connections at either the project or network level. Therefore, both the
      reject and accept lists for a given service attachment must contain
      either only projects or only networks.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    domainNames: If specified, the domain name will be used during the
      integration between the PSC connected endpoints and the Cloud DNS. For
      example, this is a valid domain name: "p.mycompany.com.". Current max
      number of domain names supported is 1.
    enableProxyProtocol: If true, enable the proxy protocol which is for
      supplying client TCP/IP address data in TCP connections that traverse
      proxies on their way to destination servers.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a ServiceAttachment. An up-to-date
      fingerprint must be provided in order to patch/update the
      ServiceAttachment; otherwise, the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve the ServiceAttachment.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always compute#serviceAttachment
      for service attachments.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    natSubnets: An array of URLs where each entry is the URL of a subnet
      provided by the service producer to use for NAT in this service
      attachment.
    producerForwardingRule: The URL of a forwarding rule with
      loadBalancingScheme INTERNAL* that is serving the endpoint identified by
      this service attachment.
    propagatedConnectionLimit: The number of consumer spokes that connected
      Private Service Connect endpoints can be propagated to through Network
      Connectivity Center. This limit lets the service producer limit how many
      propagated Private Service Connect connections can be established to
      this service attachment from a single consumer. If the connection
      preference of the service attachment is ACCEPT_MANUAL, the limit applies
      to each project or network that is listed in the consumer accept list.
      If the connection preference of the service attachment is
      ACCEPT_AUTOMATIC, the limit applies to each project that contains a
      connected endpoint. If unspecified, the default propagated connection
      limit is 250.
    pscServiceAttachmentId: [Output Only] An 128-bit global unique ID of the
      PSC service attachment.
    reconcileConnections: This flag determines whether a consumer
      accept/reject list change can reconcile the statuses of existing
      ACCEPTED or REJECTED PSC endpoints. - If false, connection policy update
      will only affect existing PENDING PSC endpoints. Existing
      ACCEPTED/REJECTED endpoints will remain untouched regardless how the
      connection policy is modified . - If true, update will affect both
      PENDING and ACCEPTED/REJECTED PSC endpoints. For example, an ACCEPTED
      PSC endpoint will be moved to REJECTED if its project is added to the
      reject list. For newly created service attachment, this boolean defaults
      to false.
    region: [Output Only] URL of the region where the service attachment
      resides. This field applies only to the region resource. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    targetService: The URL of a service serving the endpoint identified by
      this service attachment.
    tunnelingConfig: When a tunneling config is set on this service attachment
      it will encapsulate traffic between consumer and producer. When
      tunneling is enabled: - nat_subnets must be unset -
      enable_proxy_protocol must be false - producer_forwarding_rule must be a
      L4 ILB. -
  """

  class ConnectionPreferenceValueValuesEnum(_messages.Enum):
    r"""The connection preference of service attachment. The value can be set
    to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that
    always accepts the connection from consumer forwarding rules.

    Values:
      ACCEPT_AUTOMATIC: <no description>
      ACCEPT_MANUAL: <no description>
      CONNECTION_PREFERENCE_UNSPECIFIED: <no description>
    """
    ACCEPT_AUTOMATIC = 0
    ACCEPT_MANUAL = 1
    CONNECTION_PREFERENCE_UNSPECIFIED = 2

  connectedEndpoints = _messages.MessageField('ServiceAttachmentConnectedEndpoint', 1, repeated=True)
  connectionPreference = _messages.EnumField('ConnectionPreferenceValueValuesEnum', 2)
  consumerAcceptLists = _messages.MessageField('ServiceAttachmentConsumerProjectLimit', 3, repeated=True)
  consumerRejectLists = _messages.StringField(4, repeated=True)
  creationTimestamp = _messages.StringField(5)
  description = _messages.StringField(6)
  domainNames = _messages.StringField(7, repeated=True)
  enableProxyProtocol = _messages.BooleanField(8)
  fingerprint = _messages.BytesField(9)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(11, default='compute#serviceAttachment')
  name = _messages.StringField(12)
  natSubnets = _messages.StringField(13, repeated=True)
  producerForwardingRule = _messages.StringField(14)
  propagatedConnectionLimit = _messages.IntegerField(15, variant=_messages.Variant.UINT32)
  pscServiceAttachmentId = _messages.MessageField('Uint128', 16)
  reconcileConnections = _messages.BooleanField(17)
  region = _messages.StringField(18)
  selfLink = _messages.StringField(19)
  targetService = _messages.StringField(20)
  tunnelingConfig = _messages.MessageField('ServiceAttachmentTunnelingConfig', 21)


class ServiceAttachmentAggregatedList(_messages.Message):
  r"""Contains a list of ServiceAttachmentsScopedList.

  Messages:
    ItemsValue: A list of ServiceAttachmentsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ServiceAttachmentsScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of ServiceAttachmentsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        ServiceAttachments.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A ServiceAttachmentsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ServiceAttachmentsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#serviceAttachmentAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class ServiceAttachmentConnectedEndpoint(_messages.Message):
  r"""[Output Only] A connection connected to this service attachment.

  Enums:
    StatusValueValuesEnum: The status of a connected endpoint to this service
      attachment.

  Fields:
    consumerNetwork: The url of the consumer network.
    endpoint: The url of a connected endpoint.
    propagatedConnectionCount: The number of consumer Network Connectivity
      Center spokes that the connected Private Service Connect endpoint has
      propagated to.
    pscConnectionId: The PSC connection id of the connected endpoint.
    status: The status of a connected endpoint to this service attachment.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""The status of a connected endpoint to this service attachment.

    Values:
      ACCEPTED: The connection has been accepted by the producer.
      CLOSED: The connection has been closed by the producer.
      NEEDS_ATTENTION: The connection has been accepted by the producer, but
        the producer needs to take further action before the forwarding rule
        can serve traffic.
      PENDING: The connection is pending acceptance by the producer.
      REJECTED: The consumer is still connected but not using the connection.
      STATUS_UNSPECIFIED: <no description>
    """
    ACCEPTED = 0
    CLOSED = 1
    NEEDS_ATTENTION = 2
    PENDING = 3
    REJECTED = 4
    STATUS_UNSPECIFIED = 5

  consumerNetwork = _messages.StringField(1)
  endpoint = _messages.StringField(2)
  propagatedConnectionCount = _messages.IntegerField(3, variant=_messages.Variant.UINT32)
  pscConnectionId = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  status = _messages.EnumField('StatusValueValuesEnum', 5)


class ServiceAttachmentConsumerProjectLimit(_messages.Message):
  r"""A ServiceAttachmentConsumerProjectLimit object.

  Fields:
    connectionLimit: The value of the limit to set.
    networkUrl: The network URL for the network to set the limit for.
    projectIdOrNum: The project id or number for the project to set the limit
      for.
  """

  connectionLimit = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  networkUrl = _messages.StringField(2)
  projectIdOrNum = _messages.StringField(3)


class ServiceAttachmentList(_messages.Message):
  r"""A ServiceAttachmentList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ServiceAttachment resources.
    kind: [Output Only] Type of the resource. Always compute#serviceAttachment
      for service attachments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ServiceAttachment', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#serviceAttachmentList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ServiceAttachmentTunnelingConfig(_messages.Message):
  r"""Use to configure this PSC connection in tunneling mode. In tunneling
  mode traffic from consumer to producer will be encapsulated as it crosses
  the VPC boundary and traffic from producer to consumer will be decapsulated
  in the same manner.

  Enums:
    EncapsulationProfileValueValuesEnum: Specify the encapsulation protocol
      and what metadata to include in incoming encapsulated packet headers.
    RoutingModeValueValuesEnum: How this Service Attachment will treat traffic
      sent to the tunnel_ip, destined for the consumer network.

  Fields:
    encapsulationProfile: Specify the encapsulation protocol and what metadata
      to include in incoming encapsulated packet headers.
    routingMode: How this Service Attachment will treat traffic sent to the
      tunnel_ip, destined for the consumer network.
  """

  class EncapsulationProfileValueValuesEnum(_messages.Enum):
    r"""Specify the encapsulation protocol and what metadata to include in
    incoming encapsulated packet headers.

    Values:
      GENEVE_SECURITY_V1: Use GENEVE encapsulation protocol and include the
        SECURITY_V1 set of GENEVE headers.
      UNSPECIFIED_ENCAPSULATION_PROFILE: <no description>
    """
    GENEVE_SECURITY_V1 = 0
    UNSPECIFIED_ENCAPSULATION_PROFILE = 1

  class RoutingModeValueValuesEnum(_messages.Enum):
    r"""How this Service Attachment will treat traffic sent to the tunnel_ip,
    destined for the consumer network.

    Values:
      PACKET_INJECTION: Traffic sent to this service attachment will be
        reinjected into the consumer network.
      STANDARD_ROUTING: Response traffic, after de-encapsulation, will be
        returned to the client.
      UNSPECIFIED_ROUTING_MODE: <no description>
    """
    PACKET_INJECTION = 0
    STANDARD_ROUTING = 1
    UNSPECIFIED_ROUTING_MODE = 2

  encapsulationProfile = _messages.EnumField('EncapsulationProfileValueValuesEnum', 1)
  routingMode = _messages.EnumField('RoutingModeValueValuesEnum', 2)


class ServiceAttachmentsScopedList(_messages.Message):
  r"""A ServiceAttachmentsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of service
      attachments when the list is empty.

  Fields:
    serviceAttachments: A list of ServiceAttachments contained in this scope.
    warning: Informational warning which replaces the list of service
      attachments when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of service attachments
    when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  serviceAttachments = _messages.MessageField('ServiceAttachment', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ServiceIntegrationSpec(_messages.Message):
  r"""Specifies the parameters to configure an integration with instances.

  Fields:
    backupDr: A ServiceIntegrationSpecBackupDRSpec attribute.
  """

  backupDr = _messages.MessageField('ServiceIntegrationSpecBackupDRSpec', 1)


class ServiceIntegrationSpecBackupDRSpec(_messages.Message):
  r"""Specifies parameters to Backup and DR to attach a BackupPlan to a
  compute instance for managed VM backup.

  Fields:
    plan: The BackupPlan resource to attach to the instance. Specified as a
      resource reference in instances, and regional instance templates, and as
      just the plan name in global instance templates
  """

  plan = _messages.StringField(1)


class SetCommonInstanceMetadataOperationMetadata(_messages.Message):
  r"""A SetCommonInstanceMetadataOperationMetadata object.

  Messages:
    PerLocationOperationsValue: [Output Only] Status information per location
      (location name is key). Example key: zones/us-central1-a

  Fields:
    clientOperationId: [Output Only] The client operation id.
    perLocationOperations: [Output Only] Status information per location
      (location name is key). Example key: zones/us-central1-a
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class PerLocationOperationsValue(_messages.Message):
    r"""[Output Only] Status information per location (location name is key).
    Example key: zones/us-central1-a

    Messages:
      AdditionalProperty: An additional property for a
        PerLocationOperationsValue object.

    Fields:
      additionalProperties: Additional properties of type
        PerLocationOperationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a PerLocationOperationsValue object.

      Fields:
        key: Name of the additional property.
        value: A
          SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
          attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  clientOperationId = _messages.StringField(1)
  perLocationOperations = _messages.MessageField('PerLocationOperationsValue', 2)


class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo(_messages.Message):
  r"""A SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
  object.

  Enums:
    StateValueValuesEnum: [Output Only] Status of the action, which can be one
      of the following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or
      `DONE`.

  Fields:
    error: [Output Only] If state is `ABANDONED` or `FAILED`, this field is
      populated.
    state: [Output Only] Status of the action, which can be one of the
      following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or
      `DONE`.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] Status of the action, which can be one of the following:
    `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`.

    Values:
      ABANDONED: Operation not tracked in this location e.g. zone is marked as
        DOWN.
      DONE: Operation has completed successfully.
      FAILED: Operation is in an error state.
      PROPAGATED: Operation is confirmed to be in the location.
      PROPAGATING: Operation is not yet confirmed to have been created in the
        location.
      UNSPECIFIED: <no description>
    """
    ABANDONED = 0
    DONE = 1
    FAILED = 2
    PROPAGATED = 3
    PROPAGATING = 4
    UNSPECIFIED = 5

  error = _messages.MessageField('Status', 1)
  state = _messages.EnumField('StateValueValuesEnum', 2)


class ShareSettings(_messages.Message):
  r"""The share setting for reservations and sole tenancy node groups.

  Enums:
    ShareTypeValueValuesEnum: Type of sharing for this shared-reservation

  Messages:
    FolderMapValue: A map of folder id and folder config to specify consumer
      projects for this shared-reservation. This is only valid when
      share_type's value is DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS. Folder id
      should be a string of number, and without "folders/" prefix.
    ProjectMapValue: A map of project id and project config. This is only
      valid when share_type's value is SPECIFIC_PROJECTS.

  Fields:
    folderMap: A map of folder id and folder config to specify consumer
      projects for this shared-reservation. This is only valid when
      share_type's value is DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS. Folder id
      should be a string of number, and without "folders/" prefix.
    projectMap: A map of project id and project config. This is only valid
      when share_type's value is SPECIFIC_PROJECTS.
    projects: A List of Project names to specify consumer projects for this
      shared-reservation. This is only valid when share_type's value is
      SPECIFIC_PROJECTS.
    shareType: Type of sharing for this shared-reservation
  """

  class ShareTypeValueValuesEnum(_messages.Enum):
    r"""Type of sharing for this shared-reservation

    Values:
      DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS: Shared-reservation is open to
        direct child projects of specific folders.
      LOCAL: Default value.
      ORGANIZATION: Shared-reservation is open to entire Organization
      SHARE_TYPE_UNSPECIFIED: Default value. This value is unused.
      SPECIFIC_PROJECTS: Shared-reservation is open to specific projects
    """
    DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 0
    LOCAL = 1
    ORGANIZATION = 2
    SHARE_TYPE_UNSPECIFIED = 3
    SPECIFIC_PROJECTS = 4

  @encoding.MapUnrecognizedFields('additionalProperties')
  class FolderMapValue(_messages.Message):
    r"""A map of folder id and folder config to specify consumer projects for
    this shared-reservation. This is only valid when share_type's value is
    DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS. Folder id should be a string of
    number, and without "folders/" prefix.

    Messages:
      AdditionalProperty: An additional property for a FolderMapValue object.

    Fields:
      additionalProperties: Additional properties of type FolderMapValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a FolderMapValue object.

      Fields:
        key: Name of the additional property.
        value: A ShareSettingsFolderConfig attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ShareSettingsFolderConfig', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ProjectMapValue(_messages.Message):
    r"""A map of project id and project config. This is only valid when
    share_type's value is SPECIFIC_PROJECTS.

    Messages:
      AdditionalProperty: An additional property for a ProjectMapValue object.

    Fields:
      additionalProperties: Additional properties of type ProjectMapValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ProjectMapValue object.

      Fields:
        key: Name of the additional property.
        value: A ShareSettingsProjectConfig attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ShareSettingsProjectConfig', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  folderMap = _messages.MessageField('FolderMapValue', 1)
  projectMap = _messages.MessageField('ProjectMapValue', 2)
  projects = _messages.StringField(3, repeated=True)
  shareType = _messages.EnumField('ShareTypeValueValuesEnum', 4)


class ShareSettingsFolderConfig(_messages.Message):
  r"""Config for each folder in the share settings.

  Fields:
    folderId: The folder ID, should be same as the key of this folder config
      in the parent map. Folder id should be a string of number, and without
      "folders/" prefix.
  """

  folderId = _messages.StringField(1)


class ShareSettingsProjectConfig(_messages.Message):
  r"""Config for each project in the share settings.

  Fields:
    projectId: The project ID, should be same as the key of this project
      config in the parent map.
  """

  projectId = _messages.StringField(1)


class ShieldedInstanceConfig(_messages.Message):
  r"""A set of Shielded Instance options.

  Fields:
    enableIntegrityMonitoring: Defines whether the instance has integrity
      monitoring enabled. Enabled by default.
    enableSecureBoot: Defines whether the instance has Secure Boot enabled.
      Disabled by default.
    enableVtpm: Defines whether the instance has the vTPM enabled. Enabled by
      default.
  """

  enableIntegrityMonitoring = _messages.BooleanField(1)
  enableSecureBoot = _messages.BooleanField(2)
  enableVtpm = _messages.BooleanField(3)


class ShieldedInstanceIdentity(_messages.Message):
  r"""A Shielded Instance Identity.

  Fields:
    eccP256EncryptionKey: An Endorsement Key (EK) made by the ECC P256
      algorithm issued to the Shielded Instance's vTPM.
    eccP256SigningKey: An Attestation Key (AK) made by the ECC P256 algorithm
      issued to the Shielded Instance's vTPM.
    encryptionKey: An Endorsement Key (EK) made by the RSA 2048 algorithm
      issued to the Shielded Instance's vTPM.
    kind: [Output Only] Type of the resource. Always
      compute#shieldedInstanceIdentity for shielded Instance identity entry.
    signingKey: An Attestation Key (AK) made by the RSA 2048 algorithm issued
      to the Shielded Instance's vTPM.
  """

  eccP256EncryptionKey = _messages.MessageField('ShieldedInstanceIdentityEntry', 1)
  eccP256SigningKey = _messages.MessageField('ShieldedInstanceIdentityEntry', 2)
  encryptionKey = _messages.MessageField('ShieldedInstanceIdentityEntry', 3)
  kind = _messages.StringField(4, default='compute#shieldedInstanceIdentity')
  signingKey = _messages.MessageField('ShieldedInstanceIdentityEntry', 5)


class ShieldedInstanceIdentityEntry(_messages.Message):
  r"""A Shielded Instance Identity Entry.

  Fields:
    ekCert: A PEM-encoded X.509 certificate. This field can be empty.
    ekPub: A PEM-encoded public key.
  """

  ekCert = _messages.StringField(1)
  ekPub = _messages.StringField(2)


class ShieldedInstanceIntegrityPolicy(_messages.Message):
  r"""The policy describes the baseline against which Instance boot integrity
  is measured.

  Fields:
    updateAutoLearnPolicy: Updates the integrity policy baseline using the
      measurements from the VM instance's most recent boot.
  """

  updateAutoLearnPolicy = _messages.BooleanField(1)


class ShieldedVmConfig(_messages.Message):
  r"""A set of Shielded VM options.

  Fields:
    enableIntegrityMonitoring: Defines whether the instance has integrity
      monitoring enabled.
    enableSecureBoot: Defines whether the instance has Secure Boot enabled.
    enableVtpm: Defines whether the instance has the vTPM enabled.
  """

  enableIntegrityMonitoring = _messages.BooleanField(1)
  enableSecureBoot = _messages.BooleanField(2)
  enableVtpm = _messages.BooleanField(3)


class ShieldedVmIdentity(_messages.Message):
  r"""A Shielded VM Identity.

  Fields:
    encryptionKey: An Endorsement Key (EK) issued to the Shielded VM's vTPM.
    kind: [Output Only] Type of the resource. Always
      compute#shieldedVmIdentity for shielded VM identity entry.
    signingKey: An Attestation Key (AK) issued to the Shielded VM's vTPM.
  """

  encryptionKey = _messages.MessageField('ShieldedVmIdentityEntry', 1)
  kind = _messages.StringField(2, default='compute#shieldedVmIdentity')
  signingKey = _messages.MessageField('ShieldedVmIdentityEntry', 3)


class ShieldedVmIdentityEntry(_messages.Message):
  r"""A Shielded Instance Identity Entry.

  Fields:
    ekCert: A PEM-encoded X.509 certificate. This field can be empty.
    ekPub: A PEM-encoded public key.
  """

  ekCert = _messages.StringField(1)
  ekPub = _messages.StringField(2)


class ShieldedVmIntegrityPolicy(_messages.Message):
  r"""The policy describes the baseline against which VM instance boot
  integrity is measured.

  Fields:
    updateAutoLearnPolicy: Updates the integrity policy baseline using the
      measurements from the VM instance's most recent boot.
  """

  updateAutoLearnPolicy = _messages.BooleanField(1)


class SignedUrlKey(_messages.Message):
  r"""Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs

  Fields:
    keyName: Name of the key. The name must be 1-63 characters long, and
      comply with RFC1035. Specifically, the name must be 1-63 characters long
      and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    keyValue: 128-bit key value used for signing the URL. The key value must
      be a valid RFC 4648 Section 5 base64url encoded string.
  """

  keyName = _messages.StringField(1)
  keyValue = _messages.StringField(2)


class Snapshot(_messages.Message):
  r"""Represents a Persistent Disk Snapshot resource. You can use snapshots to
  back up data on a regular interval. For more information, read Creating
  persistent disk snapshots. LINT.IfChange

  Enums:
    ArchitectureValueValuesEnum: [Output Only] The architecture of the
      snapshot. Valid values are ARM64 or X86_64.
    SnapshotTypeValueValuesEnum: Indicates the type of the snapshot.
    StatusValueValuesEnum: [Output Only] The status of the snapshot. This can
      be CREATING, DELETING, FAILED, READY, or UPLOADING.
    StorageBytesStatusValueValuesEnum: [Output Only] An indicator whether
      storageBytes is in a stable state or it is being adjusted as a result of
      shared storage reallocation. This status can either be UPDATING, meaning
      the size of the snapshot is being updated, or UP_TO_DATE, meaning the
      size of the snapshot is up-to-date.

  Messages:
    LabelsValue: Labels to apply to this snapshot. These can be later modified
      by the setLabels method. Label values may be empty.

  Fields:
    architecture: [Output Only] The architecture of the snapshot. Valid values
      are ARM64 or X86_64.
    autoCreated: [Output Only] Set to true if snapshots are automatically
      created by applying resource policy on the target disk.
    chainName: Creates the new snapshot in the snapshot chain labeled with the
      specified name. The chain name must be 1-63 characters long and comply
      with RFC1035. This is an uncommon option only for advanced service
      owners who needs to create separate snapshot chains, for example, for
      chargeback tracking. When you describe your snapshot resource, this
      field is visible only if it has a non-empty value.
    creationSizeBytes: [Output Only] Size in bytes of the snapshot at creation
      time.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    diskSizeGb: [Output Only] Size of the source disk, specified in GB.
    downloadBytes: [Output Only] Number of bytes downloaded to restore a
      snapshot to a disk.
    enableConfidentialCompute: Whether this snapshot is created from a
      confidential compute mode disk. [Output Only]: This field is not set by
      user, but from source disk.
    guestFlush: [Input Only] Whether to attempt an application consistent
      snapshot by informing the OS to prepare for the snapshot process.
    guestOsFeatures: [Output Only] A list of features to enable on the guest
      operating system. Applicable only for bootable images. Read Enabling
      guest operating system features to see a list of available options.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#snapshot for
      Snapshot resources.
    labelFingerprint: A fingerprint for the labels being applied to this
      snapshot, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a snapshot.
    labels: Labels to apply to this snapshot. These can be later modified by
      the setLabels method. Label values may be empty.
    licenseCodes: [Output Only] Integer license codes indicating which
      licenses are attached to this snapshot.
    licenses: [Output Only] A list of public visible licenses that apply to
      this snapshot. This can be because the original image had licenses
      attached (such as a Windows image).
    locationHint: An opaque location hint used to place the snapshot close to
      other resources. This field is for use by internal tools that use the
      public API.
    maxRetentionDays: Number of days the snapshot should be retained before
      being deleted automatically.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the snapshot resides. Only
      applicable for regional snapshots.
    resourceStatus: [Output only] ResourceStatus of the Snapshot resource
    satisfiesPzi: Output only. Reserved for future use.
    satisfiesPzs: [Output Only] Reserved for future use.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    snapshotEncryptionKey: Encrypts the snapshot using a customer-supplied
      encryption key. After you encrypt a snapshot using a customer-supplied
      key, you must provide the same key if you use the snapshot later. For
      example, you must provide the encryption key when you create a disk from
      the encrypted snapshot in a future request. Customer-supplied encryption
      keys do not protect access to metadata of the snapshot. If you do not
      provide an encryption key when creating the snapshot, then the snapshot
      will be encrypted using an automatically generated key and you do not
      need to provide a key to use the snapshot later.
    snapshotGroupId: [Output Only] The unique ID of the snapshot group that
      this snapshot belongs to.
    snapshotGroupName: [Output only] The snapshot group that this snapshot
      belongs to.
    snapshotType: Indicates the type of the snapshot.
    sourceDisk: The source disk used to create this snapshot.
    sourceDiskEncryptionKey: The customer-supplied encryption key of the
      source disk. Required if the source disk is protected by a customer-
      supplied encryption key.
    sourceDiskForRecoveryCheckpoint: The source disk whose recovery checkpoint
      will be used to create this snapshot.
    sourceDiskId: [Output Only] The ID value of the disk used to create this
      snapshot. This value may be used to determine whether the snapshot was
      taken from the current or a previous instance of a given disk name.
    sourceInstantSnapshot: The source instant snapshot used to create this
      snapshot. You can provide this as a partial or full URL to the resource.
      For example, the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /instantSnapshots/instantSnapshot -
      projects/project/zones/zone/instantSnapshots/instantSnapshot -
      zones/zone/instantSnapshots/instantSnapshot
    sourceInstantSnapshotEncryptionKey: Customer provided encryption key when
      creating Snapshot from Instant Snapshot.
    sourceInstantSnapshotId: [Output Only] The unique ID of the instant
      snapshot used to create this snapshot. This value identifies the exact
      instant snapshot that was used to create this snapshot. For example, if
      you created the snapshot from an instant snapshot that was later deleted
      and recreated under the same name, the source instant snapshot ID would
      identify the exact instant snapshot that was used.
    sourceSnapshotSchedulePolicy: [Output Only] URL of the resource policy
      which created this scheduled snapshot.
    sourceSnapshotSchedulePolicyId: [Output Only] ID of the resource policy
      which created this scheduled snapshot.
    status: [Output Only] The status of the snapshot. This can be CREATING,
      DELETING, FAILED, READY, or UPLOADING.
    storageBytes: [Output Only] A size of the storage used by the snapshot. As
      snapshots share storage, this number is expected to change with snapshot
      creation/deletion.
    storageBytesStatus: [Output Only] An indicator whether storageBytes is in
      a stable state or it is being adjusted as a result of shared storage
      reallocation. This status can either be UPDATING, meaning the size of
      the snapshot is being updated, or UP_TO_DATE, meaning the size of the
      snapshot is up-to-date.
    storageLocations: Cloud Storage bucket storage location of the snapshot
      (regional or multi-regional).
    userLicenses: [Output Only] A list of user provided licenses represented
      by a list of URLs to the license resource.
  """

  class ArchitectureValueValuesEnum(_messages.Enum):
    r"""[Output Only] The architecture of the snapshot. Valid values are ARM64
    or X86_64.

    Values:
      ARCHITECTURE_UNSPECIFIED: Default value indicating Architecture is not
        set.
      ARM64: Machines with architecture ARM64
      X86_64: Machines with architecture X86_64
    """
    ARCHITECTURE_UNSPECIFIED = 0
    ARM64 = 1
    X86_64 = 2

  class SnapshotTypeValueValuesEnum(_messages.Enum):
    r"""Indicates the type of the snapshot.

    Values:
      ARCHIVE: <no description>
      STANDARD: <no description>
    """
    ARCHIVE = 0
    STANDARD = 1

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the snapshot. This can be CREATING,
    DELETING, FAILED, READY, or UPLOADING.

    Values:
      CREATING: Snapshot creation is in progress.
      DELETING: Snapshot is currently being deleted.
      FAILED: Snapshot creation failed.
      READY: Snapshot has been created successfully.
      UPLOADING: Snapshot is being uploaded.
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3
    UPLOADING = 4

  class StorageBytesStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] An indicator whether storageBytes is in a stable state
    or it is being adjusted as a result of shared storage reallocation. This
    status can either be UPDATING, meaning the size of the snapshot is being
    updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.

    Values:
      UPDATING: <no description>
      UP_TO_DATE: <no description>
    """
    UPDATING = 0
    UP_TO_DATE = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this snapshot. These can be later modified by the
    setLabels method. Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  architecture = _messages.EnumField('ArchitectureValueValuesEnum', 1)
  autoCreated = _messages.BooleanField(2)
  chainName = _messages.StringField(3)
  creationSizeBytes = _messages.IntegerField(4)
  creationTimestamp = _messages.StringField(5)
  description = _messages.StringField(6)
  diskSizeGb = _messages.IntegerField(7)
  downloadBytes = _messages.IntegerField(8)
  enableConfidentialCompute = _messages.BooleanField(9)
  guestFlush = _messages.BooleanField(10)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 11, repeated=True)
  id = _messages.IntegerField(12, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(13, default='compute#snapshot')
  labelFingerprint = _messages.BytesField(14)
  labels = _messages.MessageField('LabelsValue', 15)
  licenseCodes = _messages.IntegerField(16, repeated=True)
  licenses = _messages.StringField(17, repeated=True)
  locationHint = _messages.StringField(18)
  maxRetentionDays = _messages.IntegerField(19, variant=_messages.Variant.INT32)
  name = _messages.StringField(20)
  region = _messages.StringField(21)
  resourceStatus = _messages.MessageField('SnapshotResourceStatus', 22)
  satisfiesPzi = _messages.BooleanField(23)
  satisfiesPzs = _messages.BooleanField(24)
  selfLink = _messages.StringField(25)
  selfLinkWithId = _messages.StringField(26)
  snapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 27)
  snapshotGroupId = _messages.StringField(28)
  snapshotGroupName = _messages.StringField(29)
  snapshotType = _messages.EnumField('SnapshotTypeValueValuesEnum', 30)
  sourceDisk = _messages.StringField(31)
  sourceDiskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 32)
  sourceDiskForRecoveryCheckpoint = _messages.StringField(33)
  sourceDiskId = _messages.StringField(34)
  sourceInstantSnapshot = _messages.StringField(35)
  sourceInstantSnapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 36)
  sourceInstantSnapshotId = _messages.StringField(37)
  sourceSnapshotSchedulePolicy = _messages.StringField(38)
  sourceSnapshotSchedulePolicyId = _messages.StringField(39)
  status = _messages.EnumField('StatusValueValuesEnum', 40)
  storageBytes = _messages.IntegerField(41)
  storageBytesStatus = _messages.EnumField('StorageBytesStatusValueValuesEnum', 42)
  storageLocations = _messages.StringField(43, repeated=True)
  userLicenses = _messages.StringField(44, repeated=True)


class SnapshotAggregatedList(_messages.Message):
  r"""A SnapshotAggregatedList object.

  Messages:
    ItemsValue: A list of SnapshotsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SnapshotsScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#snapshotAggregatedList for aggregated lists of snapshots.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of SnapshotsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of snapshots.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A SnapshotsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SnapshotsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#snapshotAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class SnapshotGroup(_messages.Message):
  r"""Represents a SnapshotGroup resource. A snapshot group is a set of
  snapshots that represents a point in time state of a consistency group.

  Enums:
    StatusValueValuesEnum: [Output Only]

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: Optional. An optional description of this resource. Provide
      this property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#snapshotGroup for
      SnapshotGroup resources.
    name: Identifier. Name of the resource; provided by the client when the
      resource is created. The name must be 1-63 characters long, and comply
      with RFC1035. Specifically, the name must be 1-63 characters long and
      match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means
      the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    sourceInfo: [Output Only]
    sourceInstantSnapshotGroup: Input field for the source instant snapshot
      group.
    sourceInstantSnapshotGroupInfo: [Output Only]
    status: [Output Only]
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only]

    Values:
      CREATING: <no description>
      DELETING: <no description>
      FAILED: <no description>
      INVALID: <no description>
      READY: <no description>
      UNKNOWN: <no description>
      UPLOADING: <no description>
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    INVALID = 3
    READY = 4
    UNKNOWN = 5
    UPLOADING = 6

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default='compute#snapshotGroup')
  name = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  selfLinkWithId = _messages.StringField(7)
  sourceInfo = _messages.MessageField('SnapshotGroupSourceInfo', 8)
  sourceInstantSnapshotGroup = _messages.StringField(9)
  sourceInstantSnapshotGroupInfo = _messages.MessageField('SnapshotGroupSourceInstantSnapshotGroupInfo', 10)
  status = _messages.EnumField('StatusValueValuesEnum', 11)


class SnapshotGroupParameters(_messages.Message):
  r"""A SnapshotGroupParameters object.

  Fields:
    replicaZones: URLs of the zones where disks should be replicated to. Only
      applicable for regional resources.
    sourceSnapshotGroup: The source snapshot group used to create disks. You
      can provide this as a partial or full URL to the resource. For example,
      the following are valid values: -
      https://www.googleapis.com/compute/v1/projects/project
      /global/snapshotGroups/snapshotGroup -
      projects/project/global/snapshotGroups/snapshotGroup -
      global/snapshotGroups/snapshotGroup
    type: URL of the disk type resource describing which disk type to use to
      create disks. Provide this when creating the disk. For example:
      projects/project /zones/zone/diskTypes/pd-ssd . See Persistent disk
      types.
  """

  replicaZones = _messages.StringField(1, repeated=True)
  sourceSnapshotGroup = _messages.StringField(2)
  type = _messages.StringField(3)


class SnapshotGroupSourceInfo(_messages.Message):
  r"""A SnapshotGroupSourceInfo object.

  Fields:
    consistencyGroup: A string attribute.
    consistencyGroupId: A string attribute.
  """

  consistencyGroup = _messages.StringField(1)
  consistencyGroupId = _messages.StringField(2)


class SnapshotGroupSourceInstantSnapshotGroupInfo(_messages.Message):
  r"""A SnapshotGroupSourceInstantSnapshotGroupInfo object.

  Fields:
    instantSnapshotGroup: A string attribute.
    instantSnapshotGroupId: A string attribute.
  """

  instantSnapshotGroup = _messages.StringField(1)
  instantSnapshotGroupId = _messages.StringField(2)


class SnapshotList(_messages.Message):
  r"""Contains a list of Snapshot resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Snapshot resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Snapshot', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#snapshotList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class SnapshotResourceStatus(_messages.Message):
  r"""A SnapshotResourceStatus object.

  Fields:
    scheduledDeletionTime: [Output only] Scheduled deletion time of the
      snapshot. The snapshot will be deleted by the at any point within one
      hour after the deletion time.
  """

  scheduledDeletionTime = _messages.StringField(1)


class SnapshotSettings(_messages.Message):
  r"""A SnapshotSettings object.

  Fields:
    accessLocation: (Regional snapshots use only)Policy of which location is
      allowed to access snapshot.
    storageLocation: Policy of which storage location is going to be resolved,
      and additional data that particularizes how the policy is going to be
      carried out.
  """

  accessLocation = _messages.MessageField('SnapshotSettingsAccessLocation', 1)
  storageLocation = _messages.MessageField('SnapshotSettingsStorageLocationSettings', 2)


class SnapshotSettingsAccessLocation(_messages.Message):
  r"""A SnapshotSettingsAccessLocation object.

  Enums:
    PolicyValueValuesEnum: Policy of which location is allowed to access
      snapshot.

  Messages:
    LocationsValue: List of regions that can restore a regional snapshot from
      the current region

  Fields:
    locations: List of regions that can restore a regional snapshot from the
      current region
    policy: Policy of which location is allowed to access snapshot.
  """

  class PolicyValueValuesEnum(_messages.Enum):
    r"""Policy of which location is allowed to access snapshot.

    Values:
      ALL_REGIONS: Any regions will be able to access the source location.
      POLICY_UNSPECIFIED: <no description>
      SPECIFIC_REGIONS: Only allowlisted regions will be able to restore
        region scoped snapshots
    """
    ALL_REGIONS = 0
    POLICY_UNSPECIFIED = 1
    SPECIFIC_REGIONS = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LocationsValue(_messages.Message):
    r"""List of regions that can restore a regional snapshot from the current
    region

    Messages:
      AdditionalProperty: An additional property for a LocationsValue object.

    Fields:
      additionalProperties: Additional properties of type LocationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LocationsValue object.

      Fields:
        key: Name of the additional property.
        value: A SnapshotSettingsAccessLocationAccessLocationPreference
          attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SnapshotSettingsAccessLocationAccessLocationPreference', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  locations = _messages.MessageField('LocationsValue', 1)
  policy = _messages.EnumField('PolicyValueValuesEnum', 2)


class SnapshotSettingsAccessLocationAccessLocationPreference(_messages.Message):
  r"""A structure for specifying an allowed target region.

  Fields:
    region: Accessible region name
  """

  region = _messages.StringField(1)


class SnapshotSettingsStorageLocationSettings(_messages.Message):
  r"""A SnapshotSettingsStorageLocationSettings object.

  Enums:
    PolicyValueValuesEnum: The chosen location policy.

  Messages:
    LocationsValue: When the policy is SPECIFIC_LOCATIONS, snapshots will be
      stored in the locations listed in this field. Keys are Cloud Storage
      bucket locations. Only one location can be specified.

  Fields:
    locations: When the policy is SPECIFIC_LOCATIONS, snapshots will be stored
      in the locations listed in this field. Keys are Cloud Storage bucket
      locations. Only one location can be specified.
    policy: The chosen location policy.
  """

  class PolicyValueValuesEnum(_messages.Enum):
    r"""The chosen location policy.

    Values:
      LOCAL_REGION: Store snapshot in the same region as with the originating
        disk. No additional parameters are needed.
      NEAREST_MULTI_REGION: Store snapshot in the nearest multi region Cloud
        Storage bucket, relative to the originating disk. No additional
        parameters are needed.
      SPECIFIC_LOCATIONS: Store snapshot in the specific locations, as
        specified by the user. The list of regions to store must be defined
        under the `locations` field.
      STORAGE_LOCATION_POLICY_UNSPECIFIED: <no description>
    """
    LOCAL_REGION = 0
    NEAREST_MULTI_REGION = 1
    SPECIFIC_LOCATIONS = 2
    STORAGE_LOCATION_POLICY_UNSPECIFIED = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LocationsValue(_messages.Message):
    r"""When the policy is SPECIFIC_LOCATIONS, snapshots will be stored in the
    locations listed in this field. Keys are Cloud Storage bucket locations.
    Only one location can be specified.

    Messages:
      AdditionalProperty: An additional property for a LocationsValue object.

    Fields:
      additionalProperties: Additional properties of type LocationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LocationsValue object.

      Fields:
        key: Name of the additional property.
        value: A
          SnapshotSettingsStorageLocationSettingsStorageLocationPreference
          attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SnapshotSettingsStorageLocationSettingsStorageLocationPreference', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  locations = _messages.MessageField('LocationsValue', 1)
  policy = _messages.EnumField('PolicyValueValuesEnum', 2)


class SnapshotSettingsStorageLocationSettingsStorageLocationPreference(_messages.Message):
  r"""A structure for specifying storage locations.

  Fields:
    name: Name of the location. It should be one of the Cloud Storage buckets.
      Only one location can be specified.
  """

  name = _messages.StringField(1)


class SnapshotsScopedList(_messages.Message):
  r"""A SnapshotsScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of snapshots when the list is empty.

  Fields:
    snapshots: [Output Only] A list of snapshots contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      snapshots when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    snapshots when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  snapshots = _messages.MessageField('Snapshot', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class SourceDiskEncryptionKey(_messages.Message):
  r"""A SourceDiskEncryptionKey object.

  Fields:
    diskEncryptionKey: The customer-supplied encryption key of the source
      disk. Required if the source disk is protected by a customer-supplied
      encryption key.
    sourceDisk: URL of the disk attached to the source instance. This can be a
      full or valid partial URL. For example, the following are valid values:
      - https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /disks/disk - projects/project/zones/zone/disks/disk -
      zones/zone/disks/disk
  """

  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 1)
  sourceDisk = _messages.StringField(2)


class SourceInstanceParams(_messages.Message):
  r"""A specification of the parameters to use when creating the instance
  template from a source instance.

  Fields:
    diskConfigs: Attached disks configuration. If not provided, defaults are
      applied: For boot disk and any other R/W disks, the source images for
      each disk will be used. For read-only disks, they will be attached in
      read-only mode. Local SSD disks will be created as blank volumes.
  """

  diskConfigs = _messages.MessageField('DiskInstantiationConfig', 1, repeated=True)


class SourceInstanceProperties(_messages.Message):
  r"""DEPRECATED: Please use compute#instanceProperties instead. New
  properties will not be added to this field.

  Enums:
    KeyRevocationActionTypeValueValuesEnum: KeyRevocationActionType of the
      instance. Supported options are "STOP" and "NONE". The default value is
      "NONE" if it is not specified.
    PostKeyRevocationActionTypeValueValuesEnum: PostKeyRevocationActionType of
      the instance.

  Messages:
    LabelsValue: Labels to apply to instances that are created from this
      machine image.

  Fields:
    canIpForward: Enables instances created based on this machine image to
      send packets with source IP addresses other than their own and receive
      packets with destination IP addresses other than their own. If these
      instances will be used as an IP gateway or it will be set as the next-
      hop in a Route resource, specify true. If unsure, leave this set to
      false. See the Enable IP forwarding documentation for more information.
    deletionProtection: Whether the instance created from this machine image
      should be protected against deletion.
    description: An optional text description for the instances that are
      created from this machine image.
    disks: An array of disks that are associated with the instances that are
      created from this machine image.
    guestAccelerators: A list of guest accelerator cards' type and count to
      use for instances created from this machine image.
    keyRevocationActionType: KeyRevocationActionType of the instance.
      Supported options are "STOP" and "NONE". The default value is "NONE" if
      it is not specified.
    labels: Labels to apply to instances that are created from this machine
      image.
    machineType: The machine type to use for instances that are created from
      this machine image.
    metadata: The metadata key/value pairs to assign to instances that are
      created from this machine image. These pairs can consist of custom
      metadata or predefined keys. See Project and instance metadata for more
      information.
    minCpuPlatform: Minimum cpu/platform to be used by instances created from
      this machine image. The instance may be scheduled on the specified or
      newer cpu/platform. Applicable values are the friendly names of CPU
      platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform:
      "Intel Sandy Bridge". For more information, read Specifying a Minimum
      CPU Platform.
    networkInterfaces: An array of network access configurations for this
      interface.
    postKeyRevocationActionType: PostKeyRevocationActionType of the instance.
    scheduling: Specifies the scheduling options for the instances that are
      created from this machine image.
    serviceAccounts: A list of service accounts with specified scopes. Access
      tokens for these service accounts are available to the instances that
      are created from this machine image. Use metadata queries to obtain the
      access tokens for these instances.
    tags: A list of tags to apply to the instances that are created from this
      machine image. The tags identify valid sources or targets for network
      firewalls. The setTags method can modify this list of tags. Each tag
      within the list must comply with RFC1035.
  """

  class KeyRevocationActionTypeValueValuesEnum(_messages.Enum):
    r"""KeyRevocationActionType of the instance. Supported options are "STOP"
    and "NONE". The default value is "NONE" if it is not specified.

    Values:
      KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED: Default value. This value is
        unused.
      NONE: Indicates user chose no operation.
      STOP: Indicates user chose to opt for VM shutdown on key revocation.
    """
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 0
    NONE = 1
    STOP = 2

  class PostKeyRevocationActionTypeValueValuesEnum(_messages.Enum):
    r"""PostKeyRevocationActionType of the instance.

    Values:
      NOOP: Indicates user chose no operation.
      POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED: Default value. This value
        is unused.
      SHUTDOWN: Indicates user chose to opt for VM shutdown on key revocation.
    """
    NOOP = 0
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 1
    SHUTDOWN = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to instances that are created from this machine image.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  canIpForward = _messages.BooleanField(1)
  deletionProtection = _messages.BooleanField(2)
  description = _messages.StringField(3)
  disks = _messages.MessageField('SavedAttachedDisk', 4, repeated=True)
  guestAccelerators = _messages.MessageField('AcceleratorConfig', 5, repeated=True)
  keyRevocationActionType = _messages.EnumField('KeyRevocationActionTypeValueValuesEnum', 6)
  labels = _messages.MessageField('LabelsValue', 7)
  machineType = _messages.StringField(8)
  metadata = _messages.MessageField('Metadata', 9)
  minCpuPlatform = _messages.StringField(10)
  networkInterfaces = _messages.MessageField('NetworkInterface', 11, repeated=True)
  postKeyRevocationActionType = _messages.EnumField('PostKeyRevocationActionTypeValueValuesEnum', 12)
  scheduling = _messages.MessageField('Scheduling', 13)
  serviceAccounts = _messages.MessageField('ServiceAccount', 14, repeated=True)
  tags = _messages.MessageField('Tags', 15)


class SslCertificate(_messages.Message):
  r"""Represents an SSL certificate resource. Google Compute Engine has two
  SSL certificate resources: *
  [Global](/compute/docs/reference/rest/alpha/sslCertificates) *
  [Regional](/compute/docs/reference/rest/alpha/regionSslCertificates) The
  global SSL certificates (sslCertificates) are used by: - Global external
  Application Load Balancers - Classic Application Load Balancers - Proxy
  Network Load Balancers (with target SSL proxies) The regional SSL
  certificates (regionSslCertificates) are used by: - Regional external
  Application Load Balancers - Regional internal Application Load Balancers
  Optionally, certificate file contents that you upload can contain a set of
  up to five PEM-encoded certificates. The API call creates an object
  (sslCertificate) that holds this data. You can use SSL keys and certificates
  to secure connections to a load balancer. For more information, read
  Creating and using SSL certificates, SSL certificates quotas and limits, and
  Troubleshooting SSL certificates.

  Enums:
    TypeValueValuesEnum: (Optional) Specifies the type of SSL certificate,
      either "SELF_MANAGED" or "MANAGED". If not specified, the certificate is
      self-managed and the fields certificate and private_key are used.

  Fields:
    certificate: A value read into memory from a certificate file. The
      certificate file must be in PEM format. The certificate chain must be no
      greater than 5 certs long. The chain must include at least one
      intermediate cert.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    expireTime: [Output Only] Expire time of the certificate. RFC3339
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#sslCertificate
      for SSL certificates.
    managed: Configuration and status of a managed SSL certificate.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    privateKey: A value read into memory from a write-only private key file.
      The private key file must be in PEM format. For security, only insert
      requests include this field.
    region: [Output Only] URL of the region where the regional SSL Certificate
      resides. This field is not applicable to global SSL Certificate.
    selfLink: [Output only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    selfManaged: Configuration and status of a self-managed SSL certificate.
    subjectAlternativeNames: [Output Only] Domains associated with the
      certificate via Subject Alternative Name.
    type: (Optional) Specifies the type of SSL certificate, either
      "SELF_MANAGED" or "MANAGED". If not specified, the certificate is self-
      managed and the fields certificate and private_key are used.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""(Optional) Specifies the type of SSL certificate, either
    "SELF_MANAGED" or "MANAGED". If not specified, the certificate is self-
    managed and the fields certificate and private_key are used.

    Values:
      MANAGED: Google-managed SSLCertificate.
      SELF_MANAGED: Certificate uploaded by user.
      TYPE_UNSPECIFIED: <no description>
    """
    MANAGED = 0
    SELF_MANAGED = 1
    TYPE_UNSPECIFIED = 2

  certificate = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  expireTime = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default='compute#sslCertificate')
  managed = _messages.MessageField('SslCertificateManagedSslCertificate', 7)
  name = _messages.StringField(8)
  privateKey = _messages.StringField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  selfManaged = _messages.MessageField('SslCertificateSelfManagedSslCertificate', 13)
  subjectAlternativeNames = _messages.StringField(14, repeated=True)
  type = _messages.EnumField('TypeValueValuesEnum', 15)


class SslCertificateAggregatedList(_messages.Message):
  r"""A SslCertificateAggregatedList object.

  Messages:
    ItemsValue: A list of SslCertificatesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SslCertificatesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#sslCertificateAggregatedList for lists of SSL Certificates.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of SslCertificatesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        SslCertificates.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A SslCertificatesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SslCertificatesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#sslCertificateAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class SslCertificateList(_messages.Message):
  r"""Contains a list of SslCertificate resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SslCertificate resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('SslCertificate', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#sslCertificateList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class SslCertificateManagedSslCertificate(_messages.Message):
  r"""Configuration and status of a managed SSL certificate.

  Enums:
    StatusValueValuesEnum: [Output only] Status of the managed certificate
      resource.

  Messages:
    DomainStatusValue: [Output only] Detailed statuses of the domains
      specified for managed certificate resource.

  Fields:
    domainStatus: [Output only] Detailed statuses of the domains specified for
      managed certificate resource.
    domains: The domains for which a managed SSL certificate will be
      generated. Each Google-managed SSL certificate supports up to the
      [maximum number of domains per Google-managed SSL certificate](/load-
      balancing/docs/quotas#ssl_certificates).
    status: [Output only] Status of the managed certificate resource.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output only] Status of the managed certificate resource.

    Values:
      ACTIVE: The certificate management is working, and a certificate has
        been provisioned.
      MANAGED_CERTIFICATE_STATUS_UNSPECIFIED: <no description>
      PROVISIONING: The certificate management is working. GCP will attempt to
        provision the first certificate.
      PROVISIONING_FAILED: Certificate provisioning failed due to an issue
        with the DNS or load balancing configuration. For details of which
        domain failed, consult domain_status field.
      PROVISIONING_FAILED_PERMANENTLY: Certificate provisioning failed due to
        an issue with the DNS or load balancing configuration. It won't be
        retried. To try again delete and create a new managed SslCertificate
        resource. For details of which domain failed, consult domain_status
        field.
      RENEWAL_FAILED: Renewal of the certificate has failed due to an issue
        with the DNS or load balancing configuration. The existing cert is
        still serving; however, it will expire shortly. To provision a renewed
        certificate, delete and create a new managed SslCertificate resource.
        For details on which domain failed, consult domain_status field.
    """
    ACTIVE = 0
    MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 1
    PROVISIONING = 2
    PROVISIONING_FAILED = 3
    PROVISIONING_FAILED_PERMANENTLY = 4
    RENEWAL_FAILED = 5

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DomainStatusValue(_messages.Message):
    r"""[Output only] Detailed statuses of the domains specified for managed
    certificate resource.

    Messages:
      AdditionalProperty: An additional property for a DomainStatusValue
        object.

    Fields:
      additionalProperties: Additional properties of type DomainStatusValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DomainStatusValue object.

      Enums:
        ValueValueValuesEnum:

      Fields:
        key: Name of the additional property.
        value: A ValueValueValuesEnum attribute.
      """

      class ValueValueValuesEnum(_messages.Enum):
        r"""ValueValueValuesEnum enum type.

        Values:
          ACTIVE: A managed certificate can be provisioned, no issues for this
            domain.
          DOMAIN_STATUS_UNSPECIFIED: <no description>
          FAILED_CAA_CHECKING: Failed to check CAA records for the domain.
          FAILED_CAA_FORBIDDEN: Certificate issuance forbidden by an explicit
            CAA record for the domain.
          FAILED_NOT_VISIBLE: There seems to be problem with the user's DNS or
            load balancer configuration for this domain.
          FAILED_RATE_LIMITED: Reached rate-limit for certificates per top-
            level private domain.
          PROVISIONING: Certificate provisioning for this domain is under way.
            GCP will attempt to provision the first certificate.
        """
        ACTIVE = 0
        DOMAIN_STATUS_UNSPECIFIED = 1
        FAILED_CAA_CHECKING = 2
        FAILED_CAA_FORBIDDEN = 3
        FAILED_NOT_VISIBLE = 4
        FAILED_RATE_LIMITED = 5
        PROVISIONING = 6

      key = _messages.StringField(1)
      value = _messages.EnumField('ValueValueValuesEnum', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  domainStatus = _messages.MessageField('DomainStatusValue', 1)
  domains = _messages.StringField(2, repeated=True)
  status = _messages.EnumField('StatusValueValuesEnum', 3)


class SslCertificateSelfManagedSslCertificate(_messages.Message):
  r"""Configuration and status of a self-managed SSL certificate.

  Fields:
    certificate: A local certificate file. The certificate must be in PEM
      format. The certificate chain must be no greater than 5 certs long. The
      chain must include at least one intermediate cert.
    privateKey: A write-only private key in PEM format. Only insert requests
      will include this field.
  """

  certificate = _messages.StringField(1)
  privateKey = _messages.StringField(2)


class SslCertificatesScopedList(_messages.Message):
  r"""A SslCertificatesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    sslCertificates: List of SslCertificates contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  sslCertificates = _messages.MessageField('SslCertificate', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class SslPoliciesAggregatedList(_messages.Message):
  r"""A SslPoliciesAggregatedList object.

  Messages:
    ItemsValue: A list of SslPoliciesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SslPoliciesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#sslPolicyAggregatedList for lists of SSL Policies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of SslPoliciesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of SSL
        policies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A SslPoliciesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SslPoliciesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#sslPoliciesAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class SslPoliciesList(_messages.Message):
  r"""A SslPoliciesList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SslPolicy resources.
    kind: [Output Only] Type of the resource. Always compute#sslPoliciesList
      for lists of sslPolicies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('SslPolicy', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#sslPoliciesList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class SslPoliciesListAvailableFeaturesResponse(_messages.Message):
  r"""A SslPoliciesListAvailableFeaturesResponse object.

  Fields:
    features: A string attribute.
  """

  features = _messages.StringField(1, repeated=True)


class SslPoliciesScopedList(_messages.Message):
  r"""A SslPoliciesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of SSL
      policies when the list is empty.

  Fields:
    sslPolicies: A list of SslPolicies contained in this scope.
    warning: Informational warning which replaces the list of SSL policies
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of SSL policies when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  sslPolicies = _messages.MessageField('SslPolicy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class SslPolicy(_messages.Message):
  r"""Represents an SSL Policy resource. Use SSL policies to control SSL
  features, such as versions and cipher suites, that are offered by
  Application Load Balancers and proxy Network Load Balancers. For more
  information, read SSL policies overview.

  Enums:
    MinTlsVersionValueValuesEnum: The minimum version of SSL protocol that can
      be used by the clients to establish a connection with the load balancer.
      This can be one of TLS_1_0, TLS_1_1, TLS_1_2.
    ProfileValueValuesEnum: Profile specifies the set of SSL features that can
      be used by the load balancer when negotiating SSL with clients. This can
      be one of COMPATIBLE, MODERN, RESTRICTED, or CUSTOM. If using CUSTOM,
      the set of SSL features to enable must be specified in the
      customFeatures field.

  Messages:
    WarningsValueListEntry: A WarningsValueListEntry object.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customFeatures: A list of features enabled when the selected profile is
      CUSTOM. The method returns the set of features that can be specified in
      this list. This field must be empty if the profile is not CUSTOM.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    enabledFeatures: [Output Only] The list of features enabled in the SSL
      policy.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a SslPolicy. An up-to-date fingerprint
      must be provided in order to update the SslPolicy, otherwise the request
      will fail with error 412 conditionNotMet. To see the latest fingerprint,
      make a get() request to retrieve an SslPolicy.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output only] Type of the resource. Always compute#sslPolicyfor SSL
      policies.
    minTlsVersion: The minimum version of SSL protocol that can be used by the
      clients to establish a connection with the load balancer. This can be
      one of TLS_1_0, TLS_1_1, TLS_1_2.
    name: Name of the resource. The name must be 1-63 characters long, and
      comply with RFC1035. Specifically, the name must be 1-63 characters long
      and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    profile: Profile specifies the set of SSL features that can be used by the
      load balancer when negotiating SSL with clients. This can be one of
      COMPATIBLE, MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of
      SSL features to enable must be specified in the customFeatures field.
    region: [Output Only] URL of the region where the regional SSL policy
      resides. This field is not applicable to global SSL policies.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    tlsSettings: Security settings for the proxy. This field is only
      applicable to a global backend service with the loadBalancingScheme set
      to INTERNAL_SELF_MANAGED.
    warnings: [Output Only] If potential misconfigurations are detected for
      this SSL policy, this field will be populated with warning messages.
  """

  class MinTlsVersionValueValuesEnum(_messages.Enum):
    r"""The minimum version of SSL protocol that can be used by the clients to
    establish a connection with the load balancer. This can be one of TLS_1_0,
    TLS_1_1, TLS_1_2.

    Values:
      TLS_1_0: TLS 1.0
      TLS_1_1: TLS 1.1
      TLS_1_2: TLS 1.2
    """
    TLS_1_0 = 0
    TLS_1_1 = 1
    TLS_1_2 = 2

  class ProfileValueValuesEnum(_messages.Enum):
    r"""Profile specifies the set of SSL features that can be used by the load
    balancer when negotiating SSL with clients. This can be one of COMPATIBLE,
    MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of SSL features to
    enable must be specified in the customFeatures field.

    Values:
      COMPATIBLE: Compatible profile. Allows the broadset set of clients, even
        those which support only out-of-date SSL features to negotiate with
        the load balancer.
      CUSTOM: Custom profile. Allow only the set of allowed SSL features
        specified in the customFeatures field.
      MODERN: Modern profile. Supports a wide set of SSL features, allowing
        modern clients to negotiate SSL with the load balancer.
      RESTRICTED: Restricted profile. Supports a reduced set of SSL features,
        intended to meet stricter compliance requirements.
    """
    COMPATIBLE = 0
    CUSTOM = 1
    MODERN = 2
    RESTRICTED = 3

  class WarningsValueListEntry(_messages.Message):
    r"""A WarningsValueListEntry object.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  creationTimestamp = _messages.StringField(1)
  customFeatures = _messages.StringField(2, repeated=True)
  description = _messages.StringField(3)
  enabledFeatures = _messages.StringField(4, repeated=True)
  fingerprint = _messages.BytesField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#sslPolicy')
  minTlsVersion = _messages.EnumField('MinTlsVersionValueValuesEnum', 8)
  name = _messages.StringField(9)
  profile = _messages.EnumField('ProfileValueValuesEnum', 10)
  region = _messages.StringField(11)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)
  tlsSettings = _messages.MessageField('ServerTlsSettings', 14)
  warnings = _messages.MessageField('WarningsValueListEntry', 15, repeated=True)


class SslPolicyReference(_messages.Message):
  r"""A SslPolicyReference object.

  Fields:
    sslPolicy: URL of the SSL policy resource. Set this to empty string to
      clear any existing SSL policy associated with the target proxy resource.
  """

  sslPolicy = _messages.StringField(1)


class StandardQueryParameters(_messages.Message):
  r"""Query parameters accepted by all methods.

  Enums:
    FXgafvValueValuesEnum: V1 error format.
    AltValueValuesEnum: Data format for response.

  Fields:
    f__xgafv: V1 error format.
    access_token: OAuth access token.
    alt: Data format for response.
    callback: JSONP
    fields: Selector specifying which fields to include in a partial response.
    key: API key. Your API key identifies your project and provides you with
      API access, quota, and reports. Required unless you provide an OAuth 2.0
      token.
    oauth_token: OAuth 2.0 token for the current user.
    prettyPrint: Returns response with indentations and line breaks.
    quotaUser: Available to use for quota purposes for server-side
      applications. Can be any arbitrary string assigned to a user, but should
      not exceed 40 characters.
    trace: A tracing token of the form "token:<tokenid>" to include in api
      requests.
    uploadType: Legacy upload protocol for media (e.g. "media", "multipart").
    upload_protocol: Upload protocol for media (e.g. "raw", "multipart").
    userIp: Legacy name for parameter that has been superseded by `quotaUser`.
  """

  class AltValueValuesEnum(_messages.Enum):
    r"""Data format for response.

    Values:
      json: Responses with Content-Type of application/json
      media: Media download with context-dependent Content-Type
      proto: Responses with Content-Type of application/x-protobuf
    """
    json = 0
    media = 1
    proto = 2

  class FXgafvValueValuesEnum(_messages.Enum):
    r"""V1 error format.

    Values:
      _1: v1 error format
      _2: v2 error format
    """
    _1 = 0
    _2 = 1

  f__xgafv = _messages.EnumField('FXgafvValueValuesEnum', 1)
  access_token = _messages.StringField(2)
  alt = _messages.EnumField('AltValueValuesEnum', 3, default='json')
  callback = _messages.StringField(4)
  fields = _messages.StringField(5)
  key = _messages.StringField(6)
  oauth_token = _messages.StringField(7)
  prettyPrint = _messages.BooleanField(8, default=True)
  quotaUser = _messages.StringField(9)
  trace = _messages.StringField(10)
  uploadType = _messages.StringField(11)
  upload_protocol = _messages.StringField(12)
  userIp = _messages.StringField(13)


class StatefulPolicy(_messages.Message):
  r"""A StatefulPolicy object.

  Fields:
    preservedState: A StatefulPolicyPreservedState attribute.
  """

  preservedState = _messages.MessageField('StatefulPolicyPreservedState', 1)


class StatefulPolicyPreservedState(_messages.Message):
  r"""Configuration of preserved resources.

  Messages:
    DisksValue: Disks created on the instances that will be preserved on
      instance delete, update, etc. This map is keyed with the device names of
      the disks.
    ExternalIPsValue: External network IPs assigned to the instances that will
      be preserved on instance delete, update, etc. This map is keyed with the
      network interface name.
    InternalIPsValue: Internal network IPs assigned to the instances that will
      be preserved on instance delete, update, etc. This map is keyed with the
      network interface name.

  Fields:
    disks: Disks created on the instances that will be preserved on instance
      delete, update, etc. This map is keyed with the device names of the
      disks.
    externalIPs: External network IPs assigned to the instances that will be
      preserved on instance delete, update, etc. This map is keyed with the
      network interface name.
    internalIPs: Internal network IPs assigned to the instances that will be
      preserved on instance delete, update, etc. This map is keyed with the
      network interface name.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DisksValue(_messages.Message):
    r"""Disks created on the instances that will be preserved on instance
    delete, update, etc. This map is keyed with the device names of the disks.

    Messages:
      AdditionalProperty: An additional property for a DisksValue object.

    Fields:
      additionalProperties: Additional properties of type DisksValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DisksValue object.

      Fields:
        key: Name of the additional property.
        value: A StatefulPolicyPreservedStateDiskDevice attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StatefulPolicyPreservedStateDiskDevice', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ExternalIPsValue(_messages.Message):
    r"""External network IPs assigned to the instances that will be preserved
    on instance delete, update, etc. This map is keyed with the network
    interface name.

    Messages:
      AdditionalProperty: An additional property for a ExternalIPsValue
        object.

    Fields:
      additionalProperties: Additional properties of type ExternalIPsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ExternalIPsValue object.

      Fields:
        key: Name of the additional property.
        value: A StatefulPolicyPreservedStateNetworkIp attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StatefulPolicyPreservedStateNetworkIp', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class InternalIPsValue(_messages.Message):
    r"""Internal network IPs assigned to the instances that will be preserved
    on instance delete, update, etc. This map is keyed with the network
    interface name.

    Messages:
      AdditionalProperty: An additional property for a InternalIPsValue
        object.

    Fields:
      additionalProperties: Additional properties of type InternalIPsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a InternalIPsValue object.

      Fields:
        key: Name of the additional property.
        value: A StatefulPolicyPreservedStateNetworkIp attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StatefulPolicyPreservedStateNetworkIp', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  disks = _messages.MessageField('DisksValue', 1)
  externalIPs = _messages.MessageField('ExternalIPsValue', 2)
  internalIPs = _messages.MessageField('InternalIPsValue', 3)


class StatefulPolicyPreservedStateDiskDevice(_messages.Message):
  r"""A StatefulPolicyPreservedStateDiskDevice object.

  Enums:
    AutoDeleteValueValuesEnum: These stateful disks will never be deleted
      during autohealing, update or VM instance recreate operations. This flag
      is used to configure if the disk should be deleted after it is no longer
      used by the group, e.g. when the given instance or the whole group is
      deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted.

  Fields:
    autoDelete: These stateful disks will never be deleted during autohealing,
      update or VM instance recreate operations. This flag is used to
      configure if the disk should be deleted after it is no longer used by
      the group, e.g. when the given instance or the whole group is deleted.
      Note: disks attached in READ_ONLY mode cannot be auto-deleted.
  """

  class AutoDeleteValueValuesEnum(_messages.Enum):
    r"""These stateful disks will never be deleted during autohealing, update
    or VM instance recreate operations. This flag is used to configure if the
    disk should be deleted after it is no longer used by the group, e.g. when
    the given instance or the whole group is deleted. Note: disks attached in
    READ_ONLY mode cannot be auto-deleted.

    Values:
      NEVER: <no description>
      ON_PERMANENT_INSTANCE_DELETION: <no description>
    """
    NEVER = 0
    ON_PERMANENT_INSTANCE_DELETION = 1

  autoDelete = _messages.EnumField('AutoDeleteValueValuesEnum', 1)


class StatefulPolicyPreservedStateNetworkIp(_messages.Message):
  r"""A StatefulPolicyPreservedStateNetworkIp object.

  Enums:
    AutoDeleteValueValuesEnum: These stateful IPs will never be released
      during autohealing, update or VM instance recreate operations. This flag
      is used to configure if the IP reservation should be deleted after it is
      no longer used by the group, e.g. when the given instance or the whole
      group is deleted.

  Fields:
    autoDelete: These stateful IPs will never be released during autohealing,
      update or VM instance recreate operations. This flag is used to
      configure if the IP reservation should be deleted after it is no longer
      used by the group, e.g. when the given instance or the whole group is
      deleted.
  """

  class AutoDeleteValueValuesEnum(_messages.Enum):
    r"""These stateful IPs will never be released during autohealing, update
    or VM instance recreate operations. This flag is used to configure if the
    IP reservation should be deleted after it is no longer used by the group,
    e.g. when the given instance or the whole group is deleted.

    Values:
      NEVER: <no description>
      ON_PERMANENT_INSTANCE_DELETION: <no description>
    """
    NEVER = 0
    ON_PERMANENT_INSTANCE_DELETION = 1

  autoDelete = _messages.EnumField('AutoDeleteValueValuesEnum', 1)


class Status(_messages.Message):
  r"""The `Status` type defines a logical error model that is suitable for
  different programming environments, including REST APIs and RPC APIs. It is
  used by [gRPC](https://github.com/grpc). Each `Status` message contains
  three pieces of data: error code, error message, and error details. You can
  find out more about this error model and how to work with it in the [API
  Design Guide](https://cloud.google.com/apis/design/errors).

  Messages:
    DetailsValueListEntry: A DetailsValueListEntry object.

  Fields:
    code: The status code, which should be an enum value of google.rpc.Code.
    details: A list of messages that carry the error details. There is a
      common set of message types for APIs to use.
    message: A developer-facing error message, which should be in English. Any
      user-facing error message should be localized and sent in the
      google.rpc.Status.details field, or localized by the client.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DetailsValueListEntry(_messages.Message):
    r"""A DetailsValueListEntry object.

    Messages:
      AdditionalProperty: An additional property for a DetailsValueListEntry
        object.

    Fields:
      additionalProperties: Properties of the object. Contains field @type
        with type URL.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DetailsValueListEntry object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  code = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  details = _messages.MessageField('DetailsValueListEntry', 2, repeated=True)
  message = _messages.StringField(3)


class StoragePool(_messages.Message):
  r"""Represents a zonal storage pool resource.

  Enums:
    CapacityProvisioningTypeValueValuesEnum: Provisioning type of the byte
      capacity of the pool.
    PerformanceProvisioningTypeValueValuesEnum: Provisioning type of the
      performance-related parameters of the pool, such as throughput and IOPS.
    StateValueValuesEnum: [Output Only] The status of storage pool creation. -
      CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage
      pool creation failed. - READY: Storage pool is ready for use. -
      DELETING: Storage pool is deleting.

  Messages:
    LabelsValue: Labels to apply to this storage pool. These can be later
      modified by the setLabels method.

  Fields:
    capacityProvisioningType: Provisioning type of the byte capacity of the
      pool.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#storagePool for
      storage pools.
    labelFingerprint: A fingerprint for the labels being applied to this
      storage pool, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a storage pool.
    labels: Labels to apply to this storage pool. These can be later modified
      by the setLabels method.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    performanceProvisioningType: Provisioning type of the performance-related
      parameters of the pool, such as throughput and IOPS.
    poolProvisionedCapacityGb: Size, in GiB, of the storage pool. For more
      information about the size limits, see
      https://cloud.google.com/compute/docs/disks/storage-pools.
    poolProvisionedIops: Provisioned IOPS of the storage pool. Only relevant
      if the storage pool type is hyperdisk-balanced.
    poolProvisionedThroughput: Provisioned throughput of the storage pool.
      Only relevant if the storage pool type is hyperdisk-balanced or
      hyperdisk-throughput.
    provisionedIops: DEPRECATED -- use "pool provisioned IOPS".
    provisionedThroughput: DEPRECATED -- use "pool provisioned throughput".
    resourceStatus: [Output Only] Status information for the storage pool
      resource.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    sizeGb: DEPRECATED -- use "pool provisioned capacity gb".
    state: [Output Only] The status of storage pool creation. - CREATING:
      Storage pool is provisioning. storagePool. - FAILED: Storage pool
      creation failed. - READY: Storage pool is ready for use. - DELETING:
      Storage pool is deleting.
    status: [Output Only] Status information for the storage pool resource.
    storagePoolType: Type of the storage pool.
    zone: [Output Only] URL of the zone where the storage pool resides. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
  """

  class CapacityProvisioningTypeValueValuesEnum(_messages.Enum):
    r"""Provisioning type of the byte capacity of the pool.

    Values:
      ADVANCED: Advanced provisioning "thinly" allocates the related resource.
      STANDARD: Standard provisioning allocates the related resource for the
        pool disks' exclusive use.
      UNSPECIFIED: <no description>
    """
    ADVANCED = 0
    STANDARD = 1
    UNSPECIFIED = 2

  class PerformanceProvisioningTypeValueValuesEnum(_messages.Enum):
    r"""Provisioning type of the performance-related parameters of the pool,
    such as throughput and IOPS.

    Values:
      ADVANCED: Advanced provisioning "thinly" allocates the related resource.
      STANDARD: Standard provisioning allocates the related resource for the
        pool disks' exclusive use.
      UNSPECIFIED: <no description>
    """
    ADVANCED = 0
    STANDARD = 1
    UNSPECIFIED = 2

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of storage pool creation. - CREATING: Storage
    pool is provisioning. storagePool. - FAILED: Storage pool creation failed.
    - READY: Storage pool is ready for use. - DELETING: Storage pool is
    deleting.

    Values:
      CREATING: StoragePool is provisioning
      DELETING: StoragePool is deleting.
      FAILED: StoragePool creation failed.
      READY: StoragePool is ready for use.
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this storage pool. These can be later modified by
    the setLabels method.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  capacityProvisioningType = _messages.EnumField('CapacityProvisioningTypeValueValuesEnum', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#storagePool')
  labelFingerprint = _messages.BytesField(6)
  labels = _messages.MessageField('LabelsValue', 7)
  name = _messages.StringField(8)
  performanceProvisioningType = _messages.EnumField('PerformanceProvisioningTypeValueValuesEnum', 9)
  poolProvisionedCapacityGb = _messages.IntegerField(10)
  poolProvisionedIops = _messages.IntegerField(11)
  poolProvisionedThroughput = _messages.IntegerField(12)
  provisionedIops = _messages.IntegerField(13)
  provisionedThroughput = _messages.IntegerField(14)
  resourceStatus = _messages.MessageField('StoragePoolResourceStatus', 15)
  selfLink = _messages.StringField(16)
  selfLinkWithId = _messages.StringField(17)
  sizeGb = _messages.IntegerField(18)
  state = _messages.EnumField('StateValueValuesEnum', 19)
  status = _messages.MessageField('StoragePoolResourceStatus', 20)
  storagePoolType = _messages.StringField(21)
  zone = _messages.StringField(22)


class StoragePoolAggregatedList(_messages.Message):
  r"""A StoragePoolAggregatedList object.

  Messages:
    ItemsValue: A list of StoragePoolsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of StoragePoolsScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#storagePoolAggregatedList for aggregated lists of storage pools.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of StoragePoolsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of storage pool.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A StoragePoolsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StoragePoolsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default='compute#storagePoolAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class StoragePoolDisk(_messages.Message):
  r"""A StoragePoolDisk object.

  Enums:
    StatusValueValuesEnum: [Output Only] The disk status.

  Fields:
    attachedInstances: [Output Only] Instances this disk is attached to.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    disk: [Output Only] The URL of the disk.
    name: [Output Only] The name of the disk.
    provisionedIops: [Output Only] The number of IOPS provisioned for the
      disk.
    provisionedThroughput: [Output Only] The throughput provisioned for the
      disk.
    resourcePolicies: [Output Only] Resource policies applied to disk for
      automatic snapshot creations.
    sizeGb: [Output Only] The disk size, in GB.
    status: [Output Only] The disk status.
    type: [Output Only] The disk type.
    usedBytes: [Output Only] Amount of disk space used.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The disk status.

    Values:
      CREATING: Disk is provisioning
      DELETING: Disk is deleting.
      FAILED: Disk creation failed.
      READY: Disk is ready for use.
      RESTORING: Source data is being copied into the disk.
      UNAVAILABLE: Disk is currently unavailable and cannot be accessed,
        attached or detached.
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3
    RESTORING = 4
    UNAVAILABLE = 5

  attachedInstances = _messages.StringField(1, repeated=True)
  creationTimestamp = _messages.StringField(2)
  disk = _messages.StringField(3)
  name = _messages.StringField(4)
  provisionedIops = _messages.IntegerField(5)
  provisionedThroughput = _messages.IntegerField(6)
  resourcePolicies = _messages.StringField(7, repeated=True)
  sizeGb = _messages.IntegerField(8)
  status = _messages.EnumField('StatusValueValuesEnum', 9)
  type = _messages.StringField(10)
  usedBytes = _messages.IntegerField(11)


class StoragePoolList(_messages.Message):
  r"""A list of StoragePool resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of StoragePool resources.
    kind: [Output Only] Type of resource. Always compute#storagePoolList for
      lists of storagePools.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('StoragePool', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#storagePoolList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class StoragePoolListDisks(_messages.Message):
  r"""A StoragePoolListDisks object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of StoragePoolDisk resources.
    kind: [Output Only] Type of resource. Always compute#storagePoolListDisks
      for lists of disks in a storagePool.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('StoragePoolDisk', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#storagePoolListDisks')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class StoragePoolResourceStatus(_messages.Message):
  r"""[Output Only] Contains output only fields.

  Fields:
    aggregateDiskProvisionedIops: DEPRECATED -- use
      "total_provisioned_disk_iops".
    aggregateDiskSizeGb: DEPRECATED -- use "total provisioned disk size gb".
    diskCount: [Output Only] Number of disks used.
    lastResizeTimestamp: [Output Only] Timestamp of the last successful resize
      in RFC3339 text format.
    maxAggregateDiskSizeGb: DEPRECATED -- use "max provisioned disk size gb"
    maxTotalProvisionedDiskCapacityGb: [Output Only] Maximum allowed aggregate
      disk size in gigabytes.
    numberOfDisks: DEPRECATED -- use "disk count".
    poolUsedCapacityBytes: [Output Only] Space used by data stored in disks
      within the storage pool (in bytes). This will reflect the total number
      of bytes written to the disks in the pool, in contrast to the capacity
      of those disks.
    poolUsedIops: [Output Only] Sum of all the disks' provisioned IOPS, minus
      some amount that is allowed per disk that is not counted towards pool's
      IOPS capacity. For more information, see
      https://cloud.google.com/compute/docs/disks/storage-pools.
    poolUsedThroughput: [Output Only] Sum of all the disks' provisioned
      throughput in MB/s.
    poolUserWrittenBytes: [Output Only] Amount of data written into the pool,
      before it is compacted.
    totalProvisionedDiskCapacityGb: [Output Only] Sum of all the capacity
      provisioned in disks in this storage pool. A disk's provisioned capacity
      is the same as its total capacity.
    totalProvisionedDiskIops: [Output Only] Sum of all the disks' provisioned
      IOPS.
    totalProvisionedDiskThroughput: [Output Only] Sum of all the disks'
      provisioned throughput in MB/s, minus some amount that is allowed per
      disk that is not counted towards pool's throughput capacity.
    usedBytes: DEPRECATED -- use "pool used capacity".
    usedReducedBytes: DEPRECATED -- do not use, will be removed.
    usedThroughput: DEPRECATED -- use "pool used throughput".
  """

  aggregateDiskProvisionedIops = _messages.IntegerField(1)
  aggregateDiskSizeGb = _messages.IntegerField(2)
  diskCount = _messages.IntegerField(3)
  lastResizeTimestamp = _messages.StringField(4)
  maxAggregateDiskSizeGb = _messages.IntegerField(5)
  maxTotalProvisionedDiskCapacityGb = _messages.IntegerField(6)
  numberOfDisks = _messages.IntegerField(7)
  poolUsedCapacityBytes = _messages.IntegerField(8)
  poolUsedIops = _messages.IntegerField(9)
  poolUsedThroughput = _messages.IntegerField(10)
  poolUserWrittenBytes = _messages.IntegerField(11)
  totalProvisionedDiskCapacityGb = _messages.IntegerField(12)
  totalProvisionedDiskIops = _messages.IntegerField(13)
  totalProvisionedDiskThroughput = _messages.IntegerField(14)
  usedBytes = _messages.IntegerField(15)
  usedReducedBytes = _messages.IntegerField(16)
  usedThroughput = _messages.IntegerField(17)


class StoragePoolType(_messages.Message):
  r"""A StoragePoolType object.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      storage pool type.
    description: [Output Only] An optional description of this resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#storagePoolType
      for storage pool types.
    maxPoolProvisionedCapacityGb: [Output Only] Maximum storage pool size in
      GB.
    maxPoolProvisionedIops: [Output Only] Maximum provisioned IOPS.
    maxPoolProvisionedThroughput: [Output Only] Maximum provisioned
      throughput.
    minPoolProvisionedCapacityGb: [Output Only] Minimum storage pool size in
      GB.
    minPoolProvisionedIops: [Output Only] Minimum provisioned IOPS.
    minPoolProvisionedThroughput: [Output Only] Minimum provisioned
      throughput.
    minSizeGb: [Deprecated] This field is deprecated. Use
      minPoolProvisionedCapacityGb instead.
    name: [Output Only] Name of the resource.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    supportedDiskTypes: [Output Only] The list of disk types supported in this
      storage pool type.
    zone: [Output Only] URL of the zone where the storage pool type resides.
      You must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
  """

  creationTimestamp = _messages.StringField(1)
  deprecated = _messages.MessageField('DeprecationStatus', 2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#storagePoolType')
  maxPoolProvisionedCapacityGb = _messages.IntegerField(6)
  maxPoolProvisionedIops = _messages.IntegerField(7)
  maxPoolProvisionedThroughput = _messages.IntegerField(8)
  minPoolProvisionedCapacityGb = _messages.IntegerField(9)
  minPoolProvisionedIops = _messages.IntegerField(10)
  minPoolProvisionedThroughput = _messages.IntegerField(11)
  minSizeGb = _messages.IntegerField(12)
  name = _messages.StringField(13)
  selfLink = _messages.StringField(14)
  selfLinkWithId = _messages.StringField(15)
  supportedDiskTypes = _messages.StringField(16, repeated=True)
  zone = _messages.StringField(17)


class StoragePoolTypeAggregatedList(_messages.Message):
  r"""A StoragePoolTypeAggregatedList object.

  Messages:
    ItemsValue: A list of StoragePoolTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of StoragePoolTypesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#storagePoolTypeAggregatedList .
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of StoragePoolTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of storage pool types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A StoragePoolTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StoragePoolTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#storagePoolTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class StoragePoolTypeList(_messages.Message):
  r"""Contains a list of storage pool types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of StoragePoolType resources.
    kind: [Output Only] Type of resource. Always compute#storagePoolTypeList
      for storage pool types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('StoragePoolType', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#storagePoolTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class StoragePoolTypesScopedList(_messages.Message):
  r"""A StoragePoolTypesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of storage pool types when the list is empty.

  Fields:
    storagePoolTypes: [Output Only] A list of storage pool types contained in
      this scope.
    warning: [Output Only] Informational warning which replaces the list of
      storage pool types when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of storage
    pool types when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  storagePoolTypes = _messages.MessageField('StoragePoolType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class StoragePoolsScopedList(_messages.Message):
  r"""A StoragePoolsScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of storage pool when the list is empty.

  Fields:
    storagePools: [Output Only] A list of storage pool contained in this
      scope.
    warning: [Output Only] Informational warning which replaces the list of
      storage pool when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of storage
    pool when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  storagePools = _messages.MessageField('StoragePool', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class StructuredEntries(_messages.Message):
  r"""A StructuredEntries object.

  Messages:
    EntriesValue: Map of a partner metadata that belong to the same subdomain.
      It accepts any value including google.protobuf.Struct.

  Fields:
    entries: Map of a partner metadata that belong to the same subdomain. It
      accepts any value including google.protobuf.Struct.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class EntriesValue(_messages.Message):
    r"""Map of a partner metadata that belong to the same subdomain. It
    accepts any value including google.protobuf.Struct.

    Messages:
      AdditionalProperty: An additional property for a EntriesValue object.

    Fields:
      additionalProperties: Additional properties of type EntriesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a EntriesValue object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  entries = _messages.MessageField('EntriesValue', 1)


class Subnetwork(_messages.Message):
  r"""Represents a Subnetwork resource. A subnetwork (also known as a subnet)
  is a logical partition of a Virtual Private Cloud network with one primary
  IP range and zero or more secondary IP ranges. For more information, read
  Virtual Private Cloud (VPC) Network.

  Enums:
    AggregationIntervalValueValuesEnum: Can only be specified if VPC flow
      logging for this subnetwork is enabled. Sets the aggregation interval
      for collecting flow logs. Increasing the interval time reduces the
      amount of generated flow logs for long-lasting connections. Default is
      an interval of 5 seconds per connection. Valid values: INTERVAL_5_SEC,
      INTERVAL_30_SEC, INTERVAL_1_MIN, INTERVAL_5_MIN, INTERVAL_10_MIN,
      INTERVAL_15_MIN.
    Ipv6AccessTypeValueValuesEnum: The access type of IPv6 address this subnet
      holds. It's immutable and can only be specified during creation or the
      first time the subnet is updated into IPV4_IPV6 dual stack.
    Ipv6GceEndpointValueValuesEnum: [Output Only] Possible endpoints of this
      subnetwork. It can be one of the following: - VM_ONLY: The subnetwork
      can be used for creating instances and IPv6 addresses with VM endpoint
      type. Such a subnetwork gets external IPv6 ranges from a public
      delegated prefix and cannot be used to create NetLb. - VM_AND_FR: The
      subnetwork can be used for creating both VM instances and Forwarding
      Rules. It can also be used to reserve IPv6 addresses with both VM and FR
      endpoint types. Such a subnetwork gets its IPv6 range from Google IP
      Pool directly.
    MetadataValueValuesEnum: Can only be specified if VPC flow logging for
      this subnetwork is enabled. Configures whether metadata fields should be
      added to the reported VPC flow logs. Options are INCLUDE_ALL_METADATA,
      EXCLUDE_ALL_METADATA, and CUSTOM_METADATA. Default is
      EXCLUDE_ALL_METADATA.
    PrivateIpv6GoogleAccessValueValuesEnum: This field is for internal use.
      This field can be both set at resource creation time and updated using
      patch.
    PurposeValueValuesEnum:
    RoleValueValuesEnum: The role of subnetwork. Currently, this field is only
      used when purpose is set to GLOBAL_MANAGED_PROXY or
      REGIONAL_MANAGED_PROXY. The value can be set to ACTIVE or BACKUP. An
      ACTIVE subnetwork is one that is currently being used for Envoy-based
      load balancers in a region. A BACKUP subnetwork is one that is ready to
      be promoted to ACTIVE or is currently draining. This field can be
      updated with a patch request.
    StackTypeValueValuesEnum: The stack type for the subnet. If set to
      IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If
      set to IPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
      IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be
      both set at resource creation time and updated using patch.
    StateValueValuesEnum: [Output Only] The state of the subnetwork, which can
      be one of the following values: READY: Subnetwork is created and ready
      to use DRAINING: only applicable to subnetworks that have the purpose
      set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to
      the load balancer are being drained. A subnetwork that is draining
      cannot be used or modified until it reaches a status of READY

  Fields:
    aggregationInterval: Can only be specified if VPC flow logging for this
      subnetwork is enabled. Sets the aggregation interval for collecting flow
      logs. Increasing the interval time reduces the amount of generated flow
      logs for long-lasting connections. Default is an interval of 5 seconds
      per connection. Valid values: INTERVAL_5_SEC, INTERVAL_30_SEC,
      INTERVAL_1_MIN, INTERVAL_5_MIN, INTERVAL_10_MIN, INTERVAL_15_MIN.
    allowSubnetCidrRoutesOverlap: Whether this subnetwork's ranges can
      conflict with existing static routes. Setting this to true allows this
      subnetwork's primary and secondary ranges to overlap with (and contain)
      static routes that have already been configured on the corresponding
      network. For example if a static route has range 10.1.0.0/16, a subnet
      range 10.0.0.0/8 could only be created if allow_conflicting_routes=true.
      Overlapping is only allowed on subnetwork operations; routes whose
      ranges conflict with this subnetwork's ranges won't be allowed unless
      route.allow_conflicting_subnetworks is set to true. Typically packets
      destined to IPs within the subnetwork (which may contain
      private/sensitive data) are prevented from leaving the virtual network.
      Setting this field to true will disable this feature. The default value
      is false and applies to all existing subnetworks and automatically
      created subnetworks. This field cannot be set to true at resource
      creation time.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource. This field can be set only at
      resource creation time.
    enableFlowLogs: Whether to enable flow logging for this subnetwork. If
      this field is not explicitly set, it will not appear in get listings. If
      not set the default behavior is determined by the org policy, if there
      is no org policy specified, then it will default to disabled. This field
      isn't supported if the subnet purpose field is set to
      REGIONAL_MANAGED_PROXY.
    enableL2: Enables Layer2 communication on the subnetwork.
    enablePrivateV6Access: Deprecated in favor of enable in
      PrivateIpv6GoogleAccess. Whether the VMs in this subnet can directly
      access Google services via internal IPv6 addresses. This field can be
      both set at resource creation time and updated using patch.
    externalIpv6Prefix: The external IPv6 address range that is owned by this
      subnetwork.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a Subnetwork. An up-to-date fingerprint
      must be provided in order to update the Subnetwork, otherwise the
      request will fail with error 412 conditionNotMet. To see the latest
      fingerprint, make a get() request to retrieve a Subnetwork.
    flowSampling: Can only be specified if VPC flow logging for this
      subnetwork is enabled. The value of the field must be in [0, 1]. Set the
      sampling rate of VPC flow logs within the subnetwork where 1.0 means all
      collected logs are reported and 0.0 means no logs are reported. Default
      is 0.5 unless otherwise specified by the org policy, which means half of
      all collected logs are reported.
    gatewayAddress: [Output Only] The gateway address for default routes to
      reach destination addresses outside this subnetwork.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    internalIpv6Prefix: The internal IPv6 address range that is owned by this
      subnetwork.
    ipCidrRange: The range of internal addresses that are owned by this
      subnetwork. Provide this property when you create the subnetwork. For
      example, 10.0.0.0/8 or 100.64.0.0/10. Ranges must be unique and non-
      overlapping within a network. Only IPv4 is supported. This field is set
      at resource creation time. The range can be any range listed in the
      Valid ranges list. The range can be expanded after creation using
      expandIpCidrRange.
    ipCollection: Reference to the source of IP, like a PublicDelegatedPrefix
      (PDP) for BYOIP. The PDP must be a sub-PDP in
      EXTERNAL_IPV6_SUBNETWORK_CREATION mode. Use one of the following formats
      to specify a sub-PDP when creating a dual stack subnetwork with external
      access using BYOIP: - Full resource URL, as in
      https://www.googleapis.com/compute/v1/projects/projectId/regions/region
      /publicDelegatedPrefixes/sub-pdp-name - Partial URL, as in -
      projects/projectId/regions/region/publicDelegatedPrefixes/ sub-pdp-name
      - regions/region/publicDelegatedPrefixes/sub-pdp-name
    ipv6AccessType: The access type of IPv6 address this subnet holds. It's
      immutable and can only be specified during creation or the first time
      the subnet is updated into IPV4_IPV6 dual stack.
    ipv6CidrRange: [Output Only] This field is for internal use.
    ipv6GceEndpoint: [Output Only] Possible endpoints of this subnetwork. It
      can be one of the following: - VM_ONLY: The subnetwork can be used for
      creating instances and IPv6 addresses with VM endpoint type. Such a
      subnetwork gets external IPv6 ranges from a public delegated prefix and
      cannot be used to create NetLb. - VM_AND_FR: The subnetwork can be used
      for creating both VM instances and Forwarding Rules. It can also be used
      to reserve IPv6 addresses with both VM and FR endpoint types. Such a
      subnetwork gets its IPv6 range from Google IP Pool directly.
    kind: [Output Only] Type of the resource. Always compute#subnetwork for
      Subnetwork resources.
    logConfig: This field denotes the VPC flow logging options for this
      subnetwork. If logging is enabled, logs are exported to Cloud Logging.
    metadata: Can only be specified if VPC flow logging for this subnetwork is
      enabled. Configures whether metadata fields should be added to the
      reported VPC flow logs. Options are INCLUDE_ALL_METADATA,
      EXCLUDE_ALL_METADATA, and CUSTOM_METADATA. Default is
      EXCLUDE_ALL_METADATA.
    name: The name of the resource, provided by the client when initially
      creating the resource. The name must be 1-63 characters long, and comply
      with RFC1035. Specifically, the name must be 1-63 characters long and
      match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means
      the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    network: The URL of the network to which this subnetwork belongs, provided
      by the client when initially creating the subnetwork. This field can be
      set only at resource creation time.
    privateIpGoogleAccess: Whether the VMs in this subnet can access Google
      services without assigned external IP addresses. This field can be both
      set at resource creation time and updated using
      setPrivateIpGoogleAccess.
    privateIpv6GoogleAccess: This field is for internal use. This field can be
      both set at resource creation time and updated using patch.
    purpose: A PurposeValueValuesEnum attribute.
    region: URL of the region where the Subnetwork resides. This field can be
      set only at resource creation time.
    reservedInternalRange: The URL of the reserved internal range.
    role: The role of subnetwork. Currently, this field is only used when
      purpose is set to GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY. The
      value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that
      is currently being used for Envoy-based load balancers in a region. A
      BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is
      currently draining. This field can be updated with a patch request.
    secondaryIpRanges: An array of configurations for secondary IP ranges for
      VM instances contained in this subnetwork. The primary IP of such VM
      must belong to the primary ipCidrRange of the subnetwork. The alias IPs
      may belong to either primary or secondary ranges. This field can be
      updated with a patch request.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    stackType: The stack type for the subnet. If set to IPV4_ONLY, new VMs in
      the subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new
      VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not
      specified, IPV4_ONLY is used. This field can be both set at resource
      creation time and updated using patch.
    state: [Output Only] The state of the subnetwork, which can be one of the
      following values: READY: Subnetwork is created and ready to use
      DRAINING: only applicable to subnetworks that have the purpose set to
      INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load
      balancer are being drained. A subnetwork that is draining cannot be used
      or modified until it reaches a status of READY
    vlans: A repeated field indicating the VLAN IDs supported on this
      subnetwork. During Subnet creation, specifying vlan is valid only if
      enable_l2 is true. During Subnet Update, specifying vlan is allowed only
      for l2 enabled subnets. Restricted to only one VLAN.
  """

  class AggregationIntervalValueValuesEnum(_messages.Enum):
    r"""Can only be specified if VPC flow logging for this subnetwork is
    enabled. Sets the aggregation interval for collecting flow logs.
    Increasing the interval time reduces the amount of generated flow logs for
    long-lasting connections. Default is an interval of 5 seconds per
    connection. Valid values: INTERVAL_5_SEC, INTERVAL_30_SEC, INTERVAL_1_MIN,
    INTERVAL_5_MIN, INTERVAL_10_MIN, INTERVAL_15_MIN.

    Values:
      INTERVAL_10_MIN: <no description>
      INTERVAL_15_MIN: <no description>
      INTERVAL_1_MIN: <no description>
      INTERVAL_30_SEC: <no description>
      INTERVAL_5_MIN: <no description>
      INTERVAL_5_SEC: <no description>
    """
    INTERVAL_10_MIN = 0
    INTERVAL_15_MIN = 1
    INTERVAL_1_MIN = 2
    INTERVAL_30_SEC = 3
    INTERVAL_5_MIN = 4
    INTERVAL_5_SEC = 5

  class Ipv6AccessTypeValueValuesEnum(_messages.Enum):
    r"""The access type of IPv6 address this subnet holds. It's immutable and
    can only be specified during creation or the first time the subnet is
    updated into IPV4_IPV6 dual stack.

    Values:
      EXTERNAL: VMs on this subnet will be assigned IPv6 addresses that are
        accessible via the Internet, as well as the VPC network.
      INTERNAL: VMs on this subnet will be assigned IPv6 addresses that are
        only accessible over the VPC network.
    """
    EXTERNAL = 0
    INTERNAL = 1

  class Ipv6GceEndpointValueValuesEnum(_messages.Enum):
    r"""[Output Only] Possible endpoints of this subnetwork. It can be one of
    the following: - VM_ONLY: The subnetwork can be used for creating
    instances and IPv6 addresses with VM endpoint type. Such a subnetwork gets
    external IPv6 ranges from a public delegated prefix and cannot be used to
    create NetLb. - VM_AND_FR: The subnetwork can be used for creating both VM
    instances and Forwarding Rules. It can also be used to reserve IPv6
    addresses with both VM and FR endpoint types. Such a subnetwork gets its
    IPv6 range from Google IP Pool directly.

    Values:
      VM_AND_FR: <no description>
      VM_ONLY: <no description>
    """
    VM_AND_FR = 0
    VM_ONLY = 1

  class MetadataValueValuesEnum(_messages.Enum):
    r"""Can only be specified if VPC flow logging for this subnetwork is
    enabled. Configures whether metadata fields should be added to the
    reported VPC flow logs. Options are INCLUDE_ALL_METADATA,
    EXCLUDE_ALL_METADATA, and CUSTOM_METADATA. Default is
    EXCLUDE_ALL_METADATA.

    Values:
      EXCLUDE_ALL_METADATA: <no description>
      INCLUDE_ALL_METADATA: <no description>
    """
    EXCLUDE_ALL_METADATA = 0
    INCLUDE_ALL_METADATA = 1

  class PrivateIpv6GoogleAccessValueValuesEnum(_messages.Enum):
    r"""This field is for internal use. This field can be both set at resource
    creation time and updated using patch.

    Values:
      DISABLE_GOOGLE_ACCESS: Disable private IPv6 access to/from Google
        services.
      ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE: Bidirectional private IPv6 access
        to/from Google services.
      ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE: Outbound private IPv6 access from
        VMs in this subnet to Google services.
    """
    DISABLE_GOOGLE_ACCESS = 0
    ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 1
    ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 2

  class PurposeValueValuesEnum(_messages.Enum):
    r"""PurposeValueValuesEnum enum type.

    Values:
      AGGREGATE: Subnetwork used to aggregate multiple private subnetworks.
      CLOUD_EXTENSION: Subnetworks created for Cloud Extension Machines.
      CUSTOM_HARDWARE_LINK: Subnetwork used for Custom Hardware Link.
      GLOBAL_MANAGED_PROXY: Subnet reserved for Global Envoy-based Load
        Balancing.
      INTERNAL_HTTPS_LOAD_BALANCER: Subnet reserved for Internal HTTP(S) Load
        Balancing. This is a legacy purpose, please use REGIONAL_MANAGED_PROXY
        instead.
      PEER_MIGRATION: Subnetwork will be used for Migration from one peered
        VPC to another. (a transient state of subnetwork while migrating
        resources from one project to another).
      PRIVATE: Regular user created or automatically created subnet.
      PRIVATE_NAT: Subnetwork used as source range for Private NAT Gateways.
      PRIVATE_RFC_1918: Regular user created or automatically created subnet.
      PRIVATE_SERVICE_CONNECT: Subnetworks created for Private Service Connect
        in the producer network.
      REGIONAL_MANAGED_PROXY: Subnetwork used for Regional Envoy-based Load
        Balancing.
    """
    AGGREGATE = 0
    CLOUD_EXTENSION = 1
    CUSTOM_HARDWARE_LINK = 2
    GLOBAL_MANAGED_PROXY = 3
    INTERNAL_HTTPS_LOAD_BALANCER = 4
    PEER_MIGRATION = 5
    PRIVATE = 6
    PRIVATE_NAT = 7
    PRIVATE_RFC_1918 = 8
    PRIVATE_SERVICE_CONNECT = 9
    REGIONAL_MANAGED_PROXY = 10

  class RoleValueValuesEnum(_messages.Enum):
    r"""The role of subnetwork. Currently, this field is only used when
    purpose is set to GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY. The
    value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is
    currently being used for Envoy-based load balancers in a region. A BACKUP
    subnetwork is one that is ready to be promoted to ACTIVE or is currently
    draining. This field can be updated with a patch request.

    Values:
      ACTIVE: The ACTIVE subnet that is currently used.
      BACKUP: The BACKUP subnet that could be promoted to ACTIVE.
    """
    ACTIVE = 0
    BACKUP = 1

  class StackTypeValueValuesEnum(_messages.Enum):
    r"""The stack type for the subnet. If set to IPV4_ONLY, new VMs in the
    subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in
    the subnet can be assigned both IPv4 and IPv6 addresses. If not specified,
    IPV4_ONLY is used. This field can be both set at resource creation time
    and updated using patch.

    Values:
      IPV4_IPV6: New VMs in this subnet can have both IPv4 and IPv6 addresses.
      IPV4_ONLY: New VMs in this subnet will only be assigned IPv4 addresses.
      IPV6_ONLY: New VMs in this subnet will only be assigned IPv6 addresses.
    """
    IPV4_IPV6 = 0
    IPV4_ONLY = 1
    IPV6_ONLY = 2

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The state of the subnetwork, which can be one of the
    following values: READY: Subnetwork is created and ready to use DRAINING:
    only applicable to subnetworks that have the purpose set to
    INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load
    balancer are being drained. A subnetwork that is draining cannot be used
    or modified until it reaches a status of READY

    Values:
      DRAINING: Subnetwork is being drained.
      READY: Subnetwork is ready for use.
    """
    DRAINING = 0
    READY = 1

  aggregationInterval = _messages.EnumField('AggregationIntervalValueValuesEnum', 1)
  allowSubnetCidrRoutesOverlap = _messages.BooleanField(2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  enableFlowLogs = _messages.BooleanField(5)
  enableL2 = _messages.BooleanField(6)
  enablePrivateV6Access = _messages.BooleanField(7)
  externalIpv6Prefix = _messages.StringField(8)
  fingerprint = _messages.BytesField(9)
  flowSampling = _messages.FloatField(10, variant=_messages.Variant.FLOAT)
  gatewayAddress = _messages.StringField(11)
  id = _messages.IntegerField(12, variant=_messages.Variant.UINT64)
  internalIpv6Prefix = _messages.StringField(13)
  ipCidrRange = _messages.StringField(14)
  ipCollection = _messages.StringField(15)
  ipv6AccessType = _messages.EnumField('Ipv6AccessTypeValueValuesEnum', 16)
  ipv6CidrRange = _messages.StringField(17)
  ipv6GceEndpoint = _messages.EnumField('Ipv6GceEndpointValueValuesEnum', 18)
  kind = _messages.StringField(19, default='compute#subnetwork')
  logConfig = _messages.MessageField('SubnetworkLogConfig', 20)
  metadata = _messages.EnumField('MetadataValueValuesEnum', 21)
  name = _messages.StringField(22)
  network = _messages.StringField(23)
  privateIpGoogleAccess = _messages.BooleanField(24)
  privateIpv6GoogleAccess = _messages.EnumField('PrivateIpv6GoogleAccessValueValuesEnum', 25)
  purpose = _messages.EnumField('PurposeValueValuesEnum', 26)
  region = _messages.StringField(27)
  reservedInternalRange = _messages.StringField(28)
  role = _messages.EnumField('RoleValueValuesEnum', 29)
  secondaryIpRanges = _messages.MessageField('SubnetworkSecondaryRange', 30, repeated=True)
  selfLink = _messages.StringField(31)
  selfLinkWithId = _messages.StringField(32)
  stackType = _messages.EnumField('StackTypeValueValuesEnum', 33)
  state = _messages.EnumField('StateValueValuesEnum', 34)
  vlans = _messages.IntegerField(35, repeated=True, variant=_messages.Variant.INT32)


class SubnetworkAggregatedList(_messages.Message):
  r"""A SubnetworkAggregatedList object.

  Messages:
    ItemsValue: A list of SubnetworksScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SubnetworksScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#subnetworkAggregatedList for aggregated lists of subnetworks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of SubnetworksScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        Subnetworks.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A SubnetworksScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SubnetworksScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#subnetworkAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class SubnetworkList(_messages.Message):
  r"""Contains a list of Subnetwork resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Subnetwork resources.
    kind: [Output Only] Type of resource. Always compute#subnetworkList for
      lists of subnetworks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Subnetwork', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#subnetworkList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class SubnetworkLogConfig(_messages.Message):
  r"""The available logging options for this subnetwork.

  Enums:
    AggregationIntervalValueValuesEnum: Can only be specified if VPC flow
      logging for this subnetwork is enabled. Toggles the aggregation interval
      for collecting flow logs. Increasing the interval time will reduce the
      amount of generated flow logs for long lasting connections. Default is
      an interval of 5 seconds per connection.
    MetadataValueValuesEnum: Can only be specified if VPC flow logs for this
      subnetwork is enabled. Configures whether all, none or a subset of
      metadata fields should be added to the reported VPC flow logs. Default
      is EXCLUDE_ALL_METADATA.

  Fields:
    aggregationInterval: Can only be specified if VPC flow logging for this
      subnetwork is enabled. Toggles the aggregation interval for collecting
      flow logs. Increasing the interval time will reduce the amount of
      generated flow logs for long lasting connections. Default is an interval
      of 5 seconds per connection.
    enable: Whether to enable flow logging for this subnetwork. If this field
      is not explicitly set, it will not appear in get listings. If not set
      the default behavior is determined by the org policy, if there is no org
      policy specified, then it will default to disabled. Flow logging isn't
      supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY.
    filterExpr: Can only be specified if VPC flow logs for this subnetwork is
      enabled. The filter expression is used to define which VPC flow logs
      should be exported to Cloud Logging.
    flowSampling: Can only be specified if VPC flow logging for this
      subnetwork is enabled. The value of the field must be in [0, 1]. Set the
      sampling rate of VPC flow logs within the subnetwork where 1.0 means all
      collected logs are reported and 0.0 means no logs are reported. Default
      is 0.5 unless otherwise specified by the org policy, which means half of
      all collected logs are reported.
    metadata: Can only be specified if VPC flow logs for this subnetwork is
      enabled. Configures whether all, none or a subset of metadata fields
      should be added to the reported VPC flow logs. Default is
      EXCLUDE_ALL_METADATA.
    metadataFields: Can only be specified if VPC flow logs for this subnetwork
      is enabled and "metadata" was set to CUSTOM_METADATA.
  """

  class AggregationIntervalValueValuesEnum(_messages.Enum):
    r"""Can only be specified if VPC flow logging for this subnetwork is
    enabled. Toggles the aggregation interval for collecting flow logs.
    Increasing the interval time will reduce the amount of generated flow logs
    for long lasting connections. Default is an interval of 5 seconds per
    connection.

    Values:
      INTERVAL_10_MIN: <no description>
      INTERVAL_15_MIN: <no description>
      INTERVAL_1_MIN: <no description>
      INTERVAL_30_SEC: <no description>
      INTERVAL_5_MIN: <no description>
      INTERVAL_5_SEC: <no description>
    """
    INTERVAL_10_MIN = 0
    INTERVAL_15_MIN = 1
    INTERVAL_1_MIN = 2
    INTERVAL_30_SEC = 3
    INTERVAL_5_MIN = 4
    INTERVAL_5_SEC = 5

  class MetadataValueValuesEnum(_messages.Enum):
    r"""Can only be specified if VPC flow logs for this subnetwork is enabled.
    Configures whether all, none or a subset of metadata fields should be
    added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA.

    Values:
      CUSTOM_METADATA: <no description>
      EXCLUDE_ALL_METADATA: <no description>
      INCLUDE_ALL_METADATA: <no description>
    """
    CUSTOM_METADATA = 0
    EXCLUDE_ALL_METADATA = 1
    INCLUDE_ALL_METADATA = 2

  aggregationInterval = _messages.EnumField('AggregationIntervalValueValuesEnum', 1)
  enable = _messages.BooleanField(2)
  filterExpr = _messages.StringField(3)
  flowSampling = _messages.FloatField(4, variant=_messages.Variant.FLOAT)
  metadata = _messages.EnumField('MetadataValueValuesEnum', 5)
  metadataFields = _messages.StringField(6, repeated=True)


class SubnetworkSecondaryRange(_messages.Message):
  r"""Represents a secondary IP range of a subnetwork.

  Fields:
    ipCidrRange: The range of IP addresses belonging to this subnetwork
      secondary range. Provide this property when you create the subnetwork.
      Ranges must be unique and non-overlapping with all primary and secondary
      IP ranges within a network. Only IPv4 is supported. The range can be any
      range listed in the Valid ranges list.
    rangeName: The name associated with this subnetwork secondary range, used
      when adding an alias IP range to a VM instance. The name must be 1-63
      characters long, and comply with RFC1035. The name must be unique within
      the subnetwork.
    reservedInternalRange: The URL of the reserved internal range.
  """

  ipCidrRange = _messages.StringField(1)
  rangeName = _messages.StringField(2)
  reservedInternalRange = _messages.StringField(3)


class SubnetworksExpandIpCidrRangeRequest(_messages.Message):
  r"""A SubnetworksExpandIpCidrRangeRequest object.

  Fields:
    ipCidrRange: The IP (in CIDR format or netmask) of internal addresses that
      are legal on this Subnetwork. This range should be disjoint from other
      subnetworks within this network. This range can only be larger than
      (i.e. a superset of) the range previously defined before the update.
  """

  ipCidrRange = _messages.StringField(1)


class SubnetworksScopedList(_messages.Message):
  r"""A SubnetworksScopedList object.

  Messages:
    WarningValue: An informational warning that appears when the list of
      addresses is empty.

  Fields:
    subnetworks: A list of subnetworks contained in this scope.
    warning: An informational warning that appears when the list of addresses
      is empty.
  """

  class WarningValue(_messages.Message):
    r"""An informational warning that appears when the list of addresses is
    empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  subnetworks = _messages.MessageField('Subnetwork', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class SubnetworksScopedWarning(_messages.Message):
  r"""A SubnetworksScopedWarning object.

  Messages:
    WarningValue: An informational warning about unreachable scope

  Fields:
    scopeName: Name of the scope containing this set of Subnetworks.
    warning: An informational warning about unreachable scope
  """

  class WarningValue(_messages.Message):
    r"""An informational warning about unreachable scope

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  scopeName = _messages.StringField(1)
  warning = _messages.MessageField('WarningValue', 2)


class SubnetworksSetPrivateIpGoogleAccessRequest(_messages.Message):
  r"""A SubnetworksSetPrivateIpGoogleAccessRequest object.

  Fields:
    privateIpGoogleAccess: A boolean attribute.
  """

  privateIpGoogleAccess = _messages.BooleanField(1)


class Subsetting(_messages.Message):
  r"""Subsetting configuration for this BackendService. Currently this is
  applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load
  balancing and Traffic Director.

  Enums:
    PolicyValueValuesEnum:

  Fields:
    policy: A PolicyValueValuesEnum attribute.
    subsetSize: The number of backends per backend group assigned to each
      proxy instance or each service mesh client. An input parameter to the
      `CONSISTENT_HASH_SUBSETTING` algorithm. Can only be set if `policy` is
      set to `CONSISTENT_HASH_SUBSETTING`. Can only be set if load balancing
      scheme is `INTERNAL_MANAGED` or `INTERNAL_SELF_MANAGED`. `subset_size`
      is optional for Internal HTTP(S) load balancing and required for Traffic
      Director. If you do not provide this value, Cloud Load Balancing will
      calculate it dynamically to optimize the number of proxies/clients
      visible to each backend and vice versa. Must be greater than 0. If
      `subset_size` is larger than the number of backends/endpoints, then
      subsetting is disabled.
  """

  class PolicyValueValuesEnum(_messages.Enum):
    r"""PolicyValueValuesEnum enum type.

    Values:
      CONSISTENT_HASH_SUBSETTING: Subsetting based on consistent hashing. For
        Traffic Director, the number of backends per backend group (the subset
        size) is based on the `subset_size` parameter. For Internal HTTP(S)
        load balancing, the number of backends per backend group (the subset
        size) is dynamically adjusted in two cases: - As the number of proxy
        instances participating in Internal HTTP(S) load balancing increases,
        the subset size decreases. - When the total number of backends in a
        network exceeds the capacity of a single proxy instance, subset sizes
        are reduced automatically for each service that has backend subsetting
        enabled.
      NONE: No Subsetting. Clients may open connections and send traffic to
        all backends of this backend service. This can lead to performance
        issues if there is substantial imbalance in the count of clients and
        backends.
    """
    CONSISTENT_HASH_SUBSETTING = 0
    NONE = 1

  policy = _messages.EnumField('PolicyValueValuesEnum', 1)
  subsetSize = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class TCPHealthCheck(_messages.Message):
  r"""A TCPHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how a port is selected for
      health checking. Can be one of the following values: USE_FIXED_PORT:
      Specifies a port number explicitly using the port field in the health
      check. Supported by backend services for passthrough load balancers and
      backend services for proxy load balancers. Not supported by target
      pools. The health check supports all backends supported by the backend
      service provided the backend can be health checked. For example,
      GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint
      groups, and instance group backends. USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: Provides an indirect method of specifying the health
      check port by referring to the backend service. Only supported by
      backend services for proxy load balancers. Not supported by target
      pools. Not supported by backend services for passthrough load balancers.
      Supports all backends that can be health checked; for example,
      GCE_VM_IP_PORT network endpoint groups and instance group backends. For
      GCE_VM_IP_PORT network endpoint group backends, the health check uses
      the port number specified for each endpoint in the network endpoint
      group. For instance group backends, the health check uses the port
      number determined by looking up the backend service's named port in the
      instance group's list of named ports.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    port: The TCP port number to which the health check prober sends packets.
      The default value is 80. Valid values are 1 through 65535.
    portName: Not supported.
    portSpecification: Specifies how a port is selected for health checking.
      Can be one of the following values: USE_FIXED_PORT: Specifies a port
      number explicitly using the port field in the health check. Supported by
      backend services for passthrough load balancers and backend services for
      proxy load balancers. Not supported by target pools. The health check
      supports all backends supported by the backend service provided the
      backend can be health checked. For example, GCE_VM_IP network endpoint
      groups, GCE_VM_IP_PORT network endpoint groups, and instance group
      backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an
      indirect method of specifying the health check port by referring to the
      backend service. Only supported by backend services for proxy load
      balancers. Not supported by target pools. Not supported by backend
      services for passthrough load balancers. Supports all backends that can
      be health checked; for example, GCE_VM_IP_PORT network endpoint groups
      and instance group backends. For GCE_VM_IP_PORT network endpoint group
      backends, the health check uses the port number specified for each
      endpoint in the network endpoint group. For instance group backends, the
      health check uses the port number determined by looking up the backend
      service's named port in the instance group's list of named ports.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    request: Instructs the health check prober to send this exact ASCII
      string, up to 1024 bytes in length, after establishing the TCP
      connection.
    response: Creates a content-based TCP health check. In addition to
      establishing a TCP connection, you can configure the health check to
      pass only when the backend sends this exact response ASCII string, up to
      1024 bytes in length. For details, see: https://cloud.google.com/load-
      balancing/docs/health-check-concepts#criteria-protocol-ssl-tcp
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how a port is selected for health checking. Can be one of
    the following values: USE_FIXED_PORT: Specifies a port number explicitly
    using the port field in the health check. Supported by backend services
    for passthrough load balancers and backend services for proxy load
    balancers. Not supported by target pools. The health check supports all
    backends supported by the backend service provided the backend can be
    health checked. For example, GCE_VM_IP network endpoint groups,
    GCE_VM_IP_PORT network endpoint groups, and instance group backends.
    USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect
    method of specifying the health check port by referring to the backend
    service. Only supported by backend services for proxy load balancers. Not
    supported by target pools. Not supported by backend services for
    passthrough load balancers. Supports all backends that can be health
    checked; for example, GCE_VM_IP_PORT network endpoint groups and instance
    group backends. For GCE_VM_IP_PORT network endpoint group backends, the
    health check uses the port number specified for each endpoint in the
    network endpoint group. For instance group backends, the health check uses
    the port number determined by looking up the backend service's named port
    in the instance group's list of named ports.

    Values:
      USE_FIXED_PORT: The port number in the health check's port is used for
        health checking. Applies to network endpoint group and instance group
        backends.
      USE_NAMED_PORT: Not supported.
      USE_SERVING_PORT: For network endpoint group backends, the health check
        uses the port number specified on each endpoint in the network
        endpoint group. For instance group backends, the health check uses the
        port number specified for the backend service's named port defined in
        the instance group's named ports.
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  port = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  portName = _messages.StringField(2)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 3)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 4)
  request = _messages.StringField(5)
  response = _messages.StringField(6)


class Tags(_messages.Message):
  r"""A set of instance tags.

  Fields:
    fingerprint: Specifies a fingerprint for this request, which is
      essentially a hash of the tags' contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update tags. You must always
      provide an up-to-date fingerprint hash in order to update or change
      tags. To see the latest fingerprint, make get() request to the instance.
    items: An array of tags. Each tag must be 1-63 characters long, and comply
      with RFC1035.
  """

  fingerprint = _messages.BytesField(1)
  items = _messages.StringField(2, repeated=True)


class TargetGrpcProxy(_messages.Message):
  r"""Represents a Target gRPC Proxy resource. A target gRPC proxy is a
  component of load balancers intended for load balancing gRPC traffic. Only
  global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can
  reference a target gRPC proxy. The target gRPC Proxy references a URL map
  that specifies how traffic is routed to gRPC backend services.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a TargetGrpcProxy. An up-to-date
      fingerprint must be provided in order to patch/update the
      TargetGrpcProxy; otherwise, the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve the TargetGrpcProxy.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always compute#targetGrpcProxy
      for target grpc proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
    urlMap: URL to the UrlMap resource that defines the mapping from URL to
      the BackendService. The protocol field in the BackendService must be set
      to GRPC.
    validateForProxyless: If true, indicates that the BackendServices
      referenced by the urlMap may be accessed by gRPC applications without
      using a sidecar proxy. This will enable configuration checks on urlMap
      and its referenced BackendServices to not allow unsupported features. A
      gRPC application must use "xds:///" scheme in the target URI of the
      service it is connecting to. If false, indicates that the
      BackendServices referenced by the urlMap will be accessed by gRPC
      applications via a sidecar proxy. In this case, a gRPC application must
      not use "xds:///" scheme in the target URI of the service it is
      connecting to
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#targetGrpcProxy')
  name = _messages.StringField(6)
  selfLink = _messages.StringField(7)
  selfLinkWithId = _messages.StringField(8)
  urlMap = _messages.StringField(9)
  validateForProxyless = _messages.BooleanField(10)


class TargetGrpcProxyList(_messages.Message):
  r"""A TargetGrpcProxyList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetGrpcProxy resources.
    kind: [Output Only] Type of the resource. Always compute#targetGrpcProxy
      for target grpc proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetGrpcProxy', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#targetGrpcProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetHttpProxiesScopedList(_messages.Message):
  r"""A TargetHttpProxiesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    targetHttpProxies: A list of TargetHttpProxies contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetHttpProxies = _messages.MessageField('TargetHttpProxy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetHttpProxy(_messages.Message):
  r"""Represents a Target HTTP Proxy resource. Google Compute Engine has two
  Target HTTP Proxy resources: *
  [Global](/compute/docs/reference/rest/alpha/targetHttpProxies) *
  [Regional](/compute/docs/reference/rest/alpha/regionTargetHttpProxies) A
  target HTTP proxy is a component of Google Cloud HTTP load balancers. *
  targetHttpProxies are used by global external Application Load Balancers,
  classic Application Load Balancers, cross-region internal Application Load
  Balancers, and Traffic Director. * regionTargetHttpProxies are used by
  regional internal Application Load Balancers and regional external
  Application Load Balancers. Forwarding rules reference a target HTTP proxy,
  and the target proxy then references a URL map. For more information, read
  Using Target Proxies and Forwarding rule concepts.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a TargetHttpProxy. An up-to-date
      fingerprint must be provided in order to patch/update the
      TargetHttpProxy; otherwise, the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve the TargetHttpProxy.
    httpFilters: URLs to networkservices.HttpFilter resources enabled for xDS
      clients using this configuration. For example, https://networkservices.g
      oogleapis.com/v1alpha1/projects/project/locations/
      locationhttpFilters/httpFilter Only filters that handle outbound
      connection and stream events may be specified. These filters work in
      conjunction with a default set of HTTP filters that may already be
      configured by Traffic Director. Traffic Director will determine the
      final location of these filters within xDS configuration based on the
      name of the HTTP filter. If Traffic Director positions multiple filters
      at the same location, those filters will be in the same order as
      specified in this list. httpFilters only applies for loadbalancers with
      loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for
      more details.
    httpKeepAliveTimeoutSec: Specifies how long to keep a connection open,
      after completing a response, while there is no matching traffic (in
      seconds). If an HTTP keep-alive is not specified, a default value (610
      seconds) will be used. For global external Application Load Balancers,
      the minimum allowed value is 5 seconds and the maximum allowed value is
      1200 seconds. For classic Application Load Balancers, this option is not
      supported.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#targetHttpProxy for
      target HTTP proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    proxyBind: This field only applies when the forwarding rule that
      references this target proxy has a loadBalancingScheme set to
      INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set
      up inbound traffic interception and bind to the IP address and port
      specified in the forwarding rule. This is generally useful when using
      Traffic Director to configure Envoy as a gateway or middle proxy (in
      other words, not a sidecar proxy). The Envoy proxy listens for inbound
      requests and handles requests when it receives them. The default is
      false.
    region: [Output Only] URL of the region where the regional Target HTTP
      Proxy resides. This field is not applicable to global Target HTTP
      Proxies.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    urlMap: URL to the UrlMap resource that defines the mapping from URL to
      the BackendService.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  httpFilters = _messages.StringField(4, repeated=True)
  httpKeepAliveTimeoutSec = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default='compute#targetHttpProxy')
  name = _messages.StringField(8)
  proxyBind = _messages.BooleanField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  urlMap = _messages.StringField(13)


class TargetHttpProxyAggregatedList(_messages.Message):
  r"""A TargetHttpProxyAggregatedList object.

  Messages:
    ItemsValue: A list of TargetHttpProxiesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetHttpProxiesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#targetHttpProxyAggregatedList for lists of Target HTTP Proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetHttpProxiesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        TargetHttpProxies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetHttpProxiesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetHttpProxiesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#targetHttpProxyAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetHttpProxyList(_messages.Message):
  r"""A list of TargetHttpProxy resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetHttpProxy resources.
    kind: Type of resource. Always compute#targetHttpProxyList for lists of
      target HTTP proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetHttpProxy', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#targetHttpProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetHttpsProxiesScopedList(_messages.Message):
  r"""A TargetHttpsProxiesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    targetHttpsProxies: A list of TargetHttpsProxies contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetHttpsProxies = _messages.MessageField('TargetHttpsProxy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetHttpsProxiesSetCertificateMapRequest(_messages.Message):
  r"""A TargetHttpsProxiesSetCertificateMapRequest object.

  Fields:
    certificateMap: URL of the Certificate Map to associate with this
      TargetHttpsProxy. Accepted format is
      //certificatemanager.googleapis.com/projects/{project
      }/locations/{location}/certificateMaps/{resourceName}.
  """

  certificateMap = _messages.StringField(1)


class TargetHttpsProxiesSetQuicOverrideRequest(_messages.Message):
  r"""A TargetHttpsProxiesSetQuicOverrideRequest object.

  Enums:
    QuicOverrideValueValuesEnum: QUIC policy for the TargetHttpsProxy
      resource.

  Fields:
    quicOverride: QUIC policy for the TargetHttpsProxy resource.
  """

  class QuicOverrideValueValuesEnum(_messages.Enum):
    r"""QUIC policy for the TargetHttpsProxy resource.

    Values:
      DISABLE: The load balancer will not attempt to negotiate QUIC with
        clients.
      ENABLE: The load balancer will attempt to negotiate QUIC with clients.
      NONE: No overrides to the default QUIC policy. This option is implicit
        if no QUIC override has been specified in the request.
    """
    DISABLE = 0
    ENABLE = 1
    NONE = 2

  quicOverride = _messages.EnumField('QuicOverrideValueValuesEnum', 1)


class TargetHttpsProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A TargetHttpsProxiesSetSslCertificatesRequest object.

  Fields:
    sslCertificates: New set of SslCertificate resources to associate with
      this TargetHttpsProxy resource. At least one SSL certificate must be
      specified. Currently, you may specify up to 15 SSL certificates.
  """

  sslCertificates = _messages.StringField(1, repeated=True)


class TargetHttpsProxy(_messages.Message):
  r"""Represents a Target HTTPS Proxy resource. Google Compute Engine has two
  Target HTTPS Proxy resources: *
  [Global](/compute/docs/reference/rest/alpha/targetHttpsProxies) *
  [Regional](/compute/docs/reference/rest/alpha/regionTargetHttpsProxies) A
  target HTTPS proxy is a component of Google Cloud HTTPS load balancers. *
  targetHttpProxies are used by global external Application Load Balancers,
  classic Application Load Balancers, cross-region internal Application Load
  Balancers, and Traffic Director. * regionTargetHttpProxies are used by
  regional internal Application Load Balancers and regional external
  Application Load Balancers. Forwarding rules reference a target HTTPS proxy,
  and the target proxy then references a URL map. For more information, read
  Using Target Proxies and Forwarding rule concepts.

  Enums:
    QuicOverrideValueValuesEnum: Specifies the QUIC override policy for this
      TargetHttpsProxy resource. This setting determines whether the load
      balancer attempts to negotiate QUIC with clients. You can specify NONE,
      ENABLE, or DISABLE. - When quic-override is set to NONE, Google manages
      whether QUIC is used. - When quic-override is set to ENABLE, the load
      balancer uses QUIC when possible. - When quic-override is set to
      DISABLE, the load balancer doesn't use QUIC. - If the quic-override flag
      is not specified, NONE is implied.
    TlsEarlyDataValueValuesEnum:  Specifies whether TLS 1.3 0-RTT Data ("Early
      Data") should be accepted for this service. Early Data allows a TLS
      resumption handshake to include the initial application payload (a HTTP
      request) alongside the handshake, reducing the effective round trips to
      "zero". This applies to TLS 1.3 connections over TCP (HTTP/2) as well as
      over UDP (QUIC/h3). This can improve application performance, especially
      on networks where interruptions may be common, such as on mobile.
      Requests with Early Data will have the "Early-Data" HTTP header set on
      the request, with a value of "1", to allow the backend to determine
      whether Early Data was included. Note: TLS Early Data may allow requests
      to be replayed, as the data is sent to the backend before the handshake
      has fully completed. Applications that allow idempotent HTTP methods to
      make non-idempotent changes, such as a GET request updating a database,
      should not accept Early Data on those requests, and reject requests with
      the "Early-Data: 1" HTTP header by returning a HTTP 425 (Too Early)
      status code, in order to remain RFC compliant. The default value is
      DISABLED.

  Fields:
    authentication: [Deprecated] Use serverTlsPolicy instead.
    authorization: [Deprecated] Use authorizationPolicy instead.
    authorizationPolicy: Optional. A URL referring to a
      networksecurity.AuthorizationPolicy resource that describes how the
      proxy should authorize inbound traffic. If left blank, access will not
      be restricted by an authorization policy. Refer to the
      AuthorizationPolicy resource for additional details. authorizationPolicy
      only applies to a global TargetHttpsProxy attached to
      globalForwardingRules with the loadBalancingScheme set to
      INTERNAL_SELF_MANAGED. Note: This field currently has no impact.
    certificateMap: URL of a certificate map that identifies a certificate map
      associated with the given target proxy. This field can only be set for
      Global external Application Load Balancer or Classic Application Load
      Balancer. For other products use Certificate Manager Certificates
      instead. If set, sslCertificates will be ignored. Accepted format is
      //certificatemanager.googleapis.com/projects/{project
      }/locations/{location}/certificateMaps/{resourceName}.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a TargetHttpsProxy. An up-to-date
      fingerprint must be provided in order to patch the TargetHttpsProxy;
      otherwise, the request will fail with error 412 conditionNotMet. To see
      the latest fingerprint, make a get() request to retrieve the
      TargetHttpsProxy.
    httpFilters: URLs to networkservices.HttpFilter resources enabled for xDS
      clients using this configuration. For example,
      https://networkservices.googleapis.com/beta/projects/project/locations/
      location/httpFilters/httpFilter Only filters that handle outbound
      connection and stream events may be specified. These filters work in
      conjunction with a default set of HTTP filters that may already be
      configured by Traffic Director. Traffic Director will determine the
      final location of these filters within xDS configuration based on the
      name of the HTTP filter. If Traffic Director positions multiple filters
      at the same location, those filters will be in the same order as
      specified in this list. httpFilters only applies for loadbalancers with
      loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for
      more details.
    httpKeepAliveTimeoutSec: Specifies how long to keep a connection open,
      after completing a response, while there is no matching traffic (in
      seconds). If an HTTP keep-alive is not specified, a default value (610
      seconds) will be used. For global external Application Load Balancers,
      the minimum allowed value is 5 seconds and the maximum allowed value is
      1200 seconds. For classic Application Load Balancers, this option is not
      supported.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#targetHttpsProxy for
      target HTTPS proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    proxyBind: This field only applies when the forwarding rule that
      references this target proxy has a loadBalancingScheme set to
      INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set
      up inbound traffic interception and bind to the IP address and port
      specified in the forwarding rule. This is generally useful when using
      Traffic Director to configure Envoy as a gateway or middle proxy (in
      other words, not a sidecar proxy). The Envoy proxy listens for inbound
      requests and handles requests when it receives them. The default is
      false.
    quicOverride: Specifies the QUIC override policy for this TargetHttpsProxy
      resource. This setting determines whether the load balancer attempts to
      negotiate QUIC with clients. You can specify NONE, ENABLE, or DISABLE. -
      When quic-override is set to NONE, Google manages whether QUIC is used.
      - When quic-override is set to ENABLE, the load balancer uses QUIC when
      possible. - When quic-override is set to DISABLE, the load balancer
      doesn't use QUIC. - If the quic-override flag is not specified, NONE is
      implied.
    region: [Output Only] URL of the region where the regional
      TargetHttpsProxy resides. This field is not applicable to global
      TargetHttpsProxies.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serverTlsPolicy: Optional. A URL referring to a
      networksecurity.ServerTlsPolicy resource that describes how the proxy
      should authenticate inbound traffic. serverTlsPolicy only applies to a
      global TargetHttpsProxy attached to globalForwardingRules with the
      loadBalancingScheme set to INTERNAL_SELF_MANAGED or EXTERNAL or
      EXTERNAL_MANAGED or INTERNAL_MANAGED. It also applies to a regional
      TargetHttpsProxy attached to regional forwardingRules with the
      loadBalancingScheme set to EXTERNAL_MANAGED or INTERNAL_MANAGED. For
      details which ServerTlsPolicy resources are accepted with
      INTERNAL_SELF_MANAGED and which with EXTERNAL, INTERNAL_MANAGED,
      EXTERNAL_MANAGED loadBalancingScheme consult ServerTlsPolicy
      documentation. If left blank, communications are not encrypted.
    sslCertificates: URLs to SslCertificate resources that are used to
      authenticate connections between users and the load balancer. At least
      one SSL certificate must be specified. SslCertificates do not apply when
      the load balancing scheme is set to INTERNAL_SELF_MANAGED. The URLs
      should refer to a SSL Certificate resource or Certificate Manager
      Certificate resource. Mixing Classic Certificates and Certificate
      Manager Certificates is not allowed. Certificate Manager Certificates
      must include the certificatemanager API namespace. Using Certificate
      Manager Certificates in this field is not supported by Global external
      Application Load Balancer or Classic Application Load Balancer, use
      certificate_map instead. Currently, you may specify up to 15 Classic SSL
      Certificates or up to 100 Certificate Manager Certificates. Certificate
      Manager Certificates accepted formats are: -
      //certificatemanager.googleapis.com/projects/{project}/locations/{
      location}/certificates/{resourceName}. -
      https://certificatemanager.googleapis.com/v1alpha1/projects/{project
      }/locations/{location}/certificates/{resourceName}.
    sslPolicy: URL of SslPolicy resource that will be associated with the
      TargetHttpsProxy resource. If not set, the TargetHttpsProxy resource has
      no SSL policy configured.
    tlsEarlyData:  Specifies whether TLS 1.3 0-RTT Data ("Early Data") should
      be accepted for this service. Early Data allows a TLS resumption
      handshake to include the initial application payload (a HTTP request)
      alongside the handshake, reducing the effective round trips to "zero".
      This applies to TLS 1.3 connections over TCP (HTTP/2) as well as over
      UDP (QUIC/h3). This can improve application performance, especially on
      networks where interruptions may be common, such as on mobile. Requests
      with Early Data will have the "Early-Data" HTTP header set on the
      request, with a value of "1", to allow the backend to determine whether
      Early Data was included. Note: TLS Early Data may allow requests to be
      replayed, as the data is sent to the backend before the handshake has
      fully completed. Applications that allow idempotent HTTP methods to make
      non-idempotent changes, such as a GET request updating a database,
      should not accept Early Data on those requests, and reject requests with
      the "Early-Data: 1" HTTP header by returning a HTTP 425 (Too Early)
      status code, in order to remain RFC compliant. The default value is
      DISABLED.
    urlMap: A fully-qualified or valid partial URL to the UrlMap resource that
      defines the mapping from URL to the BackendService. For example, the
      following are all valid URLs for specifying a URL map: -
      https://www.googleapis.compute/v1/projects/project/global/urlMaps/ url-
      map - projects/project/global/urlMaps/url-map - global/urlMaps/url-map
  """

  class QuicOverrideValueValuesEnum(_messages.Enum):
    r"""Specifies the QUIC override policy for this TargetHttpsProxy resource.
    This setting determines whether the load balancer attempts to negotiate
    QUIC with clients. You can specify NONE, ENABLE, or DISABLE. - When quic-
    override is set to NONE, Google manages whether QUIC is used. - When quic-
    override is set to ENABLE, the load balancer uses QUIC when possible. -
    When quic-override is set to DISABLE, the load balancer doesn't use QUIC.
    - If the quic-override flag is not specified, NONE is implied.

    Values:
      DISABLE: The load balancer will not attempt to negotiate QUIC with
        clients.
      ENABLE: The load balancer will attempt to negotiate QUIC with clients.
      NONE: No overrides to the default QUIC policy. This option is implicit
        if no QUIC override has been specified in the request.
    """
    DISABLE = 0
    ENABLE = 1
    NONE = 2

  class TlsEarlyDataValueValuesEnum(_messages.Enum):
    r""" Specifies whether TLS 1.3 0-RTT Data ("Early Data") should be
    accepted for this service. Early Data allows a TLS resumption handshake to
    include the initial application payload (a HTTP request) alongside the
    handshake, reducing the effective round trips to "zero". This applies to
    TLS 1.3 connections over TCP (HTTP/2) as well as over UDP (QUIC/h3). This
    can improve application performance, especially on networks where
    interruptions may be common, such as on mobile. Requests with Early Data
    will have the "Early-Data" HTTP header set on the request, with a value of
    "1", to allow the backend to determine whether Early Data was included.
    Note: TLS Early Data may allow requests to be replayed, as the data is
    sent to the backend before the handshake has fully completed. Applications
    that allow idempotent HTTP methods to make non-idempotent changes, such as
    a GET request updating a database, should not accept Early Data on those
    requests, and reject requests with the "Early-Data: 1" HTTP header by
    returning a HTTP 425 (Too Early) status code, in order to remain RFC
    compliant. The default value is DISABLED.

    Values:
      DISABLED: TLS 1.3 Early Data is not advertised, and any (invalid)
        attempts to send Early Data will be rejected by closing the
        connection.
      PERMISSIVE: This enables TLS 1.3 0-RTT, and only allows Early Data to be
        included on requests with safe HTTP methods (GET, HEAD, OPTIONS,
        TRACE). This mode does not enforce any other limitations for requests
        with Early Data. The application owner should validate that Early Data
        is acceptable for a given request path.
      STRICT: This enables TLS 1.3 0-RTT, and only allows Early Data to be
        included on requests with safe HTTP methods (GET, HEAD, OPTIONS,
        TRACE) without query parameters. Requests that send Early Data with
        non-idempotent HTTP methods or with query parameters will be rejected
        with a HTTP 425.
      UNRESTRICTED: This enables TLS 1.3 Early Data for requests with any HTTP
        method including non-idempotent methods list POST. This mode does not
        enforce any other limitations. This may be valuable for gRPC use
        cases. However, we do not recommend this method unless you have
        evaluated your security stance and mitigated the risk of replay
        attacks using other mechanisms.
    """
    DISABLED = 0
    PERMISSIVE = 1
    STRICT = 2
    UNRESTRICTED = 3

  authentication = _messages.StringField(1)
  authorization = _messages.StringField(2)
  authorizationPolicy = _messages.StringField(3)
  certificateMap = _messages.StringField(4)
  creationTimestamp = _messages.StringField(5)
  description = _messages.StringField(6)
  fingerprint = _messages.BytesField(7)
  httpFilters = _messages.StringField(8, repeated=True)
  httpKeepAliveTimeoutSec = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(11, default='compute#targetHttpsProxy')
  name = _messages.StringField(12)
  proxyBind = _messages.BooleanField(13)
  quicOverride = _messages.EnumField('QuicOverrideValueValuesEnum', 14)
  region = _messages.StringField(15)
  selfLink = _messages.StringField(16)
  selfLinkWithId = _messages.StringField(17)
  serverTlsPolicy = _messages.StringField(18)
  sslCertificates = _messages.StringField(19, repeated=True)
  sslPolicy = _messages.StringField(20)
  tlsEarlyData = _messages.EnumField('TlsEarlyDataValueValuesEnum', 21)
  urlMap = _messages.StringField(22)


class TargetHttpsProxyAggregatedList(_messages.Message):
  r"""A TargetHttpsProxyAggregatedList object.

  Messages:
    ItemsValue: A list of TargetHttpsProxiesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetHttpsProxiesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#targetHttpsProxyAggregatedList for lists of Target HTTP Proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetHttpsProxiesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        TargetHttpsProxies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetHttpsProxiesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetHttpsProxiesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#targetHttpsProxyAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetHttpsProxyList(_messages.Message):
  r"""Contains a list of TargetHttpsProxy resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetHttpsProxy resources.
    kind: Type of resource. Always compute#targetHttpsProxyList for lists of
      target HTTPS proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetHttpsProxy', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#targetHttpsProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetInstance(_messages.Message):
  r"""Represents a Target Instance resource. You can use a target instance to
  handle traffic for one or more forwarding rules, which is ideal for
  forwarding protocol traffic that is managed by a single source. For example,
  ESP, AH, TCP, or UDP. For more information, read Target instances.

  Enums:
    NatPolicyValueValuesEnum: Must have a value of NO_NAT. Protocol forwarding
      delivers packets while preserving the destination IP address of the
      forwarding rule referencing the target instance.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    instance: A URL to the virtual machine instance that handles traffic for
      this target instance. When creating a target instance, you can provide
      the fully-qualified URL or a valid partial URL to the desired virtual
      machine. For example, the following are all valid URLs: -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone
      /instances/instance - projects/project/zones/zone/instances/instance -
      zones/zone/instances/instance
    kind: [Output Only] The type of the resource. Always
      compute#targetInstance for target instances.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    natPolicy: Must have a value of NO_NAT. Protocol forwarding delivers
      packets while preserving the destination IP address of the forwarding
      rule referencing the target instance.
    network: The URL of the network this target instance uses to forward
      traffic. If not specified, the traffic will be forwarded to the network
      that the default network interface belongs to.
    securityPolicy: [Output Only] The resource URL for the security policy
      associated with this target instance.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    zone: [Output Only] URL of the zone where the target instance resides. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
  """

  class NatPolicyValueValuesEnum(_messages.Enum):
    r"""Must have a value of NO_NAT. Protocol forwarding delivers packets
    while preserving the destination IP address of the forwarding rule
    referencing the target instance.

    Values:
      NO_NAT: No NAT performed.
    """
    NO_NAT = 0

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  instance = _messages.StringField(4)
  kind = _messages.StringField(5, default='compute#targetInstance')
  name = _messages.StringField(6)
  natPolicy = _messages.EnumField('NatPolicyValueValuesEnum', 7)
  network = _messages.StringField(8)
  securityPolicy = _messages.StringField(9)
  selfLink = _messages.StringField(10)
  selfLinkWithId = _messages.StringField(11)
  zone = _messages.StringField(12)


class TargetInstanceAggregatedList(_messages.Message):
  r"""A TargetInstanceAggregatedList object.

  Messages:
    ItemsValue: A list of TargetInstance resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetInstance resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetInstance resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of target
        instances.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetInstancesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetInstancesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#targetInstanceAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetInstanceList(_messages.Message):
  r"""Contains a list of TargetInstance resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetInstance resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetInstance', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#targetInstanceList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetInstancesScopedList(_messages.Message):
  r"""A TargetInstancesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of addresses
      when the list is empty.

  Fields:
    targetInstances: A list of target instances contained in this scope.
    warning: Informational warning which replaces the list of addresses when
      the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of addresses when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetInstances = _messages.MessageField('TargetInstance', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetPool(_messages.Message):
  r"""Represents a Target Pool resource. Target pools are used with external
  passthrough Network Load Balancers. A target pool references member
  instances, an associated legacy HttpHealthCheck resource, and, optionally, a
  backup target pool. For more information, read Using target pools.

  Enums:
    SessionAffinityValueValuesEnum: Session affinity option, must be one of
      the following values: NONE: Connections from the same client IP may go
      to any instance in the pool. CLIENT_IP: Connections from the same client
      IP will go to the same instance in the pool while that instance remains
      healthy. CLIENT_IP_PROTO: Connections from the same client IP with the
      same IP protocol will go to the same instance in the pool while that
      instance remains healthy.

  Fields:
    backupPool: The server-defined URL for the resource. This field is
      applicable only when the containing target pool is serving a forwarding
      rule as the primary pool, and its failoverRatio field is properly set to
      a value between [0, 1]. backupPool and failoverRatio together define the
      fallback behavior of the primary target pool: if the ratio of the
      healthy instances in the primary pool is at or below failoverRatio,
      traffic arriving at the load-balanced IP will be directed to the backup
      pool. In case where failoverRatio and backupPool are not set, or all the
      instances in the backup pool are unhealthy, the traffic will be directed
      back to the primary pool in the "force" mode, where traffic will be
      spread to the healthy instances with the best effort, or to all
      instances when no instance is healthy.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    failoverRatio: This field is applicable only when the containing target
      pool is serving a forwarding rule as the primary pool (i.e., not as a
      backup pool to some other target pool). The value of the field must be
      in [0, 1]. If set, backupPool must also be set. They together define the
      fallback behavior of the primary target pool: if the ratio of the
      healthy instances in the primary pool is at or below this number,
      traffic arriving at the load-balanced IP will be directed to the backup
      pool. In case where failoverRatio is not set or all the instances in the
      backup pool are unhealthy, the traffic will be directed back to the
      primary pool in the "force" mode, where traffic will be spread to the
      healthy instances with the best effort, or to all instances when no
      instance is healthy.
    healthChecks: The URL of the HttpHealthCheck resource. A member instance
      in this pool is considered healthy if and only if the health checks
      pass. Only legacy HttpHealthChecks are supported. Only one health check
      may be specified.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    instances: A list of resource URLs to the virtual machine instances
      serving this pool. They must live in zones contained in the same region
      as this pool.
    kind: [Output Only] Type of the resource. Always compute#targetPool for
      target pools.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the target pool resides.
    securityPolicy: [Output Only] The resource URL for the security policy
      associated with this target pool.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sessionAffinity: Session affinity option, must be one of the following
      values: NONE: Connections from the same client IP may go to any instance
      in the pool. CLIENT_IP: Connections from the same client IP will go to
      the same instance in the pool while that instance remains healthy.
      CLIENT_IP_PROTO: Connections from the same client IP with the same IP
      protocol will go to the same instance in the pool while that instance
      remains healthy.
  """

  class SessionAffinityValueValuesEnum(_messages.Enum):
    r"""Session affinity option, must be one of the following values: NONE:
    Connections from the same client IP may go to any instance in the pool.
    CLIENT_IP: Connections from the same client IP will go to the same
    instance in the pool while that instance remains healthy. CLIENT_IP_PROTO:
    Connections from the same client IP with the same IP protocol will go to
    the same instance in the pool while that instance remains healthy.

    Values:
      CLIENT_IP: 2-tuple hash on packet's source and destination IP addresses.
        Connections from the same source IP address to the same destination IP
        address will be served by the same backend VM while that VM remains
        healthy.
      CLIENT_IP_NO_DESTINATION: 1-tuple hash only on packet's source IP
        address. Connections from the same source IP address will be served by
        the same backend VM while that VM remains healthy. This option can
        only be used for Internal TCP/UDP Load Balancing.
      CLIENT_IP_PORT_PROTO: 5-tuple hash on packet's source and destination IP
        addresses, IP protocol, and source and destination ports. Connections
        for the same IP protocol from the same source IP address and port to
        the same destination IP address and port will be served by the same
        backend VM while that VM remains healthy. This option cannot be used
        for HTTP(S) load balancing.
      CLIENT_IP_PROTO: 3-tuple hash on packet's source and destination IP
        addresses, and IP protocol. Connections for the same IP protocol from
        the same source IP address to the same destination IP address will be
        served by the same backend VM while that VM remains healthy. This
        option cannot be used for HTTP(S) load balancing.
      GENERATED_COOKIE: Hash based on a cookie generated by the L7
        loadbalancer. Only valid for HTTP(S) load balancing.
      HEADER_FIELD: The hash is based on a user specified header field.
      HTTP_COOKIE: The hash is based on a user provided cookie.
      NONE: No session affinity. Connections from the same client IP may go to
        any instance in the pool.
      STRONG_COOKIE_AFFINITY: Strong cookie-based affinity. Connections
        bearing the same cookie will be served by the same backend VM while
        that VM remains healthy, as long as the cookie has not expired.
    """
    CLIENT_IP = 0
    CLIENT_IP_NO_DESTINATION = 1
    CLIENT_IP_PORT_PROTO = 2
    CLIENT_IP_PROTO = 3
    GENERATED_COOKIE = 4
    HEADER_FIELD = 5
    HTTP_COOKIE = 6
    NONE = 7
    STRONG_COOKIE_AFFINITY = 8

  backupPool = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  failoverRatio = _messages.FloatField(4, variant=_messages.Variant.FLOAT)
  healthChecks = _messages.StringField(5, repeated=True)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  instances = _messages.StringField(7, repeated=True)
  kind = _messages.StringField(8, default='compute#targetPool')
  name = _messages.StringField(9)
  region = _messages.StringField(10)
  securityPolicy = _messages.StringField(11)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)
  sessionAffinity = _messages.EnumField('SessionAffinityValueValuesEnum', 14)


class TargetPoolAggregatedList(_messages.Message):
  r"""A TargetPoolAggregatedList object.

  Messages:
    ItemsValue: A list of TargetPool resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetPool resources.
    kind: [Output Only] Type of resource. Always
      compute#targetPoolAggregatedList for aggregated lists of target pools.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetPool resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of target
        pools.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetPoolsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetPoolsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#targetPoolAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetPoolInstanceHealth(_messages.Message):
  r"""A TargetPoolInstanceHealth object.

  Fields:
    healthStatus: A HealthStatus attribute.
    kind: [Output Only] Type of resource. Always
      compute#targetPoolInstanceHealth when checking the health of an
      instance.
  """

  healthStatus = _messages.MessageField('HealthStatus', 1, repeated=True)
  kind = _messages.StringField(2, default='compute#targetPoolInstanceHealth')


class TargetPoolList(_messages.Message):
  r"""Contains a list of TargetPool resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetPool resources.
    kind: [Output Only] Type of resource. Always compute#targetPoolList for
      lists of target pools.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetPool', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#targetPoolList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetPoolsAddHealthCheckRequest(_messages.Message):
  r"""A TargetPoolsAddHealthCheckRequest object.

  Fields:
    healthChecks: The HttpHealthCheck to add to the target pool.
  """

  healthChecks = _messages.MessageField('HealthCheckReference', 1, repeated=True)


class TargetPoolsAddInstanceRequest(_messages.Message):
  r"""A TargetPoolsAddInstanceRequest object.

  Fields:
    instances: A full or partial URL to an instance to add to this target
      pool. This can be a full or partial URL. For example, the following are
      valid URLs: - https://www.googleapis.com/compute/v1/projects/project-
      id/zones/zone /instances/instance-name - projects/project-
      id/zones/zone/instances/instance-name - zones/zone/instances/instance-
      name
  """

  instances = _messages.MessageField('InstanceReference', 1, repeated=True)


class TargetPoolsRemoveHealthCheckRequest(_messages.Message):
  r"""A TargetPoolsRemoveHealthCheckRequest object.

  Fields:
    healthChecks: Health check URL to be removed. This can be a full or valid
      partial URL. For example, the following are valid URLs: -
      https://www.googleapis.com/compute/beta/projects/project
      /global/httpHealthChecks/health-check -
      projects/project/global/httpHealthChecks/health-check -
      global/httpHealthChecks/health-check
  """

  healthChecks = _messages.MessageField('HealthCheckReference', 1, repeated=True)


class TargetPoolsRemoveInstanceRequest(_messages.Message):
  r"""A TargetPoolsRemoveInstanceRequest object.

  Fields:
    instances: URLs of the instances to be removed from target pool.
  """

  instances = _messages.MessageField('InstanceReference', 1, repeated=True)


class TargetPoolsScopedList(_messages.Message):
  r"""A TargetPoolsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of addresses
      when the list is empty.

  Fields:
    targetPools: A list of target pools contained in this scope.
    warning: Informational warning which replaces the list of addresses when
      the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of addresses when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetPools = _messages.MessageField('TargetPool', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetReference(_messages.Message):
  r"""A TargetReference object.

  Fields:
    target: A string attribute.
  """

  target = _messages.StringField(1)


class TargetSslProxiesSetBackendServiceRequest(_messages.Message):
  r"""A TargetSslProxiesSetBackendServiceRequest object.

  Fields:
    service: The URL of the new BackendService resource for the
      targetSslProxy.
  """

  service = _messages.StringField(1)


class TargetSslProxiesSetCertificateMapRequest(_messages.Message):
  r"""A TargetSslProxiesSetCertificateMapRequest object.

  Fields:
    certificateMap: URL of the Certificate Map to associate with this
      TargetSslProxy. Accepted format is
      //certificatemanager.googleapis.com/projects/{project
      }/locations/{location}/certificateMaps/{resourceName}.
  """

  certificateMap = _messages.StringField(1)


class TargetSslProxiesSetProxyHeaderRequest(_messages.Message):
  r"""A TargetSslProxiesSetProxyHeaderRequest object.

  Enums:
    ProxyHeaderValueValuesEnum: The new type of proxy header to append before
      sending data to the backend. NONE or PROXY_V1 are allowed.

  Fields:
    proxyHeader: The new type of proxy header to append before sending data to
      the backend. NONE or PROXY_V1 are allowed.
  """

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""The new type of proxy header to append before sending data to the
    backend. NONE or PROXY_V1 are allowed.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 1)


class TargetSslProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A TargetSslProxiesSetSslCertificatesRequest object.

  Fields:
    sslCertificates: New set of URLs to SslCertificate resources to associate
      with this TargetSslProxy. At least one SSL certificate must be
      specified. Currently, you may specify up to 15 SSL certificates.
  """

  sslCertificates = _messages.StringField(1, repeated=True)


class TargetSslProxy(_messages.Message):
  r"""Represents a Target SSL Proxy resource. A target SSL proxy is a
  component of a Proxy Network Load Balancer. The forwarding rule references
  the target SSL proxy, and the target proxy then references a backend
  service. For more information, read Proxy Network Load Balancer overview.

  Enums:
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    certificateMap: URL of a certificate map that identifies a certificate map
      associated with the given target proxy. This field can only be set for
      global target proxies. If set, sslCertificates will be ignored. Accepted
      format is //certificatemanager.googleapis.com/projects/{project
      }/locations/{location}/certificateMaps/{resourceName}.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#targetSslProxy
      for target SSL proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    selfLink: [Output Only] Server-defined URL for the resource.
    service: URL to the BackendService resource.
    sslCertificates: URLs to SslCertificate resources that are used to
      authenticate connections to Backends. At least one SSL certificate must
      be specified. Currently, you may specify up to 15 SSL certificates.
      sslCertificates do not apply when the load balancing scheme is set to
      INTERNAL_SELF_MANAGED.
    sslPolicy: URL of SslPolicy resource that will be associated with the
      TargetSslProxy resource. If not set, the TargetSslProxy resource will
      not have any SSL policy configured.
  """

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  certificateMap = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#targetSslProxy')
  name = _messages.StringField(6)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 7)
  selfLink = _messages.StringField(8)
  service = _messages.StringField(9)
  sslCertificates = _messages.StringField(10, repeated=True)
  sslPolicy = _messages.StringField(11)


class TargetSslProxyList(_messages.Message):
  r"""Contains a list of TargetSslProxy resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetSslProxy resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetSslProxy', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#targetSslProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetTcpProxiesScopedList(_messages.Message):
  r"""A TargetTcpProxiesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    targetTcpProxies: A list of TargetTcpProxies contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetTcpProxies = _messages.MessageField('TargetTcpProxy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetTcpProxiesSetBackendServiceRequest(_messages.Message):
  r"""A TargetTcpProxiesSetBackendServiceRequest object.

  Fields:
    service: The URL of the new BackendService resource for the
      targetTcpProxy.
  """

  service = _messages.StringField(1)


class TargetTcpProxiesSetProxyHeaderRequest(_messages.Message):
  r"""A TargetTcpProxiesSetProxyHeaderRequest object.

  Enums:
    ProxyHeaderValueValuesEnum: The new type of proxy header to append before
      sending data to the backend. NONE or PROXY_V1 are allowed.

  Fields:
    proxyHeader: The new type of proxy header to append before sending data to
      the backend. NONE or PROXY_V1 are allowed.
  """

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""The new type of proxy header to append before sending data to the
    backend. NONE or PROXY_V1 are allowed.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 1)


class TargetTcpProxy(_messages.Message):
  r"""Represents a Target TCP Proxy resource. A target TCP proxy is a
  component of a Proxy Network Load Balancer. The forwarding rule references
  the target TCP proxy, and the target proxy then references a backend
  service. For more information, read Proxy Network Load Balancer overview.

  Enums:
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#targetTcpProxy
      for target TCP proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    proxyBind: This field only applies when the forwarding rule that
      references this target proxy has a loadBalancingScheme set to
      INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set
      up inbound traffic interception and bind to the IP address and port
      specified in the forwarding rule. This is generally useful when using
      Traffic Director to configure Envoy as a gateway or middle proxy (in
      other words, not a sidecar proxy). The Envoy proxy listens for inbound
      requests and handles requests when it receives them. The default is
      false.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    region: [Output Only] URL of the region where the regional TCP proxy
      resides. This field is not applicable to global TCP proxy.
    selfLink: [Output Only] Server-defined URL for the resource.
    service: URL to the BackendService resource.
  """

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default='compute#targetTcpProxy')
  name = _messages.StringField(5)
  proxyBind = _messages.BooleanField(6)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 7)
  region = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  service = _messages.StringField(10)


class TargetTcpProxyAggregatedList(_messages.Message):
  r"""A TargetTcpProxyAggregatedList object.

  Messages:
    ItemsValue: A list of TargetTcpProxiesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetTcpProxiesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#targetTcpProxyAggregatedList for lists of Target TCP Proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetTcpProxiesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        TargetTcpProxies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetTcpProxiesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetTcpProxiesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#targetTcpProxyAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetTcpProxyList(_messages.Message):
  r"""Contains a list of TargetTcpProxy resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetTcpProxy resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetTcpProxy', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#targetTcpProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetVpnGateway(_messages.Message):
  r"""Represents a Target VPN Gateway resource. The target VPN gateway
  resource represents a Classic Cloud VPN gateway. For more information, read
  the the Cloud VPN Overview.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the VPN gateway, which
      can be one of the following: CREATING, READY, FAILED, or DELETING.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    forwardingRules: [Output Only] A list of URLs to the ForwardingRule
      resources. ForwardingRules are created using
      compute.forwardingRules.insert and associated with a VPN gateway.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#targetVpnGateway for
      target VPN gateways.
    labelFingerprint: A fingerprint for the labels being applied to this
      TargetVpnGateway, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a TargetVpnGateway.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: URL of the network to which this VPN gateway is attached.
      Provided by the client when the VPN gateway is created.
    region: [Output Only] URL of the region where the target VPN gateway
      resides. You must specify this field as part of the HTTP request URL. It
      is not settable as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    status: [Output Only] The status of the VPN gateway, which can be one of
      the following: CREATING, READY, FAILED, or DELETING.
    tunnels: [Output Only] A list of URLs to VpnTunnel resources. VpnTunnels
      are created using the compute.vpntunnels.insert method and associated
      with a VPN gateway.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the VPN gateway, which can be one of the
    following: CREATING, READY, FAILED, or DELETING.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      FAILED: <no description>
      READY: <no description>
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  forwardingRules = _messages.StringField(3, repeated=True)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#targetVpnGateway')
  labelFingerprint = _messages.BytesField(6)
  labels = _messages.MessageField('LabelsValue', 7)
  name = _messages.StringField(8)
  network = _messages.StringField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  status = _messages.EnumField('StatusValueValuesEnum', 12)
  tunnels = _messages.StringField(13, repeated=True)


class TargetVpnGatewayAggregatedList(_messages.Message):
  r"""A TargetVpnGatewayAggregatedList object.

  Messages:
    ItemsValue: A list of TargetVpnGateway resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetVpnGateway resources.
    kind: [Output Only] Type of resource. Always compute#targetVpnGateway for
      target VPN gateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetVpnGateway resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of target VPN gateways.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetVpnGatewaysScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetVpnGatewaysScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#targetVpnGatewayAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetVpnGatewayList(_messages.Message):
  r"""Contains a list of TargetVpnGateway resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetVpnGateway resources.
    kind: [Output Only] Type of resource. Always compute#targetVpnGateway for
      target VPN gateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetVpnGateway', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#targetVpnGatewayList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetVpnGatewaysScopedList(_messages.Message):
  r"""A TargetVpnGatewaysScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of addresses when the list is empty.

  Fields:
    targetVpnGateways: [Output Only] A list of target VPN gateways contained
      in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      addresses when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    addresses when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetVpnGateways = _messages.MessageField('TargetVpnGateway', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TestFailure(_messages.Message):
  r"""A TestFailure object.

  Fields:
    actualOutputUrl: The actual output URL evaluated by a load balancer
      containing the scheme, host, path and query parameters.
    actualRedirectResponseCode: Actual HTTP status code for rule with
      `urlRedirect` calculated by load balancer
    actualService: BackendService or BackendBucket returned by load balancer.
    expectedOutputUrl: The expected output URL evaluated by a load balancer
      containing the scheme, host, path and query parameters.
    expectedRedirectResponseCode: Expected HTTP status code for rule with
      `urlRedirect` calculated by load balancer
    expectedService: Expected BackendService or BackendBucket resource the
      given URL should be mapped to.
    headers: HTTP headers of the request.
    host: Host portion of the URL.
    path: Path portion including query parameters in the URL.
  """

  actualOutputUrl = _messages.StringField(1)
  actualRedirectResponseCode = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  actualService = _messages.StringField(3)
  expectedOutputUrl = _messages.StringField(4)
  expectedRedirectResponseCode = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  expectedService = _messages.StringField(6)
  headers = _messages.MessageField('UrlMapTestHeader', 7, repeated=True)
  host = _messages.StringField(8)
  path = _messages.StringField(9)


class TestPermissionsRequest(_messages.Message):
  r"""A TestPermissionsRequest object.

  Fields:
    permissions: The set of permissions to check for the 'resource'.
      Permissions with wildcards (such as '*' or 'storage.*') are not allowed.
  """

  permissions = _messages.StringField(1, repeated=True)


class TestPermissionsResponse(_messages.Message):
  r"""A TestPermissionsResponse object.

  Fields:
    permissions: A subset of `TestPermissionsRequest.permissions` that the
      caller is allowed.
  """

  permissions = _messages.StringField(1, repeated=True)


class TlsCertificateContext(_messages.Message):
  r"""[Deprecated] Defines the mechanism to obtain the client or server
  certificate. Defines the mechanism to obtain the client or server
  certificate.

  Enums:
    CertificateSourceValueValuesEnum: Defines how TLS certificates are
      obtained.

  Fields:
    certificatePaths: Specifies the certificate and private key paths. This
      field is applicable only if tlsCertificateSource is set to USE_PATH.
    certificateSource: Defines how TLS certificates are obtained.
    sdsConfig: Specifies the config to retrieve certificates through SDS. This
      field is applicable only if tlsCertificateSource is set to USE_SDS.
  """

  class CertificateSourceValueValuesEnum(_messages.Enum):
    r"""Defines how TLS certificates are obtained.

    Values:
      INVALID: <no description>
      USE_PATH: USE_PATH specifies that the certificates and private key are
        obtained from a locally mounted filesystem path.
      USE_SDS: USE_SDS specifies that the certificates and private key are
        obtained from a SDS server.
    """
    INVALID = 0
    USE_PATH = 1
    USE_SDS = 2

  certificatePaths = _messages.MessageField('TlsCertificatePaths', 1)
  certificateSource = _messages.EnumField('CertificateSourceValueValuesEnum', 2)
  sdsConfig = _messages.MessageField('SdsConfig', 3)


class TlsCertificatePaths(_messages.Message):
  r"""[Deprecated] The paths to the mounted TLS Certificates and private key.
  The paths to the mounted TLS Certificates and private key.

  Fields:
    certificatePath: The path to the file holding the client or server TLS
      certificate to use.
    privateKeyPath: The path to the file holding the client or server private
      key.
  """

  certificatePath = _messages.StringField(1)
  privateKeyPath = _messages.StringField(2)


class TlsContext(_messages.Message):
  r"""[Deprecated] The TLS settings for the client or server. The TLS settings
  for the client or server.

  Fields:
    certificateContext: Defines the mechanism to obtain the client or server
      certificate.
    validationContext: Defines the mechanism to obtain the Certificate
      Authority certificate to validate the client/server certificate. If
      omitted, the proxy will not validate the server or client certificate.
  """

  certificateContext = _messages.MessageField('TlsCertificateContext', 1)
  validationContext = _messages.MessageField('TlsValidationContext', 2)


class TlsValidationContext(_messages.Message):
  r"""[Deprecated] Defines the mechanism to obtain the Certificate Authority
  certificate to validate the client/server certificate. validate the
  client/server certificate.

  Enums:
    ValidationSourceValueValuesEnum: Defines how TLS certificates are
      obtained.

  Fields:
    certificatePath: The path to the file holding the CA certificate to
      validate the client or server certificate.
    sdsConfig: Specifies the config to retrieve certificates through SDS. This
      field is applicable only if tlsCertificateSource is set to USE_SDS.
    validationSource: Defines how TLS certificates are obtained.
  """

  class ValidationSourceValueValuesEnum(_messages.Enum):
    r"""Defines how TLS certificates are obtained.

    Values:
      INVALID: <no description>
      USE_PATH: USE_PATH specifies that the certificates and private key are
        obtained from a locally mounted filesystem path.
      USE_SDS: USE_SDS specifies that the certificates and private key are
        obtained from a SDS server.
    """
    INVALID = 0
    USE_PATH = 1
    USE_SDS = 2

  certificatePath = _messages.StringField(1)
  sdsConfig = _messages.MessageField('SdsConfig', 2)
  validationSource = _messages.EnumField('ValidationSourceValueValuesEnum', 3)


class UDPHealthCheck(_messages.Message):
  r"""A UDPHealthCheck object.

  Fields:
    port: The UDP port number to which the health check prober sends packets.
      Valid values are 1 through 65535.
    portName: Not supported.
    request: Raw data of request to send in payload of UDP packet. It is an
      error if this is empty. The request data can only be ASCII.
    response: The bytes to match against the beginning of the response data.
      It is an error if this is empty. The response data can only be ASCII.
  """

  port = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  portName = _messages.StringField(2)
  request = _messages.StringField(3)
  response = _messages.StringField(4)


class Uint128(_messages.Message):
  r"""A Uint128 object.

  Fields:
    high: A string attribute.
    low: A string attribute.
  """

  high = _messages.IntegerField(1, variant=_messages.Variant.UINT64)
  low = _messages.IntegerField(2, variant=_messages.Variant.UINT64)


class UpcomingMaintenance(_messages.Message):
  r"""Upcoming Maintenance notification information.

  Enums:
    MaintenanceStatusValueValuesEnum:
    TypeValueValuesEnum: Defines the type of maintenance.

  Fields:
    canReschedule: Indicates if the maintenance can be customer triggered.
    date: [Output Only] The date when the maintenance will take place. This
      value is in RFC3339 text format. DEPRECATED: Use window_start_time
      instead.
    latestWindowStartTime: The latest time for the planned maintenance window
      to start. This timestamp value is in RFC3339 text format.
    maintenanceOnShutdown: Indicates whether the UpcomingMaintenance will be
      triggered on VM shutdown.
    maintenanceStatus: A MaintenanceStatusValueValuesEnum attribute.
    startTimeWindow: [Output Only] The start time window of the maintenance
      disruption. DEPRECATED: Use window_start_time instead. TimeWindow is a
      container for two strings that represent timestamps in "yyyy-MM-
      dd'T'HH:mm:ssZ" text format.
    time: [Output Only] The time when the maintenance will take place. This
      value is in RFC3339 text format. DEPRECATED: Use window_start_time
      instead.
    type: Defines the type of maintenance.
    windowEndTime: The time by which the maintenance disruption will be
      completed. This timestamp value is in RFC3339 text format.
    windowStartTime: The current start time of the maintenance window. This
      timestamp value is in RFC3339 text format.
  """

  class MaintenanceStatusValueValuesEnum(_messages.Enum):
    r"""MaintenanceStatusValueValuesEnum enum type.

    Values:
      ONGOING: There is ongoing maintenance on this VM.
      PENDING: There is pending maintenance.
      UNKNOWN: Unknown maintenance status. Do not use this value.
    """
    ONGOING = 0
    PENDING = 1
    UNKNOWN = 2

  class TypeValueValuesEnum(_messages.Enum):
    r"""Defines the type of maintenance.

    Values:
      SCHEDULED: Scheduled maintenance (e.g. maintenance after uptime
        guarantee is complete).
      UNKNOWN_TYPE: No type specified. Do not use this value.
      UNSCHEDULED: Unscheduled maintenance (e.g. emergency maintenance during
        uptime guarantee).
    """
    SCHEDULED = 0
    UNKNOWN_TYPE = 1
    UNSCHEDULED = 2

  canReschedule = _messages.BooleanField(1)
  date = _messages.StringField(2)
  latestWindowStartTime = _messages.StringField(3)
  maintenanceOnShutdown = _messages.BooleanField(4)
  maintenanceStatus = _messages.EnumField('MaintenanceStatusValueValuesEnum', 5)
  startTimeWindow = _messages.MessageField('UpcomingMaintenanceTimeWindow', 6)
  time = _messages.StringField(7)
  type = _messages.EnumField('TypeValueValuesEnum', 8)
  windowEndTime = _messages.StringField(9)
  windowStartTime = _messages.StringField(10)


class UpcomingMaintenanceTimeWindow(_messages.Message):
  r"""Represents a window of time using two timestamps: `earliest` and
  `latest`.

  Fields:
    earliest: A string attribute.
    latest: A string attribute.
  """

  earliest = _messages.StringField(1)
  latest = _messages.StringField(2)


class UrlMap(_messages.Message):
  r"""Represents a URL Map resource. Compute Engine has two URL Map resources:
  * [Global](/compute/docs/reference/rest/alpha/urlMaps) *
  [Regional](/compute/docs/reference/rest/alpha/regionUrlMaps) A URL map
  resource is a component of certain types of cloud load balancers and Traffic
  Director: * urlMaps are used by global external Application Load Balancers,
  classic Application Load Balancers, and cross-region internal Application
  Load Balancers. * regionUrlMaps are used by internal Application Load
  Balancers, regional external Application Load Balancers and regional
  internal Application Load Balancers. For a list of supported URL map
  features by the load balancer type, see the Load balancing features: Routing
  and traffic management table. For a list of supported URL map features for
  Traffic Director, see the Traffic Director features: Routing and traffic
  management table. This resource defines mappings from hostnames and URL
  paths to either a backend service or a backend bucket. To use the global
  urlMaps resource, the backend service must have a loadBalancingScheme of
  either EXTERNAL, EXTERNAL_MANAGED, or INTERNAL_SELF_MANAGED. To use the
  regionUrlMaps resource, the backend service must have a loadBalancingScheme
  of INTERNAL_MANAGED. For more information, read URL Map Concepts.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    defaultCustomErrorResponsePolicy: defaultCustomErrorResponsePolicy
      specifies how the Load Balancer returns error responses when
      BackendServiceor BackendBucket responds with an error. This policy takes
      effect at the load balancer level and applies only when no policy has
      been defined for the error code at lower levels like PathMatcher,
      RouteRule and PathRule within this UrlMap. For example, consider a
      UrlMap with the following configuration: -
      defaultCustomErrorResponsePolicy containing policies for responding to
      5xx and 4xx errors - A PathMatcher configured for *.example.com has
      defaultCustomErrorResponsePolicy for 4xx. If a request for
      http://www.example.com/ encounters a 404, the policy in
      pathMatcher.defaultCustomErrorResponsePolicy will be enforced. When the
      request for http://www.example.com/ encounters a 502, the policy in
      UrlMap.defaultCustomErrorResponsePolicy will be enforced. When a request
      that does not match any host in *.example.com such as
      http://www.myotherexample.com/, encounters a 404,
      UrlMap.defaultCustomErrorResponsePolicy takes effect. When used in
      conjunction with defaultRouteAction.retryPolicy, retries take
      precedence. Only once all retries are exhausted, the
      defaultCustomErrorResponsePolicy is applied. While attempting a retry,
      if load balancer is successful in reaching the service, the
      defaultCustomErrorResponsePolicy is ignored and the response from the
      service is returned to the client. defaultCustomErrorResponsePolicy is
      supported only for global external Application Load Balancers.
    defaultRouteAction: defaultRouteAction takes effect when none of the
      hostRules match. The load balancer performs advanced routing actions,
      such as URL rewrites and header transformations, before forwarding the
      request to the selected backend. Only one of defaultUrlRedirect,
      defaultService or defaultRouteAction.weightedBackendService can be set.
      URL maps for classic Application Load Balancers only support the
      urlRewrite action within defaultRouteAction. defaultRouteAction has no
      effect when the URL map is bound to a target gRPC proxy that has the
      validateForProxyless field set to true.
    defaultService: The full or partial URL of the defaultService resource to
      which traffic is directed if none of the hostRules match. If
      defaultRouteAction is also specified, advanced routing actions, such as
      URL rewrites, take effect before sending the request to the backend.
      Only one of defaultUrlRedirect, defaultService or
      defaultRouteAction.weightedBackendService can be set. defaultService has
      no effect when the URL map is bound to a target gRPC proxy that has the
      validateForProxyless field set to true.
    defaultUrlRedirect: When none of the specified hostRules match, the
      request is redirected to a URL specified by defaultUrlRedirect. Only one
      of defaultUrlRedirect, defaultService or
      defaultRouteAction.weightedBackendService can be set. Not supported when
      the URL map is bound to a target gRPC proxy.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field is
      ignored when inserting a UrlMap. An up-to-date fingerprint must be
      provided in order to update the UrlMap, otherwise the request will fail
      with error 412 conditionNotMet. To see the latest fingerprint, make a
      get() request to retrieve a UrlMap.
    headerAction: Specifies changes to request and response headers that need
      to take effect for the selected backendService. The headerAction
      specified here take effect after headerAction specified under
      pathMatcher. headerAction is not supported for load balancers that have
      their loadBalancingScheme set to EXTERNAL. Not supported when the URL
      map is bound to a target gRPC proxy that has validateForProxyless field
      set to true.
    hostRules: The list of host rules to use against the URL.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#urlMaps for url
      maps.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    pathMatchers: The list of named PathMatchers to use against the URL.
    region: [Output Only] URL of the region where the regional URL map
      resides. This field is not applicable to global URL maps. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    tests: The list of expected URL mapping tests. Request to update the
      UrlMap succeeds only if all test cases pass. You can specify a maximum
      of 100 tests per UrlMap. Not supported when the URL map is bound to a
      target gRPC proxy that has validateForProxyless field set to true.
  """

  creationTimestamp = _messages.StringField(1)
  defaultCustomErrorResponsePolicy = _messages.MessageField('CustomErrorResponsePolicy', 2)
  defaultRouteAction = _messages.MessageField('HttpRouteAction', 3)
  defaultService = _messages.StringField(4)
  defaultUrlRedirect = _messages.MessageField('HttpRedirectAction', 5)
  description = _messages.StringField(6)
  fingerprint = _messages.BytesField(7)
  headerAction = _messages.MessageField('HttpHeaderAction', 8)
  hostRules = _messages.MessageField('HostRule', 9, repeated=True)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(11, default='compute#urlMap')
  name = _messages.StringField(12)
  pathMatchers = _messages.MessageField('PathMatcher', 13, repeated=True)
  region = _messages.StringField(14)
  selfLink = _messages.StringField(15)
  tests = _messages.MessageField('UrlMapTest', 16, repeated=True)


class UrlMapList(_messages.Message):
  r"""Contains a list of UrlMap resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of UrlMap resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('UrlMap', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#urlMapList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class UrlMapReference(_messages.Message):
  r"""A UrlMapReference object.

  Fields:
    urlMap: A string attribute.
  """

  urlMap = _messages.StringField(1)


class UrlMapTest(_messages.Message):
  r"""Message for the expected URL mappings.

  Fields:
    backendServiceWeight: The weight to use for the supplied host and path
      when using advanced routing rules that involve traffic splitting.
    description: Description of this test case.
    expectedOutputUrl: The expected output URL evaluated by the load balancer
      containing the scheme, host, path and query parameters. For rules that
      forward requests to backends, the test passes only when
      expectedOutputUrl matches the request forwarded by the load balancer to
      backends. For rules with urlRewrite, the test verifies that the
      forwarded request matches hostRewrite and pathPrefixRewrite in the
      urlRewrite action. When service is specified, expectedOutputUrl`s scheme
      is ignored. For rules with urlRedirect, the test passes only if
      expectedOutputUrl matches the URL in the load balancer's redirect
      response. If urlRedirect specifies https_redirect, the test passes only
      if the scheme in expectedOutputUrl is also set to HTTPS. If urlRedirect
      specifies strip_query, the test passes only if expectedOutputUrl does
      not contain any query parameters. expectedOutputUrl is optional when
      service is specified.
    expectedRedirectResponseCode: For rules with urlRedirect, the test passes
      only if expectedRedirectResponseCode matches the HTTP status code in
      load balancer's redirect response. expectedRedirectResponseCode cannot
      be set when service is set.
    expectedUrlRedirect: The expected URL that should be redirected to for the
      host and path being tested. [Deprecated] This field is deprecated. Use
      expected_output_url instead.
    headers: HTTP headers for this request. If headers contains a host header,
      then host must also match the header value.
    host: Host portion of the URL. If headers contains a host header, then
      host must also match the header value.
    path: Path portion of the URL.
    service: Expected BackendService or BackendBucket resource the given URL
      should be mapped to. The service field cannot be set if
      expectedRedirectResponseCode is set.
  """

  backendServiceWeight = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  description = _messages.StringField(2)
  expectedOutputUrl = _messages.StringField(3)
  expectedRedirectResponseCode = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  expectedUrlRedirect = _messages.StringField(5)
  headers = _messages.MessageField('UrlMapTestHeader', 6, repeated=True)
  host = _messages.StringField(7)
  path = _messages.StringField(8)
  service = _messages.StringField(9)


class UrlMapTestHeader(_messages.Message):
  r"""HTTP headers used in UrlMapTests.

  Fields:
    name: Header name.
    value: Header value.
  """

  name = _messages.StringField(1)
  value = _messages.StringField(2)


class UrlMapValidationResult(_messages.Message):
  r"""Message representing the validation result for a UrlMap.

  Fields:
    loadErrors: A string attribute.
    loadSucceeded: Whether the given UrlMap can be successfully loaded. If
      false, 'loadErrors' indicates the reasons.
    testFailures: A TestFailure attribute.
    testPassed: If successfully loaded, this field indicates whether the test
      passed. If false, 'testFailures's indicate the reason of failure.
  """

  loadErrors = _messages.StringField(1, repeated=True)
  loadSucceeded = _messages.BooleanField(2)
  testFailures = _messages.MessageField('TestFailure', 3, repeated=True)
  testPassed = _messages.BooleanField(4)


class UrlMapsAggregatedList(_messages.Message):
  r"""A UrlMapsAggregatedList object.

  Messages:
    ItemsValue: A list of UrlMapsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of UrlMapsScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of UrlMapsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of UrlMaps.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A UrlMapsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('UrlMapsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#urlMapsAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class UrlMapsScopedList(_messages.Message):
  r"""A UrlMapsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    urlMaps: A list of UrlMaps contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  urlMaps = _messages.MessageField('UrlMap', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class UrlMapsValidateRequest(_messages.Message):
  r"""A UrlMapsValidateRequest object.

  Enums:
    LoadBalancingSchemesValueListEntryValuesEnum:

  Fields:
    loadBalancingSchemes: Specifies the load balancer type(s) this validation
      request is for. Use EXTERNAL_MANAGED for global external Application
      Load Balancers and regional external Application Load Balancers. Use
      EXTERNAL for classic Application Load Balancers. Use INTERNAL_MANAGED
      for internal Application Load Balancers. For more information, refer to
      Choosing a load balancer. If unspecified, the load balancing scheme will
      be inferred from the backend service resources this URL map references.
      If that can not be inferred (for example, this URL map only references
      backend buckets, or this Url map is for rewrites and redirects only and
      doesn't reference any backends), EXTERNAL will be used as the default
      type. If specified, the scheme(s) must not conflict with the load
      balancing scheme of the backend service resources this Url map
      references.
    resource: Content of the UrlMap to be validated.
  """

  class LoadBalancingSchemesValueListEntryValuesEnum(_messages.Enum):
    r"""LoadBalancingSchemesValueListEntryValuesEnum enum type.

    Values:
      EXTERNAL: Signifies that this will be used for classic Application Load
        Balancers.
      EXTERNAL_MANAGED: Signifies that this will be used for Envoy-based
        global external Application Load Balancers.
      LOAD_BALANCING_SCHEME_UNSPECIFIED: If unspecified, the validation will
        try to infer the scheme from the backend service resources this Url
        map references. If the inference is not possible, EXTERNAL will be
        used as the default type.
    """
    EXTERNAL = 0
    EXTERNAL_MANAGED = 1
    LOAD_BALANCING_SCHEME_UNSPECIFIED = 2

  loadBalancingSchemes = _messages.EnumField('LoadBalancingSchemesValueListEntryValuesEnum', 1, repeated=True)
  resource = _messages.MessageField('UrlMap', 2)


class UrlMapsValidateResponse(_messages.Message):
  r"""A UrlMapsValidateResponse object.

  Fields:
    result: A UrlMapValidationResult attribute.
  """

  result = _messages.MessageField('UrlMapValidationResult', 1)


class UrlRewrite(_messages.Message):
  r"""The spec for modifying the path before sending the request to the
  matched backend service.

  Fields:
    hostRewrite: Before forwarding the request to the selected service, the
      request's host header is replaced with contents of hostRewrite. The
      value must be from 1 to 255 characters.
    pathPrefixRewrite: Before forwarding the request to the selected backend
      service, the matching portion of the request's path is replaced by
      pathPrefixRewrite. The value must be from 1 to 1024 characters.
    pathTemplateRewrite:  If specified, the pattern rewrites the URL path
      (based on the :path header) using the HTTP template syntax. A
      corresponding path_template_match must be specified. Any template
      variables must exist in the path_template_match field. - -At least one
      variable must be specified in the path_template_match field - You can
      omit variables from the rewritten URL - The * and ** operators cannot be
      matched unless they have a corresponding variable name - e.g. {format=*}
      or {var=**}. For example, a path_template_match of /static/{format=**}
      could be rewritten as /static/content/{format} to prefix /content to the
      URL. Variables can also be re-ordered in a rewrite, so that
      /{country}/{format}/{suffix=**} can be rewritten as
      /content/{format}/{country}/{suffix}. At least one non-empty
      routeRules[].matchRules[].path_template_match is required. Only one of
      path_prefix_rewrite or path_template_rewrite may be specified.
  """

  hostRewrite = _messages.StringField(1)
  pathPrefixRewrite = _messages.StringField(2)
  pathTemplateRewrite = _messages.StringField(3)


class UsableSubnetwork(_messages.Message):
  r"""Subnetwork which the current user has compute.subnetworks.use permission
  on.

  Enums:
    Ipv6AccessTypeValueValuesEnum: The access type of IPv6 address this subnet
      holds. It's immutable and can only be specified during creation or the
      first time the subnet is updated into IPV4_IPV6 dual stack.
    PurposeValueValuesEnum:
    RoleValueValuesEnum: The role of subnetwork. Currently, this field is only
      used when purpose is set to GLOBAL_MANAGED_PROXY or
      REGIONAL_MANAGED_PROXY. The value can be set to ACTIVE or BACKUP. An
      ACTIVE subnetwork is one that is currently being used for Envoy-based
      load balancers in a region. A BACKUP subnetwork is one that is ready to
      be promoted to ACTIVE or is currently draining. This field can be
      updated with a patch request.
    StackTypeValueValuesEnum: The stack type for the subnet. If set to
      IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If
      set to IPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
      IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be
      both set at resource creation time and updated using patch.

  Fields:
    externalIpv6Prefix: [Output Only] The external IPv6 address range that is
      assigned to this subnetwork.
    internalIpv6Prefix: [Output Only] The internal IPv6 address range that is
      assigned to this subnetwork.
    ipCidrRange: The range of internal addresses that are owned by this
      subnetwork.
    ipv6AccessType: The access type of IPv6 address this subnet holds. It's
      immutable and can only be specified during creation or the first time
      the subnet is updated into IPV4_IPV6 dual stack.
    network: Network URL.
    purpose: A PurposeValueValuesEnum attribute.
    role: The role of subnetwork. Currently, this field is only used when
      purpose is set to GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY. The
      value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that
      is currently being used for Envoy-based load balancers in a region. A
      BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is
      currently draining. This field can be updated with a patch request.
    secondaryIpRanges: Secondary IP ranges.
    stackType: The stack type for the subnet. If set to IPV4_ONLY, new VMs in
      the subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new
      VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not
      specified, IPV4_ONLY is used. This field can be both set at resource
      creation time and updated using patch.
    subnetwork: Subnetwork URL.
  """

  class Ipv6AccessTypeValueValuesEnum(_messages.Enum):
    r"""The access type of IPv6 address this subnet holds. It's immutable and
    can only be specified during creation or the first time the subnet is
    updated into IPV4_IPV6 dual stack.

    Values:
      EXTERNAL: VMs on this subnet will be assigned IPv6 addresses that are
        accessible via the Internet, as well as the VPC network.
      INTERNAL: VMs on this subnet will be assigned IPv6 addresses that are
        only accessible over the VPC network.
    """
    EXTERNAL = 0
    INTERNAL = 1

  class PurposeValueValuesEnum(_messages.Enum):
    r"""PurposeValueValuesEnum enum type.

    Values:
      AGGREGATE: Subnetwork used to aggregate multiple private subnetworks.
      CLOUD_EXTENSION: Subnetworks created for Cloud Extension Machines.
      CUSTOM_HARDWARE_LINK: Subnetwork used for Custom Hardware Link.
      GLOBAL_MANAGED_PROXY: Subnet reserved for Global Envoy-based Load
        Balancing.
      INTERNAL_HTTPS_LOAD_BALANCER: Subnet reserved for Internal HTTP(S) Load
        Balancing. This is a legacy purpose, please use REGIONAL_MANAGED_PROXY
        instead.
      PEER_MIGRATION: Subnetwork will be used for Migration from one peered
        VPC to another. (a transient state of subnetwork while migrating
        resources from one project to another).
      PRIVATE: Regular user created or automatically created subnet.
      PRIVATE_NAT: Subnetwork used as source range for Private NAT Gateways.
      PRIVATE_RFC_1918: Regular user created or automatically created subnet.
      PRIVATE_SERVICE_CONNECT: Subnetworks created for Private Service Connect
        in the producer network.
      REGIONAL_MANAGED_PROXY: Subnetwork used for Regional Envoy-based Load
        Balancing.
    """
    AGGREGATE = 0
    CLOUD_EXTENSION = 1
    CUSTOM_HARDWARE_LINK = 2
    GLOBAL_MANAGED_PROXY = 3
    INTERNAL_HTTPS_LOAD_BALANCER = 4
    PEER_MIGRATION = 5
    PRIVATE = 6
    PRIVATE_NAT = 7
    PRIVATE_RFC_1918 = 8
    PRIVATE_SERVICE_CONNECT = 9
    REGIONAL_MANAGED_PROXY = 10

  class RoleValueValuesEnum(_messages.Enum):
    r"""The role of subnetwork. Currently, this field is only used when
    purpose is set to GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY. The
    value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is
    currently being used for Envoy-based load balancers in a region. A BACKUP
    subnetwork is one that is ready to be promoted to ACTIVE or is currently
    draining. This field can be updated with a patch request.

    Values:
      ACTIVE: The ACTIVE subnet that is currently used.
      BACKUP: The BACKUP subnet that could be promoted to ACTIVE.
    """
    ACTIVE = 0
    BACKUP = 1

  class StackTypeValueValuesEnum(_messages.Enum):
    r"""The stack type for the subnet. If set to IPV4_ONLY, new VMs in the
    subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in
    the subnet can be assigned both IPv4 and IPv6 addresses. If not specified,
    IPV4_ONLY is used. This field can be both set at resource creation time
    and updated using patch.

    Values:
      IPV4_IPV6: New VMs in this subnet can have both IPv4 and IPv6 addresses.
      IPV4_ONLY: New VMs in this subnet will only be assigned IPv4 addresses.
      IPV6_ONLY: New VMs in this subnet will only be assigned IPv6 addresses.
    """
    IPV4_IPV6 = 0
    IPV4_ONLY = 1
    IPV6_ONLY = 2

  externalIpv6Prefix = _messages.StringField(1)
  internalIpv6Prefix = _messages.StringField(2)
  ipCidrRange = _messages.StringField(3)
  ipv6AccessType = _messages.EnumField('Ipv6AccessTypeValueValuesEnum', 4)
  network = _messages.StringField(5)
  purpose = _messages.EnumField('PurposeValueValuesEnum', 6)
  role = _messages.EnumField('RoleValueValuesEnum', 7)
  secondaryIpRanges = _messages.MessageField('UsableSubnetworkSecondaryRange', 8, repeated=True)
  stackType = _messages.EnumField('StackTypeValueValuesEnum', 9)
  subnetwork = _messages.StringField(10)


class UsableSubnetworkSecondaryRange(_messages.Message):
  r"""Secondary IP range of a usable subnetwork.

  Fields:
    ipCidrRange: The range of IP addresses belonging to this subnetwork
      secondary range.
    rangeName: The name associated with this subnetwork secondary range, used
      when adding an alias IP range to a VM instance. The name must be 1-63
      characters long, and comply with RFC1035. The name must be unique within
      the subnetwork.
  """

  ipCidrRange = _messages.StringField(1)
  rangeName = _messages.StringField(2)


class UsableSubnetworksAggregatedList(_messages.Message):
  r"""A UsableSubnetworksAggregatedList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output] A list of usable subnetwork URLs.
    kind: [Output Only] Type of resource. Always
      compute#usableSubnetworksAggregatedList for aggregated lists of usable
      subnetworks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results. In
      special cases listUsable may return 0 subnetworks and nextPageToken
      which still should be used to get the next page of results.
    scopedWarnings: [Output Only] Informational warning messages for failures
      encountered from scopes.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('UsableSubnetwork', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#usableSubnetworksAggregatedList')
  nextPageToken = _messages.StringField(4)
  scopedWarnings = _messages.MessageField('SubnetworksScopedWarning', 5, repeated=True)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class UsageExportLocation(_messages.Message):
  r"""The location in Cloud Storage and naming method of the daily usage
  report. Contains bucket_name and report_name prefix.

  Fields:
    bucketName: The name of an existing bucket in Cloud Storage where the
      usage report object is stored. The Google Service Account is granted
      write access to this bucket. This can either be the bucket name by
      itself, such as example-bucket, or the bucket name with gs:// or
      https://storage.googleapis.com/ in front of it, such as gs://example-
      bucket.
    reportNamePrefix: An optional prefix for the name of the usage report
      object stored in bucketName. If not supplied, defaults to usage_gce. The
      report is stored as a CSV file named report_name_prefix_gce_YYYYMMDD.csv
      where YYYYMMDD is the day of the usage according to Pacific Time. If you
      supply a prefix, it should conform to Cloud Storage object naming
      conventions.
  """

  bucketName = _messages.StringField(1)
  reportNamePrefix = _messages.StringField(2)


class VmEndpointNatMappings(_messages.Message):
  r"""Contain information of Nat mapping for a VM endpoint (i.e., NIC).

  Fields:
    instanceName: Name of the VM instance which the endpoint belongs to
    interfaceNatMappings: A VmEndpointNatMappingsInterfaceNatMappings
      attribute.
  """

  instanceName = _messages.StringField(1)
  interfaceNatMappings = _messages.MessageField('VmEndpointNatMappingsInterfaceNatMappings', 2, repeated=True)


class VmEndpointNatMappingsInterfaceNatMappings(_messages.Message):
  r"""Contain information of Nat mapping for an interface of this endpoint.

  Fields:
    drainNatIpPortRanges: List of all drain IP:port-range mappings assigned to
      this interface. These ranges are inclusive, that is, both the first and
      the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
      "1.1.1.1:2234-2234"].
    natIpPortRanges: A list of all IP:port-range mappings assigned to this
      interface. These ranges are inclusive, that is, both the first and the
      last ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
      "1.1.1.1:2234-2234"].
    numTotalDrainNatPorts: Total number of drain ports across all NAT IPs
      allocated to this interface. It equals to the aggregated port number in
      the field drain_nat_ip_port_ranges.
    numTotalNatPorts: Total number of ports across all NAT IPs allocated to
      this interface. It equals to the aggregated port number in the field
      nat_ip_port_ranges.
    ruleMappings: Information about mappings provided by rules in this NAT.
    sourceAliasIpRange: Alias IP range for this interface endpoint. It will be
      a private (RFC 1918) IP range. Examples: "10.33.4.55/32", or
      "192.168.5.0/24".
    sourceVirtualIp: Primary IP of the VM for this NIC.
  """

  drainNatIpPortRanges = _messages.StringField(1, repeated=True)
  natIpPortRanges = _messages.StringField(2, repeated=True)
  numTotalDrainNatPorts = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  numTotalNatPorts = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  ruleMappings = _messages.MessageField('VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings', 5, repeated=True)
  sourceAliasIpRange = _messages.StringField(6)
  sourceVirtualIp = _messages.StringField(7)


class VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings(_messages.Message):
  r"""Contains information of NAT Mappings provided by a NAT Rule.

  Fields:
    drainNatIpPortRanges: List of all drain IP:port-range mappings assigned to
      this interface by this rule. These ranges are inclusive, that is, both
      the first and the last ports can be used for NAT. Example:
      ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].
    natIpPortRanges: A list of all IP:port-range mappings assigned to this
      interface by this rule. These ranges are inclusive, that is, both the
      first and the last ports can be used for NAT. Example:
      ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].
    numTotalDrainNatPorts: Total number of drain ports across all NAT IPs
      allocated to this interface by this rule. It equals the aggregated port
      number in the field drain_nat_ip_port_ranges.
    numTotalNatPorts: Total number of ports across all NAT IPs allocated to
      this interface by this rule. It equals the aggregated port number in the
      field nat_ip_port_ranges.
    ruleNumber: Rule number of the NAT Rule.
  """

  drainNatIpPortRanges = _messages.StringField(1, repeated=True)
  natIpPortRanges = _messages.StringField(2, repeated=True)
  numTotalDrainNatPorts = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  numTotalNatPorts = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  ruleNumber = _messages.IntegerField(5, variant=_messages.Variant.INT32)


class VmEndpointNatMappingsList(_messages.Message):
  r"""Contains a list of VmEndpointNatMappings.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always
      compute#vmEndpointNatMappingsList for lists of Nat mappings of VM
      endpoints.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    result: [Output Only] A list of Nat mapping information of VM endpoints.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  kind = _messages.StringField(2, default='compute#vmEndpointNatMappingsList')
  nextPageToken = _messages.StringField(3)
  result = _messages.MessageField('VmEndpointNatMappings', 4, repeated=True)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class VpnGateway(_messages.Message):
  r"""Represents a HA VPN gateway. HA VPN is a high-availability (HA) Cloud
  VPN solution that lets you securely connect your on-premises network to your
  Google Cloud Virtual Private Cloud network through an IPsec VPN connection
  in a single region. For more information about Cloud HA VPN solutions, see
  Cloud VPN topologies .

  Enums:
    GatewayIpVersionValueValuesEnum: The IP family of the gateway IPs for the
      HA-VPN gateway interfaces. If not specified, IPV4 will be used.
    StackTypeValueValuesEnum: The stack type for this VPN gateway to identify
      the IP protocols that are enabled. Possible values are: IPV4_ONLY,
      IPV4_IPV6, IPV6_ONLY. If not specified, IPV4_ONLY is used if the gateway
      IP version is IPV4, or IPV4_IPV6 if the gateway IP version is IPV6.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    gatewayIpVersion: The IP family of the gateway IPs for the HA-VPN gateway
      interfaces. If not specified, IPV4 will be used.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#vpnGateway for VPN
      gateways.
    labelFingerprint: A fingerprint for the labels being applied to this
      VpnGateway, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a VpnGateway.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: URL of the network to which this VPN gateway is attached.
      Provided by the client when the VPN gateway is created.
    region: [Output Only] URL of the region where the VPN gateway resides.
    selfLink: [Output Only] Server-defined URL for the resource.
    stackType: The stack type for this VPN gateway to identify the IP
      protocols that are enabled. Possible values are: IPV4_ONLY, IPV4_IPV6,
      IPV6_ONLY. If not specified, IPV4_ONLY is used if the gateway IP version
      is IPV4, or IPV4_IPV6 if the gateway IP version is IPV6.
    vpnInterfaces: The list of VPN interfaces associated with this VPN
      gateway.
  """

  class GatewayIpVersionValueValuesEnum(_messages.Enum):
    r"""The IP family of the gateway IPs for the HA-VPN gateway interfaces. If
    not specified, IPV4 will be used.

    Values:
      IPV4: Every HA-VPN gateway interface is configured with an IPv4 address.
      IPV6: Every HA-VPN gateway interface is configured with an IPv6 address.
    """
    IPV4 = 0
    IPV6 = 1

  class StackTypeValueValuesEnum(_messages.Enum):
    r"""The stack type for this VPN gateway to identify the IP protocols that
    are enabled. Possible values are: IPV4_ONLY, IPV4_IPV6, IPV6_ONLY. If not
    specified, IPV4_ONLY is used if the gateway IP version is IPV4, or
    IPV4_IPV6 if the gateway IP version is IPV6.

    Values:
      IPV4_IPV6: Enable VPN gateway with both IPv4 and IPv6 protocols.
      IPV4_ONLY: Enable VPN gateway with only IPv4 protocol.
      IPV6_ONLY: Enable VPN gateway with only IPv6 protocol.
    """
    IPV4_IPV6 = 0
    IPV4_ONLY = 1
    IPV6_ONLY = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  gatewayIpVersion = _messages.EnumField('GatewayIpVersionValueValuesEnum', 3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default='compute#vpnGateway')
  labelFingerprint = _messages.BytesField(6)
  labels = _messages.MessageField('LabelsValue', 7)
  name = _messages.StringField(8)
  network = _messages.StringField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  stackType = _messages.EnumField('StackTypeValueValuesEnum', 12)
  vpnInterfaces = _messages.MessageField('VpnGatewayVpnGatewayInterface', 13, repeated=True)


class VpnGatewayAggregatedList(_messages.Message):
  r"""A VpnGatewayAggregatedList object.

  Messages:
    ItemsValue: A list of VpnGateway resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of VpnGateway resources.
    kind: [Output Only] Type of resource. Always compute#vpnGateway for VPN
      gateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of VpnGateway resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of VPN gateways.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A VpnGatewaysScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('VpnGatewaysScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#vpnGatewayAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class VpnGatewayList(_messages.Message):
  r"""Contains a list of VpnGateway resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of VpnGateway resources.
    kind: [Output Only] Type of resource. Always compute#vpnGateway for VPN
      gateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('VpnGateway', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#vpnGatewayList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class VpnGatewayStatus(_messages.Message):
  r"""A VpnGatewayStatus object.

  Fields:
    vpnConnections: List of VPN connection for this VpnGateway.
  """

  vpnConnections = _messages.MessageField('VpnGatewayStatusVpnConnection', 1, repeated=True)


class VpnGatewayStatusHighAvailabilityRequirementState(_messages.Message):
  r"""Describes the high availability requirement state for the VPN connection
  between this Cloud VPN gateway and a peer gateway.

  Enums:
    StateValueValuesEnum: Indicates the high availability requirement state
      for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,
      CONNECTION_REDUNDANCY_NOT_MET.
    UnsatisfiedReasonValueValuesEnum: Indicates the reason why the VPN
      connection does not meet the high availability redundancy
      criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE.

  Fields:
    state: Indicates the high availability requirement state for the VPN
      connection. Valid values are CONNECTION_REDUNDANCY_MET,
      CONNECTION_REDUNDANCY_NOT_MET.
    unsatisfiedReason: Indicates the reason why the VPN connection does not
      meet the high availability redundancy criteria/requirement. Valid values
      is INCOMPLETE_TUNNELS_COVERAGE.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""Indicates the high availability requirement state for the VPN
    connection. Valid values are CONNECTION_REDUNDANCY_MET,
    CONNECTION_REDUNDANCY_NOT_MET.

    Values:
      CONNECTION_REDUNDANCY_MET: VPN tunnels are configured with adequate
        redundancy from Cloud VPN gateway to the peer VPN gateway. For both
        GCP-to-non-GCP and GCP-to-GCP connections, the adequate redundancy is
        a pre-requirement for users to get 99.99% availability on GCP side;
        please note that for any connection, end-to-end 99.99% availability is
        subject to proper configuration on the peer VPN gateway.
      CONNECTION_REDUNDANCY_NOT_MET: VPN tunnels are not configured with
        adequate redundancy from the Cloud VPN gateway to the peer gateway
    """
    CONNECTION_REDUNDANCY_MET = 0
    CONNECTION_REDUNDANCY_NOT_MET = 1

  class UnsatisfiedReasonValueValuesEnum(_messages.Enum):
    r"""Indicates the reason why the VPN connection does not meet the high
    availability redundancy criteria/requirement. Valid values is
    INCOMPLETE_TUNNELS_COVERAGE.

    Values:
      INCOMPLETE_TUNNELS_COVERAGE: <no description>
    """
    INCOMPLETE_TUNNELS_COVERAGE = 0

  state = _messages.EnumField('StateValueValuesEnum', 1)
  unsatisfiedReason = _messages.EnumField('UnsatisfiedReasonValueValuesEnum', 2)


class VpnGatewayStatusTunnel(_messages.Message):
  r"""Contains some information about a VPN tunnel.

  Fields:
    localGatewayInterface: The VPN gateway interface this VPN tunnel is
      associated with.
    peerGatewayInterface: The peer gateway interface this VPN tunnel is
      connected to, the peer gateway could either be an external VPN gateway
      or a Google Cloud VPN gateway.
    tunnelUrl: URL reference to the VPN tunnel.
  """

  localGatewayInterface = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  peerGatewayInterface = _messages.IntegerField(2, variant=_messages.Variant.UINT32)
  tunnelUrl = _messages.StringField(3)


class VpnGatewayStatusVpnConnection(_messages.Message):
  r"""A VPN connection contains all VPN tunnels connected from this VpnGateway
  to the same peer gateway. The peer gateway could either be an external VPN
  gateway or a Google Cloud VPN gateway.

  Fields:
    peerExternalGateway: URL reference to the peer external VPN gateways to
      which the VPN tunnels in this VPN connection are connected. This field
      is mutually exclusive with peer_gcp_gateway.
    peerGcpGateway: URL reference to the peer side VPN gateways to which the
      VPN tunnels in this VPN connection are connected. This field is mutually
      exclusive with peer_gcp_gateway.
    state: HighAvailabilityRequirementState for the VPN connection.
    tunnels: List of VPN tunnels that are in this VPN connection.
  """

  peerExternalGateway = _messages.StringField(1)
  peerGcpGateway = _messages.StringField(2)
  state = _messages.MessageField('VpnGatewayStatusHighAvailabilityRequirementState', 3)
  tunnels = _messages.MessageField('VpnGatewayStatusTunnel', 4, repeated=True)


class VpnGatewayVpnGatewayInterface(_messages.Message):
  r"""A VPN gateway interface.

  Fields:
    id: [Output Only] Numeric identifier for this VPN interface associated
      with the VPN gateway.
    interconnectAttachment: URL of the VLAN attachment
      (interconnectAttachment) resource for this VPN gateway interface. When
      the value of this field is present, the VPN gateway is used for HA VPN
      over Cloud Interconnect; all egress or ingress traffic for this VPN
      gateway interface goes through the specified VLAN attachment resource.
    ipAddress: [Output Only] IP address for this VPN interface associated with
      the VPN gateway. The IP address could be either a regional external IP
      address or a regional internal IP address. The two IP addresses for a
      VPN gateway must be all regional external or regional internal IP
      addresses. There cannot be a mix of regional external IP addresses and
      regional internal IP addresses. For HA VPN over Cloud Interconnect, the
      IP addresses for both interfaces could either be regional internal IP
      addresses or regional external IP addresses. For regular (non HA VPN
      over Cloud Interconnect) HA VPN tunnels, the IP address must be a
      regional external IP address.
    ipv6Address: [Output Only] IPv6 address for this VPN interface associated
      with the VPN gateway. The IPv6 address must be a regional external IPv6
      address. The format is RFC 5952 format (e.g. 2001:db8::2d9:51:0:0).
  """

  id = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  interconnectAttachment = _messages.StringField(2)
  ipAddress = _messages.StringField(3)
  ipv6Address = _messages.StringField(4)


class VpnGatewaysGetStatusResponse(_messages.Message):
  r"""A VpnGatewaysGetStatusResponse object.

  Fields:
    result: A VpnGatewayStatus attribute.
  """

  result = _messages.MessageField('VpnGatewayStatus', 1)


class VpnGatewaysScopedList(_messages.Message):
  r"""A VpnGatewaysScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of addresses when the list is empty.

  Fields:
    vpnGateways: [Output Only] A list of VPN gateways contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      addresses when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    addresses when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  vpnGateways = _messages.MessageField('VpnGateway', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class VpnTunnel(_messages.Message):
  r"""Represents a Cloud VPN Tunnel resource. For more information about VPN,
  read the the Cloud VPN Overview.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the VPN tunnel, which
      can be one of the following: - PROVISIONING: Resource is being allocated
      for the VPN tunnel. - WAITING_FOR_FULL_CONFIG: Waiting to receive all
      VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel,
      ForwardingRule, and Route resources are needed to setup the VPN tunnel.
      - FIRST_HANDSHAKE: Successful first handshake with the peer VPN. -
      ESTABLISHED: Secure session is successfully established with the peer
      VPN. - NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS -
      AUTHORIZATION_ERROR: Auth error (for example, bad shared secret). -
      NEGOTIATION_FAILURE: Handshake failed. - DEPROVISIONING: Resources are
      being deallocated for the VPN tunnel. - FAILED: Tunnel creation has
      failed and the tunnel is not ready to be used. - NO_INCOMING_PACKETS: No
      incoming packets from peer. - REJECTED: Tunnel configuration was
      rejected, can be result of being denied access. - ALLOCATING_RESOURCES:
      Cloud VPN is in the process of allocating all required resources. -
      STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for
      Classic VPN tunnels or the project is in frozen state. -
      PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably
      behind NAT. - TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not
      allowed for an HA-VPN tunnel.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    cipherSuite: User specified list of ciphers to use for the phase 1 and
      phase 2 of the IKE protocol.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    detailedStatus: [Output Only] Detailed status message for the VPN tunnel.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ikeVersion: IKE protocol version to use when establishing the VPN tunnel
      with the peer VPN gateway. Acceptable IKE versions are 1 or 2. The
      default version is 2.
    kind: [Output Only] Type of resource. Always compute#vpnTunnel for VPN
      tunnels.
    labelFingerprint: A fingerprint for the labels being applied to this
      VpnTunnel, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve a VpnTunnel.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    localTrafficSelector: Local traffic selector to use when establishing the
      VPN tunnel with the peer VPN gateway. The value should be a CIDR
      formatted string, for example: 192.168.0.0/16. The ranges must be
      disjoint. Only IPv4 is supported for Classic VPN tunnels. This field is
      output only for HA VPN tunnels.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    peerExternalGateway: URL of the peer side external VPN gateway to which
      this VPN tunnel is connected. Provided by the client when the VPN tunnel
      is created. This field is exclusive with the field peerGcpGateway.
    peerExternalGatewayInterface: The interface ID of the external VPN gateway
      to which this VPN tunnel is connected. Provided by the client when the
      VPN tunnel is created. Possible values are: `0`, `1`, `2`, `3`. The
      number of IDs in use depends on the external VPN gateway redundancy
      type.
    peerGcpGateway: URL of the peer side HA VPN gateway to which this VPN
      tunnel is connected. Provided by the client when the VPN tunnel is
      created. This field can be used when creating highly available VPN from
      VPC network to VPC network, the field is exclusive with the field
      peerExternalGateway. If provided, the VPN tunnel will automatically use
      the same vpnGatewayInterface ID in the peer Google Cloud VPN gateway.
    peerIp: IP address of the peer VPN gateway. Only IPv4 is supported. This
      field can be set only for Classic VPN tunnels.
    region: [Output Only] URL of the region where the VPN tunnel resides. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    remoteTrafficSelector: Remote traffic selectors to use when establishing
      the VPN tunnel with the peer VPN gateway. The value should be a CIDR
      formatted string, for example: 192.168.0.0/16. The ranges should be
      disjoint. Only IPv4 is supported for Classic VPN tunnels. This field is
      output only for HA VPN tunnels.
    router: URL of the router resource to be used for dynamic routing.
    selfLink: [Output Only] Server-defined URL for the resource.
    sharedSecret: Shared secret used to set the secure session between the
      Cloud VPN gateway and the peer VPN gateway.
    sharedSecretHash: Hash of the shared secret.
    status: [Output Only] The status of the VPN tunnel, which can be one of
      the following: - PROVISIONING: Resource is being allocated for the VPN
      tunnel. - WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related
      configs from the user. Network, TargetVpnGateway, VpnTunnel,
      ForwardingRule, and Route resources are needed to setup the VPN tunnel.
      - FIRST_HANDSHAKE: Successful first handshake with the peer VPN. -
      ESTABLISHED: Secure session is successfully established with the peer
      VPN. - NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS -
      AUTHORIZATION_ERROR: Auth error (for example, bad shared secret). -
      NEGOTIATION_FAILURE: Handshake failed. - DEPROVISIONING: Resources are
      being deallocated for the VPN tunnel. - FAILED: Tunnel creation has
      failed and the tunnel is not ready to be used. - NO_INCOMING_PACKETS: No
      incoming packets from peer. - REJECTED: Tunnel configuration was
      rejected, can be result of being denied access. - ALLOCATING_RESOURCES:
      Cloud VPN is in the process of allocating all required resources. -
      STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for
      Classic VPN tunnels or the project is in frozen state. -
      PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably
      behind NAT. - TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not
      allowed for an HA-VPN tunnel.
    targetVpnGateway: URL of the Target VPN gateway with which this VPN tunnel
      is associated. Provided by the client when the VPN tunnel is created.
      This field can be set only for Classic VPN tunnels.
    vpnGateway: URL of the VPN gateway with which this VPN tunnel is
      associated. Provided by the client when the VPN tunnel is created. This
      must be used (instead of target_vpn_gateway) if a High Availability VPN
      gateway resource is created.
    vpnGatewayInterface: The interface ID of the VPN gateway with which this
      VPN tunnel is associated. Possible values are: `0`, `1`.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the VPN tunnel, which can be one of the
    following: - PROVISIONING: Resource is being allocated for the VPN tunnel.
    - WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from
    the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route
    resources are needed to setup the VPN tunnel. - FIRST_HANDSHAKE:
    Successful first handshake with the peer VPN. - ESTABLISHED: Secure
    session is successfully established with the peer VPN. - NETWORK_ERROR:
    Deprecated, replaced by NO_INCOMING_PACKETS - AUTHORIZATION_ERROR: Auth
    error (for example, bad shared secret). - NEGOTIATION_FAILURE: Handshake
    failed. - DEPROVISIONING: Resources are being deallocated for the VPN
    tunnel. - FAILED: Tunnel creation has failed and the tunnel is not ready
    to be used. - NO_INCOMING_PACKETS: No incoming packets from peer. -
    REJECTED: Tunnel configuration was rejected, can be result of being denied
    access. - ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating
    all required resources. - STOPPED: Tunnel is stopped due to its Forwarding
    Rules being deleted for Classic VPN tunnels or the project is in frozen
    state. - PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP,
    probably behind NAT. - TS_NARROWING_NOT_ALLOWED: Traffic selector
    narrowing not allowed for an HA-VPN tunnel.

    Values:
      ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all
        required resources (specifically, a borg task).
      AUTHORIZATION_ERROR: Auth error (e.g. bad shared secret).
      DEPROVISIONING: Resources is being deallocated for the VPN tunnel.
      ESTABLISHED: Secure session is successfully established with peer VPN.
      FAILED: Tunnel creation has failed and the tunnel is not ready to be
        used.
      FIRST_HANDSHAKE: Successful first handshake with peer VPN.
      NEGOTIATION_FAILURE: Handshake failed.
      NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS
      NO_INCOMING_PACKETS: No incoming packets from peer
      PROVISIONING: Resource is being allocated for the VPN tunnel.
      REJECTED: Tunnel configuration was rejected, can be result of being
        denylisted.
      STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted.
      WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from
        user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule and Route
        resources are needed to setup VPN tunnel.
    """
    ALLOCATING_RESOURCES = 0
    AUTHORIZATION_ERROR = 1
    DEPROVISIONING = 2
    ESTABLISHED = 3
    FAILED = 4
    FIRST_HANDSHAKE = 5
    NEGOTIATION_FAILURE = 6
    NETWORK_ERROR = 7
    NO_INCOMING_PACKETS = 8
    PROVISIONING = 9
    REJECTED = 10
    STOPPED = 11
    WAITING_FOR_FULL_CONFIG = 12

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  cipherSuite = _messages.MessageField('VpnTunnelCipherSuite', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  detailedStatus = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  ikeVersion = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  kind = _messages.StringField(7, default='compute#vpnTunnel')
  labelFingerprint = _messages.BytesField(8)
  labels = _messages.MessageField('LabelsValue', 9)
  localTrafficSelector = _messages.StringField(10, repeated=True)
  name = _messages.StringField(11)
  peerExternalGateway = _messages.StringField(12)
  peerExternalGatewayInterface = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  peerGcpGateway = _messages.StringField(14)
  peerIp = _messages.StringField(15)
  region = _messages.StringField(16)
  remoteTrafficSelector = _messages.StringField(17, repeated=True)
  router = _messages.StringField(18)
  selfLink = _messages.StringField(19)
  sharedSecret = _messages.StringField(20)
  sharedSecretHash = _messages.StringField(21)
  status = _messages.EnumField('StatusValueValuesEnum', 22)
  targetVpnGateway = _messages.StringField(23)
  vpnGateway = _messages.StringField(24)
  vpnGatewayInterface = _messages.IntegerField(25, variant=_messages.Variant.INT32)


class VpnTunnelAggregatedList(_messages.Message):
  r"""A VpnTunnelAggregatedList object.

  Messages:
    ItemsValue: A list of VpnTunnelsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of VpnTunnelsScopedList resources.
    kind: [Output Only] Type of resource. Always compute#vpnTunnel for VPN
      tunnels.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of VpnTunnelsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of VPN
        tunnels.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A VpnTunnelsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('VpnTunnelsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default='compute#vpnTunnelAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class VpnTunnelCipherSuite(_messages.Message):
  r"""A VpnTunnelCipherSuite object.

  Fields:
    phase1: A VpnTunnelPhase1Algorithms attribute.
    phase2: A VpnTunnelPhase2Algorithms attribute.
  """

  phase1 = _messages.MessageField('VpnTunnelPhase1Algorithms', 1)
  phase2 = _messages.MessageField('VpnTunnelPhase2Algorithms', 2)


class VpnTunnelList(_messages.Message):
  r"""Contains a list of VpnTunnel resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of VpnTunnel resources.
    kind: [Output Only] Type of resource. Always compute#vpnTunnel for VPN
      tunnels.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('VpnTunnel', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#vpnTunnelList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class VpnTunnelPhase1Algorithms(_messages.Message):
  r"""A VpnTunnelPhase1Algorithms object.

  Fields:
    dh: A string attribute.
    encryption: A string attribute.
    integrity: A string attribute.
    prf: A string attribute.
  """

  dh = _messages.StringField(1, repeated=True)
  encryption = _messages.StringField(2, repeated=True)
  integrity = _messages.StringField(3, repeated=True)
  prf = _messages.StringField(4, repeated=True)


class VpnTunnelPhase2Algorithms(_messages.Message):
  r"""A VpnTunnelPhase2Algorithms object.

  Fields:
    encryption: A string attribute.
    integrity: A string attribute.
    pfs: A string attribute.
  """

  encryption = _messages.StringField(1, repeated=True)
  integrity = _messages.StringField(2, repeated=True)
  pfs = _messages.StringField(3, repeated=True)


class VpnTunnelsScopedList(_messages.Message):
  r"""A VpnTunnelsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of addresses
      when the list is empty.

  Fields:
    vpnTunnels: A list of VPN tunnels contained in this scope.
    warning: Informational warning which replaces the list of addresses when
      the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of addresses when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  vpnTunnels = _messages.MessageField('VpnTunnel', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class WafExpressionSet(_messages.Message):
  r"""A WafExpressionSet object.

  Fields:
    aliases: A list of alternate IDs. The format should be: - E.g. XSS-stable
      Generic suffix like "stable" is particularly useful if a policy likes to
      avail newer set of expressions without having to change the policy. A
      given alias name can't be used for more than one entity set.
    expressions: List of available expressions.
    id: Google specified expression set ID. The format should be: - E.g.
      XSS-20170329 required
  """

  aliases = _messages.StringField(1, repeated=True)
  expressions = _messages.MessageField('WafExpressionSetExpression', 2, repeated=True)
  id = _messages.StringField(3)


class WafExpressionSetExpression(_messages.Message):
  r"""A WafExpressionSetExpression object.

  Fields:
    id: Expression ID should uniquely identify the origin of the expression.
      E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version
      2.9.1 rule id 973337. The ID could be used to determine the individual
      attack definition that has been detected. It could also be used to
      exclude it from the policy in case of false positive. required
    sensitivity: The sensitivity value associated with the WAF rule ID. This
      corresponds to the ModSecurity paranoia level, ranging from 1 to 4. 0 is
      reserved for opt-in only rules.
  """

  id = _messages.StringField(1)
  sensitivity = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class WaitForReplicationCatchUpRequest(_messages.Message):
  r"""A WaitForReplicationCatchUpRequest object.

  Fields:
    maxWaitDuration: A string attribute.
  """

  maxWaitDuration = _messages.StringField(1)


class WeightedBackendService(_messages.Message):
  r"""In contrast to a single BackendService in HttpRouteAction to which all
  matching traffic is directed to, WeightedBackendService allows traffic to be
  split across multiple backend services. The volume of traffic for each
  backend service is proportional to the weight specified in each
  WeightedBackendService

  Fields:
    backendService: The full or partial URL to the default BackendService
      resource. Before forwarding the request to backendService, the load
      balancer applies any relevant headerActions specified as part of this
      backendServiceWeight.
    headerAction: Specifies changes to request and response headers that need
      to take effect for the selected backendService. headerAction specified
      here take effect before headerAction in the enclosing HttpRouteRule,
      PathMatcher and UrlMap. headerAction is not supported for load balancers
      that have their loadBalancingScheme set to EXTERNAL. Not supported when
      the URL map is bound to a target gRPC proxy that has
      validateForProxyless field set to true.
    weight: Specifies the fraction of traffic sent to a backend service,
      computed as weight / (sum of all weightedBackendService weights in
      routeAction) . The selection of a backend service is determined only for
      new traffic. Once a user's request has been directed to a backend
      service, subsequent requests are sent to the same backend service as
      determined by the backend service's session affinity policy. Don't
      configure session affinity if you're using weighted traffic splitting.
      If you do, the weighted traffic splitting configuration takes
      precedence. The value must be from 0 to 1000.
  """

  backendService = _messages.StringField(1)
  headerAction = _messages.MessageField('HttpHeaderAction', 2)
  weight = _messages.IntegerField(3, variant=_messages.Variant.UINT32)


class Wire(_messages.Message):
  r"""A pseudowire that connects two Interconnect connections.

  Fields:
    adminEnabled: [Output Only] Indicates whether the wire is enabled. When
      false, the wire is disabled. When true and when the wire group of the
      wire is also enabled, the wire is enabled. Defaults to true.
    endpoints: Wire endpoints are specific Interconnect connections.
    label: [Output Only] A label that identifies the wire. The format of this
      label combines the existing labels of the wire group endpoints and
      Interconnect connections used by this wire in alphabetical order as
      follows: `ENDPOINT_A+CONNECTION_A1,ENDPOINT_B+CONNECTION_B1`, where: -
      ENDPOINT_A and ENDPOINT_B: are the labels that you entered as map keys
      when you specified the wire group endpoint objects. - CONNECTION_A1 and
      CONNECTION_B1: are the labels that you entered as map keys when you
      specified the wire group Interconnect objects.
    wireProperties: [Output Only] Properties of the wire.
  """

  adminEnabled = _messages.BooleanField(1)
  endpoints = _messages.MessageField('WireEndpoint', 2, repeated=True)
  label = _messages.StringField(3)
  wireProperties = _messages.MessageField('WireProperties', 4)


class WireEndpoint(_messages.Message):
  r"""Wire endpoints are specific Interconnect connections.

  Fields:
    interconnect: A string attribute.
    vlanTag: A integer attribute.
  """

  interconnect = _messages.StringField(1)
  vlanTag = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class WireGroup(_messages.Message):
  r"""A resource that represents a group of redundant wires.

  Messages:
    EndpointsValue: A map that contains the logical endpoints of the wire
      group. Specify key-value pairs for the map as follows: - Key: an RFC1035
      user-specified label. - Value: an Endpoint object.
    WireInputsValue: A map that contains optional settings for individual
      wires. Specify key-value pairs for the map as follows: - Key: the label
      of an existing wire. To view a wire label and its format, see the
      wires[].label field. - Value: a WireInputs object.

  Fields:
    adminEnabled: Indicates whether the wires in the wire group are enabled.
      When false, the wires in the wire group are disabled. When true and when
      there is simultaneously no wire-specific override of `adminEnabled` to
      false, a given wire is enabled. Defaults to true.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of the wire group.
    endpoints: A map that contains the logical endpoints of the wire group.
      Specify key-value pairs for the map as follows: - Key: an RFC1035 user-
      specified label. - Value: an Endpoint object.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always compute#wireGroups for
      wire groups.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: A string attribute.
    serviceLevel: Service level details determined for the wire group
      configuration.
    topology: Topology details for the wire group configuration.
    wireGroupProperties: Properties of the wire group.
    wireInputs: A map that contains optional settings for individual wires.
      Specify key-value pairs for the map as follows: - Key: the label of an
      existing wire. To view a wire label and its format, see the
      wires[].label field. - Value: a WireInputs object.
    wireProperties: Properties for all wires in the wire group.
    wires: The single/redundant wire(s) managed by the wire group.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class EndpointsValue(_messages.Message):
    r"""A map that contains the logical endpoints of the wire group. Specify
    key-value pairs for the map as follows: - Key: an RFC1035 user-specified
    label. - Value: an Endpoint object.

    Messages:
      AdditionalProperty: An additional property for a EndpointsValue object.

    Fields:
      additionalProperties: Additional properties of type EndpointsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a EndpointsValue object.

      Fields:
        key: Name of the additional property.
        value: A WireGroupEndpoint attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('WireGroupEndpoint', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class WireInputsValue(_messages.Message):
    r"""A map that contains optional settings for individual wires. Specify
    key-value pairs for the map as follows: - Key: the label of an existing
    wire. To view a wire label and its format, see the wires[].label field. -
    Value: a WireInputs object.

    Messages:
      AdditionalProperty: An additional property for a WireInputsValue object.

    Fields:
      additionalProperties: Additional properties of type WireInputsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a WireInputsValue object.

      Fields:
        key: Name of the additional property.
        value: A WireGroupWireInputs attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('WireGroupWireInputs', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  adminEnabled = _messages.BooleanField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  endpoints = _messages.MessageField('EndpointsValue', 4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default='compute#wireGroup')
  name = _messages.StringField(7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  serviceLevel = _messages.MessageField('WireGroupServiceLevel', 10)
  topology = _messages.MessageField('WireGroupTopology', 11)
  wireGroupProperties = _messages.MessageField('WireGroupProperties', 12)
  wireInputs = _messages.MessageField('WireInputsValue', 13)
  wireProperties = _messages.MessageField('WireProperties', 14)
  wires = _messages.MessageField('Wire', 15, repeated=True)


class WireGroupEndpoint(_messages.Message):
  r"""A logical endpoint for the wire group. An endpoint represents a metro
  that contains redundant Interconnect connections. A wire group is created
  between two endpoints.

  Messages:
    InterconnectsValue: A map that contains the redundant Interconnect
      connections. Specify key-value pairs for the map as follows: - Key: an
      RFC1035 user-specified label. - Value: an Interconnect object.

  Fields:
    interconnects: A map that contains the redundant Interconnect connections.
      Specify key-value pairs for the map as follows: - Key: an RFC1035 user-
      specified label. - Value: an Interconnect object.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class InterconnectsValue(_messages.Message):
    r"""A map that contains the redundant Interconnect connections. Specify
    key-value pairs for the map as follows: - Key: an RFC1035 user-specified
    label. - Value: an Interconnect object.

    Messages:
      AdditionalProperty: An additional property for a InterconnectsValue
        object.

    Fields:
      additionalProperties: Additional properties of type InterconnectsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a InterconnectsValue object.

      Fields:
        key: Name of the additional property.
        value: A WireGroupEndpointInterconnect attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('WireGroupEndpointInterconnect', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  interconnects = _messages.MessageField('InterconnectsValue', 1)


class WireGroupEndpointInterconnect(_messages.Message):
  r"""The redundant Interconnect connections for this endpoint.

  Fields:
    interconnect: An Interconnect connection. You can specify the connection
      as a partial or full URL. If the connection is in a different project
      from the cross-site network, use a format that specifies the project.
      See the following examples of partial and full URLs:
      global/interconnects/NAME projects/PROJECT_ID/global/interconnects/NAME
      - https://compute.googleapis.com/compute/projects/PROJECT_ID
      /global/interconnects/NAME
    vlanTags: To configure the wire group for VLAN mode, enter a VLAN tag,
      which is a number from `2` to `4093`. You can autoallocate a tag by
      entering `0`. To configure the wire group for port mode, enter `-1`.
      Review the following guidelines: - A VLAN tag must be unique for an
      Interconnect connection across all attachments and wire groups. - Both
      endpoints of a wire must use the same VLAN tag value. - Single wire and
      redundant type wire groups must have only one VLAN tag. - Port mode
      pseudowires must have a single VLAN tag with a value of `-1` for both
      endpoints. - Box and cross type wire groups must have two VLAN tags. The
      first is for the same-zone pseudowire, and the second is for the cross-
      zone pseudowire.
  """

  interconnect = _messages.StringField(1)
  vlanTags = _messages.IntegerField(2, repeated=True, variant=_messages.Variant.INT32)


class WireGroupList(_messages.Message):
  r"""Response for the list request.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of wire group resources.
    kind: [Output Only] Type of the resource. Always compute#wireGroups for
      wire groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources. end_interface:
      MixerListResponseWithEtagBuilder
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('WireGroup', 3, repeated=True)
  kind = _messages.StringField(4, default='compute#wireGroup')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class WireGroupProperties(_messages.Message):
  r"""The properties of a wire group. These properties determine how a group
  of redundant wires are created and managed.

  Enums:
    TypeValueValuesEnum: The type of the wire group, one of the following: -
      WIRE: a single pseudowire over two Interconnect connections with no
      redundancy. - REDUNDANT: two pseudowires over four Interconnect
      connections, with two connections in one metro and two connections in
      another metro. Each redundant pair of Interconnect connections spans
      both edge availability domains of the metro. Each pseudowire connects
      Interconnect connections in matching edge availability domains of the
      two metros. - BOX_AND_CROSS: four pseudowires over four Interconnect
      connections, with two connections in one metro and two connections in
      another metro. Each redundant pair of Interconnect connections spans
      both edge availability domains of the metro. Two pseudowires connect
      Interconnect connections in matching edge availability domains of the
      two metros. Two additional pseudowires connect the non-matching edge
      availability domains of the two metros.

  Fields:
    type: The type of the wire group, one of the following: - WIRE: a single
      pseudowire over two Interconnect connections with no redundancy. -
      REDUNDANT: two pseudowires over four Interconnect connections, with two
      connections in one metro and two connections in another metro. Each
      redundant pair of Interconnect connections spans both edge availability
      domains of the metro. Each pseudowire connects Interconnect connections
      in matching edge availability domains of the two metros. -
      BOX_AND_CROSS: four pseudowires over four Interconnect connections, with
      two connections in one metro and two connections in another metro. Each
      redundant pair of Interconnect connections spans both edge availability
      domains of the metro. Two pseudowires connect Interconnect connections
      in matching edge availability domains of the two metros. Two additional
      pseudowires connect the non-matching edge availability domains of the
      two metros.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of the wire group, one of the following: - WIRE: a single
    pseudowire over two Interconnect connections with no redundancy. -
    REDUNDANT: two pseudowires over four Interconnect connections, with two
    connections in one metro and two connections in another metro. Each
    redundant pair of Interconnect connections spans both edge availability
    domains of the metro. Each pseudowire connects Interconnect connections in
    matching edge availability domains of the two metros. - BOX_AND_CROSS:
    four pseudowires over four Interconnect connections, with two connections
    in one metro and two connections in another metro. Each redundant pair of
    Interconnect connections spans both edge availability domains of the
    metro. Two pseudowires connect Interconnect connections in matching edge
    availability domains of the two metros. Two additional pseudowires connect
    the non-matching edge availability domains of the two metros.

    Values:
      BOX_AND_CROSS: Four pseudowires over four Interconnect connections, with
        two connections in one metro and two connections in another metro.
        Each redundant pair of Interconnect connections spans both edge
        availability domains of the metro. Two pseudowires connect
        Interconnect connections in matching edge availability domains of the
        two metros. Two additional pseudowires connect the non-matching edge
        availability domains of the two metros.
      REDUNDANT: Two pseudowires over four Interconnect connections, with two
        connections in one metro and two connections in another metro. Each
        redundant pair of Interconnect connections spans both edge
        availability domains of the metro. Each pseudowire connects
        Interconnect connections in matching edge availability domains of the
        two metros.
      WIRE: A single pseudowire over two Interconnect connections with no
        redundancy.
    """
    BOX_AND_CROSS = 0
    REDUNDANT = 1
    WIRE = 2

  type = _messages.EnumField('TypeValueValuesEnum', 1)


class WireGroupServiceLevel(_messages.Message):
  r"""Service level details determined for the wire group configuration.

  Enums:
    AvailabilityClassValueValuesEnum: [Output Only] The availability SLA that
      the wire group qualifies for. One of the following:
      `NO_AVAILABILITY_SLA`, `AVAILABILITY_99`, `AVAILABILITY_999`, or
      `AVAILABILITY_9995`.

  Fields:
    availabilityClass: [Output Only] The availability SLA that the wire group
      qualifies for. One of the following: `NO_AVAILABILITY_SLA`,
      `AVAILABILITY_99`, `AVAILABILITY_999`, or `AVAILABILITY_9995`.
  """

  class AvailabilityClassValueValuesEnum(_messages.Enum):
    r"""[Output Only] The availability SLA that the wire group qualifies for.
    One of the following: `NO_AVAILABILITY_SLA`, `AVAILABILITY_99`,
    `AVAILABILITY_999`, or `AVAILABILITY_9995`.

    Values:
      AVAILABILITY_99: 99% availability
      AVAILABILITY_999: 99.9% availability
      AVAILABILITY_9995: 99.95% availability
      NO_AVAILABILITY_SLA: No SLA
    """
    AVAILABILITY_99 = 0
    AVAILABILITY_999 = 1
    AVAILABILITY_9995 = 2
    NO_AVAILABILITY_SLA = 3

  availabilityClass = _messages.EnumField('AvailabilityClassValueValuesEnum', 1)


class WireGroupTopology(_messages.Message):
  r"""Topology details for the wire group.

  Fields:
    endpoints: Topology details for all endpoints in the wire group.
  """

  endpoints = _messages.MessageField('WireGroupTopologyEndpoint', 1, repeated=True)


class WireGroupTopologyEndpoint(_messages.Message):
  r"""Topology details for a single wire group endpoint.

  Fields:
    city: The InterconnectLocation.city (metropolitan area designator) that
      all interconnects are located in.
    label: Endpoint label from the wire group.
  """

  city = _messages.StringField(1)
  label = _messages.StringField(2)


class WireGroupWireInputs(_messages.Message):
  r"""Optional settings for individual wires. Allows wire-level control that
  can be useful for migration purposes. If you use this field, you opt-out of
  the SLA for the wire group.

  Fields:
    adminEnabled: Indicates whether the wire is enabled. When false, the wire
      is disabled. When true and when the wire group of the wire is also
      enabled, the wire is enabled. Defaults to true.
    wirePropertyOverrides: The overridden properties for the wire. Any
      properties that are not overridden are omitted from the object. Review
      the following guidelines: - If you apply wire overrides to a wire and
      its wire group bandwidth configuration is set to
      `SHARED_WITH_WIRE_GROUP`, the `meteredBandwidth` and
      `unmeteredBandwidth` properties must not differ from the wire group. -
      Overrides generate a `configurationNotice`. Ensure that differences in
      wire configuration are temporary. An example use case for wire overrides
      is slowly rolling out configuration changes to individual wires in a
      wire group.
  """

  adminEnabled = _messages.BooleanField(1)
  wirePropertyOverrides = _messages.MessageField('WireProperties', 2)


class WireProperties(_messages.Message):
  r"""The properties of a wire.

  Enums:
    BandwidthAllocationValueValuesEnum: The configuration of the bandwidth
      allocation, one of the following: - ALLOCATE_PER_WIRE: configures a
      separate unmetered bandwidth allocation (and associated charges) for
      each wire in the group. - SHARED_WITH_WIRE_GROUP: configures one
      unmetered bandwidth allocation for the wire group. The unmetered
      bandwidth is divided equally across each wire in the group, but dynamic
      throttling reallocates unused unmetered bandwidth from unused or
      underused wires to other wires in the group. For example, with a four-
      wire box-and-cross group, when one Interconnect connection is down, the
      unmetered bandwidth of the two down wires is reallocated to the
      remaining up wires.
    FaultResponseValueValuesEnum: Response when a fault is detected in a
      pseudowire: - NONE: default. - DISABLE_PORT: set the port line protocol
      down when inline probes detect a fault. This setting is only permitted
      on port mode pseudowires.
    NetworkServiceClassValueValuesEnum: The network service class.

  Fields:
    bandwidthAllocation: The configuration of the bandwidth allocation, one of
      the following: - ALLOCATE_PER_WIRE: configures a separate unmetered
      bandwidth allocation (and associated charges) for each wire in the
      group. - SHARED_WITH_WIRE_GROUP: configures one unmetered bandwidth
      allocation for the wire group. The unmetered bandwidth is divided
      equally across each wire in the group, but dynamic throttling
      reallocates unused unmetered bandwidth from unused or underused wires to
      other wires in the group. For example, with a four-wire box-and-cross
      group, when one Interconnect connection is down, the unmetered bandwidth
      of the two down wires is reallocated to the remaining up wires.
    bandwidthMetered: The metered bandwidth in Gigabits per second, using
      decimal units. `10` is 10 Gbps, `100` is 100 Gbps. The default value is
      `0`. You can specify unlimited bandwidth by entering `-1`. However,
      actual data transfer is limited by the port speed.
    bandwidthUnmetered: The unmetered bandwidth in Gigabits per second, using
      decimal units. `10` is 10 Gbps, `100` is 100 Gbps.
    faultResponse: Response when a fault is detected in a pseudowire: - NONE:
      default. - DISABLE_PORT: set the port line protocol down when inline
      probes detect a fault. This setting is only permitted on port mode
      pseudowires.
    networkServiceClass: The network service class.
  """

  class BandwidthAllocationValueValuesEnum(_messages.Enum):
    r"""The configuration of the bandwidth allocation, one of the following: -
    ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation
    (and associated charges) for each wire in the group. -
    SHARED_WITH_WIRE_GROUP: configures one unmetered bandwidth allocation for
    the wire group. The unmetered bandwidth is divided equally across each
    wire in the group, but dynamic throttling reallocates unused unmetered
    bandwidth from unused or underused wires to other wires in the group. For
    example, with a four-wire box-and-cross group, when one Interconnect
    connection is down, the unmetered bandwidth of the two down wires is
    reallocated to the remaining up wires.

    Values:
      ALLOCATE_PER_WIRE: Configures a separate unmetered bandwidth allocation
        (and associated charges) for each wire in the group.
      SHARED_WITH_WIRE_GROUP: Configures one unmetered bandwidth allocation
        for the wire group. The unmetered bandwidth is divided equally across
        each wire in the group, but dynamic throttling reallocates unused
        unmetered bandwidth from unused or underused wires to other wires in
        the group. For example, with a four-wire box-and-cross group, when one
        Interconnect connection is down, the unmetered bandwidth of the two
        down wires is reallocated to the remaining up wires.
    """
    ALLOCATE_PER_WIRE = 0
    SHARED_WITH_WIRE_GROUP = 1

  class FaultResponseValueValuesEnum(_messages.Enum):
    r"""Response when a fault is detected in a pseudowire: - NONE: default. -
    DISABLE_PORT: set the port line protocol down when inline probes detect a
    fault. This setting is only permitted on port mode pseudowires.

    Values:
      DISABLE_PORT: Set the port line protocol down when inline probes detect
        a fault. This setting is only permitted on port mode pseudowires.
      NONE: Default.
    """
    DISABLE_PORT = 0
    NONE = 1

  class NetworkServiceClassValueValuesEnum(_messages.Enum):
    r"""The network service class.

    Values:
      BRONZE: The lowest service class.
      GOLD: The highest service class.
    """
    BRONZE = 0
    GOLD = 1

  bandwidthAllocation = _messages.EnumField('BandwidthAllocationValueValuesEnum', 1)
  bandwidthMetered = _messages.IntegerField(2)
  bandwidthUnmetered = _messages.IntegerField(3)
  faultResponse = _messages.EnumField('FaultResponseValueValuesEnum', 4)
  networkServiceClass = _messages.EnumField('NetworkServiceClassValueValuesEnum', 5)


class XpnHostList(_messages.Message):
  r"""A XpnHostList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: [Output Only] A list of shared VPC host project URLs.
    kind: [Output Only] Type of resource. Always compute#xpnHostList for lists
      of shared VPC hosts.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Project', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#xpnHostList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class XpnResourceId(_messages.Message):
  r"""Service resource (a.k.a service project) ID.

  Enums:
    TypeValueValuesEnum: The type of the service resource.

  Fields:
    id: The ID of the service resource. In the case of projects, this field
      supports project id (e.g., my-project-123) and project number (e.g.
      12345678).
    type: The type of the service resource.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of the service resource.

    Values:
      PROJECT: <no description>
      XPN_RESOURCE_TYPE_UNSPECIFIED: <no description>
    """
    PROJECT = 0
    XPN_RESOURCE_TYPE_UNSPECIFIED = 1

  id = _messages.StringField(1)
  type = _messages.EnumField('TypeValueValuesEnum', 2)


class Zone(_messages.Message):
  r"""Represents a Zone resource. A zone is a deployment area. These
  deployment areas are subsets of a region. For example the zone us-east1-b is
  located in the us-east1 region. For more information, read Regions and
  Zones.

  Enums:
    StatusValueValuesEnum: [Output Only] Status of the zone, either UP or
      DOWN.

  Fields:
    availableCpuPlatforms: [Output Only] Available cpu/platform selections for
      the zone.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      zone.
    description: [Output Only] Textual description of the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#zone for zones.
    name: [Output Only] Name of the resource.
    region: [Output Only] Full URL reference to the region which hosts the
      zone.
    selfLink: [Output Only] Server-defined URL for the resource.
    status: [Output Only] Status of the zone, either UP or DOWN.
    supportsPzs: [Output Only] Reserved for future use.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] Status of the zone, either UP or DOWN.

    Values:
      DOWN: <no description>
      UP: <no description>
    """
    DOWN = 0
    UP = 1

  availableCpuPlatforms = _messages.StringField(1, repeated=True)
  creationTimestamp = _messages.StringField(2)
  deprecated = _messages.MessageField('DeprecationStatus', 3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default='compute#zone')
  name = _messages.StringField(7)
  region = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  status = _messages.EnumField('StatusValueValuesEnum', 10)
  supportsPzs = _messages.BooleanField(11)


class ZoneList(_messages.Message):
  r"""Contains a list of zone resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Zone resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: Warning about failed cleanup of transient changes made
          by a failed operation.
        DEPRECATED_RESOURCE_USED: A link to a deprecated resource was created.
        DEPRECATED_TYPE_USED: When deploying and at least one of the resources
          has a type marked as deprecated
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: The user created a boot disk that is
          larger than image size.
        EXPERIMENTAL_TYPE_USED: When deploying and at least one of the
          resources has a type marked as experimental
        EXTERNAL_API_WARNING: Warning that is present in an external api call
        FIELD_VALUE_OVERRIDEN: Warning that value of a field has been
          overridden. Deprecated unused field.
        INJECTED_KERNELS_DEPRECATED: The operation involved use of an injected
          kernel, which is deprecated.
        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB: A WEIGHTED_MAGLEV
          backend service is associated with a health check that is not of
          type HTTP/HTTPS/HTTP2.
        LARGE_DEPLOYMENT_WARNING: When deploying a deployment with a
          exceedingly large number of resources
        LIST_OVERHEAD_QUOTA_EXCEED: Resource can't be retrieved due to list
          overhead quota exceed which captures the amount of resources
          filtered out by user-defined list filter.
        MISSING_TYPE_DEPENDENCY: A resource depends on a missing type
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: The route's nextHopIp address is not
          assigned to an instance on the network.
        NEXT_HOP_CANNOT_IP_FORWARD: The route's next hop instance cannot ip
          forward.
        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE: The route's nextHopInstance
          URL refers to an instance that does not have an ipv6 interface on
          the same network as the route.
        NEXT_HOP_INSTANCE_NOT_FOUND: The route's nextHopInstance URL refers to
          an instance that does not exist.
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: The route's nextHopInstance URL
          refers to an instance that is not on the same network as the route.
        NEXT_HOP_NOT_RUNNING: The route's next hop instance does not have a
          status of RUNNING.
        NOT_CRITICAL_ERROR: Error which is not critical. We decided to
          continue the process despite the mentioned error.
        NO_RESULTS_ON_PAGE: No results are present on a particular list page.
        PARTIAL_SUCCESS: Success is reported, but some results may be missing
          due to errors
        QUOTA_INFO_UNAVAILABLE: Quota information is not available to client
          requests (e.g: regions.list).
        REQUIRED_TOS_AGREEMENT: The user attempted to use a resource that
          requires a TOS they have not accepted.
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: Warning that a resource is
          in use.
        RESOURCE_NOT_DELETED: One or more of the resources set to auto-delete
          could not be deleted because they were in use.
        SCHEMA_VALIDATION_IGNORED: When a resource schema validation is
          ignored.
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: Instance template used in instance
          group manager is valid as such, but its application does not make a
          lot of sense, because it allows only single instance in instance
          group.
        UNDECLARED_PROPERTIES: When undeclared properties in the schema are
          present
        UNREACHABLE: A given scope cannot be reached.
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 8
      LARGE_DEPLOYMENT_WARNING = 9
      LIST_OVERHEAD_QUOTA_EXCEED = 10
      MISSING_TYPE_DEPENDENCY = 11
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 12
      NEXT_HOP_CANNOT_IP_FORWARD = 13
      NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 14
      NEXT_HOP_INSTANCE_NOT_FOUND = 15
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 16
      NEXT_HOP_NOT_RUNNING = 17
      NOT_CRITICAL_ERROR = 18
      NO_RESULTS_ON_PAGE = 19
      PARTIAL_SUCCESS = 20
      QUOTA_INFO_UNAVAILABLE = 21
      REQUIRED_TOS_AGREEMENT = 22
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 23
      RESOURCE_NOT_DELETED = 24
      SCHEMA_VALIDATION_IGNORED = 25
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 26
      UNDECLARED_PROPERTIES = 27
      UNREACHABLE = 28

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Zone', 2, repeated=True)
  kind = _messages.StringField(3, default='compute#zoneList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ZoneSetLabelsRequest(_messages.Message):
  r"""A ZoneSetLabelsRequest object.

  Messages:
    LabelsValue: The labels to set for this resource.

  Fields:
    labelFingerprint: The fingerprint of the previous set of labels for this
      resource, used to detect conflicts. The fingerprint is initially
      generated by Compute Engine and changes after every request to modify or
      update labels. You must always provide an up-to-date fingerprint hash in
      order to update or change labels. Make a get() request to the resource
      to get the latest fingerprint.
    labels: The labels to set for this resource.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""The labels to set for this resource.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class ZoneSetPolicyRequest(_messages.Message):
  r"""A ZoneSetPolicyRequest object.

  Fields:
    bindings: Flatten Policy to create a backwacd compatible wire-format.
      Deprecated. Use 'policy' to specify bindings.
    etag: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify the etag.
    policy: REQUIRED: The complete policy to be applied to the 'resource'. The
      size of the policy is limited to a few 10s of KB. An empty policy is in
      general a valid policy but certain services (like Projects) might reject
      them.
  """

  bindings = _messages.MessageField('Binding', 1, repeated=True)
  etag = _messages.BytesField(2)
  policy = _messages.MessageField('Policy', 3)


encoding.AddCustomJsonFieldMapping(
    StandardQueryParameters, 'f__xgafv', '$.xgafv')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_1', '1')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_2', '2')
